/*
**	This file is automatically generated.  Do not edit it by hand.
**/
/*  Define mapping of sym_k_..._object codes to widget names.  */

externaldef(uil_sym_glbl) int uil_max_object = 88;
static char *uil_widget_names_vec[] = {
    "",	/* NOT USED */
    "DtEditor",
    "DtHelpDialog",
    "DtHelpQuickDialog",
    "DtMenuButton",
    "DtPrintSetupBox",
    "DtPrintSetupDialog",
    "DtTerm",
    "DtTermPrimitive",
    "XmArrowButton",
    "XmArrowButtonGadget",
    "XmBulletinBoard",
    "XmBulletinBoardDialog",
    "XmButtonBox",
    "XmCascadeButton",
    "XmCascadeButtonGadget",
    "XmCheckBox",
    "XmColorSelector",
    "XmColumn",
    "XmComboBox",
    "XmCommand",
    "XmCommandDialog",
    "XmContainer",
    "XmDataField",
    "XmDialogShell",
    "XmDrawingArea",
    "XmDrawnButton",
    "XmDropDown",
    "XmErrorDialog",
    "XmFileSelectionBox",
    "XmFileSelectionDialog",
    "XmFontSelector",
    "XmForm",
    "XmFormDialog",
    "XmFrame",
    "XmIconBox",
    "XmIconButton",
    "XmIconGadget",
    "XmInformationDialog",
    "XmLabel",
    "XmLabelGadget",
    "XmList",
    "XmMainWindow",
    "XmMenuBar",
    "XmMenuShell",
    "XmMessageBox",
    "XmMessageDialog",
    "XmMultiList",
    "XmNotebook",
    "XmOptionMenu",
    "XmOutline",
    "XmPaned",
    "XmPanedWindow",
    "XmPopupMenu",
    "XmPromptDialog",
    "XmPulldownMenu",
    "XmPushButton",
    "XmPushButtonGadget",
    "XmQuestionDialog",
    "XmRadioBox",
    "XmRenderTable",
    "XmRendition",
    "XmRowColumn",
    "XmScale",
    "XmScrollBar",
    "XmScrolledList",
    "XmScrolledText",
    "XmScrolledWindow",
    "XmSelectionBox",
    "XmSelectionDialog",
    "XmSeparator",
    "XmSeparatorGadget",
    "XmSimpleSpinBox",
    "XmSpinBox",
    "XmTab",
    "XmTabBox",
    "XmTabList",
    "XmTabStack",
    "XmTearOffButton",
    "XmTemplateDialog",
    "XmText",
    "XmTextField",
    "XmToggleButton",
    "XmToggleButtonGadget",
    "XmTree",
    "XmWarningDialog",
    "XmWorkArea",
    "XmWorkingDialog",
    "user_defined",
};
externaldef(uil_sym_glbl) char **uil_widget_names =
		uil_widget_names_vec;


/*  Define mapping of sym_k_..._arg codes to argument names.  */

externaldef(uil_sym_glbl) int uil_max_arg = 714;
static char *uil_argument_names_vec[] = {
    "",	/* NOT USED */
    "DtNallowSendEvents",
    "DtNappCursorDefault",
    "DtNappKeypadDefault",
    "DtNautoShowCursorPosition",
    "DtNautoWrap",
    "DtNbackLabelString",
    "DtNbackgroundIsSelect",
    "DtNbaseHeight",
    "DtNbaseWidth",
    "DtNblinkRate",
    "DtNbuttonFontList",
    "DtNc132",
    "DtNcascadePixmap",
    "DtNcenterToggleLabel",
    "DtNchangeAllButtonLabel",
    "DtNchangeButtonLabel",
    "DtNchangeFieldLabel",
    "DtNcharCursorStyle",
    "DtNcloseLabelString",
    "DtNcolumns",
    "DtNconsoleMode",
    "DtNcopies",
    "DtNcsWidth",
    "DtNcurrentLineLabel",
    "DtNcursorPosition",
    "DtNcursorPositionVisible",
    "DtNdescription",
    "DtNdialogTitle",
    "DtNeditable",
    "DtNemulationId",
    "DtNexecutionPolicy",
    "DtNfileName",
    "DtNfindButtonLabel",
    "DtNfindChangeDialogTitle",
    "DtNfindFieldLabel",
    "DtNformatAllButtonLabel",
    "DtNformatParagraphButtonLabel",
    "DtNformatSettingsDialogTitle",
    "DtNheightInc",
    "DtNhelpFile",
    "DtNhelpLabelString",
    "DtNhelpOnHelpVolume",
    "DtNhelpPrint",
    "DtNhelpType",
    "DtNhelpVolume",
    "DtNinformationDialogTitle",
    "DtNinsertLabel",
    "DtNjumpScroll",
    "DtNjustifyToggleLabel",
    "DtNkshMode",
    "DtNlabelFontList",
    "DtNleftAlignToggleLabel",
    "DtNleftMarginFieldLabel",
    "DtNlocationId",
    "DtNlogFile",
    "DtNlogInhibit",
    "DtNlogging",
    "DtNmanPage",
    "DtNmapOnOutput",
    "DtNmapOnOutputDelay",
    "DtNmarginBell",
    "DtNmarginHeight",
    "DtNmarginWidth",
    "DtNmaxLength",
    "DtNminimizeButtons",
    "DtNmisspelledListLabel",
    "DtNmoreLabelString",
    "DtNnMarginBell",
    "DtNoverstrike",
    "DtNoverstrikeLabel",
    "DtNpaperSize",
    "DtNpointerBlank",
    "DtNpointerBlankDelay",
    "DtNpointerColor",
    "DtNpointerColorBackground",
    "DtNpointerShape",
    "DtNprintDestination",
    "DtNprintLabelString",
    "DtNprintSetupMode",
    "DtNprinter",
    "DtNprinterInfoProc",
    "DtNprinterName",
    "DtNreverseVideo",
    "DtNreverseWrap",
    "DtNrightAlignToggleLabel",
    "DtNrightMarginFieldLabel",
    "DtNrows",
    "DtNsaveLines",
    "DtNscrollBarPolicy",
    "DtNscrollHorizontal",
    "DtNscrollLeftSide",
    "DtNscrollTopSide",
    "DtNscrollVertical",
    "DtNselectFileProc",
    "DtNselectPrinterProc",
    "DtNshadowType",
    "DtNshowNewWindowButton",
    "DtNshowStatusLine",
    "DtNspellDialogTitle",
    "DtNspellFilter",
    "DtNstickyNextCursor",
    "DtNstickyPrevCursor",
    "DtNstringData",
    "DtNsubMenuId",
    "DtNsubprocessArgv",
    "DtNsubprocessCmd",
    "DtNsubprocessExec",
    "DtNsubprocessLoginShell",
    "DtNsubprocessPid",
    "DtNsubprocessTerminationCatch",
    "DtNsunFunctionKeys",
    "DtNtermDevice",
    "DtNtermDeviceAllocate",
    "DtNtermId",
    "DtNtermName",
    "DtNtermSlaveName",
    "DtNtextBackground",
    "DtNtextFontList",
    "DtNtextForeground",
    "DtNtextTranslations",
    "DtNtopCharacter",
    "DtNtopicTitle",
    "DtNtotalLineCountLabel",
    "DtNttyModes",
    "DtNuserBoldFont",
    "DtNuserFont",
    "DtNverifyPrinterProc",
    "DtNverticalScrollBar",
    "DtNvisiblePathCount",
    "DtNvisualBell",
    "DtNwidthInc",
    "DtNwordWrap",
    "DtNworkAreaLocation",
    "XmN100DPIstring",
    "XmN75DPIstring",
    "XmNaccelerator",
    "XmNacceleratorText",
    "XmNaccelerators",
    "XmNadjustLast",
    "XmNadjustMargin",
    "XmNalignment",
    "XmNallowOverlap",
    "XmNallowResize",
    "XmNallowShellResize",
    "XmNallowUnusedSpace",
    "XmNancestorSensitive",
    "XmNanyLowerString",
    "XmNanyString",
    "XmNapplyLabelString",
    "XmNarmColor",
    "XmNarmPixmap",
    "XmNarrowDirection",
    "XmNarrowLayout",
    "XmNarrowOrientation",
    "XmNarrowSensitivity",
    "XmNarrowSize",
    "XmNarrowSpacing",
    "XmNaudibleWarning",
    "XmNautoClose",
    "XmNautoDragModel",
    "XmNautoFill",
    "XmNautoShowCursorPosition",
    "XmNautoUnmanage",
    "XmNautomaticSelection",
    "XmNbackPageBackground",
    "XmNbackPageForeground",
    "XmNbackPageNumber",
    "XmNbackPagePlacement",
    "XmNbackPageSize",
    "XmNbackground",
    "XmNbackgroundPixmap",
    "XmNbaseHeight",
    "XmNbaseWidth",
    "XmNbindingPixmap",
    "XmNbindingType",
    "XmNbindingWidth",
    "XmNblinkRate",
    "XmNblueSliderLabel",
    "XmNboldString",
    "XmNborderColor",
    "XmNborderPixmap",
    "XmNborderWidth",
    "XmNbothString",
    "XmNbottomAttachment",
    "XmNbottomOffset",
    "XmNbottomPosition",
    "XmNbottomShadowColor",
    "XmNbottomShadowPixmap",
    "XmNbottomWidget",
    "XmNbuttonCount",
    "XmNbuttonFontList",
    "XmNbuttonRenderTable",
    "XmNbuttons",
    "XmNcancelButton",
    "XmNcancelLabelString",
    "XmNcascadePixmap",
    "XmNcellX",
    "XmNcellY",
    "XmNchildHorizontalAlignment",
    "XmNchildHorizontalSpacing",
    "XmNchildPlacement",
    "XmNchildType",
    "XmNchildVerticalAlignment",
    "XmNclipWindow",
    "XmNcloseFolderPixmap",
    "XmNcollapsedStatePixmap",
    "XmNcolorListTogLabel",
    "XmNcolorMode",
    "XmNcolorName",
    "XmNcolormap",
    "XmNcolumnTitles",
    "XmNcolumns",
    "XmNcomboBoxType",
    "XmNcomboTranslations",
    "XmNcommand",
    "XmNcommandWindow",
    "XmNcommandWindowLocation",
    "XmNcompressStyle",
    "XmNconnectNodes",
    "XmNconnectStyle",
    "XmNconstrainWidth",
    "XmNcreatePopupChildProc",
    "XmNcurrentFont",
    "XmNcurrentPageNumber",
    "XmNcursor",
    "XmNcursorPosition",
    "XmNcursorPositionVisible",
    "XmNcustomizedCombinationBox",
    "XmNdarkThreshold",
    "XmNdecimal",
    "XmNdecimalPoints",
    "XmNdefaultArrowSensitivity",
    "XmNdefaultButton",
    "XmNdefaultButtonShadowThickness",
    "XmNdefaultButtonType",
    "XmNdefaultEncodingString",
    "XmNdefaultEntryLabelAlignment",
    "XmNdefaultEntryLabelFontList",
    "XmNdefaultEntryLabelRenderTable",
    "XmNdefaultFillStyle",
    "XmNdefaultFontList",
    "XmNdefaultPosition",
    "XmNdeleteResponse",
    "XmNdepth",
    "XmNdetail",
    "XmNdetailColumnHeading",
    "XmNdetailColumnHeadingCount",
    "XmNdetailCount",
    "XmNdetailOrder",
    "XmNdetailOrderCount",
    "XmNdetailShadowThickness",
    "XmNdetailTabList",
    "XmNdialogStyle",
    "XmNdialogTitle",
    "XmNdialogType",
    "XmNdirListItemCount",
    "XmNdirListItems",
    "XmNdirListLabelString",
    "XmNdirMask",
    "XmNdirSearchProc",
    "XmNdirSpec",
    "XmNdirectory",
    "XmNdirectoryValid",
    "XmNdistribution",
    "XmNdoubleClickInterval",
    "XmNeditMode",
    "XmNeditable",
    "XmNencodingList",
    "XmNencodingString",
    "XmNentryAlignment",
    "XmNentryBackground",
    "XmNentryBorder",
    "XmNentryClass",
    "XmNentryData",
    "XmNentryLabelAlignment",
    "XmNentryLabelFontList",
    "XmNentryLabelPixmap",
    "XmNentryLabelRenderTable",
    "XmNentryLabelString",
    "XmNentryLabelType",
    "XmNentryParent",
    "XmNentryVerticalAlignment",
    "XmNentryViewType",
    "XmNequalSize",
    "XmNexpandedStatePixmap",
    "XmNfamilyString",
    "XmNfileListItemCount",
    "XmNfileListItems",
    "XmNfileListLabelString",
    "XmNfileReadError",
    "XmNfileSearchProc",
    "XmNfileTypeMask",
    "XmNfillOnArm",
    "XmNfillOnSelect",
    "XmNfillOption",
    "XmNfillStyle",
    "XmNfilterLabelString",
    "XmNfindLabel",
    "XmNfirstColumn",
    "XmNfirstColumnPixmaps",
    "XmNfirstPageNumber",
    "XmNfirstRow",
    "XmNfont",
    "XmNfontEncoding",
    "XmNfontFoundry",
    "XmNfontList",
    "XmNfontName",
    "XmNfontSize",
    "XmNfontStyle",
    "XmNfontType",
    "XmNforeground",
    "XmNforegroundThreshold",
    "XmNfractionBase",
    "XmNframeBackground",
    "XmNframeChildType",
    "XmNframeShadowThickness",
    "XmNfreeTabPixmap",
    "XmNgeometry",
    "XmNgreenSliderLabel",
    "XmNheight",
    "XmNheightInc",
    "XmNhelpLabelString",
    "XmNhighlightColor",
    "XmNhighlightOnEnter",
    "XmNhighlightPixmap",
    "XmNhighlightThickness",
    "XmNhistoryItemCount",
    "XmNhistoryItems",
    "XmNhistoryMaxItems",
    "XmNhistoryVisibleItemCount",
    "XmNhorizontalDelta",
    "XmNhorizontalMargin",
    "XmNhorizontalNodeSpace",
    "XmNhorizontalScrollBar",
    "XmNhorizontalSpacing",
    "XmNiconMask",
    "XmNiconName",
    "XmNiconNameEncoding",
    "XmNiconPixmap",
    "XmNiconPlacement",
    "XmNiconTextPadding",
    "XmNiconWindow",
    "XmNiconX",
    "XmNiconY",
    "XmNiconic",
    "XmNincrement",
    "XmNincrementValue",
    "XmNindentSpace",
    "XmNindeterminateInsensitivePixmap",
    "XmNindeterminatePixmap",
    "XmNindicatorOn",
    "XmNindicatorSize",
    "XmNindicatorType",
    "XmNinitialDelay",
    "XmNinitialFocus",
    "XmNinitialResourcesPersistent",
    "XmNinitialState",
    "XmNinnerMarginHeight",
    "XmNinnerMarginWidth",
    "XmNinput",
    "XmNinputMethod",
    "XmNinputPolicy",
    "XmNinsertBefore",
    "XmNinsertPosition",
    "XmNisAligned",
    "XmNisHomogeneous",
    "XmNitalicString",
    "XmNitemCount",
    "XmNitemSpacing",
    "XmNitems",
    "XmNkeyboardFocusPolicy",
    "XmNlabel",
    "XmNlabelFontList",
    "XmNlabelInsensitivePixmap",
    "XmNlabelPixmap",
    "XmNlabelRenderTable",
    "XmNlabelSpacing",
    "XmNlabelString",
    "XmNlabelType",
    "XmNlargeCellHeight",
    "XmNlargeCellWidth",
    "XmNlargeIconMask",
    "XmNlargeIconPixmap",
    "XmNlargeIconX",
    "XmNlargeIconY",
    "XmNlastPageNumber",
    "XmNlayoutDirection",
    "XmNlayoutType",
    "XmNleftAttachment",
    "XmNleftOffset",
    "XmNleftPosition",
    "XmNleftWidget",
    "XmNlightThreshold",
    "XmNlineBackgroundColor",
    "XmNlineColor",
    "XmNlineStyle",
    "XmNlineWidth",
    "XmNlist",
    "XmNlistItemCount",
    "XmNlistItems",
    "XmNlistLabelString",
    "XmNlistMarginHeight",
    "XmNlistMarginWidth",
    "XmNlistSizePolicy",
    "XmNlistSpacing",
    "XmNlistUpdated",
    "XmNlistVisibleItemCount",
    "XmNloadModel",
    "XmNmainWindowMarginHeight",
    "XmNmainWindowMarginWidth",
    "XmNmajorTabSpacing",
    "XmNmappedWhenManaged",
    "XmNmappingDelay",
    "XmNmargin",
    "XmNmarginBottom",
    "XmNmarginHeight",
    "XmNmarginLeft",
    "XmNmarginRight",
    "XmNmarginTop",
    "XmNmarginWidth",
    "XmNmatchBehavior",
    "XmNmaxAspectX",
    "XmNmaxAspectY",
    "XmNmaxHeight",
    "XmNmaxLength",
    "XmNmaxWidth",
    "XmNmaximum",
    "XmNmaximumValue",
    "XmNmenuAccelerator",
    "XmNmenuBar",
    "XmNmenuHelpWidget",
    "XmNmenuHistory",
    "XmNmenuPost",
    "XmNmessageAlignment",
    "XmNmessageString",
    "XmNmessageWindow",
    "XmNminAspectX",
    "XmNminAspectY",
    "XmNminHeight",
    "XmNminWidth",
    "XmNminimizeButtons",
    "XmNminimum",
    "XmNminimumCellHeight",
    "XmNminimumCellWidth",
    "XmNminimumHorizontalCells",
    "XmNminimumValue",
    "XmNminimumVerticalCells",
    "XmNminorTabSpacing",
    "XmNmnemonic",
    "XmNmnemonicCharSet",
    "XmNmonoSpaceString",
    "XmNmultiClick",
    "XmNmustMatch",
    "XmNmwmDecorations",
    "XmNmwmFunctions",
    "XmNmwmInputMode",
    "XmNmwmMenu",
    "XmNnavigationType",
    "XmNnewVisualStyle",
    "XmNnoCellError",
    "XmNnoMatchString",
    "XmNnoResize",
    "XmNnodeCloseFolderPixmap",
    "XmNnodeOpenFolderPixmap",
    "XmNnodeState",
    "XmNnotebookChildType",
    "XmNnumColumns",
    "XmNnumRows",
    "XmNnumStacks",
    "XmNnumValues",
    "XmNoffsetModel",
    "XmNokLabelString",
    "XmNopenClosePadding",
    "XmNopenFolderPixmap",
    "XmNoptionString",
    "XmNorientation",
    "XmNotherString",
    "XmNoutlineButtonPolicy",
    "XmNoutlineColumnWidth",
    "XmNoutlineIndentation",
    "XmNoutlineLineStyle",
    "XmNoutlineState",
    "XmNoverrideRedirect",
    "XmNpacking",
    "XmNpageIncrement",
    "XmNpageNumber",
    "XmNpaneMaximum",
    "XmNpaneMinimum",
    "XmNparentNode",
    "XmNpattern",
    "XmNpendingDelete",
    "XmNpicture",
    "XmNpixmap",
    "XmNpixmapDepth",
    "XmNpixmapHeight",
    "XmNpixmapPlacement",
    "XmNpixmapTextPadding",
    "XmNpixmapWidth",
    "XmNpopupCursor",
    "XmNpopupEnabled",
    "XmNpopupOffset",
    "XmNpopupShellWidget",
    "XmNposition",
    "XmNpositionIndex",
    "XmNpositionMode",
    "XmNpositionType",
    "XmNpreeditType",
    "XmNpreferredPaneSize",
    "XmNprimaryOwnership",
    "XmNprocessingDirection",
    "XmNpromptString",
    "XmNpropSpaceString",
    "XmNpushButtonEnabled",
    "XmNqualifySearchDataProc",
    "XmNradioAlwaysOne",
    "XmNradioBehavior",
    "XmNrecomputeSize",
    "XmNredSliderLabel",
    "XmNrefigureMode",
    "XmNrenderTable",
    "XmNrenditionBackground",
    "XmNrenditionForeground",
    "XmNrepeatDelay",
    "XmNresizable",
    "XmNresizeHeight",
    "XmNresizePolicy",
    "XmNresizeToPreferred",
    "XmNresizeWidth",
    "XmNrgbFile",
    "XmNrightAttachment",
    "XmNrightOffset",
    "XmNrightPosition",
    "XmNrightWidget",
    "XmNrowColumnType",
    "XmNrows",
    "XmNrubberPositioning",
    "XmNsampleText",
    "XmNsashHeight",
    "XmNsashIndent",
    "XmNsashShadowThickness",
    "XmNsashTranslations",
    "XmNsashWidth",
    "XmNsaveUnder",
    "XmNscaleHeight",
    "XmNscaleMultiple",
    "XmNscaleWidth",
    "XmNscalingString",
    "XmNscreen",
    "XmNscrollBarDisplayPolicy",
    "XmNscrollBarPlacement",
    "XmNscrollHorizontal",
    "XmNscrollLeftSide",
    "XmNscrollTopSide",
    "XmNscrollVertical",
    "XmNscrolledWindowChildType",
    "XmNscrolledWindowMarginHeight",
    "XmNscrolledWindowMarginWidth",
    "XmNscrollingPolicy",
    "XmNselectColor",
    "XmNselectInsensitivePixmap",
    "XmNselectPixmap",
    "XmNselectThreshold",
    "XmNselectedColumn",
    "XmNselectedItem",
    "XmNselectedItemCount",
    "XmNselectedItems",
    "XmNselectedPosition",
    "XmNselectedPositionCount",
    "XmNselectedPositions",
    "XmNselectionArray",
    "XmNselectionArrayCount",
    "XmNselectionLabelString",
    "XmNselectionMode",
    "XmNselectionPolicy",
    "XmNselectionTechnique",
    "XmNsensitive",
    "XmNseparatorOn",
    "XmNseparatorType",
    "XmNset",
    "XmNshadowThickness",
    "XmNshadowType",
    "XmNshellUnitType",
    "XmNshowArrows",
    "XmNshowAsDefault",
    "XmNshowEntryLabel",
    "XmNshowFind",
    "XmNshowFontName",
    "XmNshowLabel",
    "XmNshowNameString",
    "XmNshowSash",
    "XmNshowSeparator",
    "XmNshowValue",
    "XmNsizeString",
    "XmNskipAdjust",
    "XmNsliderMark",
    "XmNsliderSize",
    "XmNsliderTogLabel",
    "XmNsliderVisual",
    "XmNslidingMode",
    "XmNsmallCellHeight",
    "XmNsmallCellWidth",
    "XmNsmallIconMask",
    "XmNsmallIconPixmap",
    "XmNsmallIconX",
    "XmNsmallIconY",
    "XmNsnapBackMultiple",
    "XmNsortFunctions",
    "XmNsource",
    "XmNspacing",
    "XmNspatialIncludeModel",
    "XmNspatialResizeModel",
    "XmNspatialSnapModel",
    "XmNspatialStyle",
    "XmNspinBoxChildType",
    "XmNstackedEffect",
    "XmNstretchable",
    "XmNstrikethruType",
    "XmNstringDirection",
    "XmNsubMenuId",
    "XmNsymbolPixmap",
    "XmNtabAlignment",
    "XmNtabAutoSelect",
    "XmNtabBackground",
    "XmNtabBackgroundPixmap",
    "XmNtabCornerPercent",
    "XmNtabEdge",
    "XmNtabForeground",
    "XmNtabLabelPixmap",
    "XmNtabLabelSpacing",
    "XmNtabLabelString",
    "XmNtabList",
    "XmNtabMarginHeight",
    "XmNtabMarginWidth",
    "XmNtabMode",
    "XmNtabOffset",
    "XmNtabOrientation",
    "XmNtabPixmapPlacement",
    "XmNtabSelectColor",
    "XmNtabSelectPixmap",
    "XmNtabSide",
    "XmNtabStringDirection",
    "XmNtabStyle",
    "XmNtabValue",
    "XmNtearOffModel",
    "XmNtearOffTitle",
    "XmNtextAccelerators",
    "XmNtextColumns",
    "XmNtextField",
    "XmNtextFontList",
    "XmNtextRenderTable",
    "XmNtextRows",
    "XmNtextString",
    "XmNtextTranslations",
    "XmNtitle",
    "XmNtitleEncoding",
    "XmNtitleString",
    "XmNtoggleMode",
    "XmNtoolTipEnable",
    "XmNtoolTipPostDelay",
    "XmNtoolTipPostDuration",
    "XmNtoolTipString",
    "XmNtopAttachment",
    "XmNtopCharacter",
    "XmNtopItemPosition",
    "XmNtopOffset",
    "XmNtopPosition",
    "XmNtopShadowColor",
    "XmNtopShadowPixmap",
    "XmNtopWidget",
    "XmNtransient",
    "XmNtransientFor",
    "XmNtranslations",
    "XmNtraversalOn",
    "XmNtroughColor",
    "XmNunderlineType",
    "XmNuniformTabSize",
    "XmNunitType",
    "XmNunpostBehavior",
    "XmNunselectColor",
    "XmNuseAsyncGeometry",
    "XmNuseImageCache",
    "XmNuseScaling",
    "XmNuseTextField",
    "XmNuserData",
    "XmNvalue",
    "XmNvalueWcs",
    "XmNvalues",
    "XmNverify",
    "XmNverifyBell",
    "XmNverticalDelta",
    "XmNverticalMargin",
    "XmNverticalNodeSpace",
    "XmNverticalScrollBar",
    "XmNverticalSpacing",
    "XmNviewType",
    "XmNvisibleItemCount",
    "XmNvisibleWhenOff",
    "XmNvisual",
    "XmNvisualEmphasis",
    "XmNvisualPolicy",
    "XmNwaitForWm",
    "XmNwhichButton",
    "XmNwidth",
    "XmNwidthInc",
    "XmNwinGravity",
    "XmNwindowGroup",
    "XmNwmTimeout",
    "XmNwordWrap",
    "XmNworkWindow",
    "XmNwrap",
    "XmNx",
    "XmNxlfdString",
    "XmNy",
    "XmStringComponent",
};
externaldef(uil_sym_glbl) char **uil_argument_names =
		uil_argument_names_vec;


/*  Define mapping of sym_k_..._reason to reason names.  */

externaldef(uil_sym_glbl) int uil_max_reason = 81;
static char *uil_reason_names_vec[] = {
    "",	/* NOT USED */
    "DtNcancelCallback",
    "DtNcascadingCallback",
    "DtNcloseCallback",
    "DtNclosePrintDisplayCallback",
    "DtNhyperLinkCallback",
    "DtNinputVerifyCallback",
    "DtNoutputLogCallback",
    "DtNprintCallback",
    "DtNsetupCallback",
    "DtNstatusChangeCallback",
    "DtNsubprocessTerminationCallback",
    "DtNtextDeselectCallback",
    "DtNtextSelectCallback",
    "MrmNcreateCallback",
    "XmNactivateCallback",
    "XmNapplyCallback",
    "XmNarmCallback",
    "XmNbrowseSelectionCallback",
    "XmNcancelCallback",
    "XmNcascadingCallback",
    "XmNcommandChangedCallback",
    "XmNcommandEnteredCallback",
    "XmNconvertCallback",
    "XmNdecrementCallback",
    "XmNdefaultActionCallback",
    "XmNdestinationCallback",
    "XmNdestroyCallback",
    "XmNdisarmCallback",
    "XmNdoubleClickCallback",
    "XmNdragCallback",
    "XmNentryCallback",
    "XmNexposeCallback",
    "XmNextendedSelectionCallback",
    "XmNfocusCallback",
    "XmNfocusMovedCallback",
    "XmNgainPrimaryCallback",
    "XmNhelpCallback",
    "XmNincrementCallback",
    "XmNinputCallback",
    "XmNitemFoundCallback",
    "XmNitemNotFoundCallback",
    "XmNlosePrimaryCallback",
    "XmNlosingFocusCallback",
    "XmNmapCallback",
    "XmNmodifyVerifyCallback",
    "XmNmodifyVerifyCallbackWcs",
    "XmNmotionVerifyCallback",
    "XmNmultipleSelectionCallback",
    "XmNnoMatchCallback",
    "XmNnodeStateBegEndCallback",
    "XmNnodeStateCallback",
    "XmNnodeStateChangedCallback",
    "XmNokCallback",
    "XmNoutlineChangedCallback",
    "XmNpageChangedCallback",
    "XmNpageDecrementCallback",
    "XmNpageIncrementCallback",
    "XmNpictureErrorCallback",
    "XmNpopdownCallback",
    "XmNpopupCallback",
    "XmNpopupHandlerCallback",
    "XmNrealizeCallback",
    "XmNresizeCallback",
    "XmNselectCallback",
    "XmNselectionCallback",
    "XmNsimpleCallback",
    "XmNsingleSelectionCallback",
    "XmNtabSelectedCallback",
    "XmNtearOffMenuActivateCallback",
    "XmNtearOffMenuDeactivateCallback",
    "XmNtoBottomCallback",
    "XmNtoTopCallback",
    "XmNtraversalCallback",
    "XmNtraverseObscuredCallback",
    "XmNunmapCallback",
    "XmNunselectCallback",
    "XmNupdateShellCallback",
    "XmNupdateTextCallback",
    "XmNvalidateCallback",
    "XmNvalueChangedCallback",
    "XmNverifyTextCallback",
};
externaldef(uil_sym_glbl) char **uil_reason_names =
		uil_reason_names_vec;


/*  Define mapping of sym_k_..._enumval to enumeration value names.  */

externaldef(uil_sym_glbl) int uil_max_enumset = 116;
externaldef(uil_sym_glbl) int uil_max_enumval = 399;
static char *uil_enumval_names_vec[] = {
    "",	/* NOT USED */
    "Always",
    "DtHELP_AS_NEEDED_SCROLLBARS",
    "DtHELP_EXECUTE_ALL",
    "DtHELP_EXECUTE_NONE",
    "DtHELP_EXECUTE_QUERY_ALL",
    "DtHELP_EXECUTE_QUERY_UNALIASED",
    "DtHELP_NO_SCROLLBARS",
    "DtHELP_PAPERSIZE_A4",
    "DtHELP_PAPERSIZE_B5",
    "DtHELP_PAPERSIZE_EXECUTIVE",
    "DtHELP_PAPERSIZE_LEGAL",
    "DtHELP_PAPERSIZE_LETTER",
    "DtHELP_STATIC_SCROLLBARS",
    "DtHELP_TYPE_DYNAMIC_STRING",
    "DtHELP_TYPE_FILE",
    "DtHELP_TYPE_MAN_PAGE",
    "DtHELP_TYPE_STRING",
    "DtHELP_TYPE_TOPIC",
    "DtLONG_NAME",
    "DtMEDIUM_NAME",
    "DtPRINT_CLOSE_CONNECTION",
    "DtPRINT_NO_DESTINATION",
    "DtPRINT_RELEASE_CONNECTION",
    "DtPRINT_SETUP_PLAIN",
    "DtPRINT_SETUP_XP",
    "DtPRINT_TO_FILE",
    "DtPRINT_TO_PRINTER",
    "DtSHADOW_ETCHED_IN",
    "DtSHADOW_ETCHED_OUT",
    "DtSHADOW_IN",
    "DtSHADOW_OUT",
    "DtSHORT_NAME",
    "DtTERM_CHAR_CURSOR_BAR",
    "DtTERM_CHAR_CURSOR_BOX",
    "DtTERM_CHAR_CURSOR_INVISIBLE",
    "DtWORK_AREA_BOTTOM",
    "DtWORK_AREA_NONE",
    "DtWORK_AREA_TOP",
    "DtWORK_AREA_TOP_AND_BOTTOM",
    "FALSE",
    "IconicState",
    "LineDoubleDash",
    "LineOnOffDash",
    "LineSolid",
    "MWM_DECOR_ALL",
    "MWM_DECOR_BORDER",
    "MWM_DECOR_MAXIMIZE",
    "MWM_DECOR_MENU",
    "MWM_DECOR_MINIMIZE",
    "MWM_DECOR_RESIZEH",
    "MWM_DECOR_TITLE",
    "MWM_FUNC_ALL",
    "MWM_FUNC_CLOSE",
    "MWM_FUNC_MOVE",
    "MWM_FUNC_RESIZE",
    "MWM_INPUT_FULL_APPLICATION_MODAL",
    "MWM_INPUT_MODELESS",
    "MWM_INPUT_PRIMARY_APPLICATION_MODAL",
    "MWM_INPUT_SYSTEM_MODAL",
    "NormalState",
    "NotUseful",
    "TRUE",
    "WhenMapped",
    "Xm1000TH_INCHES",
    "Xm100TH_FONT_UNITS",
    "Xm100TH_MILLIMETERS",
    "Xm100TH_POINTS",
    "XmABSOLUTE",
    "XmADD_MODE",
    "XmALIGNMENT_BASELINE_BOTTOM",
    "XmALIGNMENT_BASELINE_TOP",
    "XmALIGNMENT_BEGINNING",
    "XmALIGNMENT_CENTER",
    "XmALIGNMENT_CONTENTS_BOTTOM",
    "XmALIGNMENT_CONTENTS_TOP",
    "XmALIGNMENT_END",
    "XmALIGNMENT_UNSPECIFIED",
    "XmALIGNMENT_WIDGET_BOTTOM",
    "XmALIGNMENT_WIDGET_TOP",
    "XmANY_ICON",
    "XmAPPEND",
    "XmAPPLICATION_DEFINED",
    "XmARROWS_BEGINNING",
    "XmARROWS_DECREMENT_SENSITIVE",
    "XmARROWS_DEFAULT_SENSITIVITY",
    "XmARROWS_END",
    "XmARROWS_FLAT_BEGINNING",
    "XmARROWS_FLAT_END",
    "XmARROWS_HORIZONTAL",
    "XmARROWS_INCREMENT_SENSITIVE",
    "XmARROWS_INSENSITIVE",
    "XmARROWS_SENSITIVE",
    "XmARROWS_SPLIT",
    "XmARROWS_VERTICAL",
    "XmARROW_DOWN",
    "XmARROW_LEFT",
    "XmARROW_RIGHT",
    "XmARROW_UP",
    "XmAS_IS",
    "XmAS_NEEDED",
    "XmATTACH_FORM",
    "XmATTACH_NONE",
    "XmATTACH_OPPOSITE_FORM",
    "XmATTACH_OPPOSITE_WIDGET",
    "XmATTACH_POSITION",
    "XmATTACH_SELF",
    "XmATTACH_WIDGET",
    "XmAUTOMATIC",
    "XmAUTO_DRAG_DISABLED",
    "XmAUTO_DRAG_ENABLED",
    "XmAUTO_SELECT",
    "XmAlwaysOpen",
    "XmBACKGROUND_COLOR",
    "XmBELL",
    "XmBOTTOM_LEFT",
    "XmBOTTOM_RIGHT",
    "XmBOTTOM_TO_TOP",
    "XmBOTTOM_TO_TOP_LEFT_TO_RIGHT",
    "XmBOTTOM_TO_TOP_RIGHT_TO_LEFT",
    "XmBROWSE_SELECT",
    "XmCELLS",
    "XmCENTER",
    "XmCENTIMETERS",
    "XmCLIP_WINDOW",
    "XmCLOSEST",
    "XmCOLLAPSED",
    "XmCOMBO_BOX",
    "XmCOMMAND_ABOVE_WORKSPACE",
    "XmCOMMAND_BELOW_WORKSPACE",
    "XmCOMMAND_WINDOW",
    "XmCONSTANT",
    "XmClosed",
    "XmDEFAULT_DIRECTION",
    "XmDESTROY",
    "XmDETAIL",
    "XmDIALOG_APPLICATION_MODAL",
    "XmDIALOG_CANCEL_BUTTON",
    "XmDIALOG_COMMAND",
    "XmDIALOG_DEFAULT_BUTTON",
    "XmDIALOG_ERROR",
    "XmDIALOG_FILE_SELECTION",
    "XmDIALOG_FULL_APPLICATION_MODAL",
    "XmDIALOG_HELP_BUTTON",
    "XmDIALOG_INFORMATION",
    "XmDIALOG_MESSAGE",
    "XmDIALOG_MESSAGE_LABEL",
    "XmDIALOG_MODELESS",
    "XmDIALOG_OK_BUTTON",
    "XmDIALOG_PRIMARY_APPLICATION_MODAL",
    "XmDIALOG_PROMPT",
    "XmDIALOG_QUESTION",
    "XmDIALOG_SELECTION",
    "XmDIALOG_SEPARATOR",
    "XmDIALOG_SYMBOL_LABEL",
    "XmDIALOG_SYSTEM_MODAL",
    "XmDIALOG_TEMPLATE",
    "XmDIALOG_WARNING",
    "XmDIALOG_WORKING",
    "XmDIALOG_WORK_AREA",
    "XmDISTRIBUTE_SPREAD",
    "XmDISTRIBUTE_TIGHT",
    "XmDOUBLE_DASHED_LINE",
    "XmDOUBLE_LINE",
    "XmDO_NOTHING",
    "XmDROP_DOWN_COMBO_BOX",
    "XmDROP_DOWN_LIST",
    "XmEACH_SIDE",
    "XmETCHED_LINE",
    "XmEXCLUSIVE_TAB_GROUP",
    "XmEXPANDED",
    "XmEXPLICIT",
    "XmEXTENDED_SELECT",
    "XmFILE_ANY_TYPE",
    "XmFILE_DIRECTORY",
    "XmFILE_REGULAR",
    "XmFILL_FLUSH",
    "XmFILL_RAGGED",
    "XmFILL_UNSPECIFIED",
    "XmFIRST_FIT",
    "XmFIRST_POSITION",
    "XmFONT_IS_FONT",
    "XmFONT_IS_FONTSET",
    "XmFONT_IS_XFT",
    "XmFONT_UNITS",
    "XmFOREGROUND_COLOR",
    "XmFRAME_GENERIC_CHILD",
    "XmFRAME_TITLE_CHILD",
    "XmFRAME_WORKAREA_CHILD",
    "XmFillAll",
    "XmFillMajor",
    "XmFillMinor",
    "XmFillNone",
    "XmGENERIC_CHILD",
    "XmGRID",
    "XmGROW_BALANCED",
    "XmGROW_MAJOR",
    "XmGROW_MINOR",
    "XmHORIZONTAL",
    "XmHOR_SCROLLBAR",
    "XmHidden",
    "XmINCHES",
    "XmINDETERMINATE",
    "XmINDICATOR_BOX",
    "XmINDICATOR_CHECK",
    "XmINDICATOR_CHECK_BOX",
    "XmINDICATOR_CROSS",
    "XmINDICATOR_CROSS_BOX",
    "XmINDICATOR_FILL",
    "XmINDICATOR_NONE",
    "XmINHERIT_POLICY",
    "XmINVALID_MATCH_BEHAVIOR",
    "XmIconBottom",
    "XmIconLeft",
    "XmIconNone",
    "XmIconOnly",
    "XmIconRight",
    "XmIconTop",
    "XmLARGE_ICON",
    "XmLAST_POSITION",
    "XmLEFT_TO_RIGHT",
    "XmLEFT_TO_RIGHT_BOTTOM_TO_TOP",
    "XmLEFT_TO_RIGHT_TOP_TO_BOTTOM",
    "XmLOAD_DEFERRED",
    "XmLOAD_IMMEDIATE",
    "XmListMode",
    "XmMAJOR_TAB",
    "XmMARQUEE",
    "XmMARQUEE_EXTEND_BOTH",
    "XmMARQUEE_EXTEND_START",
    "XmMAX_ON_BOTTOM",
    "XmMAX_ON_LEFT",
    "XmMAX_ON_RIGHT",
    "XmMAX_ON_TOP",
    "XmMAX_SIDE",
    "XmMENU_BAR",
    "XmMENU_OPTION",
    "XmMENU_POPUP",
    "XmMENU_PULLDOWN",
    "XmMESSAGE_WINDOW",
    "XmMILLIMETERS",
    "XmMINOR_TAB",
    "XmMIN_SIDE",
    "XmMULTICLICK_DISCARD",
    "XmMULTICLICK_KEEP",
    "XmMULTIPLE_SELECT",
    "XmMULTI_LINE_EDIT",
    "XmNEAR_BORDER",
    "XmNEAR_SLIDER",
    "XmNONE",
    "XmNORMAL_MODE",
    "XmNOT_SELECTED",
    "XmNO_AUTO_SELECT",
    "XmNO_LINE",
    "XmNO_ORIENTATION",
    "XmNO_PACKING",
    "XmNO_SCROLL",
    "XmNUMERIC",
    "XmN_OF_MANY",
    "XmONE_BASED",
    "XmONE_OF_MANY",
    "XmONE_OF_MANY_DIAMOND",
    "XmONE_OF_MANY_ROUND",
    "XmOUTLINE",
    "XmOUTLINE_BUTTON_ABSENT",
    "XmOUTLINE_BUTTON_PRESENT",
    "XmOWN_ALWAYS",
    "XmOWN_MULTIPLE",
    "XmOWN_NEVER",
    "XmOWN_POSSIBLE_MULTIPLE",
    "XmOpen",
    "XmPACK_COLUMN",
    "XmPACK_NONE",
    "XmPACK_TIGHT",
    "XmPAGE",
    "XmPAGE_SCROLLER",
    "XmPER_SHELL",
    "XmPER_WIDGET",
    "XmPIXELS",
    "XmPIXMAP",
    "XmPIXMAP_AND_STRING",
    "XmPIXMAP_BOTTOM",
    "XmPIXMAP_LEFT",
    "XmPIXMAP_NONE",
    "XmPIXMAP_ONLY",
    "XmPIXMAP_OVERLAP_ONLY",
    "XmPIXMAP_RIGHT",
    "XmPIXMAP_TOP",
    "XmPLACE_ABOVE_SELECTION",
    "XmPLACE_BELOW_SELECTION",
    "XmPLACE_TOP",
    "XmPOINTER",
    "XmPOINTS",
    "XmPOSITION_INDEX",
    "XmPOSITION_VALUE",
    "XmQUICK_NAVIGATE",
    "XmRELATIVE",
    "XmRESIZE_ANY",
    "XmRESIZE_GROW",
    "XmRESIZE_IF_POSSIBLE",
    "XmRESIZE_NONE",
    "XmRIGHT_TO_LEFT",
    "XmRIGHT_TO_LEFT_BOTTOM_TO_TOP",
    "XmRIGHT_TO_LEFT_TOP_TO_BOTTOM",
    "XmROUND_MARK",
    "XmSCROLL_HOR",
    "XmSCROLL_VERT",
    "XmSELECTED",
    "XmSELECT_ALL",
    "XmSELECT_LINE",
    "XmSELECT_PARAGRAPH",
    "XmSELECT_POSITION",
    "XmSELECT_WHITESPACE",
    "XmSELECT_WORD",
    "XmSET",
    "XmSHADOWED_BACKGROUND",
    "XmSHADOW_ETCHED_IN",
    "XmSHADOW_ETCHED_IN_DASH",
    "XmSHADOW_ETCHED_OUT",
    "XmSHADOW_ETCHED_OUT_DASH",
    "XmSHADOW_IN",
    "XmSHADOW_OUT",
    "XmSINGLE",
    "XmSINGLE_DASHED_LINE",
    "XmSINGLE_LINE",
    "XmSINGLE_LINE_EDIT",
    "XmSINGLE_SELECT",
    "XmSLIDER",
    "XmSMALL_ICON",
    "XmSNAP_TO_GRID",
    "XmSOLID",
    "XmSPATIAL",
    "XmSPIRAL",
    "XmSTATIC",
    "XmSTATUS_AREA",
    "XmSTICKY_TAB_GROUP",
    "XmSTRING",
    "XmSTRING_COMPONENT_CHARSET",
    "XmSTRING_COMPONENT_DIRECTION",
    "XmSTRING_COMPONENT_LAYOUT_POP",
    "XmSTRING_COMPONENT_LAYOUT_PUSH",
    "XmSTRING_COMPONENT_LOCALE",
    "XmSTRING_COMPONENT_LOCALE_TEXT",
    "XmSTRING_COMPONENT_RENDITION_BEGIN",
    "XmSTRING_COMPONENT_RENDITION_END",
    "XmSTRING_COMPONENT_SEPARATOR",
    "XmSTRING_COMPONENT_TAB",
    "XmSTRING_COMPONENT_TEXT",
    "XmSTRING_COMPONENT_UNKNOWN",
    "XmSTRING_COMPONENT_WIDECHAR_TEXT",
    "XmSTRING_DIRECTION_DEFAULT",
    "XmSTRING_DIRECTION_L_TO_R",
    "XmSTRING_DIRECTION_R_TO_L",
    "XmSTRING_DIRECTION_UNSET",
    "XmScaleMode",
    "XmTABS_BASIC",
    "XmTABS_BEVELED",
    "XmTABS_BOTTOM_TO_TOP",
    "XmTABS_LEFT_TO_RIGHT",
    "XmTABS_ON_BOTTOM",
    "XmTABS_ON_LEFT",
    "XmTABS_ON_RIGHT",
    "XmTABS_ON_TOP",
    "XmTABS_RIGHT_TO_LEFT",
    "XmTABS_ROUNDED",
    "XmTABS_SQUARED",
    "XmTABS_STACKED",
    "XmTABS_STACKED_STATIC",
    "XmTABS_TOP_TO_BOTTOM",
    "XmTAB_EDGE_BOTTOM_RIGHT",
    "XmTAB_EDGE_TOP_LEFT",
    "XmTAB_GROUP",
    "XmTAB_ORIENTATION_DYNAMIC",
    "XmTEAR_OFF_DISABLED",
    "XmTEAR_OFF_ENABLED",
    "XmTHERMOMETER",
    "XmTHUMB_MARK",
    "XmTOGGLE_BOOLEAN",
    "XmTOGGLE_INDETERMINATE",
    "XmTOP_LEFT",
    "XmTOP_RIGHT",
    "XmTOP_TO_BOTTOM",
    "XmTOP_TO_BOTTOM_LEFT_TO_RIGHT",
    "XmTOP_TO_BOTTOM_RIGHT_TO_LEFT",
    "XmTOUCH_ONLY",
    "XmTOUCH_OVER",
    "XmTROUGH_COLOR",
    "XmTreeCompressLeaves",
    "XmTreeCompressNone",
    "XmTreeDirect",
    "XmTreeLadder",
    "XmUNMAP",
    "XmUNPOST",
    "XmUNPOST_AND_REPLAY",
    "XmUNSET",
    "XmVARIABLE",
    "XmVERTICAL",
    "XmVERT_SCROLLBAR",
    "XmWORK_AREA",
    "XmZERO_BASED",
};
externaldef(uil_sym_glbl) char **uil_enumval_names =
		uil_enumval_names_vec;


/*  Define mapping of sym_k_..._charset to enumeration value names.  */

externaldef(uil_sym_glbl) int uil_max_charset = 27;
static char *uil_charset_names_vec[] = {
    "",	/* NOT USED */
    "<userdefined>",
    "XmFONTLIST_DEFAULT_TAG",
    "_MOTIF_DEFAULT_LOCALE",
    "ansi_cyrillic",
    "big5",
    "dos_cyrillic",
    "euc",
    "gb_hanzi",
    "gb_hanzi_gr",
    "iso_arabic",
    "iso_arabic_lr",
    "iso_cyrillic",
    "iso_greek",
    "iso_hebrew",
    "iso_hebrew_lr",
    "iso_ir_111",
    "iso_latin1",
    "iso_latin2",
    "iso_latin3",
    "iso_latin4",
    "iso_latin5",
    "jis_kanji",
    "jis_kanji_gr",
    "jis_katakana",
    "ksc_hangul",
    "ksc_hangul_gr",
    "utf8",
};
externaldef(uil_sym_glbl) char **uil_charset_names =
		uil_charset_names_vec;


/*  Define mapping of sym_k_..._child codes to child names.  */

externaldef(uil_sym_glbl) int uil_max_child = 33;
static char *uil_child_names_vec[] = {
    "",	/* NOT USED */
    "Xm_Apply",
    "Xm_Arrow",
    "Xm_Cancel",
    "Xm_ColorListToggle",
    "Xm_ColorSlidersToggle",
    "Xm_Dir",
    "Xm_DirList",
    "Xm_Filter",
    "Xm_FilterLabel",
    "Xm_FilterText",
    "Xm_Find",
    "Xm_FindText",
    "Xm_Help",
    "Xm_HorScrollBar",
    "Xm_Items",
    "Xm_ItemsList",
    "Xm_Label",
    "Xm_List",
    "Xm_Message",
    "Xm_OK",
    "Xm_OptionButton",
    "Xm_OptionLabel",
    "Xm_Selection",
    "Xm_Separator",
    "Xm_Separator1",
    "Xm_Separator2",
    "Xm_Separator3",
    "Xm_Symbol",
    "Xm_TearOffControl",
    "Xm_Text",
    "Xm_TextField",
    "Xm_Title",
    "Xm_VertScrollBar",
};
externaldef(uil_sym_glbl) char **uil_child_names =
		uil_child_names_vec;
