/* $XConsortium: ObsoStr.c /main/5 1995/08/29 11:15:29 drk $ */
/*
 * Motif
 *
 * Copyright (c) 1987-2012, The Open Group. All rights reserved.
 *
 * These libraries and programs are free software; you can
 * redistribute them and/or modify them under the terms of the GNU
 * Lesser General Public License as published by the Free Software
 * Foundation; either version 2 of the License, or (at your option)
 * any later version.
 *
 * These libraries and programs are distributed in the hope that
 * they will be useful, but WITHOUT ANY WARRANTY; without even the
 * implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
 * PURPOSE. See the GNU Lesser General Public License for more
 * details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with these librararies and programs; if not, write
 * to the Free Software Foundation, Inc., 51 Franklin Street, Fifth
 * Floor, Boston, MA 02110-1301 USA
 * 
 */
/*
 * HISTORY
 */

#ifdef HAVE_CONFIG_H
#include <config.h>
#endif



/*** This file contains the 700 or so globals that were used in 1.2.0
     but not in 1.2.1 where they were replaced by a big array */

/* Define _XmConst before including anything, so that the
 * declarations will be in agreement with the definitions.
 */
#ifndef _XmConst
#if defined(__STDC__) || !defined( NO_CONST )
#define _XmConst const
#else
#define _XmConst
#endif /* __STDC__ */
#endif /* _XmConst */

#include <Xm/XmP.h>


_XmConst char _XmSCAcceleratorText[] = "AcceleratorText" ;
_XmConst char _XmSCAccelerator[] = "Accelerator" ;
_XmConst char _XmSCAdjustLast[] = "AdjustLast" ;
_XmConst char _XmSCAdjustMargin[] = "AdjustMargin" ;
_XmConst char _XmSCAlignment[] = "Alignment" ;
_XmConst char _XmSCAllowOverlap[] = "AllowOverlap" ;
_XmConst char _XmSCAnimationMask[] = "AnimationMask" ;
_XmConst char _XmSCAnimationPixmapDepth[] = "AnimationPixmapDepth" ;
_XmConst char _XmSCAnimationPixmap[] = "AnimationPixmap" ;
_XmConst char _XmSCAnimationStyle[] = "AnimationStyle" ;
_XmConst char _XmSCApplyLabelString[] = "ApplyLabelString" ;
_XmConst char _XmSCArmCallback[] = "ArmCallback" ;
_XmConst char _XmSCArmColor[] = "ArmColor" ;
_XmConst char _XmSCArmPixmap[] = "ArmPixmap" ;
_XmConst char _XmSCArrowDirection[] = "ArrowDirection" ;
_XmConst char _XmSCAtomList[] = "AtomList" ;
_XmConst char _XmSCAttachment[] = "Attachment" ;
_XmConst char _XmSCAudibleWarning[] = "AudibleWarning" ;
_XmConst char _XmSCAutoShowCursorPosition[] = "AutoShowCursorPosition" ;
_XmConst char _XmSCAutoUnmanage[] = "AutoUnmanage" ;
_XmConst char _XmSCAutomaticSelection[] = "AutomaticSelection" ;
_XmConst char _XmSCAvailability[] = "Availability" ;
_XmConst char _XmSCBackgroundPixmap[] = "BackgroundPixmap" ;
_XmConst char _XmSCBlendModel[] = "BlendModel" ;
_XmConst char _XmSCBlinkRate[] = "BlinkRate" ;
_XmConst char _XmSCBooleanDimension[] = "BooleanDimension" ;
_XmConst char _XmSCBottomShadowColor[] = "BottomShadowColor" ;
_XmConst char _XmSCBottomShadowPixmap[] = "BottomShadowPixmap" ;
_XmConst char _XmSCButtonAcceleratorText[] = "ButtonAcceleratorText" ;
_XmConst char _XmSCButtonAccelerators[] = "ButtonAccelerators" ;
_XmConst char _XmSCButtonCount[] = "ButtonCount" ;
_XmConst char _XmSCButtonFontList[] = "ButtonFontList" ;
_XmConst char _XmSCButtonMnemonicCharSets[] = "ButtonMnemonicCharSets" ;
_XmConst char _XmSCButtonMnemonics[] = "ButtonMnemonics" ;
_XmConst char _XmSCButtonSet[] = "ButtonSet" ;
_XmConst char _XmSCButtonType[] = "ButtonType" ;
_XmConst char _XmSCButtons[] = "Buttons" ;
_XmConst char _XmSCCallbackProc[] = "CallbackProc" ;
_XmConst char _XmSCCancelLabelString[] = "CancelLabelString" ;
_XmConst char _XmSCCharSetTable[] = "CharSetTable" ;
_XmConst char _XmSCChar[] = "Char" ;
_XmConst char _XmSCChildHorizontalAlignment[] = "ChildHorizontalAlignment" ;
_XmConst char _XmSCChildHorizontalSpacing[] = "ChildHorizontalSpacing" ;
_XmConst char _XmSCChildPlacement[] = "ChildPlacement" ;
_XmConst char _XmSCChildType[] = "ChildType" ;
_XmConst char _XmSCChildVerticalAlignment[] = "ChildVerticalAlignment" ;
_XmConst char _XmSCChildren[] = "Children" ;
_XmConst char _XmSCClientData[] = "ClientData" ;
_XmConst char _XmSCClipWindow[] = "ClipWindow" ;
_XmConst char _XmSCColumns[] = "Columns" ;
_XmConst char _XmSCCommandWindowLocation[] = "CommandWindowLocation" ;
_XmConst char _XmSCCommandWindow[] = "CommandWindow" ;
_XmConst char _XmSCCompoundText[] = "CompoundText" ;
_XmConst char _XmSCConvertProc[] = "ConvertProc" ;
_XmConst char _XmSCCursorBackground[] = "CursorBackground" ;
_XmConst char _XmSCCursorForeground[] = "CursorForeground" ;
_XmConst char _XmSCCursorPositionVisible[] = "CursorPositionVisible" ;
_XmConst char _XmSCCursorPosition[] = "CursorPosition" ;
_XmConst char _XmSCDarkThreshold[] = "DarkThreshold" ;
_XmConst char _XmSCDecimalPoints[] = "DecimalPoints" ;
_XmConst char _XmSCDefaultButtonShadowThickness[] = "DefaultButtonShadowThickness" ;
_XmConst char _XmSCDefaultButtonType[] = "DefaultButtonType" ;
_XmConst char _XmSCDefaultFontList[] = "DefaultFontList" ;
_XmConst char _XmSCDefaultNoneCursorIcon[] = "DefaultNoneCursorIcon" ;
_XmConst char _XmSCDefaultPosition[] = "DefaultPosition" ;
_XmConst char _XmSCDefaultValidCursorIcon[] = "DefaultValidCursorIcon" ;
_XmConst char _XmSCDefaultInvalidCursorIcon[] = "DefaultInvalidCursorIcon" ;
_XmConst char _XmSCDefaultMoveCursorIcon[] = "DefaultMoveCursorIcon" ;
_XmConst char _XmSCDefaultCopyCursorIcon[] = "DefaultCopyCursorIcon" ;
_XmConst char _XmSCDefaultLinkCursorIcon[] = "DefaultLinkCursorIcon" ;
_XmConst char _XmSCDefaultSourceCursorIcon[] = "DefaultSourceCursorIcon" ;
_XmConst char _XmSCDeleteResponse[] = "DeleteResponse" ;
_XmConst char _XmSCDesktopParent[] = "DesktopParent" ;
_XmConst char _XmSCDialogStyle[] = "DialogStyle" ;
_XmConst char _XmSCDialogTitle[] = "DialogTitle" ;
_XmConst char _XmSCDialogType[] = "DialogType" ;
_XmConst char _XmSCDirListItemCount[] = "DirListItemCount" ;
_XmConst char _XmSCDirListItems[] = "DirListItems" ;
_XmConst char _XmSCDirListLabelString[] = "DirListLabelString" ;
_XmConst char _XmSCDirMask[] = "DirMask" ;
_XmConst char _XmSCDirSearchProc[] = "DirSearchProc" ;
_XmConst char _XmSCDirSpec[] = "DirSpec" ;
_XmConst char _XmSCDirectoryValid[] = "DirectoryValid" ;
_XmConst char _XmSCDirectory[] = "Directory" ;
_XmConst char _XmSCDisarmCallback[] = "DisarmCallback" ;
_XmConst char _XmSCDoubleClickInterval[] = "DoubleClickInterval" ;
_XmConst char _XmSCDragContextClass[] = "DragContextClass" ;
_XmConst char _XmSCDragDropFinishCallback[] = "DragDropFinishCallback" ;
_XmConst char _XmSCDragIconClass[] = "DragIconClass" ;
_XmConst char _XmSCDragInitiatorProtocolStyle[] = "DragInitiatorProtocolStyle" ;
_XmConst char _XmSCDragMotionCallback[] = "DragMotionCallback" ;
_XmConst char _XmSCDragOperations[] = "DragOperations" ;
_XmConst char _XmSCDragOverMode[] = "DragOverMode" ;
_XmConst char _XmSCDragProc[] = "DragProc" ;
_XmConst char _XmSCDragReceiverProtocolStyle[] = "DragReceiverProtocolStyle" ;
_XmConst char _XmSCDropProc[] = "DropProc" ;
_XmConst char _XmSCDropRectangles[] = "DropRectangles" ;
_XmConst char _XmSCDropSiteActivity[] = "DropSiteActivity" ;
_XmConst char _XmSCDropSiteEnterCallback[] = "DropSiteEnterCallback" ;
_XmConst char _XmSCDropSiteLeaveCallback[] = "DropSiteLeaveCallback" ;
_XmConst char _XmSCDropSiteManagerClass[] = "DropSiteManagerClass" ;
_XmConst char _XmSCDropSiteOperations[] = "DropSiteOperations" ;
_XmConst char _XmSCDropSiteType[] = "DropSiteType" ;
_XmConst char _XmSCDropStartCallback[] = "DropStartCallback" ;
_XmConst char _XmSCDropTransferClass[] = "DropTransferClass" ;
_XmConst char _XmSCDropTransfers[] = "DropTransfers" ;
_XmConst char _XmSCEditable[] = "Editable" ;
_XmConst char _XmSCEntryBorder[] = "EntryBorder" ;
_XmConst char _XmSCEntryClass[] = "EntryClass" ;
_XmConst char _XmSCExportTargets[] = "ExportTargets" ;
_XmConst char _XmSCExposeCallback[] = "ExposeCallback" ;
_XmConst char _XmSCExtensionType[] = "ExtensionType" ;
_XmConst char _XmSCFileListItemCount[] = "FileListItemCount" ;
_XmConst char _XmSCFileListItems[] = "FileListItems" ;
_XmConst char _XmSCFileListLabelString[] = "FileListLabelString" ;
_XmConst char _XmSCFileSearchProc[] = "FileSearchProc" ;
_XmConst char _XmSCFileTypeMask[] = "FileTypeMask" ;
_XmConst char _XmSCFillOnArm[] = "FillOnArm" ;
_XmConst char _XmSCFillOnSelect[] = "FillOnSelect" ;
_XmConst char _XmSCFilterLabelString[] = "FilterLabelString" ;
_XmConst char _XmSCFontList[] = "FontList" ;
_XmConst char _XmSCForegroundThreshold[] = "ForegroundThreshold" ;
_XmConst char _XmSCGadgetPixmap[] = "GadgetPixmap" ;
_XmConst char _XmSCHelpLabelString[] = "HelpLabelString" ;
_XmConst char _XmSCHighlightColor[] = "HighlightColor" ;
_XmConst char _XmSCHighlightOnEnter[] = "HighlightOnEnter" ;
_XmConst char _XmSCHighlightPixmap[] = "HighlightPixmap" ;
_XmConst char _XmSCHighlightThickness[] = "HighlightThickness" ;
_XmConst char _XmSCHorizontalDimension[] = "HorizontalDimension" ;
_XmConst char _XmSCHorizontalFontUnit[] = "HorizontalFontUnit" ;
_XmConst char _XmSCHorizontalInt[] = "HorizontalInt" ;
_XmConst char _XmSCHorizontalPosition[] = "HorizontalPosition" ;
_XmConst char _XmSCHorizontalScrollBar[] = "HorizontalScrollBar" ;
_XmConst char _XmSCHot[] = "Hot" ;
_XmConst char _XmSCICCHandle[] = "ICCHandle" ;
_XmConst char _XmSCIconAttachment[] = "IconAttachment" ;
_XmConst char _XmSCImportTargets[] = "ImportTargets" ;
_XmConst char _XmSCIncrement[] = "Increment" ;
_XmConst char _XmSCIncremental[] = "Incremental" ;
_XmConst char _XmSCIndicatorOn[] = "IndicatorOn" ;
_XmConst char _XmSCIndicatorSize[] = "IndicatorSize" ;
_XmConst char _XmSCIndicatorType[] = "IndicatorType" ;
_XmConst char _XmSCInitialDelay[] = "InitialDelay" ;
_XmConst char _XmSCInitialFocus[] = "InitialFocus" ;
_XmConst char _XmSCInputCreate[] = "InputCreate" ;
_XmConst char _XmSCInputMethod[] = "InputMethod" ;
_XmConst char _XmSCInvalidCursorForeground[] = "InvalidCursorForeground" ;
_XmConst char _XmSCIsAligned[] = "IsAligned" ;
_XmConst char _XmSCIsHomogeneous[] = "IsHomogeneous" ;
_XmConst char _XmSCItemCount[] = "ItemCount" ;
_XmConst char _XmSCItems[] = "Items" ;
_XmConst char _XmSCKeySymTable[] = "KeySymTable" ;
_XmConst char _XmSCKeySym[] = "KeySym" ;
_XmConst char _XmSCKeyboardFocusPolicy[] = "KeyboardFocusPolicy" ;
_XmConst char _XmSCLabelFontList[] = "LabelFontList" ;
_XmConst char _XmSCLabelInsensitivePixmap[] = "LabelInsensitivePixmap" ;
_XmConst char _XmSCLabelPixmap[] = "LabelPixmap" ;
_XmConst char _XmSCLabelString[] = "LabelString" ;
_XmConst char _XmSCLabelType[] = "LabelType" ;
_XmConst char _XmSCLightThreshold[] = "LightThreshold" ;
_XmConst char _XmSCListLabelString[] = "ListLabelString" ;
_XmConst char _XmSCListMarginHeight[] = "ListMarginHeight" ;
_XmConst char _XmSCListMarginWidth[] = "ListMarginWidth" ;
_XmConst char _XmSCListSizePolicy[] = "ListSizePolicy" ;
_XmConst char _XmSCListSpacing[] = "ListSpacing" ;
_XmConst char _XmSCListUpdated[] = "ListUpdated" ;
_XmConst char _XmSCLogicalParent[] = "LogicalParent" ;
_XmConst char _XmSCMainWindowMarginHeight[] = "MainWindowMarginHeight" ;
_XmConst char _XmSCMainWindowMarginWidth[] = "MainWindowMarginWidth" ;
_XmConst char _XmSCManBottomShadowPixmap[] = "ManBottomShadowPixmap" ;
_XmConst char _XmSCManForegroundPixmap[] = "ManForegroundPixmap" ;
_XmConst char _XmSCManHighlightPixmap[] = "ManHighlightPixmap" ;
_XmConst char _XmSCManTopShadowPixmap[] = "ManTopShadowPixmap" ;
_XmConst char _XmSCMappingDelay[] = "MappingDelay" ;
_XmConst char _XmSCMarginBottom[] = "MarginBottom" ;
_XmConst char _XmSCMarginHeight[] = "MarginHeight" ;
_XmConst char _XmSCMarginLeft[] = "MarginLeft" ;
_XmConst char _XmSCMarginRight[] = "MarginRight" ;
_XmConst char _XmSCMarginTop[] = "MarginTop" ;
_XmConst char _XmSCMarginWidth[] = "MarginWidth" ;
_XmConst char _XmSCMask[] = "Mask" ;
_XmConst char _XmSCMaxItems[] = "MaxItems" ;
_XmConst char _XmSCMaxLength[] = "MaxLength" ;
_XmConst char _XmSCMaxValue[] = "MaxValue" ;
_XmConst char _XmSCMaximum[] = "Maximum" ;
_XmConst char _XmSCMenuBar[] = "MenuBar" ;
_XmConst char _XmSCMenuPost[] = "MenuPost" ;
_XmConst char _XmSCMenuWidget[] = "MenuWidget" ;
_XmConst char _XmSCMessageProc[] = "MessageProc" ;
_XmConst char _XmSCMessageWindow[] = "MessageWindow" ;
_XmConst char _XmSCMinimizeButtons[] = "MinimizeButtons" ;
_XmConst char _XmSCMinimum[] = "Minimum" ;
_XmConst char _XmSCMnemonicCharSet[] = "MnemonicCharSet" ;
_XmConst char _XmSCMnemonic[] = "Mnemonic" ;
_XmConst char _XmSCMoveOpaque[] = "MoveOpaque" ;
_XmConst char _XmSCMultiClick[] = "MultiClick" ;
_XmConst char _XmSCMustMatch[] = "MustMatch" ;
_XmConst char _XmSCMwmDecorations[] = "MwmDecorations" ;
_XmConst char _XmSCMwmFunctions[] = "MwmFunctions" ;
_XmConst char _XmSCMwmInputMode[] = "MwmInputMode" ;
_XmConst char _XmSCMwmMenu[] = "MwmMenu" ;
_XmConst char _XmSCMwmMessages[] = "MwmMessages" ;
_XmConst char _XmSCNavigationType[] = "NavigationType" ;
_XmConst char _XmSCNeedsMotion[] = "NeedsMotion" ;
_XmConst char _XmSCNoMatchString[] = "NoMatchString" ;
_XmConst char _XmSCNoResize[] = "NoResize" ;
_XmConst char _XmSCNoneCursorForeground[] = "NoneCursorForeground" ;
_XmConst char _XmSCNotifyProc[] = "NotifyProc" ;
_XmConst char _XmSCNumChildren[] = "NumChildren" ;
_XmConst char _XmSCNumColumns[] = "NumColumns" ;
_XmConst char _XmSCNumDropRectangles[] = "NumDropRectangles" ;
_XmConst char _XmSCNumDropTransfers[] = "NumDropTransfers" ;
_XmConst char _XmSCNumExportTargets[] = "NumExportTargets" ;
_XmConst char _XmSCNumImportTargets[] = "NumImportTargets" ;
_XmConst char _XmSCOffset[] = "Offset" ;
_XmConst char _XmSCOkLabelString[] = "OkLabelString" ;
_XmConst char _XmSCOperationChangedCallback[] = "OperationChangedCallback" ;
_XmConst char _XmSCOperationCursorIcon[] = "OperationCursorIcon" ;
_XmConst char _XmSCOptionLabel[] = "OptionLabel" ;
_XmConst char _XmSCOptionMnemonic[] = "OptionMnemonic" ;
_XmConst char _XmSCOutputCreate[] = "OutputCreate" ;
_XmConst char _XmSCPacking[] = "Packing" ;
_XmConst char _XmSCPageIncrement[] = "PageIncrement" ;
_XmConst char _XmSCPaneMaximum[] = "PaneMaximum" ;
_XmConst char _XmSCPaneMinimum[] = "PaneMinimum" ;
_XmConst char _XmSCPattern[] = "Pattern" ;
_XmConst char _XmSCPendingDelete[] = "PendingDelete" ;
_XmConst char _XmSCPopupEnabled[] = "PopupEnabled" ;
_XmConst char _XmSCPositionIndex[] = "PositionIndex" ;
_XmConst char _XmSCPostFromButton[] = "PostFromButton" ;
_XmConst char _XmSCPostFromCount[] = "PostFromCount" ;
_XmConst char _XmSCPostFromList[] = "PostFromList" ;
_XmConst char _XmSCPreeditType[] = "PreeditType" ;
_XmConst char _XmSCPrimForegroundPixmap[] = "PrimForegroundPixmap" ;
_XmConst char _XmSCProc[] = "Proc" ;
_XmConst char _XmSCProcessingDirection[] = "ProcessingDirection" ;
_XmConst char _XmSCPromptString[] = "PromptString" ;
_XmConst char _XmSCProtocolCallback[] = "ProtocolCallback" ;
_XmConst char _XmSCPushButtonEnabled[] = "PushButtonEnabled" ;
_XmConst char _XmSCQualifySearchDataProc[] = "QualifySearchDataProc" ;
_XmConst char _XmSCRadioAlwaysOne[] = "RadioAlwaysOne" ;
_XmConst char _XmSCRadioBehavior[] = "RadioBehavior" ;
_XmConst char _XmSCRecomputeSize[] = "RecomputeSize" ;
_XmConst char _XmSCRectangleList[] = "RectangleList" ;
_XmConst char _XmSCRectangles[] = "Rectangles" ;
_XmConst char _XmSCRepeatDelay[] = "RepeatDelay" ;
_XmConst char _XmSCResizeCallback[] = "ResizeCallback" ;
_XmConst char _XmSCResizeHeight[] = "ResizeHeight" ;
_XmConst char _XmSCResizePolicy[] = "ResizePolicy" ;
_XmConst char _XmSCResizeWidth[] = "ResizeWidth" ;
_XmConst char _XmSCRowColumnType[] = "RowColumnType" ;
_XmConst char _XmSCRows[] = "Rows" ;
_XmConst char _XmSCRubberPositioning[] = "RubberPositioning" ;
_XmConst char _XmSCSashHeight[] = "SashHeight" ;
_XmConst char _XmSCSashIndent[] = "SashIndent" ;
_XmConst char _XmSCSashWidth[] = "SashWidth" ;
_XmConst char _XmSCScaleHeight[] = "ScaleHeight" ;
_XmConst char _XmSCScaleMultiple[] = "ScaleMultiple" ;
_XmConst char _XmSCScaleWidth[] = "ScaleWidth" ;
_XmConst char _XmSCScrollBarDisplayPolicy[] = "ScrollBarDisplayPolicy" ;
_XmConst char _XmSCScrollBarPlacement[] = "ScrollBarPlacement" ;
_XmConst char _XmSCScrollSide[] = "ScrollSide" ;
_XmConst char _XmSCScroll[] = "Scroll" ;
_XmConst char _XmSCScrolledWindowMarginHeight[] = "ScrolledWindowMarginHeight" ;
_XmConst char _XmSCScrolledWindowMarginWidth[] = "ScrolledWindowMarginWidth" ;
_XmConst char _XmSCScrollingPolicy[] = "ScrollingPolicy" ;
_XmConst char _XmSCSelectColor[] = "SelectColor" ;
_XmConst char _XmSCSelectInsensitivePixmap[] = "SelectInsensitivePixmap" ;
_XmConst char _XmSCSelectPixmap[] = "SelectPixmap" ;
_XmConst char _XmSCSelectThreshold[] = "SelectThreshold" ;
_XmConst char _XmSCSelectedItemCount[] = "SelectedItemCount" ;
_XmConst char _XmSCSelectedItems[] = "SelectedItems" ;
_XmConst char _XmSCSelectionArrayCount[] = "SelectionArrayCount" ;
_XmConst char _XmSCSelectionLabelString[] = "SelectionLabelString" ;
_XmConst char _XmSCSelectionPolicy[] = "SelectionPolicy" ;
_XmConst char _XmSCSelectionType[] = "SelectionType" ;
_XmConst char _XmSCSeparatorOn[] = "SeparatorOn" ;
_XmConst char _XmSCSeparatorType[] = "SeparatorType" ;
_XmConst char _XmSCSet[] = "Set" ;
_XmConst char _XmSCShadowThickness[] = "ShadowThickness" ;
_XmConst char _XmSCShadowType[] = "ShadowType" ;
_XmConst char _XmSCShellHorizDim[] = "ShellHorizDim" ;
_XmConst char _XmSCShellHorizPos[] = "ShellHorizPos" ;
_XmConst char _XmSCShellUnitType[] = "ShellUnitType" ;
_XmConst char _XmSCShellVertDim[] = "ShellVertDim" ;
_XmConst char _XmSCShellVertPos[] = "ShellVertPos" ;
_XmConst char _XmSCShowArrows[] = "ShowArrows" ;
_XmConst char _XmSCShowAsDefault[] = "ShowAsDefault" ;
_XmConst char _XmSCShowSeparator[] = "ShowSeparator" ;
_XmConst char _XmSCShowValue[] = "ShowValue" ;
_XmConst char _XmSCSimpleCheckBox[] = "SimpleCheckBox" ;
_XmConst char _XmSCSimpleMenuBar[] = "SimpleMenuBar" ;
_XmConst char _XmSCSimpleOptionMenu[] = "SimpleOptionMenu" ;
_XmConst char _XmSCSimplePopupMenu[] = "SimplePopupMenu" ;
_XmConst char _XmSCSimplePulldownMenu[] = "SimplePulldownMenu" ;
_XmConst char _XmSCSimpleRadioBox[] = "SimpleRadioBox" ;
_XmConst char _XmSCSizePolicy[] = "SizePolicy" ;
_XmConst char _XmSCSliderSize[] = "SliderSize" ;
_XmConst char _XmSCSourceCursorIcon[] = "SourceCursorIcon" ;
_XmConst char _XmSCSourceIsExternal[] = "SourceIsExternal" ;
_XmConst char _XmSCSourcePixmapIcon[] = "SourcePixmapIcon" ;
_XmConst char _XmSCSourceWidget[] = "SourceWidget" ;
_XmConst char _XmSCSourceWindow[] = "SourceWindow" ;
_XmConst char _XmSCSource[] = "Source" ;
_XmConst char _XmSCSpacing[] = "Spacing" ;
_XmConst char _XmSCStartTime[] = "StartTime" ;
_XmConst char _XmSCStateCursorIcon[] = "StateCursorIcon" ;
_XmConst char _XmSCStringDirection[] = "StringDirection" ;
_XmConst char _XmSCTearOffModel[] = "TearOffModel" ;
_XmConst char _XmSCTextFontList[] = "TextFontList" ;
_XmConst char _XmSCTextString[] = "TextString" ;
_XmConst char _XmSCTextValue[] = "TextValue" ;
_XmConst char _XmSCTitleString[] = "TitleString" ;
_XmConst char _XmSCTopCharacter[] = "TopCharacter" ;
_XmConst char _XmSCTopItemPosition[] = "TopItemPosition" ;
_XmConst char _XmSCTopLevelEnterCallback[] = "TopLevelEnterCallback" ;
_XmConst char _XmSCTopLevelLeaveCallback[] = "TopLevelLeaveCallback" ;
_XmConst char _XmSCTopShadowColor[] = "TopShadowColor" ;
_XmConst char _XmSCTopShadowPixmap[] = "TopShadowPixmap" ;
_XmConst char _XmSCTransferProc[] = "TransferProc" ;
_XmConst char _XmSCTransferStatus[] = "TransferStatus" ;
_XmConst char _XmSCTraversalOn[] = "TraversalOn" ;
_XmConst char _XmSCTraversalType[] = "TraversalType" ;
_XmConst char _XmSCTreeUpdateProc[] = "TreeUpdateProc" ;
_XmConst char _XmSCTroughColor[] = "TroughColor" ;
_XmConst char _XmSCUnitType[] = "UnitType" ;
_XmConst char _XmSCUnpostBehavior[] = "UnpostBehavior" ;
_XmConst char _XmSCUnselectPixmap[] = "UnselectPixmap" ;
_XmConst char _XmSCUpdateSliderSize[] = "UpdateSliderSize" ;
_XmConst char _XmSCUseAsyncGeometry[] = "UseAsyncGeometry" ;
_XmConst char _XmSCUserData[] = "UserData" ;
_XmConst char _XmSCValidCursorForeground[] = "ValidCursorForeground" ;
_XmConst char _XmSCValueChangedCallback[] = "ValueChangedCallback" ;
_XmConst char _XmSCValueWcs[] = "ValueWcs" ;
_XmConst char _XmSCVerifyBell[] = "VerifyBell" ;
_XmConst char _XmSCVerticalAlignment[] = "VerticalAlignment" ;
_XmConst char _XmSCVerticalDimension[] = "VerticalDimension" ;
_XmConst char _XmSCVerticalFontUnit[] = "VerticalFontUnit" ;
_XmConst char _XmSCVerticalInt[] = "VerticalInt" ;
_XmConst char _XmSCVerticalPosition[] = "VerticalPosition" ;
_XmConst char _XmSCVerticalScrollBar[] = "VerticalScrollBar" ;
_XmConst char _XmSCVirtualBinding[] = "VirtualBinding" ;
_XmConst char _XmSCVisibleItemCount[] = "VisibleItemCount" ;
_XmConst char _XmSCVisibleWhenOff[] = "VisibleWhenOff" ;
_XmConst char _XmSCVisualPolicy[] = "VisualPolicy" ;
_XmConst char _XmSCWhichButton[] = "WhichButton" ;
_XmConst char _XmSCWordWrap[] = "WordWrap" ;
_XmConst char _XmSCWorkWindow[] = "WorkWindow" ;
_XmConst char _XmSCXmBackgroundPixmap[] = "XmBackgroundPixmap" ;
_XmConst char _XmSCXmStringCharSet[] = "XmStringCharSet" ;
_XmConst char _XmSCXmStringTable[] = "XmStringTable" ;
_XmConst char _XmSCXmString[] = "XmString" ;

_XmConst char _XmSacceleratorText[] = "acceleratorText" ;
_XmConst char _XmSaccelerator[] = "accelerator" ;
_XmConst char _XmSactivateCallback[] = "activateCallback" ;
_XmConst char _XmSadjustLast[] = "adjustLast" ;
_XmConst char _XmSadjustMargin[] = "adjustMargin" ;
_XmConst char _XmSalignment[] = "alignment" ;
_XmConst char _XmSallowOverlap[] = "allowOverlap" ;
_XmConst char _XmSallowResize[] = "allowResize" ;
_XmConst char _XmSanimationMask[] = "animationMask" ;
_XmConst char _XmSanimationPixmapDepth[] = "animationPixmapDepth" ;
_XmConst char _XmSanimationPixmap[] = "animationPixmap" ;
_XmConst char _XmSanimationStyle[] = "animationStyle" ;
_XmConst char _XmSapplyCallback[] = "applyCallback" ;
_XmConst char _XmSapplyLabelString[] = "applyLabelString" ;
_XmConst char _XmSarmCallback[] = "armCallback" ;
_XmConst char _XmSarmColor[] = "armColor" ;
_XmConst char _XmSarmPixmap[] = "armPixmap" ;
_XmConst char _XmSarrowDirection[] = "arrowDirection" ;
_XmConst char _XmSattachment[] = "attachment" ;
_XmConst char _XmSaudibleWarning[] = "audibleWarning" ;
_XmConst char _XmSautoShowCursorPosition[] = "autoShowCursorPosition" ;
_XmConst char _XmSautoUnmanage[] = "autoUnmanage" ;
_XmConst char _XmSautomaticSelection[] = "automaticSelection" ;
_XmConst char _XmSavailability[] = "availability" ;
_XmConst char _XmSblendModel[] = "blendModel" ;
_XmConst char _XmSblinkRate[] = "blinkRate" ;
_XmConst char _XmSbottomAttachment[] = "bottomAttachment" ;
_XmConst char _XmSbottomOffset[] = "bottomOffset" ;
_XmConst char _XmSbottomPosition[] = "bottomPosition" ;
_XmConst char _XmSbottomShadowColor[] = "bottomShadowColor" ;
_XmConst char _XmSbottomShadowPixmap[] = "bottomShadowPixmap" ;
_XmConst char _XmSbottomWidget[] = "bottomWidget" ;
_XmConst char _XmSbrowseSelectionCallback[] = "browseSelectionCallback" ;
_XmConst char _XmSbuttonAcceleratorText[] = "buttonAcceleratorText" ;
_XmConst char _XmSbuttonAccelerators[] = "buttonAccelerators" ;
_XmConst char _XmSbuttonCount[] = "buttonCount" ;
_XmConst char _XmSbuttonFontList[] = "buttonFontList" ;
_XmConst char _XmSbuttonMnemonicCharSets[] = "buttonMnemonicCharSets" ;
_XmConst char _XmSbuttonMnemonics[] = "buttonMnemonics" ;
_XmConst char _XmSbuttonSet[] = "buttonSet" ;
_XmConst char _XmSbuttonType[] = "buttonType" ;
_XmConst char _XmSbuttons[] = "buttons" ;
_XmConst char _XmScancelButton[] = "cancelButton" ;
_XmConst char _XmScancelCallback[] = "cancelCallback" ;
_XmConst char _XmScancelLabelString[] = "cancelLabelString" ;
_XmConst char _XmScascadeButton[] = "cascadeButton" ;
_XmConst char _XmScascadePixmap[] = "cascadePixmap" ;
_XmConst char _XmScascadingCallback[] = "cascadingCallback" ;
_XmConst char _XmScheckButton[] = "checkButton" ;
_XmConst char _XmSchildHorizontalAlignment[] = "childHorizontalAlignment" ;
_XmConst char _XmSchildHorizontalSpacing[] = "childHorizontalSpacing" ;
_XmConst char _XmSchildPlacement[] = "childPlacement" ;
_XmConst char _XmSchildPosition[] = "childPosition" ;
_XmConst char _XmSchildType[] = "childType" ;
_XmConst char _XmSchildVerticalAlignment[] = "childVerticalAlignment" ;
_XmConst char _XmSclientData[] = "clientData" ;
_XmConst char _XmSclipWindow[] = "clipWindow" ;
_XmConst char _XmScolumns[] = "columns" ;
_XmConst char _XmScommandChangedCallback[] = "commandChangedCallback" ;
_XmConst char _XmScommandEnteredCallback[] = "commandEnteredCallback" ;
_XmConst char _XmScommandWindowLocation[] = "commandWindowLocation" ;
_XmConst char _XmScommandWindow[] = "commandWindow" ;
_XmConst char _XmScommand[] = "command" ;
_XmConst char _XmSconvertProc[] = "convertProc" ;
_XmConst char _XmScursorBackground[] = "cursorBackground" ;
_XmConst char _XmScursorForeground[] = "cursorForeground" ;
_XmConst char _XmScursorPositionVisible[] = "cursorPositionVisible" ;
_XmConst char _XmScursorPosition[] = "cursorPosition" ;
_XmConst char _XmSdarkThreshold[] = "darkThreshold" ;
_XmConst char _XmSdecimalPoints[] = "decimalPoints" ;
_XmConst char _XmSdecrementCallback[] = "decrementCallback" ;
_XmConst char _XmSdefaultActionCallback[] = "defaultActionCallback" ;
_XmConst char _XmSdefaultButtonShadowThickness[] = "defaultButtonShadowThickness" ;
_XmConst char _XmSdefaultButtonType[] = "defaultButtonType" ;
_XmConst char _XmSdefaultButton[] = "defaultButton" ;
_XmConst char _XmSdefaultFontList[] = "defaultFontList" ;
_XmConst char _XmSdefaultNoneCursorIcon[] = "defaultNoneCursorIcon" ;
_XmConst char _XmSdefaultPosition[] = "defaultPosition" ;
_XmConst char _XmSdefaultValidCursorIcon[] = "defaultValidCursorIcon" ;
_XmConst char _XmSdefaultInvalidCursorIcon[] = "defaultInvalidCursorIcon" ;
_XmConst char _XmSdefaultMoveCursorIcon[] = "defaultMoveCursorIcon" ;
_XmConst char _XmSdefaultCopyCursorIcon[] = "defaultCopyCursorIcon" ;
_XmConst char _XmSdefaultLinkCursorIcon[] = "defaultLinkCursorIcon" ;
_XmConst char _XmSdefaultSourceCursorIcon[] = "defaultSourceCursorIcon" ;
_XmConst char _XmSdeleteResponse[] = "deleteResponse" ;
_XmConst char _XmSdesktopParent[] = "desktopParent" ;
_XmConst char _XmSdialogStyle[] = "dialogStyle" ;
_XmConst char _XmSdialogTitle[] = "dialogTitle" ;
_XmConst char _XmSdialogType[] = "dialogType" ;
_XmConst char _XmSdirListItemCount[] = "dirListItemCount" ;
_XmConst char _XmSdirListItems[] = "dirListItems" ;
_XmConst char _XmSdirListLabelString[] = "dirListLabelString" ;
_XmConst char _XmSdirMask[] = "dirMask" ;
_XmConst char _XmSdirSearchProc[] = "dirSearchProc" ;
_XmConst char _XmSdirSpec[] = "dirSpec" ;
_XmConst char _XmSdirectoryValid[] = "directoryValid" ;
_XmConst char _XmSdirectory[] = "directory" ;
_XmConst char _XmSdisarmCallback[] = "disarmCallback" ;
_XmConst char _XmSdoubleClickInterval[] = "doubleClickInterval" ;
_XmConst char _XmSdoubleSeparator[] = "doubleSeparator" ;
_XmConst char _XmSdragCallback[] = "dragCallback" ;
_XmConst char _XmSdragContextClass[] = "dragContextClass" ;
_XmConst char _XmSdragDropFinishCallback[] = "dragDropFinishCallback" ;
_XmConst char _XmSdragIconClass[] = "dragIconClass" ;
_XmConst char _XmSdragInitiatorProtocolStyle[] = "dragInitiatorProtocolStyle" ;
_XmConst char _XmSdragMotionCallback[] = "dragMotionCallback" ;
_XmConst char _XmSdragOperations[] = "dragOperations" ;
_XmConst char _XmSdragOverMode[] = "dragOverMode" ;
_XmConst char _XmSdragProc[] = "dragProc" ;
_XmConst char _XmSdragReceiverProtocolStyle[] = "dragReceiverProtocolStyle" ;
_XmConst char _XmSdropFinishCallback[] = "dropFinishCallback" ;
_XmConst char _XmSdropProc[] = "dropProc" ;
_XmConst char _XmSdropRectangles[] = "dropRectangles" ;
_XmConst char _XmSdropSiteActivity[] = "dropSiteActivity" ;
_XmConst char _XmSdropSiteEnterCallback[] = "dropSiteEnterCallback" ;
_XmConst char _XmSdropSiteLeaveCallback[] = "dropSiteLeaveCallback" ;
_XmConst char _XmSdropSiteManagerClass[] = "dropSiteManagerClass" ;
_XmConst char _XmSdropSiteOperations[] = "dropSiteOperations" ;
_XmConst char _XmSdropSiteType[] = "dropSiteType" ;
_XmConst char _XmSdropStartCallback[] = "dropStartCallback" ;
_XmConst char _XmSdropTransferClass[] = "dropTransferClass" ;
_XmConst char _XmSdropTransfers[] = "dropTransfers" ;
_XmConst char _XmSeditMode[] = "editMode" ;
_XmConst char _XmSeditable[] = "editable" ;
_XmConst char _XmSentryAlignment[] = "entryAlignment" ;
_XmConst char _XmSentryBorder[] = "entryBorder" ;
_XmConst char _XmSentryCallback[] = "entryCallback" ;
_XmConst char _XmSentryClass[] = "entryClass" ;
_XmConst char _XmSentryVerticalAlignment[] = "entryVerticalAlignment" ;
_XmConst char _XmSexportTargets[] = "exportTargets" ;
_XmConst char _XmSexposeCallback[] = "exposeCallback" ;
_XmConst char _XmSextendedSelectionCallback[] = "extendedSelectionCallback" ;
_XmConst char _XmSextensionType[] = "extensionType" ;
_XmConst char _XmSfileListItemCount[] = "fileListItemCount" ;
_XmConst char _XmSfileListItems[] = "fileListItems" ;
_XmConst char _XmSfileListLabelString[] = "fileListLabelString" ;
_XmConst char _XmSfileSearchProc[] = "fileSearchProc" ;
_XmConst char _XmSfileTypeMask[] = "fileTypeMask" ;
_XmConst char _XmSfillOnArm[] = "fillOnArm" ;
_XmConst char _XmSfillOnSelect[] = "fillOnSelect" ;
_XmConst char _XmSfilterLabelString[] = "filterLabelString" ;
_XmConst char _XmSfocusCallback[] = "focusCallback" ;
_XmConst char _XmSfocusMovedCallback[] = "focusMovedCallback" ;
_XmConst char _XmSfocusPolicyChanged[] = "focusPolicyChanged" ;
_XmConst char _XmSfontList[] = "fontList" ;
_XmConst char _XmSforegroundThreshold[] = "foregroundThreshold" ;
_XmConst char _XmSfractionBase[] = "fractionBase" ;
_XmConst char _XmSgainPrimaryCallback[] = "gainPrimaryCallback" ;
_XmConst char _XmShelpCallback[] = "helpCallback" ;
_XmConst char _XmShelpLabelString[] = "helpLabelString" ;
_XmConst char _XmShighlightColor[] = "highlightColor" ;
_XmConst char _XmShighlightOnEnter[] = "highlightOnEnter" ;
_XmConst char _XmShighlightPixmap[] = "highlightPixmap" ;
_XmConst char _XmShighlightThickness[] = "highlightThickness" ;
_XmConst char _XmShistoryItemCount[] = "historyItemCount" ;
_XmConst char _XmShistoryItems[] = "historyItems" ;
_XmConst char _XmShistoryMaxItems[] = "historyMaxItems" ;
_XmConst char _XmShistoryVisibleItemCount[] = "historyVisibleItemCount" ;
_XmConst char _XmShorizontalFontUnit[] = "horizontalFontUnit" ;
_XmConst char _XmShorizontalScrollBar[] = "horizontalScrollBar" ;
_XmConst char _XmShorizontalSpacing[] = "horizontalSpacing" ;
_XmConst char _XmShotX[] = "hotX" ;
_XmConst char _XmShotY[] = "hotY" ;
_XmConst char _XmSiccHandle[] = "iccHandle" ;
_XmConst char _XmSimportTargets[] = "importTargets" ;
_XmConst char _XmSincrementCallback[] = "incrementCallback" ;
_XmConst char _XmSincrement[] = "increment" ;
_XmConst char _XmSincremental[] = "incremental" ;
_XmConst char _XmSindicatorOn[] = "indicatorOn" ;
_XmConst char _XmSindicatorSize[] = "indicatorSize" ;
_XmConst char _XmSindicatorType[] = "indicatorType" ;
_XmConst char _XmSinitialDelay[] = "initialDelay" ;
_XmConst char _XmSinitialFocus[] = "initialFocus" ;
_XmConst char _XmSinputCallback[] = "inputCallback" ;
_XmConst char _XmSinputCreate[] = "inputCreate" ;
_XmConst char _XmSinputMethod[] = "inputMethod" ;
_XmConst char _XmSinvalidCursorForeground[] = "invalidCursorForeground" ;
_XmConst char _XmSisAligned[] = "isAligned" ;
_XmConst char _XmSisHomogeneous[] = "isHomogeneous" ;
_XmConst char _XmSitemCount[] = "itemCount" ;
_XmConst char _XmSitems[] = "items" ;
_XmConst char _XmSkeyboardFocusPolicy[] = "keyboardFocusPolicy" ;
_XmConst char _XmSlabelFontList[] = "labelFontList" ;
_XmConst char _XmSlabelInsensitivePixmap[] = "labelInsensitivePixmap" ;
_XmConst char _XmSlabelPixmap[] = "labelPixmap" ;
_XmConst char _XmSlabelString[] = "labelString" ;
_XmConst char _XmSlabelType[] = "labelType" ;
_XmConst char _XmSleftAttachment[] = "leftAttachment" ;
_XmConst char _XmSleftOffset[] = "leftOffset" ;
_XmConst char _XmSleftPosition[] = "leftPosition" ;
_XmConst char _XmSleftWidget[] = "leftWidget" ;
_XmConst char _XmSlightThreshold[] = "lightThreshold" ;
_XmConst char _XmSlistItemCount[] = "listItemCount" ;
_XmConst char _XmSlistItems[] = "listItems" ;
_XmConst char _XmSlistLabelString[] = "listLabelString" ;
_XmConst char _XmSlistMarginHeight[] = "listMarginHeight" ;
_XmConst char _XmSlistMarginWidth[] = "listMarginWidth" ;
_XmConst char _XmSlistSizePolicy[] = "listSizePolicy" ;
_XmConst char _XmSlistSpacing[] = "listSpacing" ;
_XmConst char _XmSlistUpdated[] = "listUpdated" ;
_XmConst char _XmSlistVisibleItemCount[] = "listVisibleItemCount" ;
_XmConst char _XmSlogicalParent[] = "logicalParent" ;
_XmConst char _XmSlosePrimaryCallback[] = "losePrimaryCallback" ;
_XmConst char _XmSlosingFocusCallback[] = "losingFocusCallback" ;
_XmConst char _XmSmainWindowMarginHeight[] = "mainWindowMarginHeight" ;
_XmConst char _XmSmainWindowMarginWidth[] = "mainWindowMarginWidth" ;
_XmConst char _XmSmapCallback[] = "mapCallback" ;
_XmConst char _XmSmappingDelay[] = "mappingDelay" ;
_XmConst char _XmSmarginBottom[] = "marginBottom" ;
_XmConst char _XmSmarginHeight[] = "marginHeight" ;
_XmConst char _XmSmarginLeft[] = "marginLeft" ;
_XmConst char _XmSmarginRight[] = "marginRight" ;
_XmConst char _XmSmarginTop[] = "marginTop" ;
_XmConst char _XmSmarginWidth[] = "marginWidth" ;
_XmConst char _XmSmargin[] = "margin" ;
_XmConst char _XmSmask[] = "mask" ;
_XmConst char _XmSmaxLength[] = "maxLength" ;
_XmConst char _XmSmaximum[] = "maximum" ;
_XmConst char _XmSmenuAccelerator[] = "menuAccelerator" ;
_XmConst char _XmSmenuBar[] = "menuBar" ;
_XmConst char _XmSmenuCursor[] = "menuCursor" ;
_XmConst char _XmSmenuHelpWidget[] = "menuHelpWidget" ;
_XmConst char _XmSmenuHistory[] = "menuHistory" ;
_XmConst char _XmSmenuPost[] = "menuPost" ;
_XmConst char _XmSmessageAlignment[] = "messageAlignment" ;
_XmConst char _XmSmessageProc[] = "messageProc" ;
_XmConst char _XmSmessageString[] = "messageString" ;
_XmConst char _XmSmessageWindow[] = "messageWindow" ;
_XmConst char _XmSminimizeButtons[] = "minimizeButtons" ;
_XmConst char _XmSminimum[] = "minimum" ;
_XmConst char _XmSmnemonicCharSet[] = "mnemonicCharSet" ;
_XmConst char _XmSmnemonic[] = "mnemonic" ;
_XmConst char _XmSmodifyVerifyCallbackWcs[] = "modifyVerifyCallbackWcs" ;
_XmConst char _XmSmodifyVerifyCallback[] = "modifyVerifyCallback" ;
_XmConst char _XmSmotionVerifyCallback[] = "motionVerifyCallback" ;
_XmConst char _XmSmoveOpaque[] = "moveOpaque" ;
_XmConst char _XmSmultiClick[] = "multiClick" ;
_XmConst char _XmSmultipleSelectionCallback[] = "multipleSelectionCallback" ;
_XmConst char _XmSmustMatch[] = "mustMatch" ;
_XmConst char _XmSmwmDecorations[] = "mwmDecorations" ;
_XmConst char _XmSmwmFunctions[] = "mwmFunctions" ;
_XmConst char _XmSmwmInputMode[] = "mwmInputMode" ;
_XmConst char _XmSmwmMenu[] = "mwmMenu" ;
_XmConst char _XmSmwmMessages[] = "mwmMessages" ;
_XmConst char _XmSnavigationType[] = "navigationType" ;
_XmConst char _XmSneedsMotion[] = "needsMotion" ;
_XmConst char _XmSnoMatchCallback[] = "noMatchCallback" ;
_XmConst char _XmSnoMatchString[] = "noMatchString" ;
_XmConst char _XmSnoResize[] = "noResize" ;
_XmConst char _XmSnoneCursorForeground[] = "noneCursorForeground" ;
_XmConst char _XmSnotifyProc[] = "notifyProc" ;
_XmConst char _XmSnumColumns[] = "numColumns" ;
_XmConst char _XmSnumDropRectangles[] = "numDropRectangles" ;
_XmConst char _XmSnumDropTransfers[] = "numDropTransfers" ;
_XmConst char _XmSnumExportTargets[] = "numExportTargets" ;
_XmConst char _XmSnumImportTargets[] = "numImportTargets" ;
_XmConst char _XmSnumRectangles[] = "numRectangles" ;
_XmConst char _XmSoffsetX[] = "offsetX" ;
_XmConst char _XmSoffsetY[] = "offsetY" ;
_XmConst char _XmSokCallback[] = "okCallback" ;
_XmConst char _XmSokLabelString[] = "okLabelString" ;
_XmConst char _XmSoperationChangedCallback[] = "operationChangedCallback" ;
_XmConst char _XmSoperationCursorIcon[] = "operationCursorIcon" ;
_XmConst char _XmSoptionLabel[] = "optionLabel" ;
_XmConst char _XmSoptionMnemonic[] = "optionMnemonic" ;
_XmConst char _XmSosfActivate[] = "osfActivate" ;
_XmConst char _XmSosfAddMode[] = "osfAddMode" ;
_XmConst char _XmSosfBackSpace[] = "osfBackSpace" ;
_XmConst char _XmSosfBeginLine[] = "osfBeginLine" ;
_XmConst char _XmSosfCancel[] = "osfCancel" ;
_XmConst char _XmSosfClear[] = "osfClear" ;
_XmConst char _XmSosfCopy[] = "osfCopy" ;
_XmConst char _XmSosfCut[] = "osfCut" ;
_XmConst char _XmSosfDelete[] = "osfDelete" ;
_XmConst char _XmSosfDown[] = "osfDown" ;
_XmConst char _XmSosfEndLine[] = "osfEndLine" ;
_XmConst char _XmSosfHelp[] = "osfHelp" ;
_XmConst char _XmSosfInsert[] = "osfInsert" ;
_XmConst char _XmSosfLeft[] = "osfLeft" ;
_XmConst char _XmSosfMenuBar[] = "osfMenuBar" ;
_XmConst char _XmSosfMenu[] = "osfMenu" ;
_XmConst char _XmSosfPageDown[] = "osfPageDown" ;
_XmConst char _XmSosfPageLeft[] = "osfPageLeft" ;
_XmConst char _XmSosfPageRight[] = "osfPageRight" ;
_XmConst char _XmSosfPageUp[] = "osfPageUp" ;
_XmConst char _XmSosfPaste[] = "osfPaste" ;
_XmConst char _XmSosfPrimaryPaste[] = "osfPrimaryPaste" ;
_XmConst char _XmSosfQuickPaste[] = "osfQuickPaste" ;
_XmConst char _XmSosfRight[] = "osfRight" ;
_XmConst char _XmSosfSelect[] = "osfSelect" ;
_XmConst char _XmSosfUndo[] = "osfUndo" ;
_XmConst char _XmSosfUp[] = "osfUp" ;
_XmConst char _XmSoutputCreate[] = "outputCreate" ;
_XmConst char _XmSpacking[] = "packing" ;
_XmConst char _XmSpageDecrementCallback[] = "pageDecrementCallback" ;
_XmConst char _XmSpageIncrementCallback[] = "pageIncrementCallback" ;
_XmConst char _XmSpageIncrement[] = "pageIncrement" ;
_XmConst char _XmSpaneMaximum[] = "paneMaximum" ;
_XmConst char _XmSpaneMinimum[] = "paneMinimum" ;
_XmConst char _XmSpattern[] = "pattern" ;
_XmConst char _XmSpendingDelete[] = "pendingDelete" ;
_XmConst char _XmSpopupEnabled[] = "popupEnabled" ;
_XmConst char _XmSpositionIndex[] = "positionIndex" ;
_XmConst char _XmSpostFromButton[] = "postFromButton" ;
_XmConst char _XmSpostFromCount[] = "postFromCount" ;
_XmConst char _XmSpostFromList[] = "postFromList" ;
_XmConst char _XmSpreeditType[] = "preeditType" ;
_XmConst char _XmSprocessingDirection[] = "processingDirection" ;
_XmConst char _XmSpromptString[] = "promptString" ;
_XmConst char _XmSprotocolCallback[] = "protocolCallback" ;
_XmConst char _XmSpushButtonEnabled[] = "pushButtonEnabled" ;
_XmConst char _XmSpushButton[] = "pushButton" ;
_XmConst char _XmSqualifySearchDataProc[] = "qualifySearchDataProc" ;
_XmConst char _XmSradioAlwaysOne[] = "radioAlwaysOne" ;
_XmConst char _XmSradioBehavior[] = "radioBehavior" ;
_XmConst char _XmSradioButton[] = "radioButton" ;
_XmConst char _XmSrealizeCallback[] = "realizeCallback" ;
_XmConst char _XmSrecomputeSize[] = "recomputeSize" ;
_XmConst char _XmSrectangles[] = "rectangles" ;
_XmConst char _XmSrefigureMode[] = "refigureMode" ;
_XmConst char _XmSrepeatDelay[] = "repeatDelay" ;
_XmConst char _XmSresizable[] = "resizable" ;
_XmConst char _XmSresizeCallback[] = "resizeCallback" ;
_XmConst char _XmSresizeHeight[] = "resizeHeight" ;
_XmConst char _XmSresizePolicy[] = "resizePolicy" ;
_XmConst char _XmSresizeWidth[] = "resizeWidth" ;
_XmConst char _XmSrightAttachment[] = "rightAttachment" ;
_XmConst char _XmSrightOffset[] = "rightOffset" ;
_XmConst char _XmSrightPosition[] = "rightPosition" ;
_XmConst char _XmSrightWidget[] = "rightWidget" ;
_XmConst char _XmSrowColumnType[] = "rowColumnType" ;
_XmConst char _XmSrows[] = "rows" ;
_XmConst char _XmSrubberPositioning[] = "rubberPositioning" ;
_XmConst char _XmSsashHeight[] = "sashHeight" ;
_XmConst char _XmSsashIndent[] = "sashIndent" ;
_XmConst char _XmSsashShadowThickness[] = "sashShadowThickness" ;
_XmConst char _XmSsashWidth[] = "sashWidth" ;
_XmConst char _XmSscaleHeight[] = "scaleHeight" ;
_XmConst char _XmSscaleMultiple[] = "scaleMultiple" ;
_XmConst char _XmSscaleWidth[] = "scaleWidth" ;
_XmConst char _XmSscrollBarDisplayPolicy[] = "scrollBarDisplayPolicy" ;
_XmConst char _XmSscrollBarPlacement[] = "scrollBarPlacement" ;
_XmConst char _XmSscrollHorizontal[] = "scrollHorizontal" ;
_XmConst char _XmSscrollLeftSide[] = "scrollLeftSide" ;
_XmConst char _XmSscrollTopSide[] = "scrollTopSide" ;
_XmConst char _XmSscrollVertical[] = "scrollVertical" ;
_XmConst char _XmSscrolledWindowMarginHeight[] = "scrolledWindowMarginHeight" ;
_XmConst char _XmSscrolledWindowMarginWidth[] = "scrolledWindowMarginWidth" ;
_XmConst char _XmSscrollingPolicy[] = "scrollingPolicy" ;
_XmConst char _XmSselectColor[] = "selectColor" ;
_XmConst char _XmSselectInsensitivePixmap[] = "selectInsensitivePixmap" ;
_XmConst char _XmSselectPixmap[] = "selectPixmap" ;
_XmConst char _XmSselectThreshold[] = "selectThreshold" ;
_XmConst char _XmSselectedItemCount[] = "selectedItemCount" ;
_XmConst char _XmSselectedItems[] = "selectedItems" ;
_XmConst char _XmSselectionArrayCount[] = "selectionArrayCount" ;
_XmConst char _XmSselectionLabelString[] = "selectionLabelString" ;
_XmConst char _XmSselectionPolicy[] = "selectionPolicy" ;
_XmConst char _XmSseparatorOn[] = "separatorOn" ;
_XmConst char _XmSseparatorType[] = "separatorType" ;
_XmConst char _XmSseparator[] = "separator" ;
_XmConst char _XmSset[] = "set" ;
_XmConst char _XmSshadowThickness[] = "shadowThickness" ;
_XmConst char _XmSshadowType[] = "shadowType" ;
_XmConst char _XmSshadow[] = "shadow" ;
_XmConst char _XmSshellUnitType[] = "shellUnitType" ;
_XmConst char _XmSshowArrows[] = "showArrows" ;
_XmConst char _XmSshowAsDefault[] = "showAsDefault" ;
_XmConst char _XmSshowSeparator[] = "showSeparator" ;
_XmConst char _XmSshowValue[] = "showValue" ;
_XmConst char _XmSsimpleCallback[] = "simpleCallback" ;
_XmConst char _XmSsingleSelectionCallback[] = "singleSelectionCallback" ;
_XmConst char _XmSsingleSeparator[] = "singleSeparator" ;
_XmConst char _XmSsizePolicy[] = "sizePolicy" ;
_XmConst char _XmSskipAdjust[] = "skipAdjust" ;
_XmConst char _XmSsliderSize[] = "sliderSize" ;
_XmConst char _XmSsourceCursorIcon[] = "sourceCursorIcon" ;
_XmConst char _XmSsourceIsExternal[] = "sourceIsExternal" ;
_XmConst char _XmSsourcePixmapIcon[] = "sourcePixmapIcon" ;
_XmConst char _XmSsourceWidget[] = "sourceWidget" ;
_XmConst char _XmSsourceWindow[] = "sourceWindow" ;
_XmConst char _XmSsource[] = "source" ;
_XmConst char _XmSspacing[] = "spacing" ;
_XmConst char _XmSstartTime[] = "startTime" ;
_XmConst char _XmSstateCursorIcon[] = "stateCursorIcon" ;
_XmConst char _XmSstringDirection[] = "stringDirection" ;
_XmConst char _XmSsubMenuId[] = "subMenuId" ;
_XmConst char _XmSsymbolPixmap[] = "symbolPixmap" ;
_XmConst char _XmStearOffMenuActivateCallback[] = "tearOffMenuActivateCallback" ;
_XmConst char _XmStearOffMenuDeactivateCallback[] = "tearOffMenuDeactivateCallback" ;
_XmConst char _XmStearOffModel[] = "tearOffModel" ;
_XmConst char _XmStextAccelerators[] = "textAccelerators" ;
_XmConst char _XmStextColumns[] = "textColumns" ;
_XmConst char _XmStextFontList[] = "textFontList" ;
_XmConst char _XmStextString[] = "textString" ;
_XmConst char _XmStextTranslations[] = "textTranslations" ;
_XmConst char _XmStextValue[] = "textValue" ;
_XmConst char _XmStitleString[] = "titleString" ;
_XmConst char _XmStoBottomCallback[] = "toBottomCallback" ;
_XmConst char _XmStoPositionCallback[] = "toPositionCallback" ;
_XmConst char _XmStoTopCallback[] = "toTopCallback" ;
_XmConst char _XmStopAttachment[] = "topAttachment" ;
_XmConst char _XmStopCharacter[] = "topCharacter" ;
_XmConst char _XmStopItemPosition[] = "topItemPosition" ;
_XmConst char _XmStopLevelEnterCallback[] = "topLevelEnterCallback" ;
_XmConst char _XmStopLevelLeaveCallback[] = "topLevelLeaveCallback" ;
_XmConst char _XmStopOffset[] = "topOffset" ;
_XmConst char _XmStopPosition[] = "topPosition" ;
_XmConst char _XmStopShadowColor[] = "topShadowColor" ;
_XmConst char _XmStopShadowPixmap[] = "topShadowPixmap" ;
_XmConst char _XmStopWidget[] = "topWidget" ;
_XmConst char _XmStransferProc[] = "transferProc" ;
_XmConst char _XmStransferStatus[] = "transferStatus" ;
_XmConst char _XmStraversalCallback[] = "traversalCallback" ;
_XmConst char _XmStraversalOn[] = "traversalOn" ;
_XmConst char _XmStraversalType[] = "traversalType" ;
_XmConst char _XmStraverseObscuredCallback[] = "traverseObscuredCallback" ;
_XmConst char _XmStreeUpdateProc[] = "treeUpdateProc" ;
_XmConst char _XmStroughColor[] = "troughColor" ;
_XmConst char _XmSunitType[] = "unitType" ;
_XmConst char _XmSunmapCallback[] = "unmapCallback" ;
_XmConst char _XmSunpostBehavior[] = "unpostBehavior" ;
_XmConst char _XmSunselectPixmap[] = "unselectPixmap" ;
_XmConst char _XmSupdateSliderSize[] = "updateSliderSize" ;
_XmConst char _XmSuseAsyncGeometry[] = "useAsyncGeometry" ;
_XmConst char _XmSuserData[] = "userData" ;
_XmConst char _XmSvalidCursorForeground[] = "validCursorForeground" ;
_XmConst char _XmSvalueChangedCallback[] = "valueChangedCallback" ;
_XmConst char _XmSvalueWcs[] = "valueWcs" ;
_XmConst char _XmSverifyBell[] = "verifyBell" ;
_XmConst char _XmSverticalFontUnit[] = "verticalFontUnit" ;
_XmConst char _XmSverticalScrollBar[] = "verticalScrollBar" ;
_XmConst char _XmSverticalSpacing[] = "verticalSpacing" ;
_XmConst char _XmSvisibleItemCount[] = "visibleItemCount" ;
_XmConst char _XmSvisibleWhenOff[] = "visibleWhenOff" ;
_XmConst char _XmSvisualPolicy[] = "visualPolicy" ;
_XmConst char _XmSwhichButton[] = "whichButton" ;
_XmConst char _XmSwordWrap[] = "wordWrap" ;
_XmConst char _XmSworkWindow[] = "workWindow" ;

/* Exceptions to the naming convention:
 */
_XmConst char _XmSEMPTY_STRING[] = "" ;
_XmConst char _XmSCFONTLIST_DEFAULT_TAG_STRING[] = "FONTLIST_DEFAULT_TAG_STRING" ;
_XmConst char _XmSCISO8859_DASH_1[] = "ISO8859-1" ;
_XmConst char _XmSCXmFONTLIST_DEFAULT_TAG_STRING[] = "XmFONTLIST_DEFAULT_TAG_STRING" ;
