/*
**	This file is automatically generated.  Do not edit it by hand.
**/

/*
 * Bit vectors for each child. The entries in the vector correspond
 * to each class.
 */

/* sym_k_Xm_Apply_child */
static unsigned char child_class_vec1[] =
  {
  0, 0, _BIT_MASK(sym_k_XmCommand_object) |
  _BIT_MASK(sym_k_XmCommandDialog_object) |
  0, _BIT_MASK(sym_k_XmFileSelectionBox_object) |
  _BIT_MASK(sym_k_XmFileSelectionDialog_object) |
  0, 0, 0, _BIT_MASK(sym_k_XmPromptDialog_object) |
  0, 0, _BIT_MASK(sym_k_XmSelectionBox_object) |
  _BIT_MASK(sym_k_XmSelectionDialog_object) |
  0, 0, 0, 0};

/* sym_k_Xm_Arrow_child */
static unsigned char child_class_vec2[] =
  {
  0, 0, 0, _BIT_MASK(sym_k_XmDropDown_object) |
  0, 0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_Xm_Cancel_child */
static unsigned char child_class_vec3[] =
  {
  0, 0, _BIT_MASK(sym_k_XmCommand_object) |
  _BIT_MASK(sym_k_XmCommandDialog_object) |
  0, _BIT_MASK(sym_k_XmErrorDialog_object) |
  _BIT_MASK(sym_k_XmFileSelectionBox_object) |
  _BIT_MASK(sym_k_XmFileSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmInformationDialog_object) |
  0, _BIT_MASK(sym_k_XmMessageBox_object) |
  _BIT_MASK(sym_k_XmMessageDialog_object) |
  0, _BIT_MASK(sym_k_XmPromptDialog_object) |
  0, _BIT_MASK(sym_k_XmQuestionDialog_object) |
  0, _BIT_MASK(sym_k_XmSelectionBox_object) |
  _BIT_MASK(sym_k_XmSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmTemplateDialog_object) |
  0, _BIT_MASK(sym_k_XmWarningDialog_object) |
  _BIT_MASK(sym_k_XmWorkingDialog_object) |
  0, 0};

/* sym_k_Xm_ColorListToggle_child */
static unsigned char child_class_vec4[] =
  {
  0, 0, _BIT_MASK(sym_k_XmColorSelector_object) |
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_Xm_ColorSlidersToggle_child */
static unsigned char child_class_vec5[] =
  {
  0, 0, _BIT_MASK(sym_k_XmColorSelector_object) |
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_Xm_Dir_child */
static unsigned char child_class_vec6[] =
  {
  0, 0, 0, _BIT_MASK(sym_k_XmFileSelectionBox_object) |
  _BIT_MASK(sym_k_XmFileSelectionDialog_object) |
  0, 0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_Xm_DirList_child */
static unsigned char child_class_vec7[] =
  {
  0, 0, 0, _BIT_MASK(sym_k_XmFileSelectionBox_object) |
  _BIT_MASK(sym_k_XmFileSelectionDialog_object) |
  0, 0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_Xm_Filter_child */
static unsigned char child_class_vec8[] =
  {
  0, 0, 0, _BIT_MASK(sym_k_XmFileSelectionBox_object) |
  _BIT_MASK(sym_k_XmFileSelectionDialog_object) |
  0, 0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_Xm_FilterLabel_child */
static unsigned char child_class_vec9[] =
  {
  0, 0, 0, _BIT_MASK(sym_k_XmFileSelectionBox_object) |
  _BIT_MASK(sym_k_XmFileSelectionDialog_object) |
  0, 0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_Xm_FilterText_child */
static unsigned char child_class_vec10[] =
  {
  0, 0, 0, _BIT_MASK(sym_k_XmFileSelectionBox_object) |
  _BIT_MASK(sym_k_XmFileSelectionDialog_object) |
  0, 0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_Xm_Find_child */
static unsigned char child_class_vec11[] =
  {
  0, 0, 0, 0, 0, _BIT_MASK(sym_k_XmMultiList_object) |
  0, 0, 0, 0, 0, 0, 0};

/* sym_k_Xm_FindText_child */
static unsigned char child_class_vec12[] =
  {
  0, 0, 0, 0, 0, _BIT_MASK(sym_k_XmMultiList_object) |
  0, 0, 0, 0, 0, 0, 0};

/* sym_k_Xm_Help_child */
static unsigned char child_class_vec13[] =
  {
  0, 0, _BIT_MASK(sym_k_XmCommand_object) |
  _BIT_MASK(sym_k_XmCommandDialog_object) |
  0, _BIT_MASK(sym_k_XmErrorDialog_object) |
  _BIT_MASK(sym_k_XmFileSelectionBox_object) |
  _BIT_MASK(sym_k_XmFileSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmInformationDialog_object) |
  0, _BIT_MASK(sym_k_XmMessageBox_object) |
  _BIT_MASK(sym_k_XmMessageDialog_object) |
  0, _BIT_MASK(sym_k_XmPromptDialog_object) |
  0, _BIT_MASK(sym_k_XmQuestionDialog_object) |
  0, _BIT_MASK(sym_k_XmSelectionBox_object) |
  _BIT_MASK(sym_k_XmSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmTemplateDialog_object) |
  0, _BIT_MASK(sym_k_XmWarningDialog_object) |
  _BIT_MASK(sym_k_XmWorkingDialog_object) |
  0, 0};

/* sym_k_Xm_HorScrollBar_child */
static unsigned char child_class_vec14[] =
  {
  0, 0, 0, 0, 0, _BIT_MASK(sym_k_XmMainWindow_object) |
  0, 0, 0, _BIT_MASK(sym_k_XmScrolledList_object) |
  _BIT_MASK(sym_k_XmScrolledText_object) |
  _BIT_MASK(sym_k_XmScrolledWindow_object) |
  0, 0, 0, 0};

/* sym_k_Xm_Items_child */
static unsigned char child_class_vec15[] =
  {
  0, 0, _BIT_MASK(sym_k_XmCommand_object) |
  _BIT_MASK(sym_k_XmCommandDialog_object) |
  0, _BIT_MASK(sym_k_XmFileSelectionBox_object) |
  _BIT_MASK(sym_k_XmFileSelectionDialog_object) |
  0, 0, 0, _BIT_MASK(sym_k_XmPromptDialog_object) |
  0, 0, _BIT_MASK(sym_k_XmSelectionBox_object) |
  _BIT_MASK(sym_k_XmSelectionDialog_object) |
  0, 0, 0, 0};

/* sym_k_Xm_ItemsList_child */
static unsigned char child_class_vec16[] =
  {
  0, 0, _BIT_MASK(sym_k_XmCommand_object) |
  _BIT_MASK(sym_k_XmCommandDialog_object) |
  0, _BIT_MASK(sym_k_XmFileSelectionBox_object) |
  _BIT_MASK(sym_k_XmFileSelectionDialog_object) |
  0, 0, 0, _BIT_MASK(sym_k_XmPromptDialog_object) |
  0, 0, _BIT_MASK(sym_k_XmSelectionBox_object) |
  _BIT_MASK(sym_k_XmSelectionDialog_object) |
  0, 0, 0, 0};

/* sym_k_Xm_Label_child */
static unsigned char child_class_vec17[] =
  {
  0, 0, 0, _BIT_MASK(sym_k_XmDropDown_object) |
  0, 0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_Xm_List_child */
static unsigned char child_class_vec18[] =
  {
  0, 0, _BIT_MASK(sym_k_XmColorSelector_object) |
  _BIT_MASK(sym_k_XmComboBox_object) |
  0, _BIT_MASK(sym_k_XmDropDown_object) |
  0, 0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_Xm_Message_child */
static unsigned char child_class_vec19[] =
  {
  0, 0, 0, _BIT_MASK(sym_k_XmErrorDialog_object) |
  0, _BIT_MASK(sym_k_XmInformationDialog_object) |
  0, _BIT_MASK(sym_k_XmMessageBox_object) |
  _BIT_MASK(sym_k_XmMessageDialog_object) |
  0, 0, _BIT_MASK(sym_k_XmQuestionDialog_object) |
  0, 0, _BIT_MASK(sym_k_XmTemplateDialog_object) |
  0, _BIT_MASK(sym_k_XmWarningDialog_object) |
  _BIT_MASK(sym_k_XmWorkingDialog_object) |
  0, 0};

/* sym_k_Xm_OK_child */
static unsigned char child_class_vec20[] =
  {
  0, 0, _BIT_MASK(sym_k_XmCommand_object) |
  _BIT_MASK(sym_k_XmCommandDialog_object) |
  0, _BIT_MASK(sym_k_XmErrorDialog_object) |
  _BIT_MASK(sym_k_XmFileSelectionBox_object) |
  _BIT_MASK(sym_k_XmFileSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmInformationDialog_object) |
  0, _BIT_MASK(sym_k_XmMessageBox_object) |
  _BIT_MASK(sym_k_XmMessageDialog_object) |
  0, _BIT_MASK(sym_k_XmPromptDialog_object) |
  0, _BIT_MASK(sym_k_XmQuestionDialog_object) |
  0, _BIT_MASK(sym_k_XmSelectionBox_object) |
  _BIT_MASK(sym_k_XmSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmTemplateDialog_object) |
  0, _BIT_MASK(sym_k_XmWarningDialog_object) |
  _BIT_MASK(sym_k_XmWorkingDialog_object) |
  0, 0};

/* sym_k_Xm_OptionButton_child */
static unsigned char child_class_vec21[] =
  {
  0, 0, 0, 0, 0, 0, _BIT_MASK(sym_k_XmOptionMenu_object) |
  0, 0, 0, 0, 0, 0};

/* sym_k_Xm_OptionLabel_child */
static unsigned char child_class_vec22[] =
  {
  0, 0, 0, 0, 0, 0, _BIT_MASK(sym_k_XmOptionMenu_object) |
  0, 0, 0, 0, 0, 0};

/* sym_k_Xm_Selection_child */
static unsigned char child_class_vec23[] =
  {
  0, 0, _BIT_MASK(sym_k_XmCommand_object) |
  _BIT_MASK(sym_k_XmCommandDialog_object) |
  0, _BIT_MASK(sym_k_XmFileSelectionBox_object) |
  _BIT_MASK(sym_k_XmFileSelectionDialog_object) |
  0, 0, 0, _BIT_MASK(sym_k_XmPromptDialog_object) |
  0, 0, _BIT_MASK(sym_k_XmSelectionBox_object) |
  _BIT_MASK(sym_k_XmSelectionDialog_object) |
  0, 0, 0, 0};

/* sym_k_Xm_Separator_child */
static unsigned char child_class_vec24[] =
  {
  0, 0, _BIT_MASK(sym_k_XmCommand_object) |
  _BIT_MASK(sym_k_XmCommandDialog_object) |
  0, _BIT_MASK(sym_k_XmErrorDialog_object) |
  _BIT_MASK(sym_k_XmFileSelectionBox_object) |
  _BIT_MASK(sym_k_XmFileSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmInformationDialog_object) |
  0, _BIT_MASK(sym_k_XmMessageBox_object) |
  _BIT_MASK(sym_k_XmMessageDialog_object) |
  0, _BIT_MASK(sym_k_XmPromptDialog_object) |
  0, _BIT_MASK(sym_k_XmQuestionDialog_object) |
  0, _BIT_MASK(sym_k_XmSelectionBox_object) |
  _BIT_MASK(sym_k_XmSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmTemplateDialog_object) |
  0, _BIT_MASK(sym_k_XmWarningDialog_object) |
  _BIT_MASK(sym_k_XmWorkingDialog_object) |
  0, 0};

/* sym_k_Xm_Separator1_child */
static unsigned char child_class_vec25[] =
  {
  0, 0, 0, 0, 0, _BIT_MASK(sym_k_XmMainWindow_object) |
  0, 0, 0, 0, 0, 0, 0};

/* sym_k_Xm_Separator2_child */
static unsigned char child_class_vec26[] =
  {
  0, 0, 0, 0, 0, _BIT_MASK(sym_k_XmMainWindow_object) |
  0, 0, 0, 0, 0, 0, 0};

/* sym_k_Xm_Separator3_child */
static unsigned char child_class_vec27[] =
  {
  0, 0, 0, 0, 0, _BIT_MASK(sym_k_XmMainWindow_object) |
  0, 0, 0, 0, 0, 0, 0};

/* sym_k_Xm_Symbol_child */
static unsigned char child_class_vec28[] =
  {
  0, 0, 0, _BIT_MASK(sym_k_XmErrorDialog_object) |
  0, _BIT_MASK(sym_k_XmInformationDialog_object) |
  0, _BIT_MASK(sym_k_XmMessageBox_object) |
  _BIT_MASK(sym_k_XmMessageDialog_object) |
  0, 0, _BIT_MASK(sym_k_XmQuestionDialog_object) |
  0, 0, _BIT_MASK(sym_k_XmTemplateDialog_object) |
  0, _BIT_MASK(sym_k_XmWarningDialog_object) |
  _BIT_MASK(sym_k_XmWorkingDialog_object) |
  0, 0};

/* sym_k_Xm_TearOffControl_child */
static unsigned char child_class_vec29[] =
  {
  0, 0, 0, 0, 0, 0, _BIT_MASK(sym_k_XmPopupMenu_object) |
  _BIT_MASK(sym_k_XmPulldownMenu_object) |
  0, 0, 0, 0, 0, 0};

/* sym_k_Xm_Text_child */
static unsigned char child_class_vec30[] =
  {
  0, 0, _BIT_MASK(sym_k_XmComboBox_object) |
  _BIT_MASK(sym_k_XmCommand_object) |
  _BIT_MASK(sym_k_XmCommandDialog_object) |
  0, _BIT_MASK(sym_k_XmDropDown_object) |
  _BIT_MASK(sym_k_XmFileSelectionBox_object) |
  _BIT_MASK(sym_k_XmFileSelectionDialog_object) |
  0, 0, 0, _BIT_MASK(sym_k_XmPromptDialog_object) |
  0, 0, _BIT_MASK(sym_k_XmSelectionBox_object) |
  _BIT_MASK(sym_k_XmSelectionDialog_object) |
  0, 0, 0, 0};

/* sym_k_Xm_TextField_child */
static unsigned char child_class_vec31[] =
  {
  0, 0, _BIT_MASK(sym_k_XmComboBox_object) |
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_Xm_Title_child */
static unsigned char child_class_vec32[] =
  {
  0, 0, 0, 0, 0, _BIT_MASK(sym_k_XmMultiList_object) |
  0, 0, _BIT_MASK(sym_k_XmScale_object) |
  0, 0, 0, 0, 0};

/* sym_k_Xm_VertScrollBar_child */
static unsigned char child_class_vec33[] =
  {
  0, 0, 0, 0, 0, _BIT_MASK(sym_k_XmMainWindow_object) |
  0, 0, 0, _BIT_MASK(sym_k_XmScrolledList_object) |
  _BIT_MASK(sym_k_XmScrolledText_object) |
  _BIT_MASK(sym_k_XmScrolledWindow_object) |
  0, 0, 0, 0};

/*
 * Table of bit vectors accessed by sym_k_..._child
 */
static unsigned char *allowed_child_table_vec[] =
  {
  NULL,	/* UNUSED */
  child_class_vec1,
  child_class_vec2,
  child_class_vec3,
  child_class_vec4,
  child_class_vec5,
  child_class_vec6,
  child_class_vec7,
  child_class_vec8,
  child_class_vec9,
  child_class_vec10,
  child_class_vec11,
  child_class_vec12,
  child_class_vec13,
  child_class_vec14,
  child_class_vec15,
  child_class_vec16,
  child_class_vec17,
  child_class_vec18,
  child_class_vec19,
  child_class_vec20,
  child_class_vec21,
  child_class_vec22,
  child_class_vec23,
  child_class_vec24,
  child_class_vec25,
  child_class_vec26,
  child_class_vec27,
  child_class_vec28,
  child_class_vec29,
  child_class_vec30,
  child_class_vec31,
  child_class_vec32,
  child_class_vec33,
  };
externaldef(uil_sym_glbl) unsigned char **allowed_child_table =
		allowed_child_table_vec;
