/*
**	This file is automatically generated.  Do not edit it by hand.
**/

/*
 * Enumeration value vectors for each enumeration set
 */


static unsigned short int enum_value_vec1[] =
  {
    73,
    76,
    72,
  };

static unsigned short int enum_value_vec2[] =
  {
    98,
    95,
    96,
    97,
  };

static unsigned short int enum_value_vec3[] =
  {
    86,
    83,
    93,
    88,
    87,
  };

static unsigned short int enum_value_vec4[] =
  {
    94,
    89,
  };

static unsigned short int enum_value_vec5[] =
  {
    91,
    90,
    84,
    92,
    85,
  };

static unsigned short int enum_value_vec6[] =
  {
    102,
    101,
    103,
    107,
    104,
    105,
    106,
  };

static unsigned short int enum_value_vec7[] =
  {
    249,
    114,
  };

static unsigned short int enum_value_vec8[] =
  {
    110,
    109,
  };

static unsigned short int enum_value_vec9[] =
  {
    252,
    111,
    40,
    62,
  };

static unsigned short int enum_value_vec10[] =
  {
    61,
    63,
    1,
  };

static unsigned short int enum_value_vec11[] =
  {
    330,
    332,
    285,
  };

static unsigned short int enum_value_vec12[] =
  {
    40,
    62,
  };

static unsigned short int enum_value_vec13[] =
  {
    290,
    288,
    289,
  };

static unsigned short int enum_value_vec14[] =
  {
    71,
    73,
    70,
    78,
    79,
  };

static unsigned short int enum_value_vec15[] =
  {
    225,
    354,
  };

static unsigned short int enum_value_vec16[] =
  {
    127,
    165,
    166,
  };

static unsigned short int enum_value_vec17[] =
  {
    128,
    129,
  };

static unsigned short int enum_value_vec18[] =
  {
    348,
    337,
    347,
    338,
    345,
    342,
    341,
    349,
    340,
    339,
    343,
    344,
    346,
  };

static unsigned short int enum_value_vec19[] =
  {
    390,
    389,
  };

static unsigned short int enum_value_vec20[] =
  {
    322,
  };

static unsigned short int enum_value_vec21[] =
  {
    137,
    139,
    143,
    146,
    148,
    153,
    154,
  };

static unsigned short int enum_value_vec22[] =
  {
    134,
    391,
    164,
  };

static unsigned short int enum_value_vec23[] =
  {
    155,
    149,
    147,
    159,
    142,
    136,
  };

static unsigned short int enum_value_vec24[] =
  {
    150,
    152,
    159,
    141,
    140,
    144,
    145,
    151,
    157,
    158,
    156,
    138,
  };

static unsigned short int enum_value_vec25[] =
  {
    34,
    33,
    35,
  };

static unsigned short int enum_value_vec26[] =
  {
    4,
    5,
    6,
    3,
  };

static unsigned short int enum_value_vec27[] =
  {
    18,
    17,
    16,
    15,
    14,
  };

static unsigned short int enum_value_vec28[] =
  {
    12,
    11,
    10,
    8,
    9,
  };

static unsigned short int enum_value_vec29[] =
  {
    22,
    27,
    26,
  };

static unsigned short int enum_value_vec30[] =
  {
    32,
    20,
    19,
  };

static unsigned short int enum_value_vec31[] =
  {
    21,
    23,
  };

static unsigned short int enum_value_vec32[] =
  {
    7,
    13,
    2,
  };

static unsigned short int enum_value_vec33[] =
  {
    24,
    25,
  };

static unsigned short int enum_value_vec34[] =
  {
    30,
    31,
    28,
    29,
  };

static unsigned short int enum_value_vec35[] =
  {
    37,
    38,
    39,
    36,
  };

static unsigned short int enum_value_vec36[] =
  {
    326,
    172,
  };

static unsigned short int enum_value_vec37[] =
  {
    325,
    246,
  };

static unsigned short int enum_value_vec38[] =
  {
    218,
    328,
    80,
  };

static unsigned short int enum_value_vec39[] =
  {
    175,
    174,
    173,
  };

static unsigned short int enum_value_vec40[] =
  {
    192,
    190,
    191,
    189,
  };

static unsigned short int enum_value_vec41[] =
  {
    99,
    181,
    182,
    183,
  };

static unsigned short int enum_value_vec42[] =
  {
    186,
    188,
    187,
  };

static unsigned short int enum_value_vec43[] =
  {
    112,
    270,
    132,
    200,
  };

static unsigned short int enum_value_vec44[] =
  {
    218,
    328,
  };

static unsigned short int enum_value_vec45[] =
  {
    217,
    213,
    216,
    212,
    215,
    214,
  };

static unsigned short int enum_value_vec46[] =
  {
    258,
    260,
    262,
    261,
  };

static unsigned short int enum_value_vec47[] =
  {
    60,
    41,
  };

static unsigned short int enum_value_vec48[] =
  {
    276,
    277,
    210,
  };

static unsigned short int enum_value_vec49[] =
  {
    171,
    291,
  };

static unsigned short int enum_value_vec50[] =
  {
    336,
    279,
    280,
  };

static unsigned short int enum_value_vec51[] =
  {
    303,
    222,
    302,
    221,
    383,
    382,
    119,
    118,
    381,
    117,
    301,
    220,
    133,
  };

static unsigned short int enum_value_vec52[] =
  {
    263,
    331,
    135,
  };

static unsigned short int enum_value_vec53[] =
  {
    99,
    324,
    163,
    323,
    162,
    253,
  };

static unsigned short int enum_value_vec54[] =
  {
    131,
    395,
    299,
  };

static unsigned short int enum_value_vec55[] =
  {
    99,
    224,
    223,
  };

static unsigned short int enum_value_vec56[] =
  {
    295,
    211,
  };

static unsigned short int enum_value_vec57[] =
  {
    243,
    244,
  };

static unsigned short int enum_value_vec58[] =
  {
    45,
    46,
    50,
    51,
    48,
    49,
    47,
  };

static unsigned short int enum_value_vec59[] =
  {
    52,
    55,
    54,
    49,
    47,
    53,
  };

static unsigned short int enum_value_vec60[] =
  {
    57,
    58,
    59,
    56,
  };

static unsigned short int enum_value_vec61[] =
  {
    249,
    371,
    335,
    169,
  };

static unsigned short int enum_value_vec62[] =
  {
    274,
    226,
    241,
    334,
    275,
  };

static unsigned short int enum_value_vec63[] =
  {
    68,
    296,
  };

static unsigned short int enum_value_vec64[] =
  {
    254,
    396,
    198,
  };

static unsigned short int enum_value_vec65[] =
  {
    265,
    264,
  };

static unsigned short int enum_value_vec66[] =
  {
    126,
    170,
  };

static unsigned short int enum_value_vec67[] =
  {
    255,
    273,
    271,
    272,
  };

static unsigned short int enum_value_vec68[] =
  {
    219,
    180,
  };

static unsigned short int enum_value_vec69[] =
  {
    399,
    259,
  };

static unsigned short int enum_value_vec70[] =
  {
    293,
    294,
  };

static unsigned short int enum_value_vec71[] =
  {
    268,
    266,
    267,
    269,
  };

static unsigned short int enum_value_vec72[] =
  {
    233,
    230,
    231,
    232,
  };

static unsigned short int enum_value_vec73[] =
  {
    300,
    297,
    298,
  };

static unsigned short int enum_value_vec74[] =
  {
    398,
    235,
    238,
    237,
    236,
  };

static unsigned short int enum_value_vec75[] =
  {
    249,
    248,
    247,
    40,
    62,
  };

static unsigned short int enum_value_vec76[] =
  {
    100,
    333,
  };

static unsigned short int enum_value_vec77[] =
  {
    379,
    115,
    380,
    116,
  };

static unsigned short int enum_value_vec78[] =
  {
    199,
    397,
    130,
    239,
    305,
    306,
    256,
    124,
    193,
  };

static unsigned short int enum_value_vec79[] =
  {
    108,
    82,
  };

static unsigned short int enum_value_vec80[] =
  {
    250,
    69,
  };

static unsigned short int enum_value_vec81[] =
  {
    326,
    245,
    172,
    120,
  };

static unsigned short int enum_value_vec82[] =
  {
    227,
    229,
    228,
    384,
    385,
  };

static unsigned short int enum_value_vec83[] =
  {
    324,
    163,
    323,
    162,
    253,
    316,
    318,
    317,
    319,
  };

static unsigned short int enum_value_vec84[] =
  {
    320,
    321,
    316,
    318,
  };

static unsigned short int enum_value_vec85[] =
  {
    167,
    234,
    242,
    40,
    62,
  };

static unsigned short int enum_value_vec86[] =
  {
    249,
    168,
    376,
    304,
  };

static unsigned short int enum_value_vec87[] =
  {
    113,
    185,
    386,
    315,
  };

static unsigned short int enum_value_vec88[] =
  {
    327,
    375,
  };

static unsigned short int enum_value_vec89[] =
  {
    81,
    125,
    179,
  };

static unsigned short int enum_value_vec90[] =
  {
    197,
    196,
    195,
  };

static unsigned short int enum_value_vec91[] =
  {
    249,
    329,
    122,
  };

static unsigned short int enum_value_vec92[] =
  {
    249,
    194,
    121,
  };

static unsigned short int enum_value_vec93[] =
  {
    336,
    257,
  };

static unsigned short int enum_value_vec94[] =
  {
    351,
    352,
  };

static unsigned short int enum_value_vec95[] =
  {
    374,
    373,
  };

static unsigned short int enum_value_vec96[] =
  {
    351,
    352,
    353,
    350,
    133,
  };

static unsigned short int enum_value_vec97[] =
  {
    311,
    312,
    313,
    309,
    308,
    310,
  };

static unsigned short int enum_value_vec98[] =
  {
    209,
    208,
    203,
    204,
    205,
    206,
    207,
    40,
    62,
  };

static unsigned short int enum_value_vec99[] =
  {
    377,
    378,
  };

static unsigned short int enum_value_vec100[] =
  {
    394,
    314,
    202,
    40,
    62,
  };

static unsigned short int enum_value_vec101[] =
  {
    278,
    66,
    64,
    67,
    65,
    201,
    123,
    240,
    292,
    184,
  };

static unsigned short int enum_value_vec102[] =
  {
    393,
    392,
  };

static unsigned short int enum_value_vec103[] =
  {
    71,
    73,
    70,
    75,
    74,
  };

static unsigned short int enum_value_vec104[] =
  {
    307,
    251,
  };

static unsigned short int enum_value_vec105[] =
  {
    395,
    131,
  };

static unsigned short int enum_value_vec106[] =
  {
    72,
    73,
    76,
    77,
  };

static unsigned short int enum_value_vec107[] =
  {
    161,
    160,
  };

static unsigned short int enum_value_vec108[] =
  {
    178,
    176,
    177,
  };

static unsigned short int enum_value_vec109[] =
  {
    287,
    281,
    286,
    282,
    283,
    284,
  };

static unsigned short int enum_value_vec110[] =
  {
    370,
    369,
  };

static unsigned short int enum_value_vec111[] =
  {
    355,
    366,
    367,
  };

static unsigned short int enum_value_vec112[] =
  {
    372,
    363,
    358,
    368,
    357,
  };

static unsigned short int enum_value_vec113[] =
  {
    362,
    359,
    361,
    360,
  };

static unsigned short int enum_value_vec114[] =
  {
    365,
    364,
    356,
  };

static unsigned short int enum_value_vec115[] =
  {
    388,
    387,
    387,
  };

static unsigned short int enum_value_vec116[] =
  {
    44,
    43,
    42,
  };

/*
 * Enumeration set descriptor table
 */
static UilEnumSetDescDef enum_set_table_vec[] =
  {
    {0,NULL},
    {3,enum_value_vec1},
    {4,enum_value_vec2},
    {5,enum_value_vec3},
    {2,enum_value_vec4},
    {5,enum_value_vec5},
    {7,enum_value_vec6},
    {2,enum_value_vec7},
    {2,enum_value_vec8},
    {4,enum_value_vec9},
    {3,enum_value_vec10},
    {3,enum_value_vec11},
    {2,enum_value_vec12},
    {3,enum_value_vec13},
    {5,enum_value_vec14},
    {2,enum_value_vec15},
    {3,enum_value_vec16},
    {2,enum_value_vec17},
    {13,enum_value_vec18},
    {2,enum_value_vec19},
    {1,enum_value_vec20},
    {7,enum_value_vec21},
    {3,enum_value_vec22},
    {6,enum_value_vec23},
    {12,enum_value_vec24},
    {3,enum_value_vec25},
    {4,enum_value_vec26},
    {5,enum_value_vec27},
    {5,enum_value_vec28},
    {3,enum_value_vec29},
    {3,enum_value_vec30},
    {2,enum_value_vec31},
    {3,enum_value_vec32},
    {2,enum_value_vec33},
    {4,enum_value_vec34},
    {4,enum_value_vec35},
    {2,enum_value_vec36},
    {2,enum_value_vec37},
    {3,enum_value_vec38},
    {3,enum_value_vec39},
    {4,enum_value_vec40},
    {4,enum_value_vec41},
    {3,enum_value_vec42},
    {4,enum_value_vec43},
    {2,enum_value_vec44},
    {6,enum_value_vec45},
    {4,enum_value_vec46},
    {2,enum_value_vec47},
    {3,enum_value_vec48},
    {2,enum_value_vec49},
    {3,enum_value_vec50},
    {13,enum_value_vec51},
    {3,enum_value_vec52},
    {6,enum_value_vec53},
    {3,enum_value_vec54},
    {3,enum_value_vec55},
    {2,enum_value_vec56},
    {2,enum_value_vec57},
    {7,enum_value_vec58},
    {6,enum_value_vec59},
    {4,enum_value_vec60},
    {4,enum_value_vec61},
    {5,enum_value_vec62},
    {2,enum_value_vec63},
    {3,enum_value_vec64},
    {2,enum_value_vec65},
    {2,enum_value_vec66},
    {4,enum_value_vec67},
    {2,enum_value_vec68},
    {2,enum_value_vec69},
    {2,enum_value_vec70},
    {4,enum_value_vec71},
    {4,enum_value_vec72},
    {3,enum_value_vec73},
    {5,enum_value_vec74},
    {5,enum_value_vec75},
    {2,enum_value_vec76},
    {4,enum_value_vec77},
    {9,enum_value_vec78},
    {2,enum_value_vec79},
    {2,enum_value_vec80},
    {4,enum_value_vec81},
    {5,enum_value_vec82},
    {9,enum_value_vec83},
    {4,enum_value_vec84},
    {5,enum_value_vec85},
    {4,enum_value_vec86},
    {4,enum_value_vec87},
    {2,enum_value_vec88},
    {3,enum_value_vec89},
    {3,enum_value_vec90},
    {3,enum_value_vec91},
    {3,enum_value_vec92},
    {2,enum_value_vec93},
    {2,enum_value_vec94},
    {2,enum_value_vec95},
    {5,enum_value_vec96},
    {6,enum_value_vec97},
    {9,enum_value_vec98},
    {2,enum_value_vec99},
    {5,enum_value_vec100},
    {10,enum_value_vec101},
    {2,enum_value_vec102},
    {5,enum_value_vec103},
    {2,enum_value_vec104},
    {2,enum_value_vec105},
    {4,enum_value_vec106},
    {2,enum_value_vec107},
    {3,enum_value_vec108},
    {6,enum_value_vec109},
    {2,enum_value_vec110},
    {3,enum_value_vec111},
    {5,enum_value_vec112},
    {4,enum_value_vec113},
    {3,enum_value_vec114},
    {3,enum_value_vec115},
    {3,enum_value_vec116},
  };
externaldef(uil_sym_glbl) UilEnumSetDescDef *enum_set_table =
		enum_set_table_vec;
/*
 * Enumeration set table, accessed by sym_k_..._arg code. Each non-zero entry
 * is the sym_k_..._enumset code for the argument's enumeration set.
 */
static unsigned short int argument_enumset_table_vec[] =
  {
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    25,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    26,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    27,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    28,
    0,
    0,
    0,
    0,
    0,
    29,
    0,
    33,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    32,
    0,
    0,
    0,
    0,
    0,
    0,
    34,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    35,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    1,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    2,
    3,
    4,
    5,
    0,
    0,
    7,
    0,
    8,
    0,
    0,
    0,
    9,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    11,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    6,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    1,
    0,
    13,
    42,
    14,
    0,
    0,
    0,
    0,
    15,
    0,
    0,
    0,
    0,
    16,
    0,
    0,
    0,
    17,
    115,
    0,
    19,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    5,
    0,
    0,
    21,
    0,
    106,
    0,
    0,
    108,
    0,
    0,
    22,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    23,
    0,
    24,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    107,
    0,
    37,
    0,
    0,
    0,
    1,
    0,
    0,
    0,
    0,
    106,
    0,
    0,
    0,
    0,
    0,
    0,
    103,
    38,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    39,
    0,
    0,
    40,
    108,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    41,
    0,
    0,
    0,
    0,
    42,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    45,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    98,
    0,
    46,
    0,
    0,
    0,
    47,
    0,
    0,
    0,
    0,
    48,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    49,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    50,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    51,
    52,
    6,
    0,
    0,
    0,
    0,
    0,
    0,
    116,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    54,
    0,
    0,
    0,
    55,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    56,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    1,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    57,
    0,
    58,
    59,
    60,
    0,
    61,
    0,
    0,
    0,
    0,
    0,
    0,
    43,
    62,
    0,
    0,
    0,
    0,
    63,
    0,
    0,
    0,
    0,
    64,
    0,
    65,
    0,
    0,
    20,
    66,
    0,
    67,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    109,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    68,
    69,
    70,
    0,
    0,
    71,
    72,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    73,
    0,
    0,
    0,
    6,
    0,
    0,
    0,
    74,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    76,
    77,
    0,
    0,
    0,
    0,
    78,
    0,
    0,
    79,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    80,
    81,
    82,
    0,
    0,
    83,
    100,
    0,
    84,
    101,
    85,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    75,
    0,
    0,
    86,
    0,
    0,
    87,
    88,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    89,
    90,
    91,
    92,
    93,
    0,
    0,
    53,
    94,
    0,
    0,
    1,
    0,
    0,
    0,
    0,
    110,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    111,
    0,
    112,
    109,
    0,
    0,
    113,
    94,
    114,
    0,
    95,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    99,
    0,
    0,
    0,
    0,
    6,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    53,
    0,
    101,
    102,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    44,
    0,
    0,
    0,
    104,
    105,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    18,
  };
externaldef(uil_sym_glbl) unsigned short int *argument_enumset_table =
		argument_enumset_table_vec;
/*
 * Enumeration value table, accessed by sym_k_..._enumval code. Each entry is
 * the actual value associated with the code.
 */
static int enumval_values_table_vec[] =
  {
  0,
  Always,
  DtHELP_AS_NEEDED_SCROLLBARS,
  DtHELP_EXECUTE_ALL,
  DtHELP_EXECUTE_NONE,
  DtHELP_EXECUTE_QUERY_ALL,
  DtHELP_EXECUTE_QUERY_UNALIASED,
  DtHELP_NO_SCROLLBARS,
  DtHELP_PAPERSIZE_A4,
  DtHELP_PAPERSIZE_B5,
  DtHELP_PAPERSIZE_EXECUTIVE,
  DtHELP_PAPERSIZE_LEGAL,
  DtHELP_PAPERSIZE_LETTER,
  DtHELP_STATIC_SCROLLBARS,
  DtHELP_TYPE_DYNAMIC_STRING,
  DtHELP_TYPE_FILE,
  DtHELP_TYPE_MAN_PAGE,
  DtHELP_TYPE_STRING,
  DtHELP_TYPE_TOPIC,
  DtLONG_NAME,
  DtMEDIUM_NAME,
  DtPRINT_CLOSE_CONNECTION,
  DtPRINT_NO_DESTINATION,
  DtPRINT_RELEASE_CONNECTION,
  DtPRINT_SETUP_PLAIN,
  DtPRINT_SETUP_XP,
  DtPRINT_TO_FILE,
  DtPRINT_TO_PRINTER,
  DtSHADOW_ETCHED_IN,
  DtSHADOW_ETCHED_OUT,
  DtSHADOW_IN,
  DtSHADOW_OUT,
  DtSHORT_NAME,
  DtTERM_CHAR_CURSOR_BAR,
  DtTERM_CHAR_CURSOR_BOX,
  DtTERM_CHAR_CURSOR_INVISIBLE,
  DtWORK_AREA_BOTTOM,
  DtWORK_AREA_NONE,
  DtWORK_AREA_TOP,
  DtWORK_AREA_TOP_AND_BOTTOM,
  FALSE,
  IconicState,
  LineDoubleDash,
  LineOnOffDash,
  LineSolid,
  MWM_DECOR_ALL,
  MWM_DECOR_BORDER,
  MWM_DECOR_MAXIMIZE,
  MWM_DECOR_MENU,
  MWM_DECOR_MINIMIZE,
  MWM_DECOR_RESIZEH,
  MWM_DECOR_TITLE,
  MWM_FUNC_ALL,
  MWM_FUNC_CLOSE,
  MWM_FUNC_MOVE,
  MWM_FUNC_RESIZE,
  MWM_INPUT_FULL_APPLICATION_MODAL,
  MWM_INPUT_MODELESS,
  MWM_INPUT_PRIMARY_APPLICATION_MODAL,
  MWM_INPUT_SYSTEM_MODAL,
  NormalState,
  NotUseful,
  TRUE,
  WhenMapped,
  Xm1000TH_INCHES,
  Xm100TH_FONT_UNITS,
  Xm100TH_MILLIMETERS,
  Xm100TH_POINTS,
  XmABSOLUTE,
  XmADD_MODE,
  XmALIGNMENT_BASELINE_BOTTOM,
  XmALIGNMENT_BASELINE_TOP,
  XmALIGNMENT_BEGINNING,
  XmALIGNMENT_CENTER,
  XmALIGNMENT_CONTENTS_BOTTOM,
  XmALIGNMENT_CONTENTS_TOP,
  XmALIGNMENT_END,
  XmALIGNMENT_UNSPECIFIED,
  XmALIGNMENT_WIDGET_BOTTOM,
  XmALIGNMENT_WIDGET_TOP,
  XmANY_ICON,
  XmAPPEND,
  XmAPPLICATION_DEFINED,
  XmARROWS_BEGINNING,
  XmARROWS_DECREMENT_SENSITIVE,
  XmARROWS_DEFAULT_SENSITIVITY,
  XmARROWS_END,
  XmARROWS_FLAT_BEGINNING,
  XmARROWS_FLAT_END,
  XmARROWS_HORIZONTAL,
  XmARROWS_INCREMENT_SENSITIVE,
  XmARROWS_INSENSITIVE,
  XmARROWS_SENSITIVE,
  XmARROWS_SPLIT,
  XmARROWS_VERTICAL,
  XmARROW_DOWN,
  XmARROW_LEFT,
  XmARROW_RIGHT,
  XmARROW_UP,
  XmAS_IS,
  XmAS_NEEDED,
  XmATTACH_FORM,
  XmATTACH_NONE,
  XmATTACH_OPPOSITE_FORM,
  XmATTACH_OPPOSITE_WIDGET,
  XmATTACH_POSITION,
  XmATTACH_SELF,
  XmATTACH_WIDGET,
  XmAUTOMATIC,
  XmAUTO_DRAG_DISABLED,
  XmAUTO_DRAG_ENABLED,
  XmAUTO_SELECT,
  XmAlwaysOpen,
  XmBACKGROUND_COLOR,
  XmBELL,
  XmBOTTOM_LEFT,
  XmBOTTOM_RIGHT,
  XmBOTTOM_TO_TOP,
  XmBOTTOM_TO_TOP_LEFT_TO_RIGHT,
  XmBOTTOM_TO_TOP_RIGHT_TO_LEFT,
  XmBROWSE_SELECT,
  XmCELLS,
  XmCENTER,
  XmCENTIMETERS,
  XmCLIP_WINDOW,
  XmCLOSEST,
  XmCOLLAPSED,
  XmCOMBO_BOX,
  XmCOMMAND_ABOVE_WORKSPACE,
  XmCOMMAND_BELOW_WORKSPACE,
  XmCOMMAND_WINDOW,
  XmCONSTANT,
  XmClosed,
  XmDEFAULT_DIRECTION,
  XmDESTROY,
  XmDETAIL,
  XmDIALOG_APPLICATION_MODAL,
  XmDIALOG_CANCEL_BUTTON,
  XmDIALOG_COMMAND,
  XmDIALOG_DEFAULT_BUTTON,
  XmDIALOG_ERROR,
  XmDIALOG_FILE_SELECTION,
  XmDIALOG_FULL_APPLICATION_MODAL,
  XmDIALOG_HELP_BUTTON,
  XmDIALOG_INFORMATION,
  XmDIALOG_MESSAGE,
  XmDIALOG_MESSAGE_LABEL,
  XmDIALOG_MODELESS,
  XmDIALOG_OK_BUTTON,
  XmDIALOG_PRIMARY_APPLICATION_MODAL,
  XmDIALOG_PROMPT,
  XmDIALOG_QUESTION,
  XmDIALOG_SELECTION,
  XmDIALOG_SEPARATOR,
  XmDIALOG_SYMBOL_LABEL,
  XmDIALOG_SYSTEM_MODAL,
  XmDIALOG_TEMPLATE,
  XmDIALOG_WARNING,
  XmDIALOG_WORKING,
  XmDIALOG_WORK_AREA,
  XmDISTRIBUTE_SPREAD,
  XmDISTRIBUTE_TIGHT,
  XmDOUBLE_DASHED_LINE,
  XmDOUBLE_LINE,
  XmDO_NOTHING,
  XmDROP_DOWN_COMBO_BOX,
  XmDROP_DOWN_LIST,
  XmEACH_SIDE,
  XmETCHED_LINE,
  XmEXCLUSIVE_TAB_GROUP,
  XmEXPANDED,
  XmEXPLICIT,
  XmEXTENDED_SELECT,
  XmFILE_ANY_TYPE,
  XmFILE_DIRECTORY,
  XmFILE_REGULAR,
  XmFILL_FLUSH,
  XmFILL_RAGGED,
  XmFILL_UNSPECIFIED,
  XmFIRST_FIT,
  XmFIRST_POSITION,
  XmFONT_IS_FONT,
  XmFONT_IS_FONTSET,
  XmFONT_IS_XFT,
  XmFONT_UNITS,
  XmFOREGROUND_COLOR,
  XmFRAME_GENERIC_CHILD,
  XmFRAME_TITLE_CHILD,
  XmFRAME_WORKAREA_CHILD,
  XmFillAll,
  XmFillMajor,
  XmFillMinor,
  XmFillNone,
  XmGENERIC_CHILD,
  XmGRID,
  XmGROW_BALANCED,
  XmGROW_MAJOR,
  XmGROW_MINOR,
  XmHORIZONTAL,
  XmHOR_SCROLLBAR,
  XmHidden,
  XmINCHES,
  XmINDETERMINATE,
  XmINDICATOR_BOX,
  XmINDICATOR_CHECK,
  XmINDICATOR_CHECK_BOX,
  XmINDICATOR_CROSS,
  XmINDICATOR_CROSS_BOX,
  XmINDICATOR_FILL,
  XmINDICATOR_NONE,
  XmINHERIT_POLICY,
  XmINVALID_MATCH_BEHAVIOR,
  XmIconBottom,
  XmIconLeft,
  XmIconNone,
  XmIconOnly,
  XmIconRight,
  XmIconTop,
  XmLARGE_ICON,
  XmLAST_POSITION,
  XmLEFT_TO_RIGHT,
  XmLEFT_TO_RIGHT_BOTTOM_TO_TOP,
  XmLEFT_TO_RIGHT_TOP_TO_BOTTOM,
  XmLOAD_DEFERRED,
  XmLOAD_IMMEDIATE,
  XmListMode,
  XmMAJOR_TAB,
  XmMARQUEE,
  XmMARQUEE_EXTEND_BOTH,
  XmMARQUEE_EXTEND_START,
  XmMAX_ON_BOTTOM,
  XmMAX_ON_LEFT,
  XmMAX_ON_RIGHT,
  XmMAX_ON_TOP,
  XmMAX_SIDE,
  XmMENU_BAR,
  XmMENU_OPTION,
  XmMENU_POPUP,
  XmMENU_PULLDOWN,
  XmMESSAGE_WINDOW,
  XmMILLIMETERS,
  XmMINOR_TAB,
  XmMIN_SIDE,
  XmMULTICLICK_DISCARD,
  XmMULTICLICK_KEEP,
  XmMULTIPLE_SELECT,
  XmMULTI_LINE_EDIT,
  XmNEAR_BORDER,
  XmNEAR_SLIDER,
  XmNONE,
  XmNORMAL_MODE,
  XmNOT_SELECTED,
  XmNO_AUTO_SELECT,
  XmNO_LINE,
  XmNO_ORIENTATION,
  XmNO_PACKING,
  XmNO_SCROLL,
  XmNUMERIC,
  XmN_OF_MANY,
  XmONE_BASED,
  XmONE_OF_MANY,
  XmONE_OF_MANY_DIAMOND,
  XmONE_OF_MANY_ROUND,
  XmOUTLINE,
  XmOUTLINE_BUTTON_ABSENT,
  XmOUTLINE_BUTTON_PRESENT,
  XmOWN_ALWAYS,
  XmOWN_MULTIPLE,
  XmOWN_NEVER,
  XmOWN_POSSIBLE_MULTIPLE,
  XmOpen,
  XmPACK_COLUMN,
  XmPACK_NONE,
  XmPACK_TIGHT,
  XmPAGE,
  XmPAGE_SCROLLER,
  XmPER_SHELL,
  XmPER_WIDGET,
  XmPIXELS,
  XmPIXMAP,
  XmPIXMAP_AND_STRING,
  XmPIXMAP_BOTTOM,
  XmPIXMAP_LEFT,
  XmPIXMAP_NONE,
  XmPIXMAP_ONLY,
  XmPIXMAP_OVERLAP_ONLY,
  XmPIXMAP_RIGHT,
  XmPIXMAP_TOP,
  XmPLACE_ABOVE_SELECTION,
  XmPLACE_BELOW_SELECTION,
  XmPLACE_TOP,
  XmPOINTER,
  XmPOINTS,
  XmPOSITION_INDEX,
  XmPOSITION_VALUE,
  XmQUICK_NAVIGATE,
  XmRELATIVE,
  XmRESIZE_ANY,
  XmRESIZE_GROW,
  XmRESIZE_IF_POSSIBLE,
  XmRESIZE_NONE,
  XmRIGHT_TO_LEFT,
  XmRIGHT_TO_LEFT_BOTTOM_TO_TOP,
  XmRIGHT_TO_LEFT_TOP_TO_BOTTOM,
  XmROUND_MARK,
  XmSCROLL_HOR,
  XmSCROLL_VERT,
  XmSELECTED,
  XmSELECT_ALL,
  XmSELECT_LINE,
  XmSELECT_PARAGRAPH,
  XmSELECT_POSITION,
  XmSELECT_WHITESPACE,
  XmSELECT_WORD,
  XmSET,
  XmSHADOWED_BACKGROUND,
  XmSHADOW_ETCHED_IN,
  XmSHADOW_ETCHED_IN_DASH,
  XmSHADOW_ETCHED_OUT,
  XmSHADOW_ETCHED_OUT_DASH,
  XmSHADOW_IN,
  XmSHADOW_OUT,
  XmSINGLE,
  XmSINGLE_DASHED_LINE,
  XmSINGLE_LINE,
  XmSINGLE_LINE_EDIT,
  XmSINGLE_SELECT,
  XmSLIDER,
  XmSMALL_ICON,
  XmSNAP_TO_GRID,
  XmSOLID,
  XmSPATIAL,
  XmSPIRAL,
  XmSTATIC,
  XmSTATUS_AREA,
  XmSTICKY_TAB_GROUP,
  XmSTRING,
  XmSTRING_COMPONENT_CHARSET,
  XmSTRING_COMPONENT_DIRECTION,
  XmSTRING_COMPONENT_LAYOUT_POP,
  XmSTRING_COMPONENT_LAYOUT_PUSH,
  XmSTRING_COMPONENT_LOCALE,
  XmSTRING_COMPONENT_LOCALE_TEXT,
  XmSTRING_COMPONENT_RENDITION_BEGIN,
  XmSTRING_COMPONENT_RENDITION_END,
  XmSTRING_COMPONENT_SEPARATOR,
  XmSTRING_COMPONENT_TAB,
  XmSTRING_COMPONENT_TEXT,
  XmSTRING_COMPONENT_UNKNOWN,
  XmSTRING_COMPONENT_WIDECHAR_TEXT,
  XmSTRING_DIRECTION_DEFAULT,
  XmSTRING_DIRECTION_L_TO_R,
  XmSTRING_DIRECTION_R_TO_L,
  XmSTRING_DIRECTION_UNSET,
  XmScaleMode,
  XmTABS_BASIC,
  XmTABS_BEVELED,
  XmTABS_BOTTOM_TO_TOP,
  XmTABS_LEFT_TO_RIGHT,
  XmTABS_ON_BOTTOM,
  XmTABS_ON_LEFT,
  XmTABS_ON_RIGHT,
  XmTABS_ON_TOP,
  XmTABS_RIGHT_TO_LEFT,
  XmTABS_ROUNDED,
  XmTABS_SQUARED,
  XmTABS_STACKED,
  XmTABS_STACKED_STATIC,
  XmTABS_TOP_TO_BOTTOM,
  XmTAB_EDGE_BOTTOM_RIGHT,
  XmTAB_EDGE_TOP_LEFT,
  XmTAB_GROUP,
  XmTAB_ORIENTATION_DYNAMIC,
  XmTEAR_OFF_DISABLED,
  XmTEAR_OFF_ENABLED,
  XmTHERMOMETER,
  XmTHUMB_MARK,
  XmTOGGLE_BOOLEAN,
  XmTOGGLE_INDETERMINATE,
  XmTOP_LEFT,
  XmTOP_RIGHT,
  XmTOP_TO_BOTTOM,
  XmTOP_TO_BOTTOM_LEFT_TO_RIGHT,
  XmTOP_TO_BOTTOM_RIGHT_TO_LEFT,
  XmTOUCH_ONLY,
  XmTOUCH_OVER,
  XmTROUGH_COLOR,
  XmTreeCompressLeaves,
  XmTreeCompressNone,
  XmTreeDirect,
  XmTreeLadder,
  XmUNMAP,
  XmUNPOST,
  XmUNPOST_AND_REPLAY,
  XmUNSET,
  XmVARIABLE,
  XmVERTICAL,
  XmVERT_SCROLLBAR,
  XmWORK_AREA,
  XmZERO_BASED,
  };
externaldef(uil_sym_glbl) int *enumval_values_table =
		enumval_values_table_vec;
