/*
**	This file is automatically generated.  Do not edit it by hand.
**/

/*	Token name table */
static char *tok_token_name_table_vec[] = 
  {
    "UILEOF",
    "NAME",
    "FONT_NAME",
    "COLOR_NAME",
    "ARGUMENT_NAME",
    "REASON_NAME",
    "CHARSET_NAME",
    "ENUMVAL_NAME",
    "CLASS_NAME",
    "UNS_FLOAT_LITERAL",
    "COMP_STRING",
    "CHAR_8_LITERAL",
    "UNS_INT_LITERAL",
    "LEFT_PAREN",
    "RIGHT_PAREN",
    "COLON",
    "SEMICOLON",
    "LEFT_BRACE",
    "RIGHT_BRACE",
    "COMMA",
    "EQUAL_SIGN",
    "NOT",
    "PLUS",
    "MINUS",
    "AND",
    "OR",
    "XOR",
    "MULTIPLY",
    "DIVIDE",
    "LEFT_SHIFT",
    "RIGHT_SHIFT",
    "LIST",
    "IDENTIFIER",
    "END",
    "MODULE",
    "UILTRUE",
    "UILFALSE",
    "INCLUDE",
    "MACRO",
    "ON",
    "OFF",
    "VALUE",
    "ARGUMENTS",
    "CALLBACKS",
    "PROCEDURES",
    "CONTROLS",
    "PROCEDURE",
    "OBJECT",
    "OBJECTS",
    "WIDGET",
    "GADGET",
    "FONT",
    "ARGUMENT",
    "REASON",
    "PIXMAP",
    "COLOR",
    "NAMES",
    "CHARACTER_SET",
    "CASE_SENSITIVE",
    "CASE_INSENSITIVE",
    "VERSION",
    "MANAGED",
    "UNMANAGED",
    "PRIVATE",
    "IMPORTED",
    "EXPORTED",
    "UILFILE",
    "STRING_TABLE",
    "TRANSLATION_TABLE",
    "COMPOUND_STRING",
    "FONT_TABLE",
    "ANY",
    "STRING",
    "BOOLEAN",
    "ICON",
    "RIGHT_TO_LEFT",
    "BACKGROUND",
    "FOREGROUND",
    "COLOR_TABLE",
    "FLOAT",
    "INTEGER",
    "CLASS_REC_NAME",
    "ASCIZ_TABLE",
    "INTEGER_TABLE",
    "ASCIZ_STRING_TABLE",
    "COMPOUND_STRING_TABLE",
    "XBITMAPFILE",
    "SEPARATE",
    "SIXTEEN_BIT",
    "POUND",
    "KEYSYM",
    "SINGLE_FLOAT",
    "RGB",
    "WIDE_CHARACTER",
    "LOC_STRING",
    "FONTSET",
    "CHILD_NAME",
    "COMPOUND_STRING_COMPONENT",
    "IN",
    "CM",
    "MM",
    "PT",
    "FU",
    "PIXEL",
    "PIXELS",
    "INCH",
    "INCHES",
    "CENTIMETER",
    "CENTIMETERS",
    "MILLIMETER",
    "MILLIMETERS",
    "POINT",
    "POINTS",
    "FONT_UNIT",
    "FONT_UNITS",
    "PIX",
  };
externaldef(uil_sym_glbl) char **tok_token_name_table =
		tok_token_name_table_vec;

/*	Number of entries in table */
externaldef(uil_sym_glbl) int tok_num_tokens = 116;
