/*
**	This file is automatically generated.  Do not edit it by hand.
**/
/*  Table of the class type of children
    The table is indexed by child with each entry the
    permitted class for that child.
*/

static unsigned char child_class_table_vec[] =
  {
    0,
    sym_k_XmPushButton_object,
    sym_k_XmArrowButton_object,
    sym_k_XmPushButton_object,
    sym_k_XmToggleButton_object,
    sym_k_XmToggleButton_object,
    sym_k_XmLabel_object,
    sym_k_XmScrolledList_object,
    sym_k_XmPushButton_object,
    sym_k_XmLabel_object,
    sym_k_XmText_object,
    sym_k_XmPushButton_object,
    sym_k_XmText_object,
    sym_k_XmPushButton_object,
    sym_k_XmScrollBar_object,
    sym_k_XmLabel_object,
    sym_k_XmScrolledList_object,
    sym_k_XmLabel_object,
    sym_k_XmList_object,
    sym_k_XmLabel_object,
    sym_k_XmPushButton_object,
    sym_k_XmCascadeButtonGadget_object,
    sym_k_XmLabelGadget_object,
    sym_k_XmLabel_object,
    sym_k_XmSeparator_object,
    sym_k_XmSeparator_object,
    sym_k_XmSeparator_object,
    sym_k_XmSeparator_object,
    sym_k_XmLabel_object,
    sym_k_XmTearOffButton_object,
    sym_k_XmText_object,
    sym_k_XmTextField_object,
    sym_k_XmLabel_object,
    sym_k_XmScrollBar_object,
  };
externaldef(uil_sym_glbl) unsigned char *child_class_table =
	 child_class_table_vec;
