
#ifndef _XmEditresComI_h
#define _XmEditresComI_h

#include <X11/Intrinsic.h>

#ifdef __cplusplus
extern "C" {
#endif

void _XmEditResCheckMessages(Widget w, XtPointer data, XEvent event, Boolean cont);

#ifdef __cplusplus
}  /* Close scope of 'extern "C"' declaration which encloses file. */
#endif

#endif
