/*
**	This file is automatically generated.  Do not edit it by hand.
**/

/*
 * Bit vectors for each reason. The entries in the vector correspond
 * to each class.
 */

/* sym_k_DtNcancelCallback_reason */
static unsigned char reason_class_vec1[] =
  {
  _BIT_MASK(sym_k_DtPrintSetupBox_object) |
  _BIT_MASK(sym_k_DtPrintSetupDialog_object) |
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_DtNcascadingCallback_reason */
static unsigned char reason_class_vec2[] =
  {
  _BIT_MASK(sym_k_DtMenuButton_object) |
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_DtNcloseCallback_reason */
static unsigned char reason_class_vec3[] =
  {
  _BIT_MASK(sym_k_DtHelpDialog_object) |
  _BIT_MASK(sym_k_DtHelpQuickDialog_object) |
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_DtNclosePrintDisplayCallback_reason */
static unsigned char reason_class_vec4[] =
  {
  _BIT_MASK(sym_k_DtPrintSetupBox_object) |
  _BIT_MASK(sym_k_DtPrintSetupDialog_object) |
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_DtNhyperLinkCallback_reason */
static unsigned char reason_class_vec5[] =
  {
  _BIT_MASK(sym_k_DtHelpDialog_object) |
  _BIT_MASK(sym_k_DtHelpQuickDialog_object) |
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_DtNinputVerifyCallback_reason */
static unsigned char reason_class_vec6[] =
  {
  _BIT_MASK(sym_k_DtTerm_object) |
  0, _BIT_MASK(sym_k_DtTermPrimitive_object) |
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_DtNoutputLogCallback_reason */
static unsigned char reason_class_vec7[] =
  {
  _BIT_MASK(sym_k_DtTerm_object) |
  0, _BIT_MASK(sym_k_DtTermPrimitive_object) |
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_DtNprintCallback_reason */
static unsigned char reason_class_vec8[] =
  {
  _BIT_MASK(sym_k_DtPrintSetupBox_object) |
  _BIT_MASK(sym_k_DtPrintSetupDialog_object) |
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_DtNsetupCallback_reason */
static unsigned char reason_class_vec9[] =
  {
  _BIT_MASK(sym_k_DtPrintSetupBox_object) |
  _BIT_MASK(sym_k_DtPrintSetupDialog_object) |
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_DtNstatusChangeCallback_reason */
static unsigned char reason_class_vec10[] =
  {
  _BIT_MASK(sym_k_DtTerm_object) |
  0, _BIT_MASK(sym_k_DtTermPrimitive_object) |
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_DtNsubprocessTerminationCallback_reason */
static unsigned char reason_class_vec11[] =
  {
  _BIT_MASK(sym_k_DtTerm_object) |
  0, _BIT_MASK(sym_k_DtTermPrimitive_object) |
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_DtNtextDeselectCallback_reason */
static unsigned char reason_class_vec12[] =
  {
  _BIT_MASK(sym_k_DtEditor_object) |
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_DtNtextSelectCallback_reason */
static unsigned char reason_class_vec13[] =
  {
  _BIT_MASK(sym_k_DtEditor_object) |
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_MrmNcreateCallback_reason */
static unsigned char reason_class_vec14[] =
  {
  _BIT_MASK(sym_k_DtEditor_object) |
  _BIT_MASK(sym_k_DtHelpDialog_object) |
  _BIT_MASK(sym_k_DtHelpQuickDialog_object) |
  _BIT_MASK(sym_k_DtMenuButton_object) |
  _BIT_MASK(sym_k_DtPrintSetupBox_object) |
  _BIT_MASK(sym_k_DtPrintSetupDialog_object) |
  _BIT_MASK(sym_k_DtTerm_object) |
  0, _BIT_MASK(sym_k_DtTermPrimitive_object) |
  _BIT_MASK(sym_k_XmArrowButton_object) |
  _BIT_MASK(sym_k_XmArrowButtonGadget_object) |
  _BIT_MASK(sym_k_XmBulletinBoard_object) |
  _BIT_MASK(sym_k_XmBulletinBoardDialog_object) |
  _BIT_MASK(sym_k_XmButtonBox_object) |
  _BIT_MASK(sym_k_XmCascadeButton_object) |
  _BIT_MASK(sym_k_XmCascadeButtonGadget_object) |
  0, _BIT_MASK(sym_k_XmCheckBox_object) |
  _BIT_MASK(sym_k_XmColorSelector_object) |
  _BIT_MASK(sym_k_XmColumn_object) |
  _BIT_MASK(sym_k_XmComboBox_object) |
  _BIT_MASK(sym_k_XmCommand_object) |
  _BIT_MASK(sym_k_XmCommandDialog_object) |
  _BIT_MASK(sym_k_XmContainer_object) |
  _BIT_MASK(sym_k_XmDataField_object) |
  0, _BIT_MASK(sym_k_XmDialogShell_object) |
  _BIT_MASK(sym_k_XmDrawingArea_object) |
  _BIT_MASK(sym_k_XmDrawnButton_object) |
  _BIT_MASK(sym_k_XmDropDown_object) |
  _BIT_MASK(sym_k_XmErrorDialog_object) |
  _BIT_MASK(sym_k_XmFileSelectionBox_object) |
  _BIT_MASK(sym_k_XmFileSelectionDialog_object) |
  _BIT_MASK(sym_k_XmFontSelector_object) |
  0, _BIT_MASK(sym_k_XmForm_object) |
  _BIT_MASK(sym_k_XmFormDialog_object) |
  _BIT_MASK(sym_k_XmFrame_object) |
  _BIT_MASK(sym_k_XmIconBox_object) |
  _BIT_MASK(sym_k_XmIconButton_object) |
  _BIT_MASK(sym_k_XmIconGadget_object) |
  _BIT_MASK(sym_k_XmInformationDialog_object) |
  _BIT_MASK(sym_k_XmLabel_object) |
  0, _BIT_MASK(sym_k_XmLabelGadget_object) |
  _BIT_MASK(sym_k_XmList_object) |
  _BIT_MASK(sym_k_XmMainWindow_object) |
  _BIT_MASK(sym_k_XmMenuBar_object) |
  _BIT_MASK(sym_k_XmMenuShell_object) |
  _BIT_MASK(sym_k_XmMessageBox_object) |
  _BIT_MASK(sym_k_XmMessageDialog_object) |
  _BIT_MASK(sym_k_XmMultiList_object) |
  0, _BIT_MASK(sym_k_XmNotebook_object) |
  _BIT_MASK(sym_k_XmOptionMenu_object) |
  _BIT_MASK(sym_k_XmOutline_object) |
  _BIT_MASK(sym_k_XmPaned_object) |
  _BIT_MASK(sym_k_XmPanedWindow_object) |
  _BIT_MASK(sym_k_XmPopupMenu_object) |
  _BIT_MASK(sym_k_XmPromptDialog_object) |
  _BIT_MASK(sym_k_XmPulldownMenu_object) |
  0, _BIT_MASK(sym_k_XmPushButton_object) |
  _BIT_MASK(sym_k_XmPushButtonGadget_object) |
  _BIT_MASK(sym_k_XmQuestionDialog_object) |
  _BIT_MASK(sym_k_XmRadioBox_object) |
  _BIT_MASK(sym_k_XmRenderTable_object) |
  _BIT_MASK(sym_k_XmRendition_object) |
  _BIT_MASK(sym_k_XmRowColumn_object) |
  _BIT_MASK(sym_k_XmScale_object) |
  0, _BIT_MASK(sym_k_XmScrollBar_object) |
  _BIT_MASK(sym_k_XmScrolledList_object) |
  _BIT_MASK(sym_k_XmScrolledText_object) |
  _BIT_MASK(sym_k_XmScrolledWindow_object) |
  _BIT_MASK(sym_k_XmSelectionBox_object) |
  _BIT_MASK(sym_k_XmSelectionDialog_object) |
  _BIT_MASK(sym_k_XmSeparator_object) |
  _BIT_MASK(sym_k_XmSeparatorGadget_object) |
  0, _BIT_MASK(sym_k_XmSimpleSpinBox_object) |
  _BIT_MASK(sym_k_XmSpinBox_object) |
  _BIT_MASK(sym_k_XmTab_object) |
  _BIT_MASK(sym_k_XmTabBox_object) |
  _BIT_MASK(sym_k_XmTabList_object) |
  _BIT_MASK(sym_k_XmTabStack_object) |
  _BIT_MASK(sym_k_XmTearOffButton_object) |
  _BIT_MASK(sym_k_XmTemplateDialog_object) |
  0, _BIT_MASK(sym_k_XmText_object) |
  _BIT_MASK(sym_k_XmTextField_object) |
  _BIT_MASK(sym_k_XmToggleButton_object) |
  _BIT_MASK(sym_k_XmToggleButtonGadget_object) |
  _BIT_MASK(sym_k_XmTree_object) |
  _BIT_MASK(sym_k_XmWarningDialog_object) |
  _BIT_MASK(sym_k_XmWorkArea_object) |
  _BIT_MASK(sym_k_XmWorkingDialog_object) |
  0, 0};

/* sym_k_XmNactivateCallback_reason */
static unsigned char reason_class_vec15[] =
  {
  0, _BIT_MASK(sym_k_XmArrowButton_object) |
  _BIT_MASK(sym_k_XmArrowButtonGadget_object) |
  _BIT_MASK(sym_k_XmCascadeButton_object) |
  _BIT_MASK(sym_k_XmCascadeButtonGadget_object) |
  0, _BIT_MASK(sym_k_XmDataField_object) |
  0, _BIT_MASK(sym_k_XmDrawnButton_object) |
  0, _BIT_MASK(sym_k_XmIconButton_object) |
  0, 0, 0, _BIT_MASK(sym_k_XmPushButton_object) |
  _BIT_MASK(sym_k_XmPushButtonGadget_object) |
  0, _BIT_MASK(sym_k_XmScrolledText_object) |
  0, _BIT_MASK(sym_k_XmTearOffButton_object) |
  0, _BIT_MASK(sym_k_XmText_object) |
  _BIT_MASK(sym_k_XmTextField_object) |
  0, 0};

/* sym_k_XmNapplyCallback_reason */
static unsigned char reason_class_vec16[] =
  {
  0, 0, 0, _BIT_MASK(sym_k_XmFileSelectionBox_object) |
  _BIT_MASK(sym_k_XmFileSelectionDialog_object) |
  0, 0, 0, _BIT_MASK(sym_k_XmPromptDialog_object) |
  0, 0, _BIT_MASK(sym_k_XmSelectionBox_object) |
  _BIT_MASK(sym_k_XmSelectionDialog_object) |
  0, 0, 0, 0};

/* sym_k_XmNarmCallback_reason */
static unsigned char reason_class_vec17[] =
  {
  0, _BIT_MASK(sym_k_XmArrowButton_object) |
  _BIT_MASK(sym_k_XmArrowButtonGadget_object) |
  0, 0, _BIT_MASK(sym_k_XmDrawnButton_object) |
  0, 0, 0, 0, _BIT_MASK(sym_k_XmPushButton_object) |
  _BIT_MASK(sym_k_XmPushButtonGadget_object) |
  0, 0, _BIT_MASK(sym_k_XmTearOffButton_object) |
  0, _BIT_MASK(sym_k_XmToggleButton_object) |
  _BIT_MASK(sym_k_XmToggleButtonGadget_object) |
  0, 0};

/* sym_k_XmNbrowseSelectionCallback_reason */
static unsigned char reason_class_vec18[] =
  {
  0, 0, 0, 0, 0, _BIT_MASK(sym_k_XmList_object) |
  0, 0, 0, _BIT_MASK(sym_k_XmScrolledList_object) |
  0, 0, 0, 0};

/* sym_k_XmNcancelCallback_reason */
static unsigned char reason_class_vec19[] =
  {
  0, 0, 0, _BIT_MASK(sym_k_XmErrorDialog_object) |
  _BIT_MASK(sym_k_XmFileSelectionBox_object) |
  _BIT_MASK(sym_k_XmFileSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmInformationDialog_object) |
  0, _BIT_MASK(sym_k_XmMessageBox_object) |
  _BIT_MASK(sym_k_XmMessageDialog_object) |
  0, _BIT_MASK(sym_k_XmPromptDialog_object) |
  0, _BIT_MASK(sym_k_XmQuestionDialog_object) |
  0, _BIT_MASK(sym_k_XmSelectionBox_object) |
  _BIT_MASK(sym_k_XmSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmTemplateDialog_object) |
  0, _BIT_MASK(sym_k_XmWarningDialog_object) |
  _BIT_MASK(sym_k_XmWorkingDialog_object) |
  0, 0};

/* sym_k_XmNcascadingCallback_reason */
static unsigned char reason_class_vec20[] =
  {
  0, _BIT_MASK(sym_k_XmCascadeButton_object) |
  _BIT_MASK(sym_k_XmCascadeButtonGadget_object) |
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_XmNcommandChangedCallback_reason */
static unsigned char reason_class_vec21[] =
  {
  0, 0, _BIT_MASK(sym_k_XmCommand_object) |
  _BIT_MASK(sym_k_XmCommandDialog_object) |
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_XmNcommandEnteredCallback_reason */
static unsigned char reason_class_vec22[] =
  {
  0, 0, _BIT_MASK(sym_k_XmCommand_object) |
  _BIT_MASK(sym_k_XmCommandDialog_object) |
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_XmNconvertCallback_reason */
static unsigned char reason_class_vec23[] =
  {
  _BIT_MASK(sym_k_DtMenuButton_object) |
  _BIT_MASK(sym_k_DtTerm_object) |
  0, _BIT_MASK(sym_k_DtTermPrimitive_object) |
  _BIT_MASK(sym_k_XmArrowButton_object) |
  _BIT_MASK(sym_k_XmCascadeButton_object) |
  0, _BIT_MASK(sym_k_XmContainer_object) |
  _BIT_MASK(sym_k_XmDataField_object) |
  0, _BIT_MASK(sym_k_XmDrawingArea_object) |
  _BIT_MASK(sym_k_XmDrawnButton_object) |
  0, _BIT_MASK(sym_k_XmIconButton_object) |
  _BIT_MASK(sym_k_XmLabel_object) |
  0, _BIT_MASK(sym_k_XmList_object) |
  0, 0, _BIT_MASK(sym_k_XmPushButton_object) |
  _BIT_MASK(sym_k_XmScale_object) |
  0, _BIT_MASK(sym_k_XmScrollBar_object) |
  _BIT_MASK(sym_k_XmScrolledList_object) |
  _BIT_MASK(sym_k_XmScrolledText_object) |
  _BIT_MASK(sym_k_XmSeparator_object) |
  0, _BIT_MASK(sym_k_XmTabBox_object) |
  _BIT_MASK(sym_k_XmTearOffButton_object) |
  0, _BIT_MASK(sym_k_XmText_object) |
  _BIT_MASK(sym_k_XmTextField_object) |
  _BIT_MASK(sym_k_XmToggleButton_object) |
  0, 0};

/* sym_k_XmNdecrementCallback_reason */
static unsigned char reason_class_vec24[] =
  {
  0, 0, 0, 0, 0, 0, 0, 0, _BIT_MASK(sym_k_XmScrollBar_object) |
  0, 0, 0, 0};

/* sym_k_XmNdefaultActionCallback_reason */
static unsigned char reason_class_vec25[] =
  {
  0, 0, _BIT_MASK(sym_k_XmContainer_object) |
  0, 0, 0, _BIT_MASK(sym_k_XmList_object) |
  0, 0, 0, _BIT_MASK(sym_k_XmScrolledList_object) |
  0, 0, 0, 0};

/* sym_k_XmNdestinationCallback_reason */
static unsigned char reason_class_vec26[] =
  {
  0, 0, _BIT_MASK(sym_k_XmContainer_object) |
  _BIT_MASK(sym_k_XmDataField_object) |
  0, _BIT_MASK(sym_k_XmDrawingArea_object) |
  0, 0, _BIT_MASK(sym_k_XmList_object) |
  0, 0, 0, _BIT_MASK(sym_k_XmScrolledList_object) |
  _BIT_MASK(sym_k_XmScrolledText_object) |
  0, 0, _BIT_MASK(sym_k_XmText_object) |
  _BIT_MASK(sym_k_XmTextField_object) |
  0, 0};

/* sym_k_XmNdestroyCallback_reason */
static unsigned char reason_class_vec27[] =
  {
  _BIT_MASK(sym_k_DtEditor_object) |
  _BIT_MASK(sym_k_DtHelpDialog_object) |
  _BIT_MASK(sym_k_DtHelpQuickDialog_object) |
  _BIT_MASK(sym_k_DtMenuButton_object) |
  _BIT_MASK(sym_k_DtPrintSetupBox_object) |
  _BIT_MASK(sym_k_DtPrintSetupDialog_object) |
  _BIT_MASK(sym_k_DtTerm_object) |
  0, _BIT_MASK(sym_k_DtTermPrimitive_object) |
  _BIT_MASK(sym_k_XmArrowButton_object) |
  _BIT_MASK(sym_k_XmArrowButtonGadget_object) |
  _BIT_MASK(sym_k_XmBulletinBoard_object) |
  _BIT_MASK(sym_k_XmBulletinBoardDialog_object) |
  _BIT_MASK(sym_k_XmButtonBox_object) |
  _BIT_MASK(sym_k_XmCascadeButton_object) |
  _BIT_MASK(sym_k_XmCascadeButtonGadget_object) |
  0, _BIT_MASK(sym_k_XmCheckBox_object) |
  _BIT_MASK(sym_k_XmColorSelector_object) |
  _BIT_MASK(sym_k_XmColumn_object) |
  _BIT_MASK(sym_k_XmComboBox_object) |
  _BIT_MASK(sym_k_XmCommand_object) |
  _BIT_MASK(sym_k_XmCommandDialog_object) |
  _BIT_MASK(sym_k_XmContainer_object) |
  _BIT_MASK(sym_k_XmDataField_object) |
  0, _BIT_MASK(sym_k_XmDialogShell_object) |
  _BIT_MASK(sym_k_XmDrawingArea_object) |
  _BIT_MASK(sym_k_XmDrawnButton_object) |
  _BIT_MASK(sym_k_XmDropDown_object) |
  _BIT_MASK(sym_k_XmErrorDialog_object) |
  _BIT_MASK(sym_k_XmFileSelectionBox_object) |
  _BIT_MASK(sym_k_XmFileSelectionDialog_object) |
  _BIT_MASK(sym_k_XmFontSelector_object) |
  0, _BIT_MASK(sym_k_XmForm_object) |
  _BIT_MASK(sym_k_XmFormDialog_object) |
  _BIT_MASK(sym_k_XmFrame_object) |
  _BIT_MASK(sym_k_XmIconBox_object) |
  _BIT_MASK(sym_k_XmIconButton_object) |
  _BIT_MASK(sym_k_XmIconGadget_object) |
  _BIT_MASK(sym_k_XmInformationDialog_object) |
  _BIT_MASK(sym_k_XmLabel_object) |
  0, _BIT_MASK(sym_k_XmLabelGadget_object) |
  _BIT_MASK(sym_k_XmList_object) |
  _BIT_MASK(sym_k_XmMainWindow_object) |
  _BIT_MASK(sym_k_XmMenuBar_object) |
  _BIT_MASK(sym_k_XmMenuShell_object) |
  _BIT_MASK(sym_k_XmMessageBox_object) |
  _BIT_MASK(sym_k_XmMessageDialog_object) |
  _BIT_MASK(sym_k_XmMultiList_object) |
  0, _BIT_MASK(sym_k_XmNotebook_object) |
  _BIT_MASK(sym_k_XmOptionMenu_object) |
  _BIT_MASK(sym_k_XmOutline_object) |
  _BIT_MASK(sym_k_XmPaned_object) |
  _BIT_MASK(sym_k_XmPanedWindow_object) |
  _BIT_MASK(sym_k_XmPopupMenu_object) |
  _BIT_MASK(sym_k_XmPromptDialog_object) |
  _BIT_MASK(sym_k_XmPulldownMenu_object) |
  0, _BIT_MASK(sym_k_XmPushButton_object) |
  _BIT_MASK(sym_k_XmPushButtonGadget_object) |
  _BIT_MASK(sym_k_XmQuestionDialog_object) |
  _BIT_MASK(sym_k_XmRadioBox_object) |
  _BIT_MASK(sym_k_XmRenderTable_object) |
  _BIT_MASK(sym_k_XmRendition_object) |
  _BIT_MASK(sym_k_XmRowColumn_object) |
  _BIT_MASK(sym_k_XmScale_object) |
  0, _BIT_MASK(sym_k_XmScrollBar_object) |
  _BIT_MASK(sym_k_XmScrolledList_object) |
  _BIT_MASK(sym_k_XmScrolledText_object) |
  _BIT_MASK(sym_k_XmScrolledWindow_object) |
  _BIT_MASK(sym_k_XmSelectionBox_object) |
  _BIT_MASK(sym_k_XmSelectionDialog_object) |
  _BIT_MASK(sym_k_XmSeparator_object) |
  _BIT_MASK(sym_k_XmSeparatorGadget_object) |
  0, _BIT_MASK(sym_k_XmSimpleSpinBox_object) |
  _BIT_MASK(sym_k_XmSpinBox_object) |
  _BIT_MASK(sym_k_XmTab_object) |
  _BIT_MASK(sym_k_XmTabBox_object) |
  _BIT_MASK(sym_k_XmTabList_object) |
  _BIT_MASK(sym_k_XmTabStack_object) |
  _BIT_MASK(sym_k_XmTearOffButton_object) |
  _BIT_MASK(sym_k_XmTemplateDialog_object) |
  0, _BIT_MASK(sym_k_XmText_object) |
  _BIT_MASK(sym_k_XmTextField_object) |
  _BIT_MASK(sym_k_XmToggleButton_object) |
  _BIT_MASK(sym_k_XmToggleButtonGadget_object) |
  _BIT_MASK(sym_k_XmTree_object) |
  _BIT_MASK(sym_k_XmWarningDialog_object) |
  _BIT_MASK(sym_k_XmWorkArea_object) |
  _BIT_MASK(sym_k_XmWorkingDialog_object) |
  0, 0};

/* sym_k_XmNdisarmCallback_reason */
static unsigned char reason_class_vec28[] =
  {
  0, _BIT_MASK(sym_k_XmArrowButton_object) |
  _BIT_MASK(sym_k_XmArrowButtonGadget_object) |
  0, 0, _BIT_MASK(sym_k_XmDrawnButton_object) |
  0, 0, 0, 0, _BIT_MASK(sym_k_XmPushButton_object) |
  _BIT_MASK(sym_k_XmPushButtonGadget_object) |
  0, 0, _BIT_MASK(sym_k_XmTearOffButton_object) |
  0, _BIT_MASK(sym_k_XmToggleButton_object) |
  _BIT_MASK(sym_k_XmToggleButtonGadget_object) |
  0, 0};

/* sym_k_XmNdoubleClickCallback_reason */
static unsigned char reason_class_vec29[] =
  {
  0, 0, 0, 0, _BIT_MASK(sym_k_XmIconButton_object) |
  0, _BIT_MASK(sym_k_XmMultiList_object) |
  0, 0, 0, 0, 0, 0, 0};

/* sym_k_XmNdragCallback_reason */
static unsigned char reason_class_vec30[] =
  {
  0, 0, 0, 0, 0, 0, 0, _BIT_MASK(sym_k_XmScale_object) |
  0, _BIT_MASK(sym_k_XmScrollBar_object) |
  0, 0, 0, 0};

/* sym_k_XmNentryCallback_reason */
static unsigned char reason_class_vec31[] =
  {
  0, 0, _BIT_MASK(sym_k_XmCheckBox_object) |
  0, 0, 0, _BIT_MASK(sym_k_XmMenuBar_object) |
  0, _BIT_MASK(sym_k_XmOptionMenu_object) |
  _BIT_MASK(sym_k_XmPopupMenu_object) |
  _BIT_MASK(sym_k_XmPulldownMenu_object) |
  0, _BIT_MASK(sym_k_XmRadioBox_object) |
  _BIT_MASK(sym_k_XmRowColumn_object) |
  0, 0, 0, _BIT_MASK(sym_k_XmWorkArea_object) |
  0, 0};

/* sym_k_XmNexposeCallback_reason */
static unsigned char reason_class_vec32[] =
  {
  0, 0, 0, _BIT_MASK(sym_k_XmDrawingArea_object) |
  _BIT_MASK(sym_k_XmDrawnButton_object) |
  0, 0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_XmNextendedSelectionCallback_reason */
static unsigned char reason_class_vec33[] =
  {
  0, 0, 0, 0, 0, _BIT_MASK(sym_k_XmList_object) |
  0, 0, 0, _BIT_MASK(sym_k_XmScrolledList_object) |
  0, 0, 0, 0};

/* sym_k_XmNfocusCallback_reason */
static unsigned char reason_class_vec34[] =
  {
  _BIT_MASK(sym_k_DtEditor_object) |
  _BIT_MASK(sym_k_DtHelpDialog_object) |
  _BIT_MASK(sym_k_DtHelpQuickDialog_object) |
  _BIT_MASK(sym_k_DtPrintSetupBox_object) |
  _BIT_MASK(sym_k_DtPrintSetupDialog_object) |
  0, _BIT_MASK(sym_k_XmBulletinBoard_object) |
  _BIT_MASK(sym_k_XmBulletinBoardDialog_object) |
  0, _BIT_MASK(sym_k_XmColumn_object) |
  _BIT_MASK(sym_k_XmCommand_object) |
  _BIT_MASK(sym_k_XmCommandDialog_object) |
  _BIT_MASK(sym_k_XmDataField_object) |
  0, _BIT_MASK(sym_k_XmErrorDialog_object) |
  _BIT_MASK(sym_k_XmFileSelectionBox_object) |
  _BIT_MASK(sym_k_XmFileSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmForm_object) |
  _BIT_MASK(sym_k_XmFormDialog_object) |
  _BIT_MASK(sym_k_XmInformationDialog_object) |
  0, _BIT_MASK(sym_k_XmMessageBox_object) |
  _BIT_MASK(sym_k_XmMessageDialog_object) |
  0, _BIT_MASK(sym_k_XmPromptDialog_object) |
  0, _BIT_MASK(sym_k_XmQuestionDialog_object) |
  0, _BIT_MASK(sym_k_XmScrolledText_object) |
  _BIT_MASK(sym_k_XmSelectionBox_object) |
  _BIT_MASK(sym_k_XmSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmTabStack_object) |
  _BIT_MASK(sym_k_XmTemplateDialog_object) |
  0, _BIT_MASK(sym_k_XmText_object) |
  _BIT_MASK(sym_k_XmTextField_object) |
  _BIT_MASK(sym_k_XmWarningDialog_object) |
  _BIT_MASK(sym_k_XmWorkingDialog_object) |
  0, 0};

/* sym_k_XmNfocusMovedCallback_reason */
static unsigned char reason_class_vec35[] =
  {
  _BIT_MASK(sym_k_DtHelpDialog_object) |
  _BIT_MASK(sym_k_DtHelpQuickDialog_object) |
  _BIT_MASK(sym_k_DtPrintSetupDialog_object) |
  0, _BIT_MASK(sym_k_XmBulletinBoardDialog_object) |
  0, _BIT_MASK(sym_k_XmCommandDialog_object) |
  0, _BIT_MASK(sym_k_XmDialogShell_object) |
  _BIT_MASK(sym_k_XmErrorDialog_object) |
  _BIT_MASK(sym_k_XmFileSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmFormDialog_object) |
  _BIT_MASK(sym_k_XmInformationDialog_object) |
  0, _BIT_MASK(sym_k_XmMessageDialog_object) |
  0, _BIT_MASK(sym_k_XmPromptDialog_object) |
  0, _BIT_MASK(sym_k_XmQuestionDialog_object) |
  0, _BIT_MASK(sym_k_XmSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmTemplateDialog_object) |
  0, _BIT_MASK(sym_k_XmWarningDialog_object) |
  _BIT_MASK(sym_k_XmWorkingDialog_object) |
  0, 0};

/* sym_k_XmNgainPrimaryCallback_reason */
static unsigned char reason_class_vec36[] =
  {
  0, 0, _BIT_MASK(sym_k_XmDataField_object) |
  0, 0, 0, 0, 0, 0, _BIT_MASK(sym_k_XmScrolledText_object) |
  0, 0, _BIT_MASK(sym_k_XmText_object) |
  _BIT_MASK(sym_k_XmTextField_object) |
  0, 0};

/* sym_k_XmNhelpCallback_reason */
static unsigned char reason_class_vec37[] =
  {
  _BIT_MASK(sym_k_DtEditor_object) |
  _BIT_MASK(sym_k_DtHelpDialog_object) |
  _BIT_MASK(sym_k_DtHelpQuickDialog_object) |
  _BIT_MASK(sym_k_DtMenuButton_object) |
  _BIT_MASK(sym_k_DtPrintSetupBox_object) |
  _BIT_MASK(sym_k_DtPrintSetupDialog_object) |
  _BIT_MASK(sym_k_DtTerm_object) |
  0, _BIT_MASK(sym_k_DtTermPrimitive_object) |
  _BIT_MASK(sym_k_XmArrowButton_object) |
  _BIT_MASK(sym_k_XmArrowButtonGadget_object) |
  _BIT_MASK(sym_k_XmBulletinBoard_object) |
  _BIT_MASK(sym_k_XmBulletinBoardDialog_object) |
  _BIT_MASK(sym_k_XmButtonBox_object) |
  _BIT_MASK(sym_k_XmCascadeButton_object) |
  _BIT_MASK(sym_k_XmCascadeButtonGadget_object) |
  0, _BIT_MASK(sym_k_XmCheckBox_object) |
  _BIT_MASK(sym_k_XmColorSelector_object) |
  _BIT_MASK(sym_k_XmColumn_object) |
  _BIT_MASK(sym_k_XmComboBox_object) |
  _BIT_MASK(sym_k_XmCommand_object) |
  _BIT_MASK(sym_k_XmCommandDialog_object) |
  _BIT_MASK(sym_k_XmContainer_object) |
  _BIT_MASK(sym_k_XmDataField_object) |
  0, _BIT_MASK(sym_k_XmDrawingArea_object) |
  _BIT_MASK(sym_k_XmDrawnButton_object) |
  _BIT_MASK(sym_k_XmDropDown_object) |
  _BIT_MASK(sym_k_XmErrorDialog_object) |
  _BIT_MASK(sym_k_XmFileSelectionBox_object) |
  _BIT_MASK(sym_k_XmFileSelectionDialog_object) |
  _BIT_MASK(sym_k_XmFontSelector_object) |
  0, _BIT_MASK(sym_k_XmForm_object) |
  _BIT_MASK(sym_k_XmFormDialog_object) |
  _BIT_MASK(sym_k_XmFrame_object) |
  _BIT_MASK(sym_k_XmIconBox_object) |
  _BIT_MASK(sym_k_XmIconButton_object) |
  _BIT_MASK(sym_k_XmIconGadget_object) |
  _BIT_MASK(sym_k_XmInformationDialog_object) |
  _BIT_MASK(sym_k_XmLabel_object) |
  0, _BIT_MASK(sym_k_XmLabelGadget_object) |
  _BIT_MASK(sym_k_XmList_object) |
  _BIT_MASK(sym_k_XmMainWindow_object) |
  _BIT_MASK(sym_k_XmMenuBar_object) |
  _BIT_MASK(sym_k_XmMessageBox_object) |
  _BIT_MASK(sym_k_XmMessageDialog_object) |
  _BIT_MASK(sym_k_XmMultiList_object) |
  0, _BIT_MASK(sym_k_XmNotebook_object) |
  _BIT_MASK(sym_k_XmOptionMenu_object) |
  _BIT_MASK(sym_k_XmOutline_object) |
  _BIT_MASK(sym_k_XmPaned_object) |
  _BIT_MASK(sym_k_XmPanedWindow_object) |
  _BIT_MASK(sym_k_XmPopupMenu_object) |
  _BIT_MASK(sym_k_XmPromptDialog_object) |
  _BIT_MASK(sym_k_XmPulldownMenu_object) |
  0, _BIT_MASK(sym_k_XmPushButton_object) |
  _BIT_MASK(sym_k_XmPushButtonGadget_object) |
  _BIT_MASK(sym_k_XmQuestionDialog_object) |
  _BIT_MASK(sym_k_XmRadioBox_object) |
  _BIT_MASK(sym_k_XmRowColumn_object) |
  _BIT_MASK(sym_k_XmScale_object) |
  0, _BIT_MASK(sym_k_XmScrollBar_object) |
  _BIT_MASK(sym_k_XmScrolledList_object) |
  _BIT_MASK(sym_k_XmScrolledText_object) |
  _BIT_MASK(sym_k_XmScrolledWindow_object) |
  _BIT_MASK(sym_k_XmSelectionBox_object) |
  _BIT_MASK(sym_k_XmSelectionDialog_object) |
  _BIT_MASK(sym_k_XmSeparator_object) |
  _BIT_MASK(sym_k_XmSeparatorGadget_object) |
  0, _BIT_MASK(sym_k_XmSimpleSpinBox_object) |
  _BIT_MASK(sym_k_XmSpinBox_object) |
  _BIT_MASK(sym_k_XmTabBox_object) |
  _BIT_MASK(sym_k_XmTabStack_object) |
  _BIT_MASK(sym_k_XmTearOffButton_object) |
  _BIT_MASK(sym_k_XmTemplateDialog_object) |
  0, _BIT_MASK(sym_k_XmText_object) |
  _BIT_MASK(sym_k_XmTextField_object) |
  _BIT_MASK(sym_k_XmToggleButton_object) |
  _BIT_MASK(sym_k_XmToggleButtonGadget_object) |
  _BIT_MASK(sym_k_XmTree_object) |
  _BIT_MASK(sym_k_XmWarningDialog_object) |
  _BIT_MASK(sym_k_XmWorkArea_object) |
  _BIT_MASK(sym_k_XmWorkingDialog_object) |
  0, 0};

/* sym_k_XmNincrementCallback_reason */
static unsigned char reason_class_vec38[] =
  {
  0, 0, 0, 0, 0, 0, 0, 0, _BIT_MASK(sym_k_XmScrollBar_object) |
  0, 0, 0, 0};

/* sym_k_XmNinputCallback_reason */
static unsigned char reason_class_vec39[] =
  {
  0, 0, 0, _BIT_MASK(sym_k_XmDrawingArea_object) |
  0, 0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_XmNitemFoundCallback_reason */
static unsigned char reason_class_vec40[] =
  {
  0, 0, 0, 0, 0, _BIT_MASK(sym_k_XmMultiList_object) |
  0, 0, 0, 0, 0, 0, 0};

/* sym_k_XmNitemNotFoundCallback_reason */
static unsigned char reason_class_vec41[] =
  {
  0, 0, 0, 0, 0, _BIT_MASK(sym_k_XmMultiList_object) |
  0, 0, 0, 0, 0, 0, 0};

/* sym_k_XmNlosePrimaryCallback_reason */
static unsigned char reason_class_vec42[] =
  {
  0, 0, _BIT_MASK(sym_k_XmDataField_object) |
  0, 0, 0, 0, 0, 0, _BIT_MASK(sym_k_XmScrolledText_object) |
  0, 0, _BIT_MASK(sym_k_XmText_object) |
  _BIT_MASK(sym_k_XmTextField_object) |
  0, 0};

/* sym_k_XmNlosingFocusCallback_reason */
static unsigned char reason_class_vec43[] =
  {
  _BIT_MASK(sym_k_DtEditor_object) |
  _BIT_MASK(sym_k_DtHelpDialog_object) |
  _BIT_MASK(sym_k_DtHelpQuickDialog_object) |
  _BIT_MASK(sym_k_DtPrintSetupBox_object) |
  _BIT_MASK(sym_k_DtPrintSetupDialog_object) |
  0, _BIT_MASK(sym_k_XmBulletinBoard_object) |
  _BIT_MASK(sym_k_XmBulletinBoardDialog_object) |
  0, _BIT_MASK(sym_k_XmColumn_object) |
  _BIT_MASK(sym_k_XmCommand_object) |
  _BIT_MASK(sym_k_XmCommandDialog_object) |
  _BIT_MASK(sym_k_XmDataField_object) |
  0, _BIT_MASK(sym_k_XmErrorDialog_object) |
  _BIT_MASK(sym_k_XmFileSelectionBox_object) |
  _BIT_MASK(sym_k_XmFileSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmForm_object) |
  _BIT_MASK(sym_k_XmFormDialog_object) |
  _BIT_MASK(sym_k_XmInformationDialog_object) |
  0, _BIT_MASK(sym_k_XmMessageBox_object) |
  _BIT_MASK(sym_k_XmMessageDialog_object) |
  0, _BIT_MASK(sym_k_XmPromptDialog_object) |
  0, _BIT_MASK(sym_k_XmQuestionDialog_object) |
  0, _BIT_MASK(sym_k_XmScrolledText_object) |
  _BIT_MASK(sym_k_XmSelectionBox_object) |
  _BIT_MASK(sym_k_XmSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmTabStack_object) |
  _BIT_MASK(sym_k_XmTemplateDialog_object) |
  0, _BIT_MASK(sym_k_XmText_object) |
  _BIT_MASK(sym_k_XmTextField_object) |
  _BIT_MASK(sym_k_XmWarningDialog_object) |
  _BIT_MASK(sym_k_XmWorkingDialog_object) |
  0, 0};

/* sym_k_XmNmapCallback_reason */
static unsigned char reason_class_vec44[] =
  {
  _BIT_MASK(sym_k_DtEditor_object) |
  _BIT_MASK(sym_k_DtHelpDialog_object) |
  _BIT_MASK(sym_k_DtHelpQuickDialog_object) |
  _BIT_MASK(sym_k_DtPrintSetupBox_object) |
  _BIT_MASK(sym_k_DtPrintSetupDialog_object) |
  0, _BIT_MASK(sym_k_XmBulletinBoard_object) |
  _BIT_MASK(sym_k_XmBulletinBoardDialog_object) |
  0, _BIT_MASK(sym_k_XmCheckBox_object) |
  _BIT_MASK(sym_k_XmColumn_object) |
  _BIT_MASK(sym_k_XmCommand_object) |
  _BIT_MASK(sym_k_XmCommandDialog_object) |
  0, _BIT_MASK(sym_k_XmErrorDialog_object) |
  _BIT_MASK(sym_k_XmFileSelectionBox_object) |
  _BIT_MASK(sym_k_XmFileSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmForm_object) |
  _BIT_MASK(sym_k_XmFormDialog_object) |
  _BIT_MASK(sym_k_XmInformationDialog_object) |
  0, _BIT_MASK(sym_k_XmMenuBar_object) |
  _BIT_MASK(sym_k_XmMessageBox_object) |
  _BIT_MASK(sym_k_XmMessageDialog_object) |
  0, _BIT_MASK(sym_k_XmOptionMenu_object) |
  _BIT_MASK(sym_k_XmPopupMenu_object) |
  _BIT_MASK(sym_k_XmPromptDialog_object) |
  _BIT_MASK(sym_k_XmPulldownMenu_object) |
  0, _BIT_MASK(sym_k_XmQuestionDialog_object) |
  _BIT_MASK(sym_k_XmRadioBox_object) |
  _BIT_MASK(sym_k_XmRowColumn_object) |
  0, _BIT_MASK(sym_k_XmSelectionBox_object) |
  _BIT_MASK(sym_k_XmSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmTabStack_object) |
  _BIT_MASK(sym_k_XmTemplateDialog_object) |
  0, _BIT_MASK(sym_k_XmWarningDialog_object) |
  _BIT_MASK(sym_k_XmWorkArea_object) |
  _BIT_MASK(sym_k_XmWorkingDialog_object) |
  0, 0};

/* sym_k_XmNmodifyVerifyCallback_reason */
static unsigned char reason_class_vec45[] =
  {
  0, 0, _BIT_MASK(sym_k_XmDataField_object) |
  0, 0, 0, 0, 0, 0, _BIT_MASK(sym_k_XmScrolledText_object) |
  0, _BIT_MASK(sym_k_XmSimpleSpinBox_object) |
  _BIT_MASK(sym_k_XmSpinBox_object) |
  0, _BIT_MASK(sym_k_XmText_object) |
  _BIT_MASK(sym_k_XmTextField_object) |
  0, 0};

/* sym_k_XmNmodifyVerifyCallbackWcs_reason */
static unsigned char reason_class_vec46[] =
  {
  0, 0, _BIT_MASK(sym_k_XmDataField_object) |
  0, 0, 0, 0, 0, 0, _BIT_MASK(sym_k_XmScrolledText_object) |
  0, 0, _BIT_MASK(sym_k_XmText_object) |
  _BIT_MASK(sym_k_XmTextField_object) |
  0, 0};

/* sym_k_XmNmotionVerifyCallback_reason */
static unsigned char reason_class_vec47[] =
  {
  0, 0, _BIT_MASK(sym_k_XmDataField_object) |
  0, 0, 0, 0, 0, 0, _BIT_MASK(sym_k_XmScrolledText_object) |
  0, 0, _BIT_MASK(sym_k_XmText_object) |
  _BIT_MASK(sym_k_XmTextField_object) |
  0, 0};

/* sym_k_XmNmultipleSelectionCallback_reason */
static unsigned char reason_class_vec48[] =
  {
  0, 0, 0, 0, 0, _BIT_MASK(sym_k_XmList_object) |
  0, 0, 0, _BIT_MASK(sym_k_XmScrolledList_object) |
  0, 0, 0, 0};

/* sym_k_XmNnoMatchCallback_reason */
static unsigned char reason_class_vec49[] =
  {
  0, 0, 0, _BIT_MASK(sym_k_XmFileSelectionBox_object) |
  _BIT_MASK(sym_k_XmFileSelectionDialog_object) |
  0, 0, 0, _BIT_MASK(sym_k_XmPromptDialog_object) |
  0, 0, _BIT_MASK(sym_k_XmSelectionBox_object) |
  _BIT_MASK(sym_k_XmSelectionDialog_object) |
  0, 0, 0, 0};

/* sym_k_XmNnodeStateBegEndCallback_reason */
static unsigned char reason_class_vec50[] =
  {
  0, 0, 0, 0, 0, 0, _BIT_MASK(sym_k_XmOutline_object) |
  0, 0, 0, 0, _BIT_MASK(sym_k_XmTree_object) |
  0, 0};

/* sym_k_XmNnodeStateCallback_reason */
static unsigned char reason_class_vec51[] =
  {
  0, 0, 0, 0, 0, 0, _BIT_MASK(sym_k_XmOutline_object) |
  0, 0, 0, 0, 0, 0};

/* sym_k_XmNnodeStateChangedCallback_reason */
static unsigned char reason_class_vec52[] =
  {
  0, 0, 0, 0, 0, 0, _BIT_MASK(sym_k_XmOutline_object) |
  0, 0, 0, 0, _BIT_MASK(sym_k_XmTree_object) |
  0, 0};

/* sym_k_XmNokCallback_reason */
static unsigned char reason_class_vec53[] =
  {
  0, 0, 0, _BIT_MASK(sym_k_XmErrorDialog_object) |
  _BIT_MASK(sym_k_XmFileSelectionBox_object) |
  _BIT_MASK(sym_k_XmFileSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmInformationDialog_object) |
  0, _BIT_MASK(sym_k_XmMessageBox_object) |
  _BIT_MASK(sym_k_XmMessageDialog_object) |
  0, _BIT_MASK(sym_k_XmPromptDialog_object) |
  0, _BIT_MASK(sym_k_XmQuestionDialog_object) |
  0, _BIT_MASK(sym_k_XmSelectionBox_object) |
  _BIT_MASK(sym_k_XmSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmTemplateDialog_object) |
  0, _BIT_MASK(sym_k_XmWarningDialog_object) |
  _BIT_MASK(sym_k_XmWorkingDialog_object) |
  0, 0};

/* sym_k_XmNoutlineChangedCallback_reason */
static unsigned char reason_class_vec54[] =
  {
  0, 0, _BIT_MASK(sym_k_XmContainer_object) |
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_XmNpageChangedCallback_reason */
static unsigned char reason_class_vec55[] =
  {
  0, 0, 0, 0, 0, 0, _BIT_MASK(sym_k_XmNotebook_object) |
  0, 0, 0, 0, 0, 0};

/* sym_k_XmNpageDecrementCallback_reason */
static unsigned char reason_class_vec56[] =
  {
  0, 0, 0, 0, 0, 0, 0, 0, _BIT_MASK(sym_k_XmScrollBar_object) |
  0, 0, 0, 0};

/* sym_k_XmNpageIncrementCallback_reason */
static unsigned char reason_class_vec57[] =
  {
  0, 0, 0, 0, 0, 0, 0, 0, _BIT_MASK(sym_k_XmScrollBar_object) |
  0, 0, 0, 0};

/* sym_k_XmNpictureErrorCallback_reason */
static unsigned char reason_class_vec58[] =
  {
  0, 0, _BIT_MASK(sym_k_XmDataField_object) |
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_XmNpopdownCallback_reason */
static unsigned char reason_class_vec59[] =
  {
  _BIT_MASK(sym_k_DtHelpDialog_object) |
  _BIT_MASK(sym_k_DtHelpQuickDialog_object) |
  _BIT_MASK(sym_k_DtPrintSetupDialog_object) |
  0, _BIT_MASK(sym_k_XmBulletinBoardDialog_object) |
  0, _BIT_MASK(sym_k_XmCommandDialog_object) |
  0, _BIT_MASK(sym_k_XmDialogShell_object) |
  _BIT_MASK(sym_k_XmErrorDialog_object) |
  _BIT_MASK(sym_k_XmFileSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmFormDialog_object) |
  _BIT_MASK(sym_k_XmInformationDialog_object) |
  0, _BIT_MASK(sym_k_XmMenuShell_object) |
  _BIT_MASK(sym_k_XmMessageDialog_object) |
  0, _BIT_MASK(sym_k_XmPopupMenu_object) |
  _BIT_MASK(sym_k_XmPromptDialog_object) |
  _BIT_MASK(sym_k_XmPulldownMenu_object) |
  0, _BIT_MASK(sym_k_XmQuestionDialog_object) |
  0, _BIT_MASK(sym_k_XmSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmTemplateDialog_object) |
  0, _BIT_MASK(sym_k_XmWarningDialog_object) |
  _BIT_MASK(sym_k_XmWorkingDialog_object) |
  0, 0};

/* sym_k_XmNpopupCallback_reason */
static unsigned char reason_class_vec60[] =
  {
  _BIT_MASK(sym_k_DtHelpDialog_object) |
  _BIT_MASK(sym_k_DtHelpQuickDialog_object) |
  _BIT_MASK(sym_k_DtPrintSetupDialog_object) |
  0, _BIT_MASK(sym_k_XmBulletinBoardDialog_object) |
  0, _BIT_MASK(sym_k_XmCommandDialog_object) |
  0, _BIT_MASK(sym_k_XmDialogShell_object) |
  _BIT_MASK(sym_k_XmErrorDialog_object) |
  _BIT_MASK(sym_k_XmFileSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmFormDialog_object) |
  _BIT_MASK(sym_k_XmInformationDialog_object) |
  0, _BIT_MASK(sym_k_XmMenuShell_object) |
  _BIT_MASK(sym_k_XmMessageDialog_object) |
  0, _BIT_MASK(sym_k_XmPopupMenu_object) |
  _BIT_MASK(sym_k_XmPromptDialog_object) |
  _BIT_MASK(sym_k_XmPulldownMenu_object) |
  0, _BIT_MASK(sym_k_XmQuestionDialog_object) |
  0, _BIT_MASK(sym_k_XmSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmTemplateDialog_object) |
  0, _BIT_MASK(sym_k_XmWarningDialog_object) |
  _BIT_MASK(sym_k_XmWorkingDialog_object) |
  0, 0};

/* sym_k_XmNpopupHandlerCallback_reason */
static unsigned char reason_class_vec61[] =
  {
  _BIT_MASK(sym_k_DtEditor_object) |
  _BIT_MASK(sym_k_DtHelpDialog_object) |
  _BIT_MASK(sym_k_DtHelpQuickDialog_object) |
  _BIT_MASK(sym_k_DtMenuButton_object) |
  _BIT_MASK(sym_k_DtPrintSetupBox_object) |
  _BIT_MASK(sym_k_DtPrintSetupDialog_object) |
  _BIT_MASK(sym_k_DtTerm_object) |
  0, _BIT_MASK(sym_k_DtTermPrimitive_object) |
  _BIT_MASK(sym_k_XmArrowButton_object) |
  _BIT_MASK(sym_k_XmBulletinBoard_object) |
  _BIT_MASK(sym_k_XmBulletinBoardDialog_object) |
  _BIT_MASK(sym_k_XmButtonBox_object) |
  _BIT_MASK(sym_k_XmCascadeButton_object) |
  0, _BIT_MASK(sym_k_XmCheckBox_object) |
  _BIT_MASK(sym_k_XmColorSelector_object) |
  _BIT_MASK(sym_k_XmColumn_object) |
  _BIT_MASK(sym_k_XmComboBox_object) |
  _BIT_MASK(sym_k_XmCommand_object) |
  _BIT_MASK(sym_k_XmCommandDialog_object) |
  _BIT_MASK(sym_k_XmContainer_object) |
  _BIT_MASK(sym_k_XmDataField_object) |
  0, _BIT_MASK(sym_k_XmDrawingArea_object) |
  _BIT_MASK(sym_k_XmDrawnButton_object) |
  _BIT_MASK(sym_k_XmDropDown_object) |
  _BIT_MASK(sym_k_XmErrorDialog_object) |
  _BIT_MASK(sym_k_XmFileSelectionBox_object) |
  _BIT_MASK(sym_k_XmFileSelectionDialog_object) |
  _BIT_MASK(sym_k_XmFontSelector_object) |
  0, _BIT_MASK(sym_k_XmForm_object) |
  _BIT_MASK(sym_k_XmFormDialog_object) |
  _BIT_MASK(sym_k_XmFrame_object) |
  _BIT_MASK(sym_k_XmIconBox_object) |
  _BIT_MASK(sym_k_XmIconButton_object) |
  _BIT_MASK(sym_k_XmInformationDialog_object) |
  _BIT_MASK(sym_k_XmLabel_object) |
  0, _BIT_MASK(sym_k_XmList_object) |
  _BIT_MASK(sym_k_XmMainWindow_object) |
  _BIT_MASK(sym_k_XmMenuBar_object) |
  _BIT_MASK(sym_k_XmMessageBox_object) |
  _BIT_MASK(sym_k_XmMessageDialog_object) |
  _BIT_MASK(sym_k_XmMultiList_object) |
  0, _BIT_MASK(sym_k_XmNotebook_object) |
  _BIT_MASK(sym_k_XmOptionMenu_object) |
  _BIT_MASK(sym_k_XmOutline_object) |
  _BIT_MASK(sym_k_XmPaned_object) |
  _BIT_MASK(sym_k_XmPanedWindow_object) |
  _BIT_MASK(sym_k_XmPopupMenu_object) |
  _BIT_MASK(sym_k_XmPromptDialog_object) |
  _BIT_MASK(sym_k_XmPulldownMenu_object) |
  0, _BIT_MASK(sym_k_XmPushButton_object) |
  _BIT_MASK(sym_k_XmQuestionDialog_object) |
  _BIT_MASK(sym_k_XmRadioBox_object) |
  _BIT_MASK(sym_k_XmRowColumn_object) |
  _BIT_MASK(sym_k_XmScale_object) |
  0, _BIT_MASK(sym_k_XmScrollBar_object) |
  _BIT_MASK(sym_k_XmScrolledList_object) |
  _BIT_MASK(sym_k_XmScrolledText_object) |
  _BIT_MASK(sym_k_XmScrolledWindow_object) |
  _BIT_MASK(sym_k_XmSelectionBox_object) |
  _BIT_MASK(sym_k_XmSelectionDialog_object) |
  _BIT_MASK(sym_k_XmSeparator_object) |
  0, _BIT_MASK(sym_k_XmSimpleSpinBox_object) |
  _BIT_MASK(sym_k_XmSpinBox_object) |
  _BIT_MASK(sym_k_XmTabBox_object) |
  _BIT_MASK(sym_k_XmTabStack_object) |
  _BIT_MASK(sym_k_XmTearOffButton_object) |
  _BIT_MASK(sym_k_XmTemplateDialog_object) |
  0, _BIT_MASK(sym_k_XmText_object) |
  _BIT_MASK(sym_k_XmTextField_object) |
  _BIT_MASK(sym_k_XmToggleButton_object) |
  _BIT_MASK(sym_k_XmTree_object) |
  _BIT_MASK(sym_k_XmWarningDialog_object) |
  _BIT_MASK(sym_k_XmWorkArea_object) |
  _BIT_MASK(sym_k_XmWorkingDialog_object) |
  0, 0};

/* sym_k_XmNrealizeCallback_reason */
static unsigned char reason_class_vec62[] =
  {
  _BIT_MASK(sym_k_DtHelpDialog_object) |
  _BIT_MASK(sym_k_DtHelpQuickDialog_object) |
  _BIT_MASK(sym_k_DtPrintSetupDialog_object) |
  0, _BIT_MASK(sym_k_XmBulletinBoardDialog_object) |
  0, _BIT_MASK(sym_k_XmCommandDialog_object) |
  0, _BIT_MASK(sym_k_XmDialogShell_object) |
  _BIT_MASK(sym_k_XmErrorDialog_object) |
  _BIT_MASK(sym_k_XmFileSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmFormDialog_object) |
  _BIT_MASK(sym_k_XmInformationDialog_object) |
  0, _BIT_MASK(sym_k_XmMessageDialog_object) |
  0, _BIT_MASK(sym_k_XmPromptDialog_object) |
  0, _BIT_MASK(sym_k_XmQuestionDialog_object) |
  0, _BIT_MASK(sym_k_XmSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmTemplateDialog_object) |
  0, _BIT_MASK(sym_k_XmWarningDialog_object) |
  _BIT_MASK(sym_k_XmWorkingDialog_object) |
  0, 0};

/* sym_k_XmNresizeCallback_reason */
static unsigned char reason_class_vec63[] =
  {
  0, 0, 0, _BIT_MASK(sym_k_XmDrawingArea_object) |
  _BIT_MASK(sym_k_XmDrawnButton_object) |
  0, 0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_XmNselectCallback_reason */
static unsigned char reason_class_vec64[] =
  {
  0, 0, 0, 0, 0, _BIT_MASK(sym_k_XmMultiList_object) |
  0, 0, 0, 0, _BIT_MASK(sym_k_XmTabBox_object) |
  0, 0, 0};

/* sym_k_XmNselectionCallback_reason */
static unsigned char reason_class_vec65[] =
  {
  0, 0, _BIT_MASK(sym_k_XmComboBox_object) |
  _BIT_MASK(sym_k_XmContainer_object) |
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_XmNsimpleCallback_reason */
static unsigned char reason_class_vec66[] =
  {
  0, 0, _BIT_MASK(sym_k_XmCheckBox_object) |
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_XmNsingleSelectionCallback_reason */
static unsigned char reason_class_vec67[] =
  {
  0, 0, 0, 0, 0, _BIT_MASK(sym_k_XmList_object) |
  0, 0, 0, _BIT_MASK(sym_k_XmScrolledList_object) |
  0, 0, 0, 0};

/* sym_k_XmNtabSelectedCallback_reason */
static unsigned char reason_class_vec68[] =
  {
  0, 0, 0, 0, 0, 0, 0, 0, 0, _BIT_MASK(sym_k_XmTabStack_object) |
  0, 0, 0};

/* sym_k_XmNtearOffMenuActivateCallback_reason */
static unsigned char reason_class_vec69[] =
  {
  0, 0, _BIT_MASK(sym_k_XmCheckBox_object) |
  0, 0, 0, _BIT_MASK(sym_k_XmMenuBar_object) |
  0, _BIT_MASK(sym_k_XmOptionMenu_object) |
  _BIT_MASK(sym_k_XmPopupMenu_object) |
  _BIT_MASK(sym_k_XmPulldownMenu_object) |
  0, _BIT_MASK(sym_k_XmRadioBox_object) |
  _BIT_MASK(sym_k_XmRowColumn_object) |
  0, 0, 0, _BIT_MASK(sym_k_XmWorkArea_object) |
  0, 0};

/* sym_k_XmNtearOffMenuDeactivateCallback_reason */
static unsigned char reason_class_vec70[] =
  {
  0, 0, _BIT_MASK(sym_k_XmCheckBox_object) |
  0, 0, 0, _BIT_MASK(sym_k_XmMenuBar_object) |
  0, _BIT_MASK(sym_k_XmOptionMenu_object) |
  _BIT_MASK(sym_k_XmPopupMenu_object) |
  _BIT_MASK(sym_k_XmPulldownMenu_object) |
  0, _BIT_MASK(sym_k_XmRadioBox_object) |
  _BIT_MASK(sym_k_XmRowColumn_object) |
  0, 0, 0, _BIT_MASK(sym_k_XmWorkArea_object) |
  0, 0};

/* sym_k_XmNtoBottomCallback_reason */
static unsigned char reason_class_vec71[] =
  {
  0, 0, 0, 0, 0, 0, 0, 0, _BIT_MASK(sym_k_XmScrollBar_object) |
  0, 0, 0, 0};

/* sym_k_XmNtoTopCallback_reason */
static unsigned char reason_class_vec72[] =
  {
  0, 0, 0, 0, 0, 0, 0, 0, _BIT_MASK(sym_k_XmScrollBar_object) |
  0, 0, 0, 0};

/* sym_k_XmNtraversalCallback_reason */
static unsigned char reason_class_vec73[] =
  {
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_XmNtraverseObscuredCallback_reason */
static unsigned char reason_class_vec74[] =
  {
  0, 0, 0, 0, 0, _BIT_MASK(sym_k_XmMainWindow_object) |
  0, 0, 0, _BIT_MASK(sym_k_XmScrolledList_object) |
  _BIT_MASK(sym_k_XmScrolledText_object) |
  _BIT_MASK(sym_k_XmScrolledWindow_object) |
  0, 0, 0, 0};

/* sym_k_XmNunmapCallback_reason */
static unsigned char reason_class_vec75[] =
  {
  _BIT_MASK(sym_k_DtEditor_object) |
  _BIT_MASK(sym_k_DtHelpDialog_object) |
  _BIT_MASK(sym_k_DtHelpQuickDialog_object) |
  _BIT_MASK(sym_k_DtPrintSetupBox_object) |
  _BIT_MASK(sym_k_DtPrintSetupDialog_object) |
  0, _BIT_MASK(sym_k_XmBulletinBoard_object) |
  _BIT_MASK(sym_k_XmBulletinBoardDialog_object) |
  0, _BIT_MASK(sym_k_XmCheckBox_object) |
  _BIT_MASK(sym_k_XmColumn_object) |
  _BIT_MASK(sym_k_XmCommand_object) |
  _BIT_MASK(sym_k_XmCommandDialog_object) |
  0, _BIT_MASK(sym_k_XmErrorDialog_object) |
  _BIT_MASK(sym_k_XmFileSelectionBox_object) |
  _BIT_MASK(sym_k_XmFileSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmForm_object) |
  _BIT_MASK(sym_k_XmFormDialog_object) |
  _BIT_MASK(sym_k_XmInformationDialog_object) |
  0, _BIT_MASK(sym_k_XmMenuBar_object) |
  _BIT_MASK(sym_k_XmMessageBox_object) |
  _BIT_MASK(sym_k_XmMessageDialog_object) |
  0, _BIT_MASK(sym_k_XmOptionMenu_object) |
  _BIT_MASK(sym_k_XmPopupMenu_object) |
  _BIT_MASK(sym_k_XmPromptDialog_object) |
  _BIT_MASK(sym_k_XmPulldownMenu_object) |
  0, _BIT_MASK(sym_k_XmQuestionDialog_object) |
  _BIT_MASK(sym_k_XmRadioBox_object) |
  _BIT_MASK(sym_k_XmRowColumn_object) |
  0, _BIT_MASK(sym_k_XmSelectionBox_object) |
  _BIT_MASK(sym_k_XmSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmTabStack_object) |
  _BIT_MASK(sym_k_XmTemplateDialog_object) |
  0, _BIT_MASK(sym_k_XmWarningDialog_object) |
  _BIT_MASK(sym_k_XmWorkArea_object) |
  _BIT_MASK(sym_k_XmWorkingDialog_object) |
  0, 0};

/* sym_k_XmNunselectCallback_reason */
static unsigned char reason_class_vec76[] =
  {
  0, 0, 0, 0, 0, 0, 0, 0, 0, _BIT_MASK(sym_k_XmTabBox_object) |
  0, 0, 0};

/* sym_k_XmNupdateShellCallback_reason */
static unsigned char reason_class_vec77[] =
  {
  0, 0, 0, _BIT_MASK(sym_k_XmDropDown_object) |
  0, 0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_XmNupdateTextCallback_reason */
static unsigned char reason_class_vec78[] =
  {
  0, 0, 0, _BIT_MASK(sym_k_XmDropDown_object) |
  0, 0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_XmNvalidateCallback_reason */
static unsigned char reason_class_vec79[] =
  {
  0, 0, _BIT_MASK(sym_k_XmDataField_object) |
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_XmNvalueChangedCallback_reason */
static unsigned char reason_class_vec80[] =
  {
  0, 0, _BIT_MASK(sym_k_XmDataField_object) |
  0, _BIT_MASK(sym_k_XmFontSelector_object) |
  0, 0, 0, 0, _BIT_MASK(sym_k_XmScale_object) |
  0, _BIT_MASK(sym_k_XmScrollBar_object) |
  _BIT_MASK(sym_k_XmScrolledText_object) |
  0, _BIT_MASK(sym_k_XmSimpleSpinBox_object) |
  _BIT_MASK(sym_k_XmSpinBox_object) |
  0, _BIT_MASK(sym_k_XmText_object) |
  _BIT_MASK(sym_k_XmTextField_object) |
  _BIT_MASK(sym_k_XmToggleButton_object) |
  _BIT_MASK(sym_k_XmToggleButtonGadget_object) |
  0, 0};

/* sym_k_XmNverifyTextCallback_reason */
static unsigned char reason_class_vec81[] =
  {
  0, 0, 0, _BIT_MASK(sym_k_XmDropDown_object) |
  0, 0, 0, 0, 0, 0, 0, 0, 0};

/*
 * Table of bit vectors accessed by sym_k_..._reason
 */
static unsigned char *allowed_reason_table_vec[] =
  {
  NULL,	/* UNUSED */
  reason_class_vec1,
  reason_class_vec2,
  reason_class_vec3,
  reason_class_vec4,
  reason_class_vec5,
  reason_class_vec6,
  reason_class_vec7,
  reason_class_vec8,
  reason_class_vec9,
  reason_class_vec10,
  reason_class_vec11,
  reason_class_vec12,
  reason_class_vec13,
  reason_class_vec14,
  reason_class_vec15,
  reason_class_vec16,
  reason_class_vec17,
  reason_class_vec18,
  reason_class_vec19,
  reason_class_vec20,
  reason_class_vec21,
  reason_class_vec22,
  reason_class_vec23,
  reason_class_vec24,
  reason_class_vec25,
  reason_class_vec26,
  reason_class_vec27,
  reason_class_vec28,
  reason_class_vec29,
  reason_class_vec30,
  reason_class_vec31,
  reason_class_vec32,
  reason_class_vec33,
  reason_class_vec34,
  reason_class_vec35,
  reason_class_vec36,
  reason_class_vec37,
  reason_class_vec38,
  reason_class_vec39,
  reason_class_vec40,
  reason_class_vec41,
  reason_class_vec42,
  reason_class_vec43,
  reason_class_vec44,
  reason_class_vec45,
  reason_class_vec46,
  reason_class_vec47,
  reason_class_vec48,
  reason_class_vec49,
  reason_class_vec50,
  reason_class_vec51,
  reason_class_vec52,
  reason_class_vec53,
  reason_class_vec54,
  reason_class_vec55,
  reason_class_vec56,
  reason_class_vec57,
  reason_class_vec58,
  reason_class_vec59,
  reason_class_vec60,
  reason_class_vec61,
  reason_class_vec62,
  reason_class_vec63,
  reason_class_vec64,
  reason_class_vec65,
  reason_class_vec66,
  reason_class_vec67,
  reason_class_vec68,
  reason_class_vec69,
  reason_class_vec70,
  reason_class_vec71,
  reason_class_vec72,
  reason_class_vec73,
  reason_class_vec74,
  reason_class_vec75,
  reason_class_vec76,
  reason_class_vec77,
  reason_class_vec78,
  reason_class_vec79,
  reason_class_vec80,
  reason_class_vec81,
  };
externaldef(uil_sym_glbl) unsigned char **allowed_reason_table =
		allowed_reason_table_vec;
