/*
**	This file is automatically generated.  Do not edit it by hand.
**/
/*  Table of the types of arguments
    The table is indexed by argument with each entry the
    permitted type for that argument.
*/

static unsigned char argument_type_table_vec[] =
  {
    0,
    sym_k_bool_value,
    sym_k_bool_value,
    sym_k_bool_value,
    sym_k_bool_value,
    sym_k_bool_value,
    sym_k_compound_string_value,
    sym_k_bool_value,
    sym_k_integer_value,
    sym_k_integer_value,
    sym_k_integer_value,
    sym_k_font_table_value,
    sym_k_bool_value,
    sym_k_pixmap_value,
    sym_k_compound_string_value,
    sym_k_compound_string_value,
    sym_k_compound_string_value,
    sym_k_compound_string_value,
    sym_k_integer_value,
    sym_k_compound_string_value,
    sym_k_integer_value,
    sym_k_bool_value,
    sym_k_integer_value,
    sym_k_char_8_value,
    sym_k_compound_string_value,
    sym_k_integer_value,
    sym_k_bool_value,
    sym_k_compound_string_value,
    sym_k_compound_string_value,
    sym_k_bool_value,
    sym_k_char_8_value,
    sym_k_integer_value,
    sym_k_char_8_value,
    sym_k_compound_string_value,
    sym_k_compound_string_value,
    sym_k_compound_string_value,
    sym_k_compound_string_value,
    sym_k_compound_string_value,
    sym_k_compound_string_value,
    sym_k_integer_value,
    sym_k_char_8_value,
    sym_k_compound_string_value,
    sym_k_char_8_value,
    sym_k_char_8_value,
    sym_k_integer_value,
    sym_k_char_8_value,
    sym_k_compound_string_value,
    sym_k_compound_string_value,
    sym_k_bool_value,
    sym_k_compound_string_value,
    sym_k_bool_value,
    sym_k_font_table_value,
    sym_k_compound_string_value,
    sym_k_compound_string_value,
    sym_k_char_8_value,
    sym_k_char_8_value,
    sym_k_bool_value,
    sym_k_bool_value,
    sym_k_char_8_value,
    sym_k_bool_value,
    sym_k_integer_value,
    sym_k_bool_value,
    sym_k_vertical_float_value,
    sym_k_horizontal_float_value,
    sym_k_integer_value,
    sym_k_bool_value,
    sym_k_compound_string_value,
    sym_k_compound_string_value,
    sym_k_integer_value,
    sym_k_bool_value,
    sym_k_compound_string_value,
    sym_k_integer_value,
    sym_k_bool_value,
    sym_k_integer_value,
    sym_k_color_value,
    sym_k_color_value,
    sym_k_any_value,
    sym_k_integer_value,
    sym_k_compound_string_value,
    sym_k_integer_value,
    sym_k_char_8_value,
    sym_k_any_value,
    sym_k_char_8_value,
    sym_k_bool_value,
    sym_k_bool_value,
    sym_k_compound_string_value,
    sym_k_compound_string_value,
    sym_k_integer_value,
    sym_k_char_8_value,
    sym_k_integer_value,
    sym_k_bool_value,
    sym_k_bool_value,
    sym_k_bool_value,
    sym_k_bool_value,
    sym_k_any_value,
    sym_k_any_value,
    sym_k_integer_value,
    sym_k_bool_value,
    sym_k_bool_value,
    sym_k_compound_string_value,
    sym_k_char_8_value,
    sym_k_bool_value,
    sym_k_bool_value,
    sym_k_char_8_value,
    sym_k_widget_ref_value,
    sym_k_any_value,
    sym_k_char_8_value,
    sym_k_bool_value,
    sym_k_bool_value,
    sym_k_integer_value,
    sym_k_bool_value,
    sym_k_bool_value,
    sym_k_integer_value,
    sym_k_bool_value,
    sym_k_char_8_value,
    sym_k_char_8_value,
    sym_k_char_8_value,
    sym_k_color_value,
    sym_k_font_table_value,
    sym_k_color_value,
    sym_k_trans_table_value,
    sym_k_integer_value,
    sym_k_char_8_value,
    sym_k_compound_string_value,
    sym_k_char_8_value,
    sym_k_font_table_value,
    sym_k_font_table_value,
    sym_k_any_value,
    sym_k_widget_ref_value,
    sym_k_integer_value,
    sym_k_bool_value,
    sym_k_integer_value,
    sym_k_bool_value,
    sym_k_integer_value,
    sym_k_compound_string_value,
    sym_k_compound_string_value,
    sym_k_char_8_value,
    sym_k_compound_string_value,
    sym_k_trans_table_value,
    sym_k_bool_value,
    sym_k_bool_value,
    sym_k_integer_value,
    sym_k_bool_value,
    sym_k_bool_value,
    sym_k_bool_value,
    sym_k_bool_value,
    sym_k_bool_value,
    sym_k_compound_string_value,
    sym_k_compound_string_value,
    sym_k_compound_string_value,
    sym_k_color_value,
    sym_k_pixmap_value,
    sym_k_integer_value,
    sym_k_integer_value,
    sym_k_integer_value,
    sym_k_integer_value,
    sym_k_horizontal_float_value,
    sym_k_horizontal_float_value,
    sym_k_integer_value,
    sym_k_bool_value,
    sym_k_integer_value,
    sym_k_bool_value,
    sym_k_bool_value,
    sym_k_bool_value,
    sym_k_integer_value,
    sym_k_color_value,
    sym_k_color_value,
    sym_k_integer_value,
    sym_k_integer_value,
    sym_k_horizontal_float_value,
    sym_k_color_value,
    sym_k_pixmap_value,
    sym_k_vertical_float_value,
    sym_k_horizontal_float_value,
    sym_k_pixmap_value,
    sym_k_integer_value,
    sym_k_horizontal_float_value,
    sym_k_integer_value,
    sym_k_compound_string_value,
    sym_k_compound_string_value,
    sym_k_color_value,
    sym_k_pixmap_value,
    sym_k_horizontal_float_value,
    sym_k_compound_string_value,
    sym_k_integer_value,
    sym_k_vertical_float_value,
    sym_k_integer_value,
    sym_k_color_value,
    sym_k_pixmap_value,
    sym_k_widget_ref_value,
    sym_k_integer_value,
    sym_k_font_table_value,
    sym_k_widget_ref_value,
    sym_k_string_table_value,
    sym_k_widget_ref_value,
    sym_k_compound_string_value,
    sym_k_pixmap_value,
    sym_k_integer_value,
    sym_k_integer_value,
    sym_k_integer_value,
    sym_k_horizontal_float_value,
    sym_k_integer_value,
    sym_k_integer_value,
    sym_k_integer_value,
    sym_k_widget_ref_value,
    sym_k_pixmap_value,
    sym_k_pixmap_value,
    sym_k_compound_string_value,
    sym_k_integer_value,
    sym_k_char_8_value,
    sym_k_identifier_value,
    sym_k_string_table_value,
    sym_k_integer_value,
    sym_k_integer_value,
    sym_k_trans_table_value,
    sym_k_compound_string_value,
    sym_k_widget_ref_value,
    sym_k_integer_value,
    sym_k_integer_value,
    sym_k_bool_value,
    sym_k_integer_value,
    sym_k_bool_value,
    sym_k_any_value,
    sym_k_char_8_value,
    sym_k_integer_value,
    sym_k_identifier_value,
    sym_k_integer_value,
    sym_k_bool_value,
    sym_k_bool_value,
    sym_k_integer_value,
    sym_k_char_8_value,
    sym_k_integer_value,
    sym_k_integer_value,
    sym_k_widget_ref_value,
    sym_k_horizontal_float_value,
    sym_k_integer_value,
    sym_k_char_8_value,
    sym_k_integer_value,
    sym_k_font_table_value,
    sym_k_widget_ref_value,
    sym_k_integer_value,
    sym_k_font_table_value,
    sym_k_bool_value,
    sym_k_integer_value,
    sym_k_identifier_value,
    sym_k_string_table_value,
    sym_k_string_table_value,
    sym_k_integer_value,
    sym_k_integer_value,
    sym_k_integer_table_value,
    sym_k_integer_value,
    sym_k_horizontal_float_value,
    sym_k_widget_ref_value,
    sym_k_integer_value,
    sym_k_compound_string_value,
    sym_k_integer_value,
    sym_k_integer_value,
    sym_k_string_table_value,
    sym_k_compound_string_value,
    sym_k_compound_string_value,
    sym_k_any_value,
    sym_k_compound_string_value,
    sym_k_compound_string_value,
    sym_k_bool_value,
    sym_k_integer_value,
    sym_k_integer_value,
    sym_k_integer_value,
    sym_k_bool_value,
    sym_k_asciz_table_value,
    sym_k_compound_string_value,
    sym_k_integer_value,
    sym_k_color_value,
    sym_k_horizontal_float_value,
    sym_k_class_rec_name_value,
    sym_k_identifier_value,
    sym_k_integer_value,
    sym_k_font_table_value,
    sym_k_pixmap_value,
    sym_k_widget_ref_value,
    sym_k_compound_string_value,
    sym_k_integer_value,
    sym_k_widget_ref_value,
    sym_k_integer_value,
    sym_k_integer_value,
    sym_k_bool_value,
    sym_k_pixmap_value,
    sym_k_compound_string_value,
    sym_k_integer_value,
    sym_k_string_table_value,
    sym_k_compound_string_value,
    sym_k_compound_string_value,
    sym_k_any_value,
    sym_k_integer_value,
    sym_k_bool_value,
    sym_k_bool_value,
    sym_k_integer_value,
    sym_k_integer_value,
    sym_k_compound_string_value,
    sym_k_compound_string_value,
    sym_k_integer_value,
    sym_k_bool_value,
    sym_k_integer_value,
    sym_k_integer_value,
    sym_k_font_value,
    sym_k_char_8_value,
    sym_k_char_8_value,
    sym_k_font_table_value,
    sym_k_char_8_value,
    sym_k_integer_value,
    sym_k_char_8_value,
    sym_k_integer_value,
    sym_k_color_value,
    sym_k_integer_value,
    sym_k_integer_value,
    sym_k_color_value,
    sym_k_integer_value,
    sym_k_horizontal_float_value,
    sym_k_bool_value,
    sym_k_char_8_value,
    sym_k_compound_string_value,
    sym_k_vertical_float_value,
    sym_k_vertical_float_value,
    sym_k_compound_string_value,
    sym_k_color_value,
    sym_k_bool_value,
    sym_k_pixmap_value,
    sym_k_horizontal_float_value,
    sym_k_integer_value,
    sym_k_string_table_value,
    sym_k_integer_value,
    sym_k_integer_value,
    sym_k_integer_value,
    sym_k_integer_value,
    sym_k_integer_value,
    sym_k_widget_ref_value,
    sym_k_horizontal_float_value,
    sym_k_pixmap_value,
    sym_k_char_8_value,
    sym_k_any_value,
    sym_k_pixmap_value,
    sym_k_integer_value,
    sym_k_integer_value,
    sym_k_any_value,
    sym_k_horizontal_float_value,
    sym_k_vertical_float_value,
    sym_k_bool_value,
    sym_k_integer_value,
    sym_k_integer_value,
    sym_k_integer_value,
    sym_k_pixmap_value,
    sym_k_pixmap_value,
    sym_k_integer_value,
    sym_k_horizontal_float_value,
    sym_k_integer_value,
    sym_k_integer_value,
    sym_k_widget_ref_value,
    sym_k_bool_value,
    sym_k_integer_value,
    sym_k_vertical_float_value,
    sym_k_horizontal_float_value,
    sym_k_bool_value,
    sym_k_char_8_value,
    sym_k_integer_value,
    sym_k_widget_ref_value,
    sym_k_identifier_value,
    sym_k_bool_value,
    sym_k_bool_value,
    sym_k_compound_string_value,
    sym_k_integer_value,
    sym_k_integer_value,
    sym_k_string_table_value,
    sym_k_integer_value,
    sym_k_char_8_value,
    sym_k_font_table_value,
    sym_k_pixmap_value,
    sym_k_pixmap_value,
    sym_k_widget_ref_value,
    sym_k_integer_value,
    sym_k_compound_string_value,
    sym_k_integer_value,
    sym_k_vertical_float_value,
    sym_k_horizontal_float_value,
    sym_k_pixmap_value,
    sym_k_pixmap_value,
    sym_k_horizontal_float_value,
    sym_k_vertical_float_value,
    sym_k_integer_value,
    sym_k_integer_value,
    sym_k_integer_value,
    sym_k_integer_value,
    sym_k_horizontal_float_value,
    sym_k_integer_value,
    sym_k_widget_ref_value,
    sym_k_integer_value,
    sym_k_color_value,
    sym_k_color_value,
    sym_k_integer_value,
    sym_k_integer_value,
    sym_k_widget_ref_value,
    sym_k_integer_value,
    sym_k_string_table_value,
    sym_k_compound_string_value,
    sym_k_vertical_float_value,
    sym_k_horizontal_float_value,
    sym_k_integer_value,
    sym_k_horizontal_float_value,
    sym_k_bool_value,
    sym_k_integer_value,
    sym_k_integer_value,
    sym_k_vertical_float_value,
    sym_k_horizontal_float_value,
    sym_k_vertical_float_value,
    sym_k_bool_value,
    sym_k_integer_value,
    sym_k_horizontal_float_value,
    sym_k_vertical_float_value,
    sym_k_vertical_float_value,
    sym_k_horizontal_float_value,
    sym_k_horizontal_float_value,
    sym_k_vertical_float_value,
    sym_k_horizontal_float_value,
    sym_k_integer_value,
    sym_k_integer_value,
    sym_k_integer_value,
    sym_k_vertical_float_value,
    sym_k_integer_value,
    sym_k_horizontal_float_value,
    sym_k_integer_value,
    sym_k_integer_value,
    sym_k_char_8_value,
    sym_k_widget_ref_value,
    sym_k_widget_ref_value,
    sym_k_widget_ref_value,
    sym_k_char_8_value,
    sym_k_integer_value,
    sym_k_compound_string_value,
    sym_k_widget_ref_value,
    sym_k_integer_value,
    sym_k_integer_value,
    sym_k_vertical_float_value,
    sym_k_horizontal_float_value,
    sym_k_bool_value,
    sym_k_integer_value,
    sym_k_integer_value,
    sym_k_integer_value,
    sym_k_integer_value,
    sym_k_integer_value,
    sym_k_integer_value,
    sym_k_vertical_float_value,
    sym_k_keysym_value,
    sym_k_char_8_value,
    sym_k_compound_string_value,
    sym_k_integer_value,
    sym_k_bool_value,
    sym_k_integer_value,
    sym_k_integer_value,
    sym_k_integer_value,
    sym_k_char_8_value,
    sym_k_integer_value,
    sym_k_bool_value,
    sym_k_compound_string_value,
    sym_k_compound_string_value,
    sym_k_bool_value,
    sym_k_pixmap_value,
    sym_k_pixmap_value,
    sym_k_integer_value,
    sym_k_integer_value,
    sym_k_integer_value,
    sym_k_integer_value,
    sym_k_integer_value,
    sym_k_integer_value,
    sym_k_integer_value,
    sym_k_compound_string_value,
    sym_k_integer_value,
    sym_k_pixmap_value,
    sym_k_compound_string_value,
    sym_k_integer_value,
    sym_k_compound_string_value,
    sym_k_integer_value,
    sym_k_horizontal_float_value,
    sym_k_horizontal_float_value,
    sym_k_integer_value,
    sym_k_integer_value,
    sym_k_bool_value,
    sym_k_integer_value,
    sym_k_integer_value,
    sym_k_integer_value,
    sym_k_horizontal_float_value,
    sym_k_horizontal_float_value,
    sym_k_widget_ref_value,
    sym_k_compound_string_value,
    sym_k_bool_value,
    sym_k_compound_string_value,
    sym_k_pixmap_value,
    sym_k_integer_value,
    sym_k_vertical_float_value,
    sym_k_integer_value,
    sym_k_integer_value,
    sym_k_horizontal_float_value,
    sym_k_identifier_value,
    sym_k_bool_value,
    sym_k_integer_value,
    sym_k_widget_ref_value,
    sym_k_integer_value,
    sym_k_integer_value,
    sym_k_integer_value,
    sym_k_integer_value,
    sym_k_char_8_value,
    sym_k_integer_value,
    sym_k_integer_value,
    sym_k_integer_value,
    sym_k_compound_string_value,
    sym_k_compound_string_value,
    sym_k_bool_value,
    sym_k_any_value,
    sym_k_bool_value,
    sym_k_bool_value,
    sym_k_bool_value,
    sym_k_compound_string_value,
    sym_k_bool_value,
    sym_k_widget_ref_value,
    sym_k_color_value,
    sym_k_color_value,
    sym_k_integer_value,
    sym_k_bool_value,
    sym_k_bool_value,
    sym_k_integer_value,
    sym_k_bool_value,
    sym_k_bool_value,
    sym_k_char_8_value,
    sym_k_integer_value,
    sym_k_horizontal_float_value,
    sym_k_integer_value,
    sym_k_widget_ref_value,
    sym_k_integer_value,
    sym_k_integer_value,
    sym_k_bool_value,
    sym_k_compound_string_value,
    sym_k_horizontal_float_value,
    sym_k_horizontal_float_value,
    sym_k_horizontal_float_value,
    sym_k_trans_table_value,
    sym_k_horizontal_float_value,
    sym_k_bool_value,
    sym_k_vertical_float_value,
    sym_k_integer_value,
    sym_k_horizontal_float_value,
    sym_k_compound_string_value,
    sym_k_identifier_value,
    sym_k_integer_value,
    sym_k_integer_value,
    sym_k_bool_value,
    sym_k_bool_value,
    sym_k_bool_value,
    sym_k_bool_value,
    sym_k_integer_value,
    sym_k_integer_value,
    sym_k_integer_value,
    sym_k_integer_value,
    sym_k_color_value,
    sym_k_pixmap_value,
    sym_k_pixmap_value,
    sym_k_integer_value,
    sym_k_integer_value,
    sym_k_compound_string_value,
    sym_k_integer_value,
    sym_k_string_table_value,
    sym_k_integer_value,
    sym_k_integer_value,
    sym_k_integer_table_value,
    sym_k_integer_table_value,
    sym_k_integer_value,
    sym_k_compound_string_value,
    sym_k_integer_value,
    sym_k_integer_value,
    sym_k_integer_value,
    sym_k_bool_value,
    sym_k_bool_value,
    sym_k_integer_value,
    sym_k_integer_value,
    sym_k_horizontal_float_value,
    sym_k_integer_value,
    sym_k_integer_value,
    sym_k_integer_value,
    sym_k_integer_value,
    sym_k_bool_value,
    sym_k_bool_value,
    sym_k_bool_value,
    sym_k_bool_value,
    sym_k_compound_string_value,
    sym_k_bool_value,
    sym_k_bool_value,
    sym_k_integer_value,
    sym_k_compound_string_value,
    sym_k_bool_value,
    sym_k_integer_value,
    sym_k_integer_value,
    sym_k_compound_string_value,
    sym_k_integer_value,
    sym_k_integer_value,
    sym_k_vertical_float_value,
    sym_k_horizontal_float_value,
    sym_k_pixmap_value,
    sym_k_pixmap_value,
    sym_k_horizontal_float_value,
    sym_k_vertical_float_value,
    sym_k_integer_value,
    sym_k_identifier_value,
    sym_k_any_value,
    sym_k_horizontal_float_value,
    sym_k_integer_value,
    sym_k_integer_value,
    sym_k_integer_value,
    sym_k_integer_value,
    sym_k_integer_value,
    sym_k_bool_value,
    sym_k_bool_value,
    sym_k_integer_value,
    sym_k_integer_value,
    sym_k_widget_ref_value,
    sym_k_pixmap_value,
    sym_k_integer_value,
    sym_k_bool_value,
    sym_k_color_value,
    sym_k_pixmap_value,
    sym_k_integer_value,
    sym_k_integer_value,
    sym_k_color_value,
    sym_k_pixmap_value,
    sym_k_integer_value,
    sym_k_compound_string_value,
    sym_k_identifier_value,
    sym_k_integer_value,
    sym_k_integer_value,
    sym_k_integer_value,
    sym_k_integer_value,
    sym_k_integer_value,
    sym_k_integer_value,
    sym_k_color_value,
    sym_k_pixmap_value,
    sym_k_integer_value,
    sym_k_integer_value,
    sym_k_integer_value,
    sym_k_float_value,
    sym_k_integer_value,
    sym_k_char_8_value,
    sym_k_trans_table_value,
    sym_k_integer_value,
    sym_k_widget_ref_value,
    sym_k_font_table_value,
    sym_k_widget_ref_value,
    sym_k_integer_value,
    sym_k_compound_string_value,
    sym_k_trans_table_value,
    sym_k_char_8_value,
    sym_k_any_value,
    sym_k_compound_string_value,
    sym_k_integer_value,
    sym_k_bool_value,
    sym_k_integer_value,
    sym_k_integer_value,
    sym_k_compound_string_value,
    sym_k_integer_value,
    sym_k_integer_value,
    sym_k_integer_value,
    sym_k_vertical_float_value,
    sym_k_integer_value,
    sym_k_color_value,
    sym_k_pixmap_value,
    sym_k_widget_ref_value,
    sym_k_bool_value,
    sym_k_widget_ref_value,
    sym_k_trans_table_value,
    sym_k_bool_value,
    sym_k_color_value,
    sym_k_integer_value,
    sym_k_bool_value,
    sym_k_integer_value,
    sym_k_integer_value,
    sym_k_color_value,
    sym_k_bool_value,
    sym_k_bool_value,
    sym_k_bool_value,
    sym_k_bool_value,
    sym_k_any_value,
    sym_k_any_value,
    sym_k_wchar_string_value,
    sym_k_string_table_value,
    sym_k_bool_value,
    sym_k_bool_value,
    sym_k_integer_value,
    sym_k_integer_value,
    sym_k_integer_value,
    sym_k_widget_ref_value,
    sym_k_vertical_float_value,
    sym_k_integer_value,
    sym_k_integer_value,
    sym_k_bool_value,
    sym_k_any_value,
    sym_k_integer_value,
    sym_k_integer_value,
    sym_k_bool_value,
    sym_k_integer_value,
    sym_k_horizontal_float_value,
    sym_k_horizontal_float_value,
    sym_k_integer_value,
    sym_k_any_value,
    sym_k_integer_value,
    sym_k_bool_value,
    sym_k_widget_ref_value,
    sym_k_bool_value,
    sym_k_horizontal_float_value,
    sym_k_compound_string_value,
    sym_k_vertical_float_value,
    sym_k_integer_value,
  };
externaldef(uil_sym_glbl) unsigned char *argument_type_table =
	 argument_type_table_vec;
