/*
**	This file is automatically generated.  Do not edit it by hand.
**/


/*    case sensitive keyword table    */
static key_keytable_entry_type key_table_vec[] =
  {
    {tkn_k_class_charset, sym_k_dos_cyrillic_charset, 3, CHARSET_NAME, "866"},
    {tkn_k_class_charset, sym_k_iso_latin1_charset, 5, CHARSET_NAME, "88591"},
    {tkn_k_class_charset, sym_k_iso_latin2_charset, 5, CHARSET_NAME, "88592"},
    {tkn_k_class_charset, sym_k_iso_latin3_charset, 5, CHARSET_NAME, "88593"},
    {tkn_k_class_charset, sym_k_iso_latin4_charset, 5, CHARSET_NAME, "88594"},
    {tkn_k_class_charset, sym_k_iso_latin5_charset, 5, CHARSET_NAME, "88595"},
    {tkn_k_class_charset, sym_k_iso_arabic_charset, 5, CHARSET_NAME, "88596"},
    {tkn_k_class_charset, sym_k_iso_greek_charset, 5, CHARSET_NAME, "88597"},
    {tkn_k_class_charset, sym_k_iso_hebrew_charset, 5, CHARSET_NAME, "88598"},
    {tkn_k_class_charset, sym_k_ansi_cyrillic_charset, 9, CHARSET_NAME, "ANSI-1251"},
    {tkn_k_class_charset, sym_k_ansi_cyrillic_charset, 8, CHARSET_NAME, "ANSI1251"},
    {tkn_k_class_charset, sym_k_iso_latin1_charset, 5, CHARSET_NAME, "ASCII"},
    {tkn_k_class_enumval, sym_k_Always_enumval, 6, ENUMVAL_NAME, "Always"},
    {tkn_k_class_charset, sym_k_dos_cyrillic_charset, 5, CHARSET_NAME, "CP866"},
    {tkn_k_class_class, sym_k_DtEditor_object, 8, CLASS_NAME, "DtEditor"},
    {tkn_k_class_enumval, sym_k_DtHELP_AS_NEEDED_SCROLLBARS_enumval, 27, ENUMVAL_NAME, "DtHELP_AS_NEEDED_SCROLLBARS"},
    {tkn_k_class_enumval, sym_k_DtHELP_EXECUTE_ALL_enumval, 18, ENUMVAL_NAME, "DtHELP_EXECUTE_ALL"},
    {tkn_k_class_enumval, sym_k_DtHELP_EXECUTE_NONE_enumval, 19, ENUMVAL_NAME, "DtHELP_EXECUTE_NONE"},
    {tkn_k_class_enumval, sym_k_DtHELP_EXECUTE_QUERY_ALL_enumval, 24, ENUMVAL_NAME, "DtHELP_EXECUTE_QUERY_ALL"},
    {tkn_k_class_enumval, sym_k_DtHELP_EXECUTE_QUERY_UNALIASED_enumval, 30, ENUMVAL_NAME, "DtHELP_EXECUTE_QUERY_UNALIASED"},
    {tkn_k_class_enumval, sym_k_DtHELP_NO_SCROLLBARS_enumval, 20, ENUMVAL_NAME, "DtHELP_NO_SCROLLBARS"},
    {tkn_k_class_enumval, sym_k_DtHELP_PAPERSIZE_A4_enumval, 19, ENUMVAL_NAME, "DtHELP_PAPERSIZE_A4"},
    {tkn_k_class_enumval, sym_k_DtHELP_PAPERSIZE_B5_enumval, 19, ENUMVAL_NAME, "DtHELP_PAPERSIZE_B5"},
    {tkn_k_class_enumval, sym_k_DtHELP_PAPERSIZE_EXECUTIVE_enumval, 26, ENUMVAL_NAME, "DtHELP_PAPERSIZE_EXECUTIVE"},
    {tkn_k_class_enumval, sym_k_DtHELP_PAPERSIZE_LEGAL_enumval, 22, ENUMVAL_NAME, "DtHELP_PAPERSIZE_LEGAL"},
    {tkn_k_class_enumval, sym_k_DtHELP_PAPERSIZE_LETTER_enumval, 23, ENUMVAL_NAME, "DtHELP_PAPERSIZE_LETTER"},
    {tkn_k_class_enumval, sym_k_DtHELP_STATIC_SCROLLBARS_enumval, 24, ENUMVAL_NAME, "DtHELP_STATIC_SCROLLBARS"},
    {tkn_k_class_enumval, sym_k_DtHELP_TYPE_DYNAMIC_STRING_enumval, 26, ENUMVAL_NAME, "DtHELP_TYPE_DYNAMIC_STRING"},
    {tkn_k_class_enumval, sym_k_DtHELP_TYPE_FILE_enumval, 16, ENUMVAL_NAME, "DtHELP_TYPE_FILE"},
    {tkn_k_class_enumval, sym_k_DtHELP_TYPE_MAN_PAGE_enumval, 20, ENUMVAL_NAME, "DtHELP_TYPE_MAN_PAGE"},
    {tkn_k_class_enumval, sym_k_DtHELP_TYPE_STRING_enumval, 18, ENUMVAL_NAME, "DtHELP_TYPE_STRING"},
    {tkn_k_class_enumval, sym_k_DtHELP_TYPE_TOPIC_enumval, 17, ENUMVAL_NAME, "DtHELP_TYPE_TOPIC"},
    {tkn_k_class_class, sym_k_DtHelpDialog_object, 12, CLASS_NAME, "DtHelpDialog"},
    {tkn_k_class_class, sym_k_DtHelpQuickDialog_object, 17, CLASS_NAME, "DtHelpQuickDialog"},
    {tkn_k_class_enumval, sym_k_DtLONG_NAME_enumval, 11, ENUMVAL_NAME, "DtLONG_NAME"},
    {tkn_k_class_enumval, sym_k_DtMEDIUM_NAME_enumval, 13, ENUMVAL_NAME, "DtMEDIUM_NAME"},
    {tkn_k_class_class, sym_k_DtMenuButton_object, 12, CLASS_NAME, "DtMenuButton"},
    {tkn_k_class_argument, sym_k_DtNallowSendEvents_arg, 18, ARGUMENT_NAME, "DtNallowSendEvents"},
    {tkn_k_class_argument, sym_k_DtNappCursorDefault_arg, 19, ARGUMENT_NAME, "DtNappCursorDefault"},
    {tkn_k_class_argument, sym_k_DtNappKeypadDefault_arg, 19, ARGUMENT_NAME, "DtNappKeypadDefault"},
    {tkn_k_class_argument, sym_k_DtNautoShowCursorPosition_arg, 25, ARGUMENT_NAME, "DtNautoShowCursorPosition"},
    {tkn_k_class_argument, sym_k_DtNautoWrap_arg, 11, ARGUMENT_NAME, "DtNautoWrap"},
    {tkn_k_class_argument, sym_k_DtNbackLabelString_arg, 18, ARGUMENT_NAME, "DtNbackLabelString"},
    {tkn_k_class_argument, sym_k_DtNbackgroundIsSelect_arg, 21, ARGUMENT_NAME, "DtNbackgroundIsSelect"},
    {tkn_k_class_argument, sym_k_DtNbaseHeight_arg, 13, ARGUMENT_NAME, "DtNbaseHeight"},
    {tkn_k_class_argument, sym_k_DtNbaseWidth_arg, 12, ARGUMENT_NAME, "DtNbaseWidth"},
    {tkn_k_class_argument, sym_k_DtNblinkRate_arg, 12, ARGUMENT_NAME, "DtNblinkRate"},
    {tkn_k_class_argument, sym_k_DtNbuttonFontList_arg, 17, ARGUMENT_NAME, "DtNbuttonFontList"},
    {tkn_k_class_argument, sym_k_DtNc132_arg, 7, ARGUMENT_NAME, "DtNc132"},
    {tkn_k_class_reason, sym_k_DtNcancelCallback_reason, 17, REASON_NAME, "DtNcancelCallback"},
    {tkn_k_class_argument, sym_k_DtNcascadePixmap_arg, 16, ARGUMENT_NAME, "DtNcascadePixmap"},
    {tkn_k_class_reason, sym_k_DtNcascadingCallback_reason, 20, REASON_NAME, "DtNcascadingCallback"},
    {tkn_k_class_argument, sym_k_DtNcenterToggleLabel_arg, 20, ARGUMENT_NAME, "DtNcenterToggleLabel"},
    {tkn_k_class_argument, sym_k_DtNchangeAllButtonLabel_arg, 23, ARGUMENT_NAME, "DtNchangeAllButtonLabel"},
    {tkn_k_class_argument, sym_k_DtNchangeButtonLabel_arg, 20, ARGUMENT_NAME, "DtNchangeButtonLabel"},
    {tkn_k_class_argument, sym_k_DtNchangeFieldLabel_arg, 19, ARGUMENT_NAME, "DtNchangeFieldLabel"},
    {tkn_k_class_argument, sym_k_DtNcharCursorStyle_arg, 18, ARGUMENT_NAME, "DtNcharCursorStyle"},
    {tkn_k_class_reason, sym_k_DtNcloseCallback_reason, 16, REASON_NAME, "DtNcloseCallback"},
    {tkn_k_class_argument, sym_k_DtNcloseLabelString_arg, 19, ARGUMENT_NAME, "DtNcloseLabelString"},
    {tkn_k_class_reason, sym_k_DtNclosePrintDisplayCallback_reason, 28, REASON_NAME, "DtNclosePrintDisplayCallback"},
    {tkn_k_class_argument, sym_k_DtNcolumns_arg, 10, ARGUMENT_NAME, "DtNcolumns"},
    {tkn_k_class_argument, sym_k_DtNconsoleMode_arg, 14, ARGUMENT_NAME, "DtNconsoleMode"},
    {tkn_k_class_argument, sym_k_DtNcopies_arg, 9, ARGUMENT_NAME, "DtNcopies"},
    {tkn_k_class_argument, sym_k_DtNcsWidth_arg, 10, ARGUMENT_NAME, "DtNcsWidth"},
    {tkn_k_class_argument, sym_k_DtNcurrentLineLabel_arg, 19, ARGUMENT_NAME, "DtNcurrentLineLabel"},
    {tkn_k_class_argument, sym_k_DtNcursorPosition_arg, 17, ARGUMENT_NAME, "DtNcursorPosition"},
    {tkn_k_class_argument, sym_k_DtNcursorPositionVisible_arg, 24, ARGUMENT_NAME, "DtNcursorPositionVisible"},
    {tkn_k_class_argument, sym_k_DtNdescription_arg, 14, ARGUMENT_NAME, "DtNdescription"},
    {tkn_k_class_argument, sym_k_DtNdialogTitle_arg, 14, ARGUMENT_NAME, "DtNdialogTitle"},
    {tkn_k_class_argument, sym_k_DtNeditable_arg, 11, ARGUMENT_NAME, "DtNeditable"},
    {tkn_k_class_argument, sym_k_DtNemulationId_arg, 14, ARGUMENT_NAME, "DtNemulationId"},
    {tkn_k_class_argument, sym_k_DtNexecutionPolicy_arg, 18, ARGUMENT_NAME, "DtNexecutionPolicy"},
    {tkn_k_class_argument, sym_k_DtNfileName_arg, 11, ARGUMENT_NAME, "DtNfileName"},
    {tkn_k_class_argument, sym_k_DtNfindButtonLabel_arg, 18, ARGUMENT_NAME, "DtNfindButtonLabel"},
    {tkn_k_class_argument, sym_k_DtNfindChangeDialogTitle_arg, 24, ARGUMENT_NAME, "DtNfindChangeDialogTitle"},
    {tkn_k_class_argument, sym_k_DtNfindFieldLabel_arg, 17, ARGUMENT_NAME, "DtNfindFieldLabel"},
    {tkn_k_class_argument, sym_k_DtNformatAllButtonLabel_arg, 23, ARGUMENT_NAME, "DtNformatAllButtonLabel"},
    {tkn_k_class_argument, sym_k_DtNformatParagraphButtonLabel_arg, 29, ARGUMENT_NAME, "DtNformatParagraphButtonLabel"},
    {tkn_k_class_argument, sym_k_DtNformatSettingsDialogTitle_arg, 28, ARGUMENT_NAME, "DtNformatSettingsDialogTitle"},
    {tkn_k_class_argument, sym_k_DtNheightInc_arg, 12, ARGUMENT_NAME, "DtNheightInc"},
    {tkn_k_class_argument, sym_k_DtNhelpFile_arg, 11, ARGUMENT_NAME, "DtNhelpFile"},
    {tkn_k_class_argument, sym_k_DtNhelpLabelString_arg, 18, ARGUMENT_NAME, "DtNhelpLabelString"},
    {tkn_k_class_argument, sym_k_DtNhelpOnHelpVolume_arg, 19, ARGUMENT_NAME, "DtNhelpOnHelpVolume"},
    {tkn_k_class_argument, sym_k_DtNhelpPrint_arg, 12, ARGUMENT_NAME, "DtNhelpPrint"},
    {tkn_k_class_argument, sym_k_DtNhelpType_arg, 11, ARGUMENT_NAME, "DtNhelpType"},
    {tkn_k_class_argument, sym_k_DtNhelpVolume_arg, 13, ARGUMENT_NAME, "DtNhelpVolume"},
    {tkn_k_class_reason, sym_k_DtNhyperLinkCallback_reason, 20, REASON_NAME, "DtNhyperLinkCallback"},
    {tkn_k_class_argument, sym_k_DtNinformationDialogTitle_arg, 25, ARGUMENT_NAME, "DtNinformationDialogTitle"},
    {tkn_k_class_reason, sym_k_DtNinputVerifyCallback_reason, 22, REASON_NAME, "DtNinputVerifyCallback"},
    {tkn_k_class_argument, sym_k_DtNinsertLabel_arg, 14, ARGUMENT_NAME, "DtNinsertLabel"},
    {tkn_k_class_argument, sym_k_DtNjumpScroll_arg, 13, ARGUMENT_NAME, "DtNjumpScroll"},
    {tkn_k_class_argument, sym_k_DtNjustifyToggleLabel_arg, 21, ARGUMENT_NAME, "DtNjustifyToggleLabel"},
    {tkn_k_class_argument, sym_k_DtNkshMode_arg, 10, ARGUMENT_NAME, "DtNkshMode"},
    {tkn_k_class_argument, sym_k_DtNlabelFontList_arg, 16, ARGUMENT_NAME, "DtNlabelFontList"},
    {tkn_k_class_argument, sym_k_DtNleftAlignToggleLabel_arg, 23, ARGUMENT_NAME, "DtNleftAlignToggleLabel"},
    {tkn_k_class_argument, sym_k_DtNleftMarginFieldLabel_arg, 23, ARGUMENT_NAME, "DtNleftMarginFieldLabel"},
    {tkn_k_class_argument, sym_k_DtNlocationId_arg, 13, ARGUMENT_NAME, "DtNlocationId"},
    {tkn_k_class_argument, sym_k_DtNlogFile_arg, 10, ARGUMENT_NAME, "DtNlogFile"},
    {tkn_k_class_argument, sym_k_DtNlogInhibit_arg, 13, ARGUMENT_NAME, "DtNlogInhibit"},
    {tkn_k_class_argument, sym_k_DtNlogging_arg, 10, ARGUMENT_NAME, "DtNlogging"},
    {tkn_k_class_argument, sym_k_DtNmanPage_arg, 10, ARGUMENT_NAME, "DtNmanPage"},
    {tkn_k_class_argument, sym_k_DtNmapOnOutput_arg, 14, ARGUMENT_NAME, "DtNmapOnOutput"},
    {tkn_k_class_argument, sym_k_DtNmapOnOutputDelay_arg, 19, ARGUMENT_NAME, "DtNmapOnOutputDelay"},
    {tkn_k_class_argument, sym_k_DtNmarginBell_arg, 13, ARGUMENT_NAME, "DtNmarginBell"},
    {tkn_k_class_argument, sym_k_DtNmarginHeight_arg, 15, ARGUMENT_NAME, "DtNmarginHeight"},
    {tkn_k_class_argument, sym_k_DtNmarginWidth_arg, 14, ARGUMENT_NAME, "DtNmarginWidth"},
    {tkn_k_class_argument, sym_k_DtNmaxLength_arg, 12, ARGUMENT_NAME, "DtNmaxLength"},
    {tkn_k_class_argument, sym_k_DtNminimizeButtons_arg, 18, ARGUMENT_NAME, "DtNminimizeButtons"},
    {tkn_k_class_argument, sym_k_DtNmisspelledListLabel_arg, 22, ARGUMENT_NAME, "DtNmisspelledListLabel"},
    {tkn_k_class_argument, sym_k_DtNmoreLabelString_arg, 18, ARGUMENT_NAME, "DtNmoreLabelString"},
    {tkn_k_class_argument, sym_k_DtNnMarginBell_arg, 14, ARGUMENT_NAME, "DtNnMarginBell"},
    {tkn_k_class_reason, sym_k_DtNoutputLogCallback_reason, 20, REASON_NAME, "DtNoutputLogCallback"},
    {tkn_k_class_argument, sym_k_DtNoverstrike_arg, 13, ARGUMENT_NAME, "DtNoverstrike"},
    {tkn_k_class_argument, sym_k_DtNoverstrikeLabel_arg, 18, ARGUMENT_NAME, "DtNoverstrikeLabel"},
    {tkn_k_class_argument, sym_k_DtNpaperSize_arg, 12, ARGUMENT_NAME, "DtNpaperSize"},
    {tkn_k_class_argument, sym_k_DtNpointerBlank_arg, 15, ARGUMENT_NAME, "DtNpointerBlank"},
    {tkn_k_class_argument, sym_k_DtNpointerBlankDelay_arg, 20, ARGUMENT_NAME, "DtNpointerBlankDelay"},
    {tkn_k_class_argument, sym_k_DtNpointerColor_arg, 15, ARGUMENT_NAME, "DtNpointerColor"},
    {tkn_k_class_argument, sym_k_DtNpointerColorBackground_arg, 25, ARGUMENT_NAME, "DtNpointerColorBackground"},
    {tkn_k_class_argument, sym_k_DtNpointerShape_arg, 15, ARGUMENT_NAME, "DtNpointerShape"},
    {tkn_k_class_reason, sym_k_DtNprintCallback_reason, 16, REASON_NAME, "DtNprintCallback"},
    {tkn_k_class_argument, sym_k_DtNprintDestination_arg, 19, ARGUMENT_NAME, "DtNprintDestination"},
    {tkn_k_class_argument, sym_k_DtNprintLabelString_arg, 19, ARGUMENT_NAME, "DtNprintLabelString"},
    {tkn_k_class_argument, sym_k_DtNprintSetupMode_arg, 17, ARGUMENT_NAME, "DtNprintSetupMode"},
    {tkn_k_class_argument, sym_k_DtNprinter_arg, 10, ARGUMENT_NAME, "DtNprinter"},
    {tkn_k_class_argument, sym_k_DtNprinterInfoProc_arg, 18, ARGUMENT_NAME, "DtNprinterInfoProc"},
    {tkn_k_class_argument, sym_k_DtNprinterName_arg, 14, ARGUMENT_NAME, "DtNprinterName"},
    {tkn_k_class_argument, sym_k_DtNreverseVideo_arg, 15, ARGUMENT_NAME, "DtNreverseVideo"},
    {tkn_k_class_argument, sym_k_DtNreverseWrap_arg, 14, ARGUMENT_NAME, "DtNreverseWrap"},
    {tkn_k_class_argument, sym_k_DtNrightAlignToggleLabel_arg, 24, ARGUMENT_NAME, "DtNrightAlignToggleLabel"},
    {tkn_k_class_argument, sym_k_DtNrightMarginFieldLabel_arg, 24, ARGUMENT_NAME, "DtNrightMarginFieldLabel"},
    {tkn_k_class_argument, sym_k_DtNrows_arg, 7, ARGUMENT_NAME, "DtNrows"},
    {tkn_k_class_argument, sym_k_DtNsaveLines_arg, 12, ARGUMENT_NAME, "DtNsaveLines"},
    {tkn_k_class_argument, sym_k_DtNscrollBarPolicy_arg, 18, ARGUMENT_NAME, "DtNscrollBarPolicy"},
    {tkn_k_class_argument, sym_k_DtNscrollHorizontal_arg, 19, ARGUMENT_NAME, "DtNscrollHorizontal"},
    {tkn_k_class_argument, sym_k_DtNscrollLeftSide_arg, 17, ARGUMENT_NAME, "DtNscrollLeftSide"},
    {tkn_k_class_argument, sym_k_DtNscrollTopSide_arg, 16, ARGUMENT_NAME, "DtNscrollTopSide"},
    {tkn_k_class_argument, sym_k_DtNscrollVertical_arg, 17, ARGUMENT_NAME, "DtNscrollVertical"},
    {tkn_k_class_argument, sym_k_DtNselectFileProc_arg, 17, ARGUMENT_NAME, "DtNselectFileProc"},
    {tkn_k_class_argument, sym_k_DtNselectPrinterProc_arg, 20, ARGUMENT_NAME, "DtNselectPrinterProc"},
    {tkn_k_class_reason, sym_k_DtNsetupCallback_reason, 16, REASON_NAME, "DtNsetupCallback"},
    {tkn_k_class_argument, sym_k_DtNshadowType_arg, 13, ARGUMENT_NAME, "DtNshadowType"},
    {tkn_k_class_argument, sym_k_DtNshowNewWindowButton_arg, 22, ARGUMENT_NAME, "DtNshowNewWindowButton"},
    {tkn_k_class_argument, sym_k_DtNshowStatusLine_arg, 17, ARGUMENT_NAME, "DtNshowStatusLine"},
    {tkn_k_class_argument, sym_k_DtNspellDialogTitle_arg, 19, ARGUMENT_NAME, "DtNspellDialogTitle"},
    {tkn_k_class_argument, sym_k_DtNspellFilter_arg, 14, ARGUMENT_NAME, "DtNspellFilter"},
    {tkn_k_class_reason, sym_k_DtNstatusChangeCallback_reason, 23, REASON_NAME, "DtNstatusChangeCallback"},
    {tkn_k_class_argument, sym_k_DtNstickyNextCursor_arg, 19, ARGUMENT_NAME, "DtNstickyNextCursor"},
    {tkn_k_class_argument, sym_k_DtNstickyPrevCursor_arg, 19, ARGUMENT_NAME, "DtNstickyPrevCursor"},
    {tkn_k_class_argument, sym_k_DtNstringData_arg, 13, ARGUMENT_NAME, "DtNstringData"},
    {tkn_k_class_argument, sym_k_DtNsubMenuId_arg, 12, ARGUMENT_NAME, "DtNsubMenuId"},
    {tkn_k_class_argument, sym_k_DtNsubprocessArgv_arg, 17, ARGUMENT_NAME, "DtNsubprocessArgv"},
    {tkn_k_class_argument, sym_k_DtNsubprocessCmd_arg, 16, ARGUMENT_NAME, "DtNsubprocessCmd"},
    {tkn_k_class_argument, sym_k_DtNsubprocessExec_arg, 17, ARGUMENT_NAME, "DtNsubprocessExec"},
    {tkn_k_class_argument, sym_k_DtNsubprocessLoginShell_arg, 23, ARGUMENT_NAME, "DtNsubprocessLoginShell"},
    {tkn_k_class_argument, sym_k_DtNsubprocessPid_arg, 16, ARGUMENT_NAME, "DtNsubprocessPid"},
    {tkn_k_class_reason, sym_k_DtNsubprocessTerminationCallback_reason, 32, REASON_NAME, "DtNsubprocessTerminationCallback"},
    {tkn_k_class_argument, sym_k_DtNsubprocessTerminationCatch_arg, 29, ARGUMENT_NAME, "DtNsubprocessTerminationCatch"},
    {tkn_k_class_argument, sym_k_DtNsunFunctionKeys_arg, 18, ARGUMENT_NAME, "DtNsunFunctionKeys"},
    {tkn_k_class_argument, sym_k_DtNtermDevice_arg, 13, ARGUMENT_NAME, "DtNtermDevice"},
    {tkn_k_class_argument, sym_k_DtNtermDeviceAllocate_arg, 21, ARGUMENT_NAME, "DtNtermDeviceAllocate"},
    {tkn_k_class_argument, sym_k_DtNtermId_arg, 9, ARGUMENT_NAME, "DtNtermId"},
    {tkn_k_class_argument, sym_k_DtNtermName_arg, 11, ARGUMENT_NAME, "DtNtermName"},
    {tkn_k_class_argument, sym_k_DtNtermSlaveName_arg, 16, ARGUMENT_NAME, "DtNtermSlaveName"},
    {tkn_k_class_argument, sym_k_DtNtextBackground_arg, 17, ARGUMENT_NAME, "DtNtextBackground"},
    {tkn_k_class_reason, sym_k_DtNtextDeselectCallback_reason, 23, REASON_NAME, "DtNtextDeselectCallback"},
    {tkn_k_class_argument, sym_k_DtNtextFontList_arg, 15, ARGUMENT_NAME, "DtNtextFontList"},
    {tkn_k_class_argument, sym_k_DtNtextForeground_arg, 17, ARGUMENT_NAME, "DtNtextForeground"},
    {tkn_k_class_reason, sym_k_DtNtextSelectCallback_reason, 21, REASON_NAME, "DtNtextSelectCallback"},
    {tkn_k_class_argument, sym_k_DtNtextTranslations_arg, 19, ARGUMENT_NAME, "DtNtextTranslations"},
    {tkn_k_class_argument, sym_k_DtNtopCharacter_arg, 15, ARGUMENT_NAME, "DtNtopCharacter"},
    {tkn_k_class_argument, sym_k_DtNtopicTitle_arg, 13, ARGUMENT_NAME, "DtNtopicTitle"},
    {tkn_k_class_argument, sym_k_DtNtotalLineCountLabel_arg, 22, ARGUMENT_NAME, "DtNtotalLineCountLabel"},
    {tkn_k_class_argument, sym_k_DtNttyModes_arg, 11, ARGUMENT_NAME, "DtNttyModes"},
    {tkn_k_class_argument, sym_k_DtNuserBoldFont_arg, 15, ARGUMENT_NAME, "DtNuserBoldFont"},
    {tkn_k_class_argument, sym_k_DtNuserFont_arg, 11, ARGUMENT_NAME, "DtNuserFont"},
    {tkn_k_class_argument, sym_k_DtNverifyPrinterProc_arg, 20, ARGUMENT_NAME, "DtNverifyPrinterProc"},
    {tkn_k_class_argument, sym_k_DtNverticalScrollBar_arg, 20, ARGUMENT_NAME, "DtNverticalScrollBar"},
    {tkn_k_class_argument, sym_k_DtNvisiblePathCount_arg, 19, ARGUMENT_NAME, "DtNvisiblePathCount"},
    {tkn_k_class_argument, sym_k_DtNvisualBell_arg, 13, ARGUMENT_NAME, "DtNvisualBell"},
    {tkn_k_class_argument, sym_k_DtNwidthInc_arg, 11, ARGUMENT_NAME, "DtNwidthInc"},
    {tkn_k_class_argument, sym_k_DtNwordWrap_arg, 11, ARGUMENT_NAME, "DtNwordWrap"},
    {tkn_k_class_argument, sym_k_DtNworkAreaLocation_arg, 19, ARGUMENT_NAME, "DtNworkAreaLocation"},
    {tkn_k_class_enumval, sym_k_DtPRINT_CLOSE_CONNECTION_enumval, 24, ENUMVAL_NAME, "DtPRINT_CLOSE_CONNECTION"},
    {tkn_k_class_enumval, sym_k_DtPRINT_NO_DESTINATION_enumval, 22, ENUMVAL_NAME, "DtPRINT_NO_DESTINATION"},
    {tkn_k_class_enumval, sym_k_DtPRINT_RELEASE_CONNECTION_enumval, 26, ENUMVAL_NAME, "DtPRINT_RELEASE_CONNECTION"},
    {tkn_k_class_enumval, sym_k_DtPRINT_SETUP_PLAIN_enumval, 19, ENUMVAL_NAME, "DtPRINT_SETUP_PLAIN"},
    {tkn_k_class_enumval, sym_k_DtPRINT_SETUP_XP_enumval, 16, ENUMVAL_NAME, "DtPRINT_SETUP_XP"},
    {tkn_k_class_enumval, sym_k_DtPRINT_TO_FILE_enumval, 15, ENUMVAL_NAME, "DtPRINT_TO_FILE"},
    {tkn_k_class_enumval, sym_k_DtPRINT_TO_PRINTER_enumval, 18, ENUMVAL_NAME, "DtPRINT_TO_PRINTER"},
    {tkn_k_class_class, sym_k_DtPrintSetupBox_object, 15, CLASS_NAME, "DtPrintSetupBox"},
    {tkn_k_class_class, sym_k_DtPrintSetupDialog_object, 18, CLASS_NAME, "DtPrintSetupDialog"},
    {tkn_k_class_enumval, sym_k_DtSHADOW_ETCHED_IN_enumval, 18, ENUMVAL_NAME, "DtSHADOW_ETCHED_IN"},
    {tkn_k_class_enumval, sym_k_DtSHADOW_ETCHED_OUT_enumval, 19, ENUMVAL_NAME, "DtSHADOW_ETCHED_OUT"},
    {tkn_k_class_enumval, sym_k_DtSHADOW_IN_enumval, 11, ENUMVAL_NAME, "DtSHADOW_IN"},
    {tkn_k_class_enumval, sym_k_DtSHADOW_OUT_enumval, 12, ENUMVAL_NAME, "DtSHADOW_OUT"},
    {tkn_k_class_enumval, sym_k_DtSHORT_NAME_enumval, 12, ENUMVAL_NAME, "DtSHORT_NAME"},
    {tkn_k_class_enumval, sym_k_DtTERM_CHAR_CURSOR_BAR_enumval, 22, ENUMVAL_NAME, "DtTERM_CHAR_CURSOR_BAR"},
    {tkn_k_class_enumval, sym_k_DtTERM_CHAR_CURSOR_BOX_enumval, 22, ENUMVAL_NAME, "DtTERM_CHAR_CURSOR_BOX"},
    {tkn_k_class_enumval, sym_k_DtTERM_CHAR_CURSOR_INVISIBLE_enumval, 28, ENUMVAL_NAME, "DtTERM_CHAR_CURSOR_INVISIBLE"},
    {tkn_k_class_class, sym_k_DtTerm_object, 6, CLASS_NAME, "DtTerm"},
    {tkn_k_class_class, sym_k_DtTermPrimitive_object, 15, CLASS_NAME, "DtTermPrimitive"},
    {tkn_k_class_enumval, sym_k_DtWORK_AREA_BOTTOM_enumval, 18, ENUMVAL_NAME, "DtWORK_AREA_BOTTOM"},
    {tkn_k_class_enumval, sym_k_DtWORK_AREA_NONE_enumval, 16, ENUMVAL_NAME, "DtWORK_AREA_NONE"},
    {tkn_k_class_enumval, sym_k_DtWORK_AREA_TOP_enumval, 15, ENUMVAL_NAME, "DtWORK_AREA_TOP"},
    {tkn_k_class_enumval, sym_k_DtWORK_AREA_TOP_AND_BOTTOM_enumval, 26, ENUMVAL_NAME, "DtWORK_AREA_TOP_AND_BOTTOM"},
    {tkn_k_class_enumval, sym_k_FALSE_enumval, 5, ENUMVAL_NAME, "FALSE"},
    {tkn_k_class_charset, sym_k_dos_cyrillic_charset, 7, CHARSET_NAME, "IBM-866"},
    {tkn_k_class_charset, sym_k_iso_cyrillic_charset, 10, CHARSET_NAME, "ISO-8859-5"},
    {tkn_k_class_charset, sym_k_iso_latin1_charset, 9, CHARSET_NAME, "ISOLatin1"},
    {tkn_k_class_charset, sym_k_iso_latin2_charset, 9, CHARSET_NAME, "ISOLatin2"},
    {tkn_k_class_charset, sym_k_iso_latin3_charset, 9, CHARSET_NAME, "ISOLatin3"},
    {tkn_k_class_charset, sym_k_iso_latin4_charset, 9, CHARSET_NAME, "ISOLatin4"},
    {tkn_k_class_charset, sym_k_iso_latin5_charset, 9, CHARSET_NAME, "ISOLatin5"},
    {tkn_k_class_charset, sym_k_iso_arabic_charset, 9, CHARSET_NAME, "ISOLatin6"},
    {tkn_k_class_charset, sym_k_iso_greek_charset, 9, CHARSET_NAME, "ISOLatin7"},
    {tkn_k_class_charset, sym_k_iso_hebrew_charset, 9, CHARSET_NAME, "ISOLatin8"},
    {tkn_k_class_enumval, sym_k_IconicState_enumval, 11, ENUMVAL_NAME, "IconicState"},
    {tkn_k_class_charset, sym_k_iso_ir_111_charset, 6, CHARSET_NAME, "KOI8-R"},
    {tkn_k_class_charset, sym_k_iso_ir_111_charset, 7, CHARSET_NAME, "KOI8-RU"},
    {tkn_k_class_charset, sym_k_iso_ir_111_charset, 6, CHARSET_NAME, "KOI8-U"},
    {tkn_k_class_charset, sym_k_iso_ir_111_charset, 5, CHARSET_NAME, "KOI8R"},
    {tkn_k_class_charset, sym_k_iso_ir_111_charset, 6, CHARSET_NAME, "KOI8RU"},
    {tkn_k_class_charset, sym_k_iso_ir_111_charset, 5, CHARSET_NAME, "KOI8U"},
    {tkn_k_class_enumval, sym_k_LineDoubleDash_enumval, 14, ENUMVAL_NAME, "LineDoubleDash"},
    {tkn_k_class_enumval, sym_k_LineOnOffDash_enumval, 13, ENUMVAL_NAME, "LineOnOffDash"},
    {tkn_k_class_enumval, sym_k_LineSolid_enumval, 9, ENUMVAL_NAME, "LineSolid"},
    {tkn_k_class_enumval, sym_k_MWM_DECOR_ALL_enumval, 13, ENUMVAL_NAME, "MWM_DECOR_ALL"},
    {tkn_k_class_enumval, sym_k_MWM_DECOR_BORDER_enumval, 16, ENUMVAL_NAME, "MWM_DECOR_BORDER"},
    {tkn_k_class_enumval, sym_k_MWM_DECOR_MAXIMIZE_enumval, 18, ENUMVAL_NAME, "MWM_DECOR_MAXIMIZE"},
    {tkn_k_class_enumval, sym_k_MWM_DECOR_MENU_enumval, 14, ENUMVAL_NAME, "MWM_DECOR_MENU"},
    {tkn_k_class_enumval, sym_k_MWM_DECOR_MINIMIZE_enumval, 18, ENUMVAL_NAME, "MWM_DECOR_MINIMIZE"},
    {tkn_k_class_enumval, sym_k_MWM_DECOR_RESIZEH_enumval, 17, ENUMVAL_NAME, "MWM_DECOR_RESIZEH"},
    {tkn_k_class_enumval, sym_k_MWM_DECOR_TITLE_enumval, 15, ENUMVAL_NAME, "MWM_DECOR_TITLE"},
    {tkn_k_class_enumval, sym_k_MWM_FUNC_ALL_enumval, 12, ENUMVAL_NAME, "MWM_FUNC_ALL"},
    {tkn_k_class_enumval, sym_k_MWM_FUNC_CLOSE_enumval, 14, ENUMVAL_NAME, "MWM_FUNC_CLOSE"},
    {tkn_k_class_enumval, sym_k_MWM_FUNC_MOVE_enumval, 13, ENUMVAL_NAME, "MWM_FUNC_MOVE"},
    {tkn_k_class_enumval, sym_k_MWM_FUNC_RESIZE_enumval, 15, ENUMVAL_NAME, "MWM_FUNC_RESIZE"},
    {tkn_k_class_enumval, sym_k_MWM_INPUT_FULL_APPLICATION_MODAL_enumval, 32, ENUMVAL_NAME, "MWM_INPUT_FULL_APPLICATION_MODAL"},
    {tkn_k_class_enumval, sym_k_MWM_INPUT_MODELESS_enumval, 18, ENUMVAL_NAME, "MWM_INPUT_MODELESS"},
    {tkn_k_class_enumval, sym_k_MWM_INPUT_PRIMARY_APPLICATION_MODAL_enumval, 35, ENUMVAL_NAME, "MWM_INPUT_PRIMARY_APPLICATION_MODAL"},
    {tkn_k_class_enumval, sym_k_MWM_INPUT_SYSTEM_MODAL_enumval, 22, ENUMVAL_NAME, "MWM_INPUT_SYSTEM_MODAL"},
    {tkn_k_class_reason, sym_k_MrmNcreateCallback_reason, 18, REASON_NAME, "MrmNcreateCallback"},
    {tkn_k_class_enumval, sym_k_NormalState_enumval, 11, ENUMVAL_NAME, "NormalState"},
    {tkn_k_class_enumval, sym_k_NotUseful_enumval, 9, ENUMVAL_NAME, "NotUseful"},
    {tkn_k_class_enumval, sym_k_TRUE_enumval, 4, ENUMVAL_NAME, "TRUE"},
    {tkn_k_class_charset, sym_k_ansi_cyrillic_charset, 12, CHARSET_NAME, "WINDOWS-1251"},
    {tkn_k_class_enumval, sym_k_WhenMapped_enumval, 10, ENUMVAL_NAME, "WhenMapped"},
    {tkn_k_class_enumval, sym_k_Xm1000TH_INCHES_enumval, 15, ENUMVAL_NAME, "Xm1000TH_INCHES"},
    {tkn_k_class_enumval, sym_k_Xm100TH_FONT_UNITS_enumval, 18, ENUMVAL_NAME, "Xm100TH_FONT_UNITS"},
    {tkn_k_class_enumval, sym_k_Xm100TH_MILLIMETERS_enumval, 19, ENUMVAL_NAME, "Xm100TH_MILLIMETERS"},
    {tkn_k_class_enumval, sym_k_Xm100TH_POINTS_enumval, 14, ENUMVAL_NAME, "Xm100TH_POINTS"},
    {tkn_k_class_enumval, sym_k_XmABSOLUTE_enumval, 10, ENUMVAL_NAME, "XmABSOLUTE"},
    {tkn_k_class_enumval, sym_k_XmADD_MODE_enumval, 10, ENUMVAL_NAME, "XmADD_MODE"},
    {tkn_k_class_enumval, sym_k_XmALIGNMENT_BASELINE_BOTTOM_enumval, 27, ENUMVAL_NAME, "XmALIGNMENT_BASELINE_BOTTOM"},
    {tkn_k_class_enumval, sym_k_XmALIGNMENT_BASELINE_TOP_enumval, 24, ENUMVAL_NAME, "XmALIGNMENT_BASELINE_TOP"},
    {tkn_k_class_enumval, sym_k_XmALIGNMENT_BEGINNING_enumval, 21, ENUMVAL_NAME, "XmALIGNMENT_BEGINNING"},
    {tkn_k_class_enumval, sym_k_XmALIGNMENT_CENTER_enumval, 18, ENUMVAL_NAME, "XmALIGNMENT_CENTER"},
    {tkn_k_class_enumval, sym_k_XmALIGNMENT_CONTENTS_BOTTOM_enumval, 27, ENUMVAL_NAME, "XmALIGNMENT_CONTENTS_BOTTOM"},
    {tkn_k_class_enumval, sym_k_XmALIGNMENT_CONTENTS_TOP_enumval, 24, ENUMVAL_NAME, "XmALIGNMENT_CONTENTS_TOP"},
    {tkn_k_class_enumval, sym_k_XmALIGNMENT_END_enumval, 15, ENUMVAL_NAME, "XmALIGNMENT_END"},
    {tkn_k_class_enumval, sym_k_XmALIGNMENT_UNSPECIFIED_enumval, 23, ENUMVAL_NAME, "XmALIGNMENT_UNSPECIFIED"},
    {tkn_k_class_enumval, sym_k_XmALIGNMENT_WIDGET_BOTTOM_enumval, 25, ENUMVAL_NAME, "XmALIGNMENT_WIDGET_BOTTOM"},
    {tkn_k_class_enumval, sym_k_XmALIGNMENT_WIDGET_TOP_enumval, 22, ENUMVAL_NAME, "XmALIGNMENT_WIDGET_TOP"},
    {tkn_k_class_enumval, sym_k_XmANY_ICON_enumval, 10, ENUMVAL_NAME, "XmANY_ICON"},
    {tkn_k_class_enumval, sym_k_XmAPPEND_enumval, 8, ENUMVAL_NAME, "XmAPPEND"},
    {tkn_k_class_enumval, sym_k_XmAPPLICATION_DEFINED_enumval, 21, ENUMVAL_NAME, "XmAPPLICATION_DEFINED"},
    {tkn_k_class_enumval, sym_k_XmARROWS_BEGINNING_enumval, 18, ENUMVAL_NAME, "XmARROWS_BEGINNING"},
    {tkn_k_class_enumval, sym_k_XmARROWS_DECREMENT_SENSITIVE_enumval, 28, ENUMVAL_NAME, "XmARROWS_DECREMENT_SENSITIVE"},
    {tkn_k_class_enumval, sym_k_XmARROWS_DEFAULT_SENSITIVITY_enumval, 28, ENUMVAL_NAME, "XmARROWS_DEFAULT_SENSITIVITY"},
    {tkn_k_class_enumval, sym_k_XmARROWS_END_enumval, 12, ENUMVAL_NAME, "XmARROWS_END"},
    {tkn_k_class_enumval, sym_k_XmARROWS_FLAT_BEGINNING_enumval, 23, ENUMVAL_NAME, "XmARROWS_FLAT_BEGINNING"},
    {tkn_k_class_enumval, sym_k_XmARROWS_FLAT_END_enumval, 17, ENUMVAL_NAME, "XmARROWS_FLAT_END"},
    {tkn_k_class_enumval, sym_k_XmARROWS_HORIZONTAL_enumval, 19, ENUMVAL_NAME, "XmARROWS_HORIZONTAL"},
    {tkn_k_class_enumval, sym_k_XmARROWS_INCREMENT_SENSITIVE_enumval, 28, ENUMVAL_NAME, "XmARROWS_INCREMENT_SENSITIVE"},
    {tkn_k_class_enumval, sym_k_XmARROWS_INSENSITIVE_enumval, 20, ENUMVAL_NAME, "XmARROWS_INSENSITIVE"},
    {tkn_k_class_enumval, sym_k_XmARROWS_SENSITIVE_enumval, 18, ENUMVAL_NAME, "XmARROWS_SENSITIVE"},
    {tkn_k_class_enumval, sym_k_XmARROWS_SPLIT_enumval, 14, ENUMVAL_NAME, "XmARROWS_SPLIT"},
    {tkn_k_class_enumval, sym_k_XmARROWS_VERTICAL_enumval, 17, ENUMVAL_NAME, "XmARROWS_VERTICAL"},
    {tkn_k_class_enumval, sym_k_XmARROW_DOWN_enumval, 12, ENUMVAL_NAME, "XmARROW_DOWN"},
    {tkn_k_class_enumval, sym_k_XmARROW_LEFT_enumval, 12, ENUMVAL_NAME, "XmARROW_LEFT"},
    {tkn_k_class_enumval, sym_k_XmARROW_RIGHT_enumval, 13, ENUMVAL_NAME, "XmARROW_RIGHT"},
    {tkn_k_class_enumval, sym_k_XmARROW_UP_enumval, 10, ENUMVAL_NAME, "XmARROW_UP"},
    {tkn_k_class_enumval, sym_k_XmAS_IS_enumval, 7, ENUMVAL_NAME, "XmAS_IS"},
    {tkn_k_class_enumval, sym_k_XmAS_NEEDED_enumval, 11, ENUMVAL_NAME, "XmAS_NEEDED"},
    {tkn_k_class_enumval, sym_k_XmATTACH_FORM_enumval, 13, ENUMVAL_NAME, "XmATTACH_FORM"},
    {tkn_k_class_enumval, sym_k_XmATTACH_NONE_enumval, 13, ENUMVAL_NAME, "XmATTACH_NONE"},
    {tkn_k_class_enumval, sym_k_XmATTACH_OPPOSITE_FORM_enumval, 22, ENUMVAL_NAME, "XmATTACH_OPPOSITE_FORM"},
    {tkn_k_class_enumval, sym_k_XmATTACH_OPPOSITE_WIDGET_enumval, 24, ENUMVAL_NAME, "XmATTACH_OPPOSITE_WIDGET"},
    {tkn_k_class_enumval, sym_k_XmATTACH_POSITION_enumval, 17, ENUMVAL_NAME, "XmATTACH_POSITION"},
    {tkn_k_class_enumval, sym_k_XmATTACH_SELF_enumval, 13, ENUMVAL_NAME, "XmATTACH_SELF"},
    {tkn_k_class_enumval, sym_k_XmATTACH_WIDGET_enumval, 15, ENUMVAL_NAME, "XmATTACH_WIDGET"},
    {tkn_k_class_enumval, sym_k_XmAUTOMATIC_enumval, 11, ENUMVAL_NAME, "XmAUTOMATIC"},
    {tkn_k_class_enumval, sym_k_XmAUTO_DRAG_DISABLED_enumval, 20, ENUMVAL_NAME, "XmAUTO_DRAG_DISABLED"},
    {tkn_k_class_enumval, sym_k_XmAUTO_DRAG_ENABLED_enumval, 19, ENUMVAL_NAME, "XmAUTO_DRAG_ENABLED"},
    {tkn_k_class_enumval, sym_k_XmAUTO_SELECT_enumval, 13, ENUMVAL_NAME, "XmAUTO_SELECT"},
    {tkn_k_class_enumval, sym_k_XmAlwaysOpen_enumval, 12, ENUMVAL_NAME, "XmAlwaysOpen"},
    {tkn_k_class_class, sym_k_XmArrowButton_object, 13, CLASS_NAME, "XmArrowButton"},
    {tkn_k_class_class, sym_k_XmArrowButtonGadget_object, 19, CLASS_NAME, "XmArrowButtonGadget"},
    {tkn_k_class_enumval, sym_k_XmBACKGROUND_COLOR_enumval, 18, ENUMVAL_NAME, "XmBACKGROUND_COLOR"},
    {tkn_k_class_enumval, sym_k_XmBELL_enumval, 6, ENUMVAL_NAME, "XmBELL"},
    {tkn_k_class_enumval, sym_k_XmBOTTOM_LEFT_enumval, 13, ENUMVAL_NAME, "XmBOTTOM_LEFT"},
    {tkn_k_class_enumval, sym_k_XmBOTTOM_RIGHT_enumval, 14, ENUMVAL_NAME, "XmBOTTOM_RIGHT"},
    {tkn_k_class_enumval, sym_k_XmBOTTOM_TO_TOP_enumval, 15, ENUMVAL_NAME, "XmBOTTOM_TO_TOP"},
    {tkn_k_class_enumval, sym_k_XmBOTTOM_TO_TOP_LEFT_TO_RIGHT_enumval, 29, ENUMVAL_NAME, "XmBOTTOM_TO_TOP_LEFT_TO_RIGHT"},
    {tkn_k_class_enumval, sym_k_XmBOTTOM_TO_TOP_RIGHT_TO_LEFT_enumval, 29, ENUMVAL_NAME, "XmBOTTOM_TO_TOP_RIGHT_TO_LEFT"},
    {tkn_k_class_enumval, sym_k_XmBROWSE_SELECT_enumval, 15, ENUMVAL_NAME, "XmBROWSE_SELECT"},
    {tkn_k_class_class, sym_k_XmBulletinBoard_object, 15, CLASS_NAME, "XmBulletinBoard"},
    {tkn_k_class_class, sym_k_XmBulletinBoardDialog_object, 21, CLASS_NAME, "XmBulletinBoardDialog"},
    {tkn_k_class_class, sym_k_XmButtonBox_object, 11, CLASS_NAME, "XmButtonBox"},
    {tkn_k_class_enumval, sym_k_XmCELLS_enumval, 7, ENUMVAL_NAME, "XmCELLS"},
    {tkn_k_class_enumval, sym_k_XmCENTER_enumval, 8, ENUMVAL_NAME, "XmCENTER"},
    {tkn_k_class_enumval, sym_k_XmCENTIMETERS_enumval, 13, ENUMVAL_NAME, "XmCENTIMETERS"},
    {tkn_k_class_enumval, sym_k_XmCLIP_WINDOW_enumval, 13, ENUMVAL_NAME, "XmCLIP_WINDOW"},
    {tkn_k_class_enumval, sym_k_XmCLOSEST_enumval, 9, ENUMVAL_NAME, "XmCLOSEST"},
    {tkn_k_class_enumval, sym_k_XmCOLLAPSED_enumval, 11, ENUMVAL_NAME, "XmCOLLAPSED"},
    {tkn_k_class_enumval, sym_k_XmCOMBO_BOX_enumval, 11, ENUMVAL_NAME, "XmCOMBO_BOX"},
    {tkn_k_class_enumval, sym_k_XmCOMMAND_ABOVE_WORKSPACE_enumval, 25, ENUMVAL_NAME, "XmCOMMAND_ABOVE_WORKSPACE"},
    {tkn_k_class_enumval, sym_k_XmCOMMAND_BELOW_WORKSPACE_enumval, 25, ENUMVAL_NAME, "XmCOMMAND_BELOW_WORKSPACE"},
    {tkn_k_class_enumval, sym_k_XmCOMMAND_WINDOW_enumval, 16, ENUMVAL_NAME, "XmCOMMAND_WINDOW"},
    {tkn_k_class_enumval, sym_k_XmCONSTANT_enumval, 10, ENUMVAL_NAME, "XmCONSTANT"},
    {tkn_k_class_class, sym_k_XmCascadeButton_object, 15, CLASS_NAME, "XmCascadeButton"},
    {tkn_k_class_class, sym_k_XmCascadeButtonGadget_object, 21, CLASS_NAME, "XmCascadeButtonGadget"},
    {tkn_k_class_class, sym_k_XmCheckBox_object, 10, CLASS_NAME, "XmCheckBox"},
    {tkn_k_class_enumval, sym_k_XmClosed_enumval, 8, ENUMVAL_NAME, "XmClosed"},
    {tkn_k_class_class, sym_k_XmColorSelector_object, 15, CLASS_NAME, "XmColorSelector"},
    {tkn_k_class_class, sym_k_XmColumn_object, 8, CLASS_NAME, "XmColumn"},
    {tkn_k_class_class, sym_k_XmDropDown_object, 17, CLASS_NAME, "XmCombinationBox2"},
    {tkn_k_class_class, sym_k_XmComboBox_object, 10, CLASS_NAME, "XmComboBox"},
    {tkn_k_class_class, sym_k_XmCommand_object, 9, CLASS_NAME, "XmCommand"},
    {tkn_k_class_class, sym_k_XmCommandDialog_object, 15, CLASS_NAME, "XmCommandDialog"},
    {tkn_k_class_class, sym_k_XmContainer_object, 11, CLASS_NAME, "XmContainer"},
    {tkn_k_class_enumval, sym_k_XmDEFAULT_DIRECTION_enumval, 19, ENUMVAL_NAME, "XmDEFAULT_DIRECTION"},
    {tkn_k_class_enumval, sym_k_XmDESTROY_enumval, 9, ENUMVAL_NAME, "XmDESTROY"},
    {tkn_k_class_enumval, sym_k_XmDETAIL_enumval, 8, ENUMVAL_NAME, "XmDETAIL"},
    {tkn_k_class_enumval, sym_k_XmDIALOG_APPLICATION_MODAL_enumval, 26, ENUMVAL_NAME, "XmDIALOG_APPLICATION_MODAL"},
    {tkn_k_class_enumval, sym_k_XmDIALOG_CANCEL_BUTTON_enumval, 22, ENUMVAL_NAME, "XmDIALOG_CANCEL_BUTTON"},
    {tkn_k_class_enumval, sym_k_XmDIALOG_COMMAND_enumval, 16, ENUMVAL_NAME, "XmDIALOG_COMMAND"},
    {tkn_k_class_enumval, sym_k_XmDIALOG_DEFAULT_BUTTON_enumval, 23, ENUMVAL_NAME, "XmDIALOG_DEFAULT_BUTTON"},
    {tkn_k_class_enumval, sym_k_XmDIALOG_ERROR_enumval, 14, ENUMVAL_NAME, "XmDIALOG_ERROR"},
    {tkn_k_class_enumval, sym_k_XmDIALOG_FILE_SELECTION_enumval, 23, ENUMVAL_NAME, "XmDIALOG_FILE_SELECTION"},
    {tkn_k_class_enumval, sym_k_XmDIALOG_FULL_APPLICATION_MODAL_enumval, 31, ENUMVAL_NAME, "XmDIALOG_FULL_APPLICATION_MODAL"},
    {tkn_k_class_enumval, sym_k_XmDIALOG_HELP_BUTTON_enumval, 20, ENUMVAL_NAME, "XmDIALOG_HELP_BUTTON"},
    {tkn_k_class_enumval, sym_k_XmDIALOG_INFORMATION_enumval, 20, ENUMVAL_NAME, "XmDIALOG_INFORMATION"},
    {tkn_k_class_enumval, sym_k_XmDIALOG_MESSAGE_enumval, 16, ENUMVAL_NAME, "XmDIALOG_MESSAGE"},
    {tkn_k_class_enumval, sym_k_XmDIALOG_MESSAGE_LABEL_enumval, 22, ENUMVAL_NAME, "XmDIALOG_MESSAGE_LABEL"},
    {tkn_k_class_enumval, sym_k_XmDIALOG_MODELESS_enumval, 17, ENUMVAL_NAME, "XmDIALOG_MODELESS"},
    {tkn_k_class_enumval, sym_k_XmDIALOG_OK_BUTTON_enumval, 18, ENUMVAL_NAME, "XmDIALOG_OK_BUTTON"},
    {tkn_k_class_enumval, sym_k_XmDIALOG_PRIMARY_APPLICATION_MODAL_enumval, 34, ENUMVAL_NAME, "XmDIALOG_PRIMARY_APPLICATION_MODAL"},
    {tkn_k_class_enumval, sym_k_XmDIALOG_PROMPT_enumval, 15, ENUMVAL_NAME, "XmDIALOG_PROMPT"},
    {tkn_k_class_enumval, sym_k_XmDIALOG_QUESTION_enumval, 17, ENUMVAL_NAME, "XmDIALOG_QUESTION"},
    {tkn_k_class_enumval, sym_k_XmDIALOG_SELECTION_enumval, 18, ENUMVAL_NAME, "XmDIALOG_SELECTION"},
    {tkn_k_class_enumval, sym_k_XmDIALOG_SEPARATOR_enumval, 18, ENUMVAL_NAME, "XmDIALOG_SEPARATOR"},
    {tkn_k_class_enumval, sym_k_XmDIALOG_SYMBOL_LABEL_enumval, 21, ENUMVAL_NAME, "XmDIALOG_SYMBOL_LABEL"},
    {tkn_k_class_enumval, sym_k_XmDIALOG_SYSTEM_MODAL_enumval, 21, ENUMVAL_NAME, "XmDIALOG_SYSTEM_MODAL"},
    {tkn_k_class_enumval, sym_k_XmDIALOG_TEMPLATE_enumval, 17, ENUMVAL_NAME, "XmDIALOG_TEMPLATE"},
    {tkn_k_class_enumval, sym_k_XmDIALOG_WARNING_enumval, 16, ENUMVAL_NAME, "XmDIALOG_WARNING"},
    {tkn_k_class_enumval, sym_k_XmDIALOG_WORKING_enumval, 16, ENUMVAL_NAME, "XmDIALOG_WORKING"},
    {tkn_k_class_enumval, sym_k_XmDIALOG_WORK_AREA_enumval, 18, ENUMVAL_NAME, "XmDIALOG_WORK_AREA"},
    {tkn_k_class_enumval, sym_k_XmDISTRIBUTE_SPREAD_enumval, 19, ENUMVAL_NAME, "XmDISTRIBUTE_SPREAD"},
    {tkn_k_class_enumval, sym_k_XmDISTRIBUTE_TIGHT_enumval, 18, ENUMVAL_NAME, "XmDISTRIBUTE_TIGHT"},
    {tkn_k_class_enumval, sym_k_XmDOUBLE_DASHED_LINE_enumval, 20, ENUMVAL_NAME, "XmDOUBLE_DASHED_LINE"},
    {tkn_k_class_enumval, sym_k_XmDOUBLE_LINE_enumval, 13, ENUMVAL_NAME, "XmDOUBLE_LINE"},
    {tkn_k_class_enumval, sym_k_XmDO_NOTHING_enumval, 12, ENUMVAL_NAME, "XmDO_NOTHING"},
    {tkn_k_class_enumval, sym_k_XmDROP_DOWN_COMBO_BOX_enumval, 21, ENUMVAL_NAME, "XmDROP_DOWN_COMBO_BOX"},
    {tkn_k_class_enumval, sym_k_XmDROP_DOWN_LIST_enumval, 16, ENUMVAL_NAME, "XmDROP_DOWN_LIST"},
    {tkn_k_class_class, sym_k_XmDataField_object, 11, CLASS_NAME, "XmDataField"},
    {tkn_k_class_class, sym_k_XmDialogShell_object, 13, CLASS_NAME, "XmDialogShell"},
    {tkn_k_class_class, sym_k_XmDrawingArea_object, 13, CLASS_NAME, "XmDrawingArea"},
    {tkn_k_class_class, sym_k_XmDrawnButton_object, 13, CLASS_NAME, "XmDrawnButton"},
    {tkn_k_class_class, sym_k_XmDropDown_object, 10, CLASS_NAME, "XmDropDown"},
    {tkn_k_class_enumval, sym_k_XmEACH_SIDE_enumval, 11, ENUMVAL_NAME, "XmEACH_SIDE"},
    {tkn_k_class_enumval, sym_k_XmETCHED_LINE_enumval, 13, ENUMVAL_NAME, "XmETCHED_LINE"},
    {tkn_k_class_enumval, sym_k_XmEXCLUSIVE_TAB_GROUP_enumval, 21, ENUMVAL_NAME, "XmEXCLUSIVE_TAB_GROUP"},
    {tkn_k_class_enumval, sym_k_XmEXPANDED_enumval, 10, ENUMVAL_NAME, "XmEXPANDED"},
    {tkn_k_class_enumval, sym_k_XmEXPLICIT_enumval, 10, ENUMVAL_NAME, "XmEXPLICIT"},
    {tkn_k_class_enumval, sym_k_XmEXTENDED_SELECT_enumval, 17, ENUMVAL_NAME, "XmEXTENDED_SELECT"},
    {tkn_k_class_class, sym_k_XmErrorDialog_object, 13, CLASS_NAME, "XmErrorDialog"},
    {tkn_k_class_class, sym_k_XmMultiList_object, 11, CLASS_NAME, "XmExt18List"},
    {tkn_k_class_enumval, sym_k_XmFILE_ANY_TYPE_enumval, 15, ENUMVAL_NAME, "XmFILE_ANY_TYPE"},
    {tkn_k_class_enumval, sym_k_XmFILE_DIRECTORY_enumval, 16, ENUMVAL_NAME, "XmFILE_DIRECTORY"},
    {tkn_k_class_enumval, sym_k_XmFILE_REGULAR_enumval, 14, ENUMVAL_NAME, "XmFILE_REGULAR"},
    {tkn_k_class_enumval, sym_k_XmFILL_FLUSH_enumval, 12, ENUMVAL_NAME, "XmFILL_FLUSH"},
    {tkn_k_class_enumval, sym_k_XmFILL_RAGGED_enumval, 13, ENUMVAL_NAME, "XmFILL_RAGGED"},
    {tkn_k_class_enumval, sym_k_XmFILL_UNSPECIFIED_enumval, 18, ENUMVAL_NAME, "XmFILL_UNSPECIFIED"},
    {tkn_k_class_enumval, sym_k_XmFIRST_FIT_enumval, 11, ENUMVAL_NAME, "XmFIRST_FIT"},
    {tkn_k_class_enumval, sym_k_XmFIRST_POSITION_enumval, 16, ENUMVAL_NAME, "XmFIRST_POSITION"},
    {tkn_k_class_charset, sym_k_XmFONTLIST_DEFAULT_TAG_charset, 22, CHARSET_NAME, "XmFONTLIST_DEFAULT_TAG"},
    {tkn_k_class_enumval, sym_k_XmFONT_IS_FONT_enumval, 14, ENUMVAL_NAME, "XmFONT_IS_FONT"},
    {tkn_k_class_enumval, sym_k_XmFONT_IS_FONTSET_enumval, 17, ENUMVAL_NAME, "XmFONT_IS_FONTSET"},
    {tkn_k_class_enumval, sym_k_XmFONT_IS_XFT_enumval, 13, ENUMVAL_NAME, "XmFONT_IS_XFT"},
    {tkn_k_class_enumval, sym_k_XmFONT_UNITS_enumval, 12, ENUMVAL_NAME, "XmFONT_UNITS"},
    {tkn_k_class_enumval, sym_k_XmFOREGROUND_COLOR_enumval, 18, ENUMVAL_NAME, "XmFOREGROUND_COLOR"},
    {tkn_k_class_enumval, sym_k_XmFRAME_GENERIC_CHILD_enumval, 21, ENUMVAL_NAME, "XmFRAME_GENERIC_CHILD"},
    {tkn_k_class_enumval, sym_k_XmFRAME_TITLE_CHILD_enumval, 19, ENUMVAL_NAME, "XmFRAME_TITLE_CHILD"},
    {tkn_k_class_enumval, sym_k_XmFRAME_WORKAREA_CHILD_enumval, 22, ENUMVAL_NAME, "XmFRAME_WORKAREA_CHILD"},
    {tkn_k_class_class, sym_k_XmFileSelectionBox_object, 18, CLASS_NAME, "XmFileSelectionBox"},
    {tkn_k_class_class, sym_k_XmFileSelectionDialog_object, 21, CLASS_NAME, "XmFileSelectionDialog"},
    {tkn_k_class_enumval, sym_k_XmFillAll_enumval, 9, ENUMVAL_NAME, "XmFillAll"},
    {tkn_k_class_enumval, sym_k_XmFillMajor_enumval, 11, ENUMVAL_NAME, "XmFillMajor"},
    {tkn_k_class_enumval, sym_k_XmFillMinor_enumval, 11, ENUMVAL_NAME, "XmFillMinor"},
    {tkn_k_class_enumval, sym_k_XmFillNone_enumval, 10, ENUMVAL_NAME, "XmFillNone"},
    {tkn_k_class_class, sym_k_XmFontSelector_object, 14, CLASS_NAME, "XmFontSelector"},
    {tkn_k_class_class, sym_k_XmForm_object, 6, CLASS_NAME, "XmForm"},
    {tkn_k_class_class, sym_k_XmFormDialog_object, 12, CLASS_NAME, "XmFormDialog"},
    {tkn_k_class_class, sym_k_XmFrame_object, 7, CLASS_NAME, "XmFrame"},
    {tkn_k_class_enumval, sym_k_XmGENERIC_CHILD_enumval, 15, ENUMVAL_NAME, "XmGENERIC_CHILD"},
    {tkn_k_class_enumval, sym_k_XmGRID_enumval, 6, ENUMVAL_NAME, "XmGRID"},
    {tkn_k_class_enumval, sym_k_XmGROW_BALANCED_enumval, 15, ENUMVAL_NAME, "XmGROW_BALANCED"},
    {tkn_k_class_enumval, sym_k_XmGROW_MAJOR_enumval, 12, ENUMVAL_NAME, "XmGROW_MAJOR"},
    {tkn_k_class_enumval, sym_k_XmGROW_MINOR_enumval, 12, ENUMVAL_NAME, "XmGROW_MINOR"},
    {tkn_k_class_enumval, sym_k_XmHORIZONTAL_enumval, 12, ENUMVAL_NAME, "XmHORIZONTAL"},
    {tkn_k_class_enumval, sym_k_XmHOR_SCROLLBAR_enumval, 15, ENUMVAL_NAME, "XmHOR_SCROLLBAR"},
    {tkn_k_class_enumval, sym_k_XmHidden_enumval, 8, ENUMVAL_NAME, "XmHidden"},
    {tkn_k_class_enumval, sym_k_XmINCHES_enumval, 8, ENUMVAL_NAME, "XmINCHES"},
    {tkn_k_class_enumval, sym_k_XmINDETERMINATE_enumval, 15, ENUMVAL_NAME, "XmINDETERMINATE"},
    {tkn_k_class_enumval, sym_k_XmINDICATOR_BOX_enumval, 15, ENUMVAL_NAME, "XmINDICATOR_BOX"},
    {tkn_k_class_enumval, sym_k_XmINDICATOR_CHECK_enumval, 17, ENUMVAL_NAME, "XmINDICATOR_CHECK"},
    {tkn_k_class_enumval, sym_k_XmINDICATOR_CHECK_BOX_enumval, 21, ENUMVAL_NAME, "XmINDICATOR_CHECK_BOX"},
    {tkn_k_class_enumval, sym_k_XmINDICATOR_CROSS_enumval, 17, ENUMVAL_NAME, "XmINDICATOR_CROSS"},
    {tkn_k_class_enumval, sym_k_XmINDICATOR_CROSS_BOX_enumval, 21, ENUMVAL_NAME, "XmINDICATOR_CROSS_BOX"},
    {tkn_k_class_enumval, sym_k_XmINDICATOR_FILL_enumval, 16, ENUMVAL_NAME, "XmINDICATOR_FILL"},
    {tkn_k_class_enumval, sym_k_XmINDICATOR_NONE_enumval, 16, ENUMVAL_NAME, "XmINDICATOR_NONE"},
    {tkn_k_class_enumval, sym_k_XmINHERIT_POLICY_enumval, 16, ENUMVAL_NAME, "XmINHERIT_POLICY"},
    {tkn_k_class_enumval, sym_k_XmINVALID_MATCH_BEHAVIOR_enumval, 24, ENUMVAL_NAME, "XmINVALID_MATCH_BEHAVIOR"},
    {tkn_k_class_enumval, sym_k_XmIconBottom_enumval, 12, ENUMVAL_NAME, "XmIconBottom"},
    {tkn_k_class_class, sym_k_XmIconBox_object, 9, CLASS_NAME, "XmIconBox"},
    {tkn_k_class_class, sym_k_XmIconButton_object, 12, CLASS_NAME, "XmIconButton"},
    {tkn_k_class_class, sym_k_XmIconGadget_object, 12, CLASS_NAME, "XmIconGadget"},
    {tkn_k_class_enumval, sym_k_XmIconLeft_enumval, 10, ENUMVAL_NAME, "XmIconLeft"},
    {tkn_k_class_enumval, sym_k_XmIconNone_enumval, 10, ENUMVAL_NAME, "XmIconNone"},
    {tkn_k_class_enumval, sym_k_XmIconOnly_enumval, 10, ENUMVAL_NAME, "XmIconOnly"},
    {tkn_k_class_enumval, sym_k_XmIconRight_enumval, 11, ENUMVAL_NAME, "XmIconRight"},
    {tkn_k_class_enumval, sym_k_XmIconTop_enumval, 9, ENUMVAL_NAME, "XmIconTop"},
    {tkn_k_class_class, sym_k_XmInformationDialog_object, 19, CLASS_NAME, "XmInformationDialog"},
    {tkn_k_class_enumval, sym_k_XmLARGE_ICON_enumval, 12, ENUMVAL_NAME, "XmLARGE_ICON"},
    {tkn_k_class_enumval, sym_k_XmLAST_POSITION_enumval, 15, ENUMVAL_NAME, "XmLAST_POSITION"},
    {tkn_k_class_enumval, sym_k_XmLEFT_TO_RIGHT_enumval, 15, ENUMVAL_NAME, "XmLEFT_TO_RIGHT"},
    {tkn_k_class_enumval, sym_k_XmLEFT_TO_RIGHT_BOTTOM_TO_TOP_enumval, 29, ENUMVAL_NAME, "XmLEFT_TO_RIGHT_BOTTOM_TO_TOP"},
    {tkn_k_class_enumval, sym_k_XmLEFT_TO_RIGHT_TOP_TO_BOTTOM_enumval, 29, ENUMVAL_NAME, "XmLEFT_TO_RIGHT_TOP_TO_BOTTOM"},
    {tkn_k_class_enumval, sym_k_XmLOAD_DEFERRED_enumval, 15, ENUMVAL_NAME, "XmLOAD_DEFERRED"},
    {tkn_k_class_enumval, sym_k_XmLOAD_IMMEDIATE_enumval, 16, ENUMVAL_NAME, "XmLOAD_IMMEDIATE"},
    {tkn_k_class_class, sym_k_XmLabel_object, 7, CLASS_NAME, "XmLabel"},
    {tkn_k_class_class, sym_k_XmLabelGadget_object, 13, CLASS_NAME, "XmLabelGadget"},
    {tkn_k_class_class, sym_k_XmList_object, 6, CLASS_NAME, "XmList"},
    {tkn_k_class_enumval, sym_k_XmListMode_enumval, 10, ENUMVAL_NAME, "XmListMode"},
    {tkn_k_class_enumval, sym_k_XmMAJOR_TAB_enumval, 11, ENUMVAL_NAME, "XmMAJOR_TAB"},
    {tkn_k_class_enumval, sym_k_XmMARQUEE_enumval, 9, ENUMVAL_NAME, "XmMARQUEE"},
    {tkn_k_class_enumval, sym_k_XmMARQUEE_EXTEND_BOTH_enumval, 21, ENUMVAL_NAME, "XmMARQUEE_EXTEND_BOTH"},
    {tkn_k_class_enumval, sym_k_XmMARQUEE_EXTEND_START_enumval, 22, ENUMVAL_NAME, "XmMARQUEE_EXTEND_START"},
    {tkn_k_class_enumval, sym_k_XmMAX_ON_BOTTOM_enumval, 15, ENUMVAL_NAME, "XmMAX_ON_BOTTOM"},
    {tkn_k_class_enumval, sym_k_XmMAX_ON_LEFT_enumval, 13, ENUMVAL_NAME, "XmMAX_ON_LEFT"},
    {tkn_k_class_enumval, sym_k_XmMAX_ON_RIGHT_enumval, 14, ENUMVAL_NAME, "XmMAX_ON_RIGHT"},
    {tkn_k_class_enumval, sym_k_XmMAX_ON_TOP_enumval, 12, ENUMVAL_NAME, "XmMAX_ON_TOP"},
    {tkn_k_class_enumval, sym_k_XmMAX_SIDE_enumval, 10, ENUMVAL_NAME, "XmMAX_SIDE"},
    {tkn_k_class_enumval, sym_k_XmMENU_BAR_enumval, 10, ENUMVAL_NAME, "XmMENU_BAR"},
    {tkn_k_class_enumval, sym_k_XmMENU_OPTION_enumval, 13, ENUMVAL_NAME, "XmMENU_OPTION"},
    {tkn_k_class_enumval, sym_k_XmMENU_POPUP_enumval, 12, ENUMVAL_NAME, "XmMENU_POPUP"},
    {tkn_k_class_enumval, sym_k_XmMENU_PULLDOWN_enumval, 15, ENUMVAL_NAME, "XmMENU_PULLDOWN"},
    {tkn_k_class_enumval, sym_k_XmMESSAGE_WINDOW_enumval, 16, ENUMVAL_NAME, "XmMESSAGE_WINDOW"},
    {tkn_k_class_enumval, sym_k_XmMILLIMETERS_enumval, 13, ENUMVAL_NAME, "XmMILLIMETERS"},
    {tkn_k_class_enumval, sym_k_XmMINOR_TAB_enumval, 11, ENUMVAL_NAME, "XmMINOR_TAB"},
    {tkn_k_class_enumval, sym_k_XmMIN_SIDE_enumval, 10, ENUMVAL_NAME, "XmMIN_SIDE"},
    {tkn_k_class_enumval, sym_k_XmMULTICLICK_DISCARD_enumval, 20, ENUMVAL_NAME, "XmMULTICLICK_DISCARD"},
    {tkn_k_class_enumval, sym_k_XmMULTICLICK_KEEP_enumval, 17, ENUMVAL_NAME, "XmMULTICLICK_KEEP"},
    {tkn_k_class_enumval, sym_k_XmMULTIPLE_SELECT_enumval, 17, ENUMVAL_NAME, "XmMULTIPLE_SELECT"},
    {tkn_k_class_enumval, sym_k_XmMULTI_LINE_EDIT_enumval, 17, ENUMVAL_NAME, "XmMULTI_LINE_EDIT"},
    {tkn_k_class_class, sym_k_XmMainWindow_object, 12, CLASS_NAME, "XmMainWindow"},
    {tkn_k_class_class, sym_k_XmMenuBar_object, 9, CLASS_NAME, "XmMenuBar"},
    {tkn_k_class_class, sym_k_XmMenuShell_object, 11, CLASS_NAME, "XmMenuShell"},
    {tkn_k_class_class, sym_k_XmMessageBox_object, 12, CLASS_NAME, "XmMessageBox"},
    {tkn_k_class_class, sym_k_XmMessageDialog_object, 15, CLASS_NAME, "XmMessageDialog"},
    {tkn_k_class_class, sym_k_XmMultiList_object, 11, CLASS_NAME, "XmMultiList"},
    {tkn_k_class_argument, sym_k_XmN100DPIstring_arg, 15, ARGUMENT_NAME, "XmN100DPIstring"},
    {tkn_k_class_argument, sym_k_XmN75DPIstring_arg, 14, ARGUMENT_NAME, "XmN75DPIstring"},
    {tkn_k_class_enumval, sym_k_XmNEAR_BORDER_enumval, 13, ENUMVAL_NAME, "XmNEAR_BORDER"},
    {tkn_k_class_enumval, sym_k_XmNEAR_SLIDER_enumval, 13, ENUMVAL_NAME, "XmNEAR_SLIDER"},
    {tkn_k_class_enumval, sym_k_XmNONE_enumval, 6, ENUMVAL_NAME, "XmNONE"},
    {tkn_k_class_enumval, sym_k_XmNORMAL_MODE_enumval, 13, ENUMVAL_NAME, "XmNORMAL_MODE"},
    {tkn_k_class_enumval, sym_k_XmNOT_SELECTED_enumval, 14, ENUMVAL_NAME, "XmNOT_SELECTED"},
    {tkn_k_class_enumval, sym_k_XmNO_AUTO_SELECT_enumval, 16, ENUMVAL_NAME, "XmNO_AUTO_SELECT"},
    {tkn_k_class_enumval, sym_k_XmNO_LINE_enumval, 9, ENUMVAL_NAME, "XmNO_LINE"},
    {tkn_k_class_enumval, sym_k_XmNO_ORIENTATION_enumval, 16, ENUMVAL_NAME, "XmNO_ORIENTATION"},
    {tkn_k_class_enumval, sym_k_XmNO_PACKING_enumval, 12, ENUMVAL_NAME, "XmNO_PACKING"},
    {tkn_k_class_enumval, sym_k_XmNO_SCROLL_enumval, 11, ENUMVAL_NAME, "XmNO_SCROLL"},
    {tkn_k_class_enumval, sym_k_XmNUMERIC_enumval, 9, ENUMVAL_NAME, "XmNUMERIC"},
    {tkn_k_class_enumval, sym_k_XmN_OF_MANY_enumval, 11, ENUMVAL_NAME, "XmN_OF_MANY"},
    {tkn_k_class_argument, sym_k_XmNaccelerator_arg, 14, ARGUMENT_NAME, "XmNaccelerator"},
    {tkn_k_class_argument, sym_k_XmNacceleratorText_arg, 18, ARGUMENT_NAME, "XmNacceleratorText"},
    {tkn_k_class_argument, sym_k_XmNaccelerators_arg, 15, ARGUMENT_NAME, "XmNaccelerators"},
    {tkn_k_class_reason, sym_k_XmNactivateCallback_reason, 19, REASON_NAME, "XmNactivateCallback"},
    {tkn_k_class_argument, sym_k_XmNadjustLast_arg, 13, ARGUMENT_NAME, "XmNadjustLast"},
    {tkn_k_class_argument, sym_k_XmNadjustMargin_arg, 15, ARGUMENT_NAME, "XmNadjustMargin"},
    {tkn_k_class_argument, sym_k_XmNalignment_arg, 12, ARGUMENT_NAME, "XmNalignment"},
    {tkn_k_class_argument, sym_k_XmNallowOverlap_arg, 15, ARGUMENT_NAME, "XmNallowOverlap"},
    {tkn_k_class_argument, sym_k_XmNallowResize_arg, 14, ARGUMENT_NAME, "XmNallowResize"},
    {tkn_k_class_argument, sym_k_XmNallowShellResize_arg, 19, ARGUMENT_NAME, "XmNallowShellResize"},
    {tkn_k_class_argument, sym_k_XmNallowUnusedSpace_arg, 19, ARGUMENT_NAME, "XmNallowUnusedSpace"},
    {tkn_k_class_argument, sym_k_XmNancestorSensitive_arg, 20, ARGUMENT_NAME, "XmNancestorSensitive"},
    {tkn_k_class_argument, sym_k_XmNanyLowerString_arg, 17, ARGUMENT_NAME, "XmNanyLowerString"},
    {tkn_k_class_argument, sym_k_XmNanyString_arg, 12, ARGUMENT_NAME, "XmNanyString"},
    {tkn_k_class_reason, sym_k_XmNapplyCallback_reason, 16, REASON_NAME, "XmNapplyCallback"},
    {tkn_k_class_argument, sym_k_XmNapplyLabelString_arg, 19, ARGUMENT_NAME, "XmNapplyLabelString"},
    {tkn_k_class_reason, sym_k_XmNarmCallback_reason, 14, REASON_NAME, "XmNarmCallback"},
    {tkn_k_class_argument, sym_k_XmNarmColor_arg, 11, ARGUMENT_NAME, "XmNarmColor"},
    {tkn_k_class_argument, sym_k_XmNarmPixmap_arg, 12, ARGUMENT_NAME, "XmNarmPixmap"},
    {tkn_k_class_argument, sym_k_XmNarrowDirection_arg, 17, ARGUMENT_NAME, "XmNarrowDirection"},
    {tkn_k_class_argument, sym_k_XmNarrowLayout_arg, 14, ARGUMENT_NAME, "XmNarrowLayout"},
    {tkn_k_class_argument, sym_k_XmNarrowOrientation_arg, 19, ARGUMENT_NAME, "XmNarrowOrientation"},
    {tkn_k_class_argument, sym_k_XmNarrowSensitivity_arg, 19, ARGUMENT_NAME, "XmNarrowSensitivity"},
    {tkn_k_class_argument, sym_k_XmNarrowSize_arg, 12, ARGUMENT_NAME, "XmNarrowSize"},
    {tkn_k_class_argument, sym_k_XmNarrowSpacing_arg, 15, ARGUMENT_NAME, "XmNarrowSpacing"},
    {tkn_k_class_argument, sym_k_XmNaudibleWarning_arg, 17, ARGUMENT_NAME, "XmNaudibleWarning"},
    {tkn_k_class_argument, sym_k_XmNautoClose_arg, 12, ARGUMENT_NAME, "XmNautoClose"},
    {tkn_k_class_argument, sym_k_XmNautoDragModel_arg, 16, ARGUMENT_NAME, "XmNautoDragModel"},
    {tkn_k_class_argument, sym_k_XmNautoFill_arg, 11, ARGUMENT_NAME, "XmNautoFill"},
    {tkn_k_class_argument, sym_k_XmNautoShowCursorPosition_arg, 25, ARGUMENT_NAME, "XmNautoShowCursorPosition"},
    {tkn_k_class_argument, sym_k_XmNautoUnmanage_arg, 15, ARGUMENT_NAME, "XmNautoUnmanage"},
    {tkn_k_class_argument, sym_k_XmNautomaticSelection_arg, 21, ARGUMENT_NAME, "XmNautomaticSelection"},
    {tkn_k_class_argument, sym_k_XmNbackPageBackground_arg, 21, ARGUMENT_NAME, "XmNbackPageBackground"},
    {tkn_k_class_argument, sym_k_XmNbackPageForeground_arg, 21, ARGUMENT_NAME, "XmNbackPageForeground"},
    {tkn_k_class_argument, sym_k_XmNbackPageNumber_arg, 17, ARGUMENT_NAME, "XmNbackPageNumber"},
    {tkn_k_class_argument, sym_k_XmNbackPagePlacement_arg, 20, ARGUMENT_NAME, "XmNbackPagePlacement"},
    {tkn_k_class_argument, sym_k_XmNbackPageSize_arg, 15, ARGUMENT_NAME, "XmNbackPageSize"},
    {tkn_k_class_argument, sym_k_XmNbackground_arg, 13, ARGUMENT_NAME, "XmNbackground"},
    {tkn_k_class_argument, sym_k_XmNbackgroundPixmap_arg, 19, ARGUMENT_NAME, "XmNbackgroundPixmap"},
    {tkn_k_class_argument, sym_k_XmNbaseHeight_arg, 13, ARGUMENT_NAME, "XmNbaseHeight"},
    {tkn_k_class_argument, sym_k_XmNbaseWidth_arg, 12, ARGUMENT_NAME, "XmNbaseWidth"},
    {tkn_k_class_argument, sym_k_XmNbindingPixmap_arg, 16, ARGUMENT_NAME, "XmNbindingPixmap"},
    {tkn_k_class_argument, sym_k_XmNbindingType_arg, 14, ARGUMENT_NAME, "XmNbindingType"},
    {tkn_k_class_argument, sym_k_XmNbindingWidth_arg, 15, ARGUMENT_NAME, "XmNbindingWidth"},
    {tkn_k_class_argument, sym_k_XmNblinkRate_arg, 12, ARGUMENT_NAME, "XmNblinkRate"},
    {tkn_k_class_argument, sym_k_XmNblueSliderLabel_arg, 18, ARGUMENT_NAME, "XmNblueSliderLabel"},
    {tkn_k_class_argument, sym_k_XmNboldString_arg, 13, ARGUMENT_NAME, "XmNboldString"},
    {tkn_k_class_argument, sym_k_XmNborderColor_arg, 14, ARGUMENT_NAME, "XmNborderColor"},
    {tkn_k_class_argument, sym_k_XmNborderPixmap_arg, 15, ARGUMENT_NAME, "XmNborderPixmap"},
    {tkn_k_class_argument, sym_k_XmNborderWidth_arg, 14, ARGUMENT_NAME, "XmNborderWidth"},
    {tkn_k_class_argument, sym_k_XmNbothString_arg, 13, ARGUMENT_NAME, "XmNbothString"},
    {tkn_k_class_argument, sym_k_XmNbottomAttachment_arg, 19, ARGUMENT_NAME, "XmNbottomAttachment"},
    {tkn_k_class_argument, sym_k_XmNbottomOffset_arg, 15, ARGUMENT_NAME, "XmNbottomOffset"},
    {tkn_k_class_argument, sym_k_XmNbottomPosition_arg, 17, ARGUMENT_NAME, "XmNbottomPosition"},
    {tkn_k_class_argument, sym_k_XmNbottomShadowColor_arg, 20, ARGUMENT_NAME, "XmNbottomShadowColor"},
    {tkn_k_class_argument, sym_k_XmNbottomShadowPixmap_arg, 21, ARGUMENT_NAME, "XmNbottomShadowPixmap"},
    {tkn_k_class_argument, sym_k_XmNbottomWidget_arg, 15, ARGUMENT_NAME, "XmNbottomWidget"},
    {tkn_k_class_reason, sym_k_XmNbrowseSelectionCallback_reason, 26, REASON_NAME, "XmNbrowseSelectionCallback"},
    {tkn_k_class_argument, sym_k_XmNbuttonCount_arg, 14, ARGUMENT_NAME, "XmNbuttonCount"},
    {tkn_k_class_argument, sym_k_XmNbuttonFontList_arg, 17, ARGUMENT_NAME, "XmNbuttonFontList"},
    {tkn_k_class_argument, sym_k_XmNbuttonRenderTable_arg, 20, ARGUMENT_NAME, "XmNbuttonRenderTable"},
    {tkn_k_class_argument, sym_k_XmNbuttons_arg, 10, ARGUMENT_NAME, "XmNbuttons"},
    {tkn_k_class_argument, sym_k_XmNcancelButton_arg, 15, ARGUMENT_NAME, "XmNcancelButton"},
    {tkn_k_class_reason, sym_k_XmNcancelCallback_reason, 17, REASON_NAME, "XmNcancelCallback"},
    {tkn_k_class_argument, sym_k_XmNcancelLabelString_arg, 20, ARGUMENT_NAME, "XmNcancelLabelString"},
    {tkn_k_class_argument, sym_k_XmNcascadePixmap_arg, 16, ARGUMENT_NAME, "XmNcascadePixmap"},
    {tkn_k_class_reason, sym_k_XmNcascadingCallback_reason, 20, REASON_NAME, "XmNcascadingCallback"},
    {tkn_k_class_argument, sym_k_XmNcellX_arg, 8, ARGUMENT_NAME, "XmNcellX"},
    {tkn_k_class_argument, sym_k_XmNcellY_arg, 8, ARGUMENT_NAME, "XmNcellY"},
    {tkn_k_class_argument, sym_k_XmNchildHorizontalAlignment_arg, 27, ARGUMENT_NAME, "XmNchildHorizontalAlignment"},
    {tkn_k_class_argument, sym_k_XmNchildHorizontalSpacing_arg, 25, ARGUMENT_NAME, "XmNchildHorizontalSpacing"},
    {tkn_k_class_argument, sym_k_XmNchildPlacement_arg, 17, ARGUMENT_NAME, "XmNchildPlacement"},
    {tkn_k_class_argument, sym_k_XmNchildType_arg, 12, ARGUMENT_NAME, "XmNchildType"},
    {tkn_k_class_argument, sym_k_XmNchildVerticalAlignment_arg, 25, ARGUMENT_NAME, "XmNchildVerticalAlignment"},
    {tkn_k_class_argument, sym_k_XmNclipWindow_arg, 13, ARGUMENT_NAME, "XmNclipWindow"},
    {tkn_k_class_argument, sym_k_XmNcloseFolderPixmap_arg, 20, ARGUMENT_NAME, "XmNcloseFolderPixmap"},
    {tkn_k_class_argument, sym_k_XmNcollapsedStatePixmap_arg, 23, ARGUMENT_NAME, "XmNcollapsedStatePixmap"},
    {tkn_k_class_argument, sym_k_XmNcolorListTogLabel_arg, 20, ARGUMENT_NAME, "XmNcolorListTogLabel"},
    {tkn_k_class_argument, sym_k_XmNcolorMode_arg, 12, ARGUMENT_NAME, "XmNcolorMode"},
    {tkn_k_class_argument, sym_k_XmNcolorName_arg, 12, ARGUMENT_NAME, "XmNcolorName"},
    {tkn_k_class_argument, sym_k_XmNcolormap_arg, 11, ARGUMENT_NAME, "XmNcolormap"},
    {tkn_k_class_argument, sym_k_XmNcolumnTitles_arg, 15, ARGUMENT_NAME, "XmNcolumnTitles"},
    {tkn_k_class_argument, sym_k_XmNcolumns_arg, 10, ARGUMENT_NAME, "XmNcolumns"},
    {tkn_k_class_argument, sym_k_XmNcomboBoxType_arg, 15, ARGUMENT_NAME, "XmNcomboBoxType"},
    {tkn_k_class_argument, sym_k_XmNcomboTranslations_arg, 20, ARGUMENT_NAME, "XmNcomboTranslations"},
    {tkn_k_class_argument, sym_k_XmNcommand_arg, 10, ARGUMENT_NAME, "XmNcommand"},
    {tkn_k_class_reason, sym_k_XmNcommandChangedCallback_reason, 25, REASON_NAME, "XmNcommandChangedCallback"},
    {tkn_k_class_reason, sym_k_XmNcommandEnteredCallback_reason, 25, REASON_NAME, "XmNcommandEnteredCallback"},
    {tkn_k_class_argument, sym_k_XmNcommandWindow_arg, 16, ARGUMENT_NAME, "XmNcommandWindow"},
    {tkn_k_class_argument, sym_k_XmNcommandWindowLocation_arg, 24, ARGUMENT_NAME, "XmNcommandWindowLocation"},
    {tkn_k_class_argument, sym_k_XmNcompressStyle_arg, 16, ARGUMENT_NAME, "XmNcompressStyle"},
    {tkn_k_class_argument, sym_k_XmNconnectNodes_arg, 15, ARGUMENT_NAME, "XmNconnectNodes"},
    {tkn_k_class_argument, sym_k_XmNconnectStyle_arg, 15, ARGUMENT_NAME, "XmNconnectStyle"},
    {tkn_k_class_argument, sym_k_XmNconstrainWidth_arg, 17, ARGUMENT_NAME, "XmNconstrainWidth"},
    {tkn_k_class_reason, sym_k_XmNconvertCallback_reason, 18, REASON_NAME, "XmNconvertCallback"},
    {tkn_k_class_argument, sym_k_XmNcreatePopupChildProc_arg, 23, ARGUMENT_NAME, "XmNcreatePopupChildProc"},
    {tkn_k_class_argument, sym_k_XmNcurrentFont_arg, 14, ARGUMENT_NAME, "XmNcurrentFont"},
    {tkn_k_class_argument, sym_k_XmNcurrentPageNumber_arg, 20, ARGUMENT_NAME, "XmNcurrentPageNumber"},
    {tkn_k_class_argument, sym_k_XmNcursor_arg, 9, ARGUMENT_NAME, "XmNcursor"},
    {tkn_k_class_argument, sym_k_XmNcursorPosition_arg, 17, ARGUMENT_NAME, "XmNcursorPosition"},
    {tkn_k_class_argument, sym_k_XmNcursorPositionVisible_arg, 24, ARGUMENT_NAME, "XmNcursorPositionVisible"},
    {tkn_k_class_argument, sym_k_XmNcustomizedCombinationBox_arg, 27, ARGUMENT_NAME, "XmNcustomizedCombinationBox"},
    {tkn_k_class_argument, sym_k_XmNdarkThreshold_arg, 16, ARGUMENT_NAME, "XmNdarkThreshold"},
    {tkn_k_class_argument, sym_k_XmNdecimal_arg, 10, ARGUMENT_NAME, "XmNdecimal"},
    {tkn_k_class_argument, sym_k_XmNdecimalPoints_arg, 16, ARGUMENT_NAME, "XmNdecimalPoints"},
    {tkn_k_class_reason, sym_k_XmNdecrementCallback_reason, 20, REASON_NAME, "XmNdecrementCallback"},
    {tkn_k_class_reason, sym_k_XmNdefaultActionCallback_reason, 24, REASON_NAME, "XmNdefaultActionCallback"},
    {tkn_k_class_argument, sym_k_XmNdefaultArrowSensitivity_arg, 26, ARGUMENT_NAME, "XmNdefaultArrowSensitivity"},
    {tkn_k_class_argument, sym_k_XmNdefaultButton_arg, 16, ARGUMENT_NAME, "XmNdefaultButton"},
    {tkn_k_class_argument, sym_k_XmNdefaultButtonShadowThickness_arg, 31, ARGUMENT_NAME, "XmNdefaultButtonShadowThickness"},
    {tkn_k_class_argument, sym_k_XmNdefaultButtonType_arg, 20, ARGUMENT_NAME, "XmNdefaultButtonType"},
    {tkn_k_class_argument, sym_k_XmNdefaultEncodingString_arg, 24, ARGUMENT_NAME, "XmNdefaultEncodingString"},
    {tkn_k_class_argument, sym_k_XmNdefaultEntryLabelAlignment_arg, 29, ARGUMENT_NAME, "XmNdefaultEntryLabelAlignment"},
    {tkn_k_class_argument, sym_k_XmNdefaultEntryLabelFontList_arg, 28, ARGUMENT_NAME, "XmNdefaultEntryLabelFontList"},
    {tkn_k_class_argument, sym_k_XmNdefaultEntryLabelRenderTable_arg, 31, ARGUMENT_NAME, "XmNdefaultEntryLabelRenderTable"},
    {tkn_k_class_argument, sym_k_XmNdefaultFillStyle_arg, 19, ARGUMENT_NAME, "XmNdefaultFillStyle"},
    {tkn_k_class_argument, sym_k_XmNdefaultFontList_arg, 18, ARGUMENT_NAME, "XmNdefaultFontList"},
    {tkn_k_class_argument, sym_k_XmNdefaultPosition_arg, 18, ARGUMENT_NAME, "XmNdefaultPosition"},
    {tkn_k_class_argument, sym_k_XmNdeleteResponse_arg, 17, ARGUMENT_NAME, "XmNdeleteResponse"},
    {tkn_k_class_argument, sym_k_XmNdepth_arg, 8, ARGUMENT_NAME, "XmNdepth"},
    {tkn_k_class_reason, sym_k_XmNdestinationCallback_reason, 22, REASON_NAME, "XmNdestinationCallback"},
    {tkn_k_class_reason, sym_k_XmNdestroyCallback_reason, 18, REASON_NAME, "XmNdestroyCallback"},
    {tkn_k_class_argument, sym_k_XmNdetail_arg, 9, ARGUMENT_NAME, "XmNdetail"},
    {tkn_k_class_argument, sym_k_XmNdetailColumnHeading_arg, 22, ARGUMENT_NAME, "XmNdetailColumnHeading"},
    {tkn_k_class_argument, sym_k_XmNdetailColumnHeadingCount_arg, 27, ARGUMENT_NAME, "XmNdetailColumnHeadingCount"},
    {tkn_k_class_argument, sym_k_XmNdetailCount_arg, 14, ARGUMENT_NAME, "XmNdetailCount"},
    {tkn_k_class_argument, sym_k_XmNdetailOrder_arg, 14, ARGUMENT_NAME, "XmNdetailOrder"},
    {tkn_k_class_argument, sym_k_XmNdetailOrderCount_arg, 19, ARGUMENT_NAME, "XmNdetailOrderCount"},
    {tkn_k_class_argument, sym_k_XmNdetailShadowThickness_arg, 24, ARGUMENT_NAME, "XmNdetailShadowThickness"},
    {tkn_k_class_argument, sym_k_XmNdetailTabList_arg, 16, ARGUMENT_NAME, "XmNdetailTabList"},
    {tkn_k_class_argument, sym_k_XmNdialogStyle_arg, 14, ARGUMENT_NAME, "XmNdialogStyle"},
    {tkn_k_class_argument, sym_k_XmNdialogTitle_arg, 14, ARGUMENT_NAME, "XmNdialogTitle"},
    {tkn_k_class_argument, sym_k_XmNdialogType_arg, 13, ARGUMENT_NAME, "XmNdialogType"},
    {tkn_k_class_argument, sym_k_XmNdirListItemCount_arg, 19, ARGUMENT_NAME, "XmNdirListItemCount"},
    {tkn_k_class_argument, sym_k_XmNdirListItems_arg, 15, ARGUMENT_NAME, "XmNdirListItems"},
    {tkn_k_class_argument, sym_k_XmNdirListLabelString_arg, 21, ARGUMENT_NAME, "XmNdirListLabelString"},
    {tkn_k_class_argument, sym_k_XmNdirMask_arg, 10, ARGUMENT_NAME, "XmNdirMask"},
    {tkn_k_class_argument, sym_k_XmNdirSearchProc_arg, 16, ARGUMENT_NAME, "XmNdirSearchProc"},
    {tkn_k_class_argument, sym_k_XmNdirSpec_arg, 10, ARGUMENT_NAME, "XmNdirSpec"},
    {tkn_k_class_argument, sym_k_XmNdirectory_arg, 12, ARGUMENT_NAME, "XmNdirectory"},
    {tkn_k_class_argument, sym_k_XmNdirectoryValid_arg, 17, ARGUMENT_NAME, "XmNdirectoryValid"},
    {tkn_k_class_reason, sym_k_XmNdisarmCallback_reason, 17, REASON_NAME, "XmNdisarmCallback"},
    {tkn_k_class_argument, sym_k_XmNdistribution_arg, 15, ARGUMENT_NAME, "XmNdistribution"},
    {tkn_k_class_reason, sym_k_XmNdoubleClickCallback_reason, 22, REASON_NAME, "XmNdoubleClickCallback"},
    {tkn_k_class_argument, sym_k_XmNdoubleClickInterval_arg, 22, ARGUMENT_NAME, "XmNdoubleClickInterval"},
    {tkn_k_class_reason, sym_k_XmNdragCallback_reason, 15, REASON_NAME, "XmNdragCallback"},
    {tkn_k_class_argument, sym_k_XmNeditMode_arg, 11, ARGUMENT_NAME, "XmNeditMode"},
    {tkn_k_class_argument, sym_k_XmNeditable_arg, 11, ARGUMENT_NAME, "XmNeditable"},
    {tkn_k_class_argument, sym_k_XmNencodingList_arg, 15, ARGUMENT_NAME, "XmNencodingList"},
    {tkn_k_class_argument, sym_k_XmNencodingString_arg, 17, ARGUMENT_NAME, "XmNencodingString"},
    {tkn_k_class_argument, sym_k_XmNentryAlignment_arg, 17, ARGUMENT_NAME, "XmNentryAlignment"},
    {tkn_k_class_argument, sym_k_XmNentryBackground_arg, 18, ARGUMENT_NAME, "XmNentryBackground"},
    {tkn_k_class_argument, sym_k_XmNentryBorder_arg, 14, ARGUMENT_NAME, "XmNentryBorder"},
    {tkn_k_class_reason, sym_k_XmNentryCallback_reason, 16, REASON_NAME, "XmNentryCallback"},
    {tkn_k_class_argument, sym_k_XmNentryClass_arg, 13, ARGUMENT_NAME, "XmNentryClass"},
    {tkn_k_class_argument, sym_k_XmNentryData_arg, 12, ARGUMENT_NAME, "XmNentryData"},
    {tkn_k_class_argument, sym_k_XmNentryLabelAlignment_arg, 22, ARGUMENT_NAME, "XmNentryLabelAlignment"},
    {tkn_k_class_argument, sym_k_XmNentryLabelFontList_arg, 21, ARGUMENT_NAME, "XmNentryLabelFontList"},
    {tkn_k_class_argument, sym_k_XmNentryLabelPixmap_arg, 19, ARGUMENT_NAME, "XmNentryLabelPixmap"},
    {tkn_k_class_argument, sym_k_XmNentryLabelRenderTable_arg, 24, ARGUMENT_NAME, "XmNentryLabelRenderTable"},
    {tkn_k_class_argument, sym_k_XmNentryLabelString_arg, 19, ARGUMENT_NAME, "XmNentryLabelString"},
    {tkn_k_class_argument, sym_k_XmNentryLabelType_arg, 17, ARGUMENT_NAME, "XmNentryLabelType"},
    {tkn_k_class_argument, sym_k_XmNentryParent_arg, 14, ARGUMENT_NAME, "XmNentryParent"},
    {tkn_k_class_argument, sym_k_XmNentryVerticalAlignment_arg, 25, ARGUMENT_NAME, "XmNentryVerticalAlignment"},
    {tkn_k_class_argument, sym_k_XmNentryViewType_arg, 16, ARGUMENT_NAME, "XmNentryViewType"},
    {tkn_k_class_argument, sym_k_XmNequalSize_arg, 12, ARGUMENT_NAME, "XmNequalSize"},
    {tkn_k_class_argument, sym_k_XmNexpandedStatePixmap_arg, 22, ARGUMENT_NAME, "XmNexpandedStatePixmap"},
    {tkn_k_class_reason, sym_k_XmNexposeCallback_reason, 17, REASON_NAME, "XmNexposeCallback"},
    {tkn_k_class_reason, sym_k_XmNextendedSelectionCallback_reason, 28, REASON_NAME, "XmNextendedSelectionCallback"},
    {tkn_k_class_argument, sym_k_XmNfamilyString_arg, 15, ARGUMENT_NAME, "XmNfamilyString"},
    {tkn_k_class_argument, sym_k_XmNfileListItemCount_arg, 20, ARGUMENT_NAME, "XmNfileListItemCount"},
    {tkn_k_class_argument, sym_k_XmNfileListItems_arg, 16, ARGUMENT_NAME, "XmNfileListItems"},
    {tkn_k_class_argument, sym_k_XmNfileListLabelString_arg, 22, ARGUMENT_NAME, "XmNfileListLabelString"},
    {tkn_k_class_argument, sym_k_XmNfileReadError_arg, 16, ARGUMENT_NAME, "XmNfileReadError"},
    {tkn_k_class_argument, sym_k_XmNfileSearchProc_arg, 17, ARGUMENT_NAME, "XmNfileSearchProc"},
    {tkn_k_class_argument, sym_k_XmNfileTypeMask_arg, 15, ARGUMENT_NAME, "XmNfileTypeMask"},
    {tkn_k_class_argument, sym_k_XmNfillOnArm_arg, 12, ARGUMENT_NAME, "XmNfillOnArm"},
    {tkn_k_class_argument, sym_k_XmNfillOnSelect_arg, 15, ARGUMENT_NAME, "XmNfillOnSelect"},
    {tkn_k_class_argument, sym_k_XmNfillOption_arg, 13, ARGUMENT_NAME, "XmNfillOption"},
    {tkn_k_class_argument, sym_k_XmNfillStyle_arg, 12, ARGUMENT_NAME, "XmNfillStyle"},
    {tkn_k_class_argument, sym_k_XmNfilterLabelString_arg, 20, ARGUMENT_NAME, "XmNfilterLabelString"},
    {tkn_k_class_argument, sym_k_XmNfindLabel_arg, 12, ARGUMENT_NAME, "XmNfindLabel"},
    {tkn_k_class_argument, sym_k_XmNfirstColumn_arg, 14, ARGUMENT_NAME, "XmNfirstColumn"},
    {tkn_k_class_argument, sym_k_XmNfirstColumnPixmaps_arg, 21, ARGUMENT_NAME, "XmNfirstColumnPixmaps"},
    {tkn_k_class_argument, sym_k_XmNfirstPageNumber_arg, 18, ARGUMENT_NAME, "XmNfirstPageNumber"},
    {tkn_k_class_argument, sym_k_XmNfirstRow_arg, 11, ARGUMENT_NAME, "XmNfirstRow"},
    {tkn_k_class_reason, sym_k_XmNfocusCallback_reason, 16, REASON_NAME, "XmNfocusCallback"},
    {tkn_k_class_reason, sym_k_XmNfocusMovedCallback_reason, 21, REASON_NAME, "XmNfocusMovedCallback"},
    {tkn_k_class_argument, sym_k_XmNfont_arg, 7, ARGUMENT_NAME, "XmNfont"},
    {tkn_k_class_argument, sym_k_XmNfontEncoding_arg, 15, ARGUMENT_NAME, "XmNfontEncoding"},
    {tkn_k_class_argument, sym_k_XmNfontFoundry_arg, 14, ARGUMENT_NAME, "XmNfontFoundry"},
    {tkn_k_class_argument, sym_k_XmNfontList_arg, 11, ARGUMENT_NAME, "XmNfontList"},
    {tkn_k_class_argument, sym_k_XmNfontName_arg, 11, ARGUMENT_NAME, "XmNfontName"},
    {tkn_k_class_argument, sym_k_XmNfontSize_arg, 11, ARGUMENT_NAME, "XmNfontSize"},
    {tkn_k_class_argument, sym_k_XmNfontStyle_arg, 12, ARGUMENT_NAME, "XmNfontStyle"},
    {tkn_k_class_argument, sym_k_XmNfontType_arg, 11, ARGUMENT_NAME, "XmNfontType"},
    {tkn_k_class_argument, sym_k_XmNforeground_arg, 13, ARGUMENT_NAME, "XmNforeground"},
    {tkn_k_class_argument, sym_k_XmNforegroundThreshold_arg, 22, ARGUMENT_NAME, "XmNforegroundThreshold"},
    {tkn_k_class_argument, sym_k_XmNfractionBase_arg, 15, ARGUMENT_NAME, "XmNfractionBase"},
    {tkn_k_class_argument, sym_k_XmNframeBackground_arg, 18, ARGUMENT_NAME, "XmNframeBackground"},
    {tkn_k_class_argument, sym_k_XmNframeChildType_arg, 17, ARGUMENT_NAME, "XmNframeChildType"},
    {tkn_k_class_argument, sym_k_XmNframeShadowThickness_arg, 23, ARGUMENT_NAME, "XmNframeShadowThickness"},
    {tkn_k_class_argument, sym_k_XmNfreeTabPixmap_arg, 16, ARGUMENT_NAME, "XmNfreeTabPixmap"},
    {tkn_k_class_reason, sym_k_XmNgainPrimaryCallback_reason, 22, REASON_NAME, "XmNgainPrimaryCallback"},
    {tkn_k_class_argument, sym_k_XmNgeometry_arg, 11, ARGUMENT_NAME, "XmNgeometry"},
    {tkn_k_class_argument, sym_k_XmNgreenSliderLabel_arg, 19, ARGUMENT_NAME, "XmNgreenSliderLabel"},
    {tkn_k_class_argument, sym_k_XmNheight_arg, 9, ARGUMENT_NAME, "XmNheight"},
    {tkn_k_class_argument, sym_k_XmNheightInc_arg, 12, ARGUMENT_NAME, "XmNheightInc"},
    {tkn_k_class_reason, sym_k_XmNhelpCallback_reason, 15, REASON_NAME, "XmNhelpCallback"},
    {tkn_k_class_argument, sym_k_XmNhelpLabelString_arg, 18, ARGUMENT_NAME, "XmNhelpLabelString"},
    {tkn_k_class_argument, sym_k_XmNhighlightColor_arg, 17, ARGUMENT_NAME, "XmNhighlightColor"},
    {tkn_k_class_argument, sym_k_XmNhighlightOnEnter_arg, 19, ARGUMENT_NAME, "XmNhighlightOnEnter"},
    {tkn_k_class_argument, sym_k_XmNhighlightPixmap_arg, 18, ARGUMENT_NAME, "XmNhighlightPixmap"},
    {tkn_k_class_argument, sym_k_XmNhighlightThickness_arg, 21, ARGUMENT_NAME, "XmNhighlightThickness"},
    {tkn_k_class_argument, sym_k_XmNhistoryItemCount_arg, 19, ARGUMENT_NAME, "XmNhistoryItemCount"},
    {tkn_k_class_argument, sym_k_XmNhistoryItems_arg, 15, ARGUMENT_NAME, "XmNhistoryItems"},
    {tkn_k_class_argument, sym_k_XmNhistoryMaxItems_arg, 18, ARGUMENT_NAME, "XmNhistoryMaxItems"},
    {tkn_k_class_argument, sym_k_XmNhistoryVisibleItemCount_arg, 26, ARGUMENT_NAME, "XmNhistoryVisibleItemCount"},
    {tkn_k_class_argument, sym_k_XmNhorizontalDelta_arg, 18, ARGUMENT_NAME, "XmNhorizontalDelta"},
    {tkn_k_class_argument, sym_k_XmNhorizontalMargin_arg, 19, ARGUMENT_NAME, "XmNhorizontalMargin"},
    {tkn_k_class_argument, sym_k_XmNhorizontalNodeSpace_arg, 22, ARGUMENT_NAME, "XmNhorizontalNodeSpace"},
    {tkn_k_class_argument, sym_k_XmNhorizontalScrollBar_arg, 22, ARGUMENT_NAME, "XmNhorizontalScrollBar"},
    {tkn_k_class_argument, sym_k_XmNhorizontalSpacing_arg, 20, ARGUMENT_NAME, "XmNhorizontalSpacing"},
    {tkn_k_class_argument, sym_k_XmNiconMask_arg, 11, ARGUMENT_NAME, "XmNiconMask"},
    {tkn_k_class_argument, sym_k_XmNiconName_arg, 11, ARGUMENT_NAME, "XmNiconName"},
    {tkn_k_class_argument, sym_k_XmNiconNameEncoding_arg, 19, ARGUMENT_NAME, "XmNiconNameEncoding"},
    {tkn_k_class_argument, sym_k_XmNiconPixmap_arg, 13, ARGUMENT_NAME, "XmNiconPixmap"},
    {tkn_k_class_argument, sym_k_XmNiconPlacement_arg, 16, ARGUMENT_NAME, "XmNiconPlacement"},
    {tkn_k_class_argument, sym_k_XmNiconTextPadding_arg, 18, ARGUMENT_NAME, "XmNiconTextPadding"},
    {tkn_k_class_argument, sym_k_XmNiconWindow_arg, 13, ARGUMENT_NAME, "XmNiconWindow"},
    {tkn_k_class_argument, sym_k_XmNiconX_arg, 8, ARGUMENT_NAME, "XmNiconX"},
    {tkn_k_class_argument, sym_k_XmNiconY_arg, 8, ARGUMENT_NAME, "XmNiconY"},
    {tkn_k_class_argument, sym_k_XmNiconic_arg, 9, ARGUMENT_NAME, "XmNiconic"},
    {tkn_k_class_argument, sym_k_XmNincrement_arg, 12, ARGUMENT_NAME, "XmNincrement"},
    {tkn_k_class_reason, sym_k_XmNincrementCallback_reason, 20, REASON_NAME, "XmNincrementCallback"},
    {tkn_k_class_argument, sym_k_XmNincrementValue_arg, 17, ARGUMENT_NAME, "XmNincrementValue"},
    {tkn_k_class_argument, sym_k_XmNindentSpace_arg, 14, ARGUMENT_NAME, "XmNindentSpace"},
    {tkn_k_class_argument, sym_k_XmNindeterminateInsensitivePixmap_arg, 33, ARGUMENT_NAME, "XmNindeterminateInsensitivePixmap"},
    {tkn_k_class_argument, sym_k_XmNindeterminatePixmap_arg, 22, ARGUMENT_NAME, "XmNindeterminatePixmap"},
    {tkn_k_class_argument, sym_k_XmNindicatorOn_arg, 14, ARGUMENT_NAME, "XmNindicatorOn"},
    {tkn_k_class_argument, sym_k_XmNindicatorSize_arg, 16, ARGUMENT_NAME, "XmNindicatorSize"},
    {tkn_k_class_argument, sym_k_XmNindicatorType_arg, 16, ARGUMENT_NAME, "XmNindicatorType"},
    {tkn_k_class_argument, sym_k_XmNinitialDelay_arg, 15, ARGUMENT_NAME, "XmNinitialDelay"},
    {tkn_k_class_argument, sym_k_XmNinitialFocus_arg, 15, ARGUMENT_NAME, "XmNinitialFocus"},
    {tkn_k_class_argument, sym_k_XmNinitialResourcesPersistent_arg, 29, ARGUMENT_NAME, "XmNinitialResourcesPersistent"},
    {tkn_k_class_argument, sym_k_XmNinitialState_arg, 15, ARGUMENT_NAME, "XmNinitialState"},
    {tkn_k_class_argument, sym_k_XmNinnerMarginHeight_arg, 20, ARGUMENT_NAME, "XmNinnerMarginHeight"},
    {tkn_k_class_argument, sym_k_XmNinnerMarginWidth_arg, 19, ARGUMENT_NAME, "XmNinnerMarginWidth"},
    {tkn_k_class_argument, sym_k_XmNinput_arg, 8, ARGUMENT_NAME, "XmNinput"},
    {tkn_k_class_reason, sym_k_XmNinputCallback_reason, 16, REASON_NAME, "XmNinputCallback"},
    {tkn_k_class_argument, sym_k_XmNinputMethod_arg, 14, ARGUMENT_NAME, "XmNinputMethod"},
    {tkn_k_class_argument, sym_k_XmNinputPolicy_arg, 14, ARGUMENT_NAME, "XmNinputPolicy"},
    {tkn_k_class_argument, sym_k_XmNinsertBefore_arg, 15, ARGUMENT_NAME, "XmNinsertBefore"},
    {tkn_k_class_argument, sym_k_XmNinsertPosition_arg, 17, ARGUMENT_NAME, "XmNinsertPosition"},
    {tkn_k_class_argument, sym_k_XmNisAligned_arg, 12, ARGUMENT_NAME, "XmNisAligned"},
    {tkn_k_class_argument, sym_k_XmNisHomogeneous_arg, 16, ARGUMENT_NAME, "XmNisHomogeneous"},
    {tkn_k_class_argument, sym_k_XmNitalicString_arg, 15, ARGUMENT_NAME, "XmNitalicString"},
    {tkn_k_class_argument, sym_k_XmNitemCount_arg, 12, ARGUMENT_NAME, "XmNitemCount"},
    {tkn_k_class_reason, sym_k_XmNitemFoundCallback_reason, 20, REASON_NAME, "XmNitemFoundCallback"},
    {tkn_k_class_reason, sym_k_XmNitemNotFoundCallback_reason, 23, REASON_NAME, "XmNitemNotFoundCallback"},
    {tkn_k_class_argument, sym_k_XmNitemSpacing_arg, 14, ARGUMENT_NAME, "XmNitemSpacing"},
    {tkn_k_class_argument, sym_k_XmNitems_arg, 8, ARGUMENT_NAME, "XmNitems"},
    {tkn_k_class_argument, sym_k_XmNkeyboardFocusPolicy_arg, 22, ARGUMENT_NAME, "XmNkeyboardFocusPolicy"},
    {tkn_k_class_argument, sym_k_XmNlabel_arg, 8, ARGUMENT_NAME, "XmNlabel"},
    {tkn_k_class_argument, sym_k_XmNlabelFontList_arg, 16, ARGUMENT_NAME, "XmNlabelFontList"},
    {tkn_k_class_argument, sym_k_XmNlabelInsensitivePixmap_arg, 25, ARGUMENT_NAME, "XmNlabelInsensitivePixmap"},
    {tkn_k_class_argument, sym_k_XmNlabelPixmap_arg, 14, ARGUMENT_NAME, "XmNlabelPixmap"},
    {tkn_k_class_argument, sym_k_XmNlabelRenderTable_arg, 19, ARGUMENT_NAME, "XmNlabelRenderTable"},
    {tkn_k_class_argument, sym_k_XmNlabelSpacing_arg, 15, ARGUMENT_NAME, "XmNlabelSpacing"},
    {tkn_k_class_argument, sym_k_XmNlabelString_arg, 14, ARGUMENT_NAME, "XmNlabelString"},
    {tkn_k_class_argument, sym_k_XmNlabelType_arg, 12, ARGUMENT_NAME, "XmNlabelType"},
    {tkn_k_class_argument, sym_k_XmNlargeCellHeight_arg, 18, ARGUMENT_NAME, "XmNlargeCellHeight"},
    {tkn_k_class_argument, sym_k_XmNlargeCellWidth_arg, 17, ARGUMENT_NAME, "XmNlargeCellWidth"},
    {tkn_k_class_argument, sym_k_XmNlargeIconMask_arg, 16, ARGUMENT_NAME, "XmNlargeIconMask"},
    {tkn_k_class_argument, sym_k_XmNlargeIconPixmap_arg, 18, ARGUMENT_NAME, "XmNlargeIconPixmap"},
    {tkn_k_class_argument, sym_k_XmNlargeIconX_arg, 13, ARGUMENT_NAME, "XmNlargeIconX"},
    {tkn_k_class_argument, sym_k_XmNlargeIconY_arg, 13, ARGUMENT_NAME, "XmNlargeIconY"},
    {tkn_k_class_argument, sym_k_XmNlastPageNumber_arg, 17, ARGUMENT_NAME, "XmNlastPageNumber"},
    {tkn_k_class_argument, sym_k_XmNlayoutDirection_arg, 18, ARGUMENT_NAME, "XmNlayoutDirection"},
    {tkn_k_class_argument, sym_k_XmNlayoutType_arg, 13, ARGUMENT_NAME, "XmNlayoutType"},
    {tkn_k_class_argument, sym_k_XmNleftAttachment_arg, 17, ARGUMENT_NAME, "XmNleftAttachment"},
    {tkn_k_class_argument, sym_k_XmNleftOffset_arg, 13, ARGUMENT_NAME, "XmNleftOffset"},
    {tkn_k_class_argument, sym_k_XmNleftPosition_arg, 15, ARGUMENT_NAME, "XmNleftPosition"},
    {tkn_k_class_argument, sym_k_XmNleftWidget_arg, 13, ARGUMENT_NAME, "XmNleftWidget"},
    {tkn_k_class_argument, sym_k_XmNlightThreshold_arg, 17, ARGUMENT_NAME, "XmNlightThreshold"},
    {tkn_k_class_argument, sym_k_XmNlineBackgroundColor_arg, 22, ARGUMENT_NAME, "XmNlineBackgroundColor"},
    {tkn_k_class_argument, sym_k_XmNlineColor_arg, 12, ARGUMENT_NAME, "XmNlineColor"},
    {tkn_k_class_argument, sym_k_XmNlineStyle_arg, 12, ARGUMENT_NAME, "XmNlineStyle"},
    {tkn_k_class_argument, sym_k_XmNlineWidth_arg, 12, ARGUMENT_NAME, "XmNlineWidth"},
    {tkn_k_class_argument, sym_k_XmNlist_arg, 7, ARGUMENT_NAME, "XmNlist"},
    {tkn_k_class_argument, sym_k_XmNlistItemCount_arg, 16, ARGUMENT_NAME, "XmNlistItemCount"},
    {tkn_k_class_argument, sym_k_XmNlistItems_arg, 12, ARGUMENT_NAME, "XmNlistItems"},
    {tkn_k_class_argument, sym_k_XmNlistLabelString_arg, 18, ARGUMENT_NAME, "XmNlistLabelString"},
    {tkn_k_class_argument, sym_k_XmNlistMarginHeight_arg, 19, ARGUMENT_NAME, "XmNlistMarginHeight"},
    {tkn_k_class_argument, sym_k_XmNlistMarginWidth_arg, 18, ARGUMENT_NAME, "XmNlistMarginWidth"},
    {tkn_k_class_argument, sym_k_XmNlistSizePolicy_arg, 17, ARGUMENT_NAME, "XmNlistSizePolicy"},
    {tkn_k_class_argument, sym_k_XmNlistSpacing_arg, 14, ARGUMENT_NAME, "XmNlistSpacing"},
    {tkn_k_class_argument, sym_k_XmNlistUpdated_arg, 14, ARGUMENT_NAME, "XmNlistUpdated"},
    {tkn_k_class_argument, sym_k_XmNlistVisibleItemCount_arg, 23, ARGUMENT_NAME, "XmNlistVisibleItemCount"},
    {tkn_k_class_argument, sym_k_XmNloadModel_arg, 12, ARGUMENT_NAME, "XmNloadModel"},
    {tkn_k_class_reason, sym_k_XmNlosePrimaryCallback_reason, 22, REASON_NAME, "XmNlosePrimaryCallback"},
    {tkn_k_class_reason, sym_k_XmNlosingFocusCallback_reason, 22, REASON_NAME, "XmNlosingFocusCallback"},
    {tkn_k_class_argument, sym_k_XmNmainWindowMarginHeight_arg, 25, ARGUMENT_NAME, "XmNmainWindowMarginHeight"},
    {tkn_k_class_argument, sym_k_XmNmainWindowMarginWidth_arg, 24, ARGUMENT_NAME, "XmNmainWindowMarginWidth"},
    {tkn_k_class_argument, sym_k_XmNmajorTabSpacing_arg, 18, ARGUMENT_NAME, "XmNmajorTabSpacing"},
    {tkn_k_class_reason, sym_k_XmNmapCallback_reason, 14, REASON_NAME, "XmNmapCallback"},
    {tkn_k_class_argument, sym_k_XmNmappedWhenManaged_arg, 20, ARGUMENT_NAME, "XmNmappedWhenManaged"},
    {tkn_k_class_argument, sym_k_XmNmappingDelay_arg, 15, ARGUMENT_NAME, "XmNmappingDelay"},
    {tkn_k_class_argument, sym_k_XmNmargin_arg, 9, ARGUMENT_NAME, "XmNmargin"},
    {tkn_k_class_argument, sym_k_XmNmarginBottom_arg, 15, ARGUMENT_NAME, "XmNmarginBottom"},
    {tkn_k_class_argument, sym_k_XmNmarginHeight_arg, 15, ARGUMENT_NAME, "XmNmarginHeight"},
    {tkn_k_class_argument, sym_k_XmNmarginLeft_arg, 13, ARGUMENT_NAME, "XmNmarginLeft"},
    {tkn_k_class_argument, sym_k_XmNmarginRight_arg, 14, ARGUMENT_NAME, "XmNmarginRight"},
    {tkn_k_class_argument, sym_k_XmNmarginTop_arg, 12, ARGUMENT_NAME, "XmNmarginTop"},
    {tkn_k_class_argument, sym_k_XmNmarginWidth_arg, 14, ARGUMENT_NAME, "XmNmarginWidth"},
    {tkn_k_class_argument, sym_k_XmNmatchBehavior_arg, 16, ARGUMENT_NAME, "XmNmatchBehavior"},
    {tkn_k_class_argument, sym_k_XmNmaxAspectX_arg, 13, ARGUMENT_NAME, "XmNmaxAspectX"},
    {tkn_k_class_argument, sym_k_XmNmaxAspectY_arg, 13, ARGUMENT_NAME, "XmNmaxAspectY"},
    {tkn_k_class_argument, sym_k_XmNmaxHeight_arg, 12, ARGUMENT_NAME, "XmNmaxHeight"},
    {tkn_k_class_argument, sym_k_XmNmaxLength_arg, 12, ARGUMENT_NAME, "XmNmaxLength"},
    {tkn_k_class_argument, sym_k_XmNmaxWidth_arg, 11, ARGUMENT_NAME, "XmNmaxWidth"},
    {tkn_k_class_argument, sym_k_XmNmaximum_arg, 10, ARGUMENT_NAME, "XmNmaximum"},
    {tkn_k_class_argument, sym_k_XmNmaximumValue_arg, 15, ARGUMENT_NAME, "XmNmaximumValue"},
    {tkn_k_class_argument, sym_k_XmNmenuAccelerator_arg, 18, ARGUMENT_NAME, "XmNmenuAccelerator"},
    {tkn_k_class_argument, sym_k_XmNmenuBar_arg, 10, ARGUMENT_NAME, "XmNmenuBar"},
    {tkn_k_class_argument, sym_k_XmNmenuHelpWidget_arg, 17, ARGUMENT_NAME, "XmNmenuHelpWidget"},
    {tkn_k_class_argument, sym_k_XmNmenuHistory_arg, 14, ARGUMENT_NAME, "XmNmenuHistory"},
    {tkn_k_class_argument, sym_k_XmNmenuPost_arg, 11, ARGUMENT_NAME, "XmNmenuPost"},
    {tkn_k_class_argument, sym_k_XmNmessageAlignment_arg, 19, ARGUMENT_NAME, "XmNmessageAlignment"},
    {tkn_k_class_argument, sym_k_XmNmessageString_arg, 16, ARGUMENT_NAME, "XmNmessageString"},
    {tkn_k_class_argument, sym_k_XmNmessageWindow_arg, 16, ARGUMENT_NAME, "XmNmessageWindow"},
    {tkn_k_class_argument, sym_k_XmNminAspectX_arg, 13, ARGUMENT_NAME, "XmNminAspectX"},
    {tkn_k_class_argument, sym_k_XmNminAspectY_arg, 13, ARGUMENT_NAME, "XmNminAspectY"},
    {tkn_k_class_argument, sym_k_XmNminHeight_arg, 12, ARGUMENT_NAME, "XmNminHeight"},
    {tkn_k_class_argument, sym_k_XmNminWidth_arg, 11, ARGUMENT_NAME, "XmNminWidth"},
    {tkn_k_class_argument, sym_k_XmNminimizeButtons_arg, 18, ARGUMENT_NAME, "XmNminimizeButtons"},
    {tkn_k_class_argument, sym_k_XmNminimum_arg, 10, ARGUMENT_NAME, "XmNminimum"},
    {tkn_k_class_argument, sym_k_XmNminimumCellHeight_arg, 20, ARGUMENT_NAME, "XmNminimumCellHeight"},
    {tkn_k_class_argument, sym_k_XmNminimumCellWidth_arg, 19, ARGUMENT_NAME, "XmNminimumCellWidth"},
    {tkn_k_class_argument, sym_k_XmNminimumHorizontalCells_arg, 25, ARGUMENT_NAME, "XmNminimumHorizontalCells"},
    {tkn_k_class_argument, sym_k_XmNminimumValue_arg, 15, ARGUMENT_NAME, "XmNminimumValue"},
    {tkn_k_class_argument, sym_k_XmNminimumVerticalCells_arg, 23, ARGUMENT_NAME, "XmNminimumVerticalCells"},
    {tkn_k_class_argument, sym_k_XmNminorTabSpacing_arg, 18, ARGUMENT_NAME, "XmNminorTabSpacing"},
    {tkn_k_class_argument, sym_k_XmNmnemonic_arg, 11, ARGUMENT_NAME, "XmNmnemonic"},
    {tkn_k_class_argument, sym_k_XmNmnemonicCharSet_arg, 18, ARGUMENT_NAME, "XmNmnemonicCharSet"},
    {tkn_k_class_reason, sym_k_XmNmodifyVerifyCallback_reason, 23, REASON_NAME, "XmNmodifyVerifyCallback"},
    {tkn_k_class_reason, sym_k_XmNmodifyVerifyCallbackWcs_reason, 26, REASON_NAME, "XmNmodifyVerifyCallbackWcs"},
    {tkn_k_class_argument, sym_k_XmNmonoSpaceString_arg, 18, ARGUMENT_NAME, "XmNmonoSpaceString"},
    {tkn_k_class_reason, sym_k_XmNmotionVerifyCallback_reason, 23, REASON_NAME, "XmNmotionVerifyCallback"},
    {tkn_k_class_argument, sym_k_XmNmultiClick_arg, 13, ARGUMENT_NAME, "XmNmultiClick"},
    {tkn_k_class_reason, sym_k_XmNmultipleSelectionCallback_reason, 28, REASON_NAME, "XmNmultipleSelectionCallback"},
    {tkn_k_class_argument, sym_k_XmNmustMatch_arg, 12, ARGUMENT_NAME, "XmNmustMatch"},
    {tkn_k_class_argument, sym_k_XmNmwmDecorations_arg, 17, ARGUMENT_NAME, "XmNmwmDecorations"},
    {tkn_k_class_argument, sym_k_XmNmwmFunctions_arg, 15, ARGUMENT_NAME, "XmNmwmFunctions"},
    {tkn_k_class_argument, sym_k_XmNmwmInputMode_arg, 15, ARGUMENT_NAME, "XmNmwmInputMode"},
    {tkn_k_class_argument, sym_k_XmNmwmMenu_arg, 10, ARGUMENT_NAME, "XmNmwmMenu"},
    {tkn_k_class_argument, sym_k_XmNnavigationType_arg, 17, ARGUMENT_NAME, "XmNnavigationType"},
    {tkn_k_class_argument, sym_k_XmNnewVisualStyle_arg, 17, ARGUMENT_NAME, "XmNnewVisualStyle"},
    {tkn_k_class_argument, sym_k_XmNnoCellError_arg, 14, ARGUMENT_NAME, "XmNnoCellError"},
    {tkn_k_class_reason, sym_k_XmNnoMatchCallback_reason, 18, REASON_NAME, "XmNnoMatchCallback"},
    {tkn_k_class_argument, sym_k_XmNnoMatchString_arg, 16, ARGUMENT_NAME, "XmNnoMatchString"},
    {tkn_k_class_argument, sym_k_XmNnoResize_arg, 11, ARGUMENT_NAME, "XmNnoResize"},
    {tkn_k_class_argument, sym_k_XmNnodeCloseFolderPixmap_arg, 24, ARGUMENT_NAME, "XmNnodeCloseFolderPixmap"},
    {tkn_k_class_argument, sym_k_XmNnodeOpenFolderPixmap_arg, 23, ARGUMENT_NAME, "XmNnodeOpenFolderPixmap"},
    {tkn_k_class_argument, sym_k_XmNnodeState_arg, 12, ARGUMENT_NAME, "XmNnodeState"},
    {tkn_k_class_reason, sym_k_XmNnodeStateBegEndCallback_reason, 26, REASON_NAME, "XmNnodeStateBegEndCallback"},
    {tkn_k_class_reason, sym_k_XmNnodeStateCallback_reason, 20, REASON_NAME, "XmNnodeStateCallback"},
    {tkn_k_class_reason, sym_k_XmNnodeStateChangedCallback_reason, 27, REASON_NAME, "XmNnodeStateChangedCallback"},
    {tkn_k_class_argument, sym_k_XmNnotebookChildType_arg, 20, ARGUMENT_NAME, "XmNnotebookChildType"},
    {tkn_k_class_argument, sym_k_XmNnumColumns_arg, 13, ARGUMENT_NAME, "XmNnumColumns"},
    {tkn_k_class_argument, sym_k_XmNnumRows_arg, 10, ARGUMENT_NAME, "XmNnumRows"},
    {tkn_k_class_argument, sym_k_XmNnumStacks_arg, 12, ARGUMENT_NAME, "XmNnumStacks"},
    {tkn_k_class_argument, sym_k_XmNnumValues_arg, 12, ARGUMENT_NAME, "XmNnumValues"},
    {tkn_k_class_argument, sym_k_XmNoffsetModel_arg, 14, ARGUMENT_NAME, "XmNoffsetModel"},
    {tkn_k_class_reason, sym_k_XmNokCallback_reason, 13, REASON_NAME, "XmNokCallback"},
    {tkn_k_class_argument, sym_k_XmNokLabelString_arg, 16, ARGUMENT_NAME, "XmNokLabelString"},
    {tkn_k_class_argument, sym_k_XmNopenClosePadding_arg, 19, ARGUMENT_NAME, "XmNopenClosePadding"},
    {tkn_k_class_argument, sym_k_XmNopenFolderPixmap_arg, 19, ARGUMENT_NAME, "XmNopenFolderPixmap"},
    {tkn_k_class_argument, sym_k_XmNoptionString_arg, 15, ARGUMENT_NAME, "XmNoptionString"},
    {tkn_k_class_argument, sym_k_XmNorientation_arg, 14, ARGUMENT_NAME, "XmNorientation"},
    {tkn_k_class_class, sym_k_XmNotebook_object, 10, CLASS_NAME, "XmNotebook"},
    {tkn_k_class_argument, sym_k_XmNotherString_arg, 14, ARGUMENT_NAME, "XmNotherString"},
    {tkn_k_class_argument, sym_k_XmNoutlineButtonPolicy_arg, 22, ARGUMENT_NAME, "XmNoutlineButtonPolicy"},
    {tkn_k_class_reason, sym_k_XmNoutlineChangedCallback_reason, 25, REASON_NAME, "XmNoutlineChangedCallback"},
    {tkn_k_class_argument, sym_k_XmNoutlineColumnWidth_arg, 21, ARGUMENT_NAME, "XmNoutlineColumnWidth"},
    {tkn_k_class_argument, sym_k_XmNoutlineIndentation_arg, 21, ARGUMENT_NAME, "XmNoutlineIndentation"},
    {tkn_k_class_argument, sym_k_XmNoutlineLineStyle_arg, 19, ARGUMENT_NAME, "XmNoutlineLineStyle"},
    {tkn_k_class_argument, sym_k_XmNoutlineState_arg, 15, ARGUMENT_NAME, "XmNoutlineState"},
    {tkn_k_class_argument, sym_k_XmNoverrideRedirect_arg, 19, ARGUMENT_NAME, "XmNoverrideRedirect"},
    {tkn_k_class_argument, sym_k_XmNpacking_arg, 10, ARGUMENT_NAME, "XmNpacking"},
    {tkn_k_class_reason, sym_k_XmNpageChangedCallback_reason, 22, REASON_NAME, "XmNpageChangedCallback"},
    {tkn_k_class_reason, sym_k_XmNpageDecrementCallback_reason, 24, REASON_NAME, "XmNpageDecrementCallback"},
    {tkn_k_class_argument, sym_k_XmNpageIncrement_arg, 16, ARGUMENT_NAME, "XmNpageIncrement"},
    {tkn_k_class_reason, sym_k_XmNpageIncrementCallback_reason, 24, REASON_NAME, "XmNpageIncrementCallback"},
    {tkn_k_class_argument, sym_k_XmNpageNumber_arg, 13, ARGUMENT_NAME, "XmNpageNumber"},
    {tkn_k_class_argument, sym_k_XmNpaneMaximum_arg, 14, ARGUMENT_NAME, "XmNpaneMaximum"},
    {tkn_k_class_argument, sym_k_XmNpaneMinimum_arg, 14, ARGUMENT_NAME, "XmNpaneMinimum"},
    {tkn_k_class_argument, sym_k_XmNparentNode_arg, 13, ARGUMENT_NAME, "XmNparentNode"},
    {tkn_k_class_argument, sym_k_XmNpattern_arg, 10, ARGUMENT_NAME, "XmNpattern"},
    {tkn_k_class_argument, sym_k_XmNpendingDelete_arg, 16, ARGUMENT_NAME, "XmNpendingDelete"},
    {tkn_k_class_argument, sym_k_XmNpicture_arg, 10, ARGUMENT_NAME, "XmNpicture"},
    {tkn_k_class_reason, sym_k_XmNpictureErrorCallback_reason, 23, REASON_NAME, "XmNpictureErrorCallback"},
    {tkn_k_class_argument, sym_k_XmNpixmap_arg, 9, ARGUMENT_NAME, "XmNpixmap"},
    {tkn_k_class_argument, sym_k_XmNpixmapDepth_arg, 14, ARGUMENT_NAME, "XmNpixmapDepth"},
    {tkn_k_class_argument, sym_k_XmNpixmapHeight_arg, 15, ARGUMENT_NAME, "XmNpixmapHeight"},
    {tkn_k_class_argument, sym_k_XmNpixmapPlacement_arg, 18, ARGUMENT_NAME, "XmNpixmapPlacement"},
    {tkn_k_class_argument, sym_k_XmNpixmapTextPadding_arg, 20, ARGUMENT_NAME, "XmNpixmapTextPadding"},
    {tkn_k_class_argument, sym_k_XmNpixmapWidth_arg, 14, ARGUMENT_NAME, "XmNpixmapWidth"},
    {tkn_k_class_reason, sym_k_XmNpopdownCallback_reason, 18, REASON_NAME, "XmNpopdownCallback"},
    {tkn_k_class_reason, sym_k_XmNpopupCallback_reason, 16, REASON_NAME, "XmNpopupCallback"},
    {tkn_k_class_argument, sym_k_XmNpopupCursor_arg, 14, ARGUMENT_NAME, "XmNpopupCursor"},
    {tkn_k_class_argument, sym_k_XmNpopupEnabled_arg, 15, ARGUMENT_NAME, "XmNpopupEnabled"},
    {tkn_k_class_reason, sym_k_XmNpopupHandlerCallback_reason, 23, REASON_NAME, "XmNpopupHandlerCallback"},
    {tkn_k_class_argument, sym_k_XmNpopupOffset_arg, 14, ARGUMENT_NAME, "XmNpopupOffset"},
    {tkn_k_class_argument, sym_k_XmNpopupShellWidget_arg, 19, ARGUMENT_NAME, "XmNpopupShellWidget"},
    {tkn_k_class_argument, sym_k_XmNposition_arg, 11, ARGUMENT_NAME, "XmNposition"},
    {tkn_k_class_argument, sym_k_XmNpositionIndex_arg, 16, ARGUMENT_NAME, "XmNpositionIndex"},
    {tkn_k_class_argument, sym_k_XmNpositionMode_arg, 15, ARGUMENT_NAME, "XmNpositionMode"},
    {tkn_k_class_argument, sym_k_XmNpositionType_arg, 15, ARGUMENT_NAME, "XmNpositionType"},
    {tkn_k_class_argument, sym_k_XmNpreeditType_arg, 14, ARGUMENT_NAME, "XmNpreeditType"},
    {tkn_k_class_argument, sym_k_XmNpreferredPaneSize_arg, 20, ARGUMENT_NAME, "XmNpreferredPaneSize"},
    {tkn_k_class_argument, sym_k_XmNprimaryOwnership_arg, 19, ARGUMENT_NAME, "XmNprimaryOwnership"},
    {tkn_k_class_argument, sym_k_XmNprocessingDirection_arg, 22, ARGUMENT_NAME, "XmNprocessingDirection"},
    {tkn_k_class_argument, sym_k_XmNpromptString_arg, 15, ARGUMENT_NAME, "XmNpromptString"},
    {tkn_k_class_argument, sym_k_XmNpropSpaceString_arg, 18, ARGUMENT_NAME, "XmNpropSpaceString"},
    {tkn_k_class_argument, sym_k_XmNpushButtonEnabled_arg, 20, ARGUMENT_NAME, "XmNpushButtonEnabled"},
    {tkn_k_class_argument, sym_k_XmNqualifySearchDataProc_arg, 24, ARGUMENT_NAME, "XmNqualifySearchDataProc"},
    {tkn_k_class_argument, sym_k_XmNradioAlwaysOne_arg, 17, ARGUMENT_NAME, "XmNradioAlwaysOne"},
    {tkn_k_class_argument, sym_k_XmNradioBehavior_arg, 16, ARGUMENT_NAME, "XmNradioBehavior"},
    {tkn_k_class_reason, sym_k_XmNrealizeCallback_reason, 18, REASON_NAME, "XmNrealizeCallback"},
    {tkn_k_class_argument, sym_k_XmNrecomputeSize_arg, 16, ARGUMENT_NAME, "XmNrecomputeSize"},
    {tkn_k_class_argument, sym_k_XmNredSliderLabel_arg, 17, ARGUMENT_NAME, "XmNredSliderLabel"},
    {tkn_k_class_argument, sym_k_XmNrefigureMode_arg, 15, ARGUMENT_NAME, "XmNrefigureMode"},
    {tkn_k_class_argument, sym_k_XmNrenderTable_arg, 14, ARGUMENT_NAME, "XmNrenderTable"},
    {tkn_k_class_argument, sym_k_XmNrenditionBackground_arg, 22, ARGUMENT_NAME, "XmNrenditionBackground"},
    {tkn_k_class_argument, sym_k_XmNrenditionForeground_arg, 22, ARGUMENT_NAME, "XmNrenditionForeground"},
    {tkn_k_class_argument, sym_k_XmNrepeatDelay_arg, 14, ARGUMENT_NAME, "XmNrepeatDelay"},
    {tkn_k_class_argument, sym_k_XmNresizable_arg, 12, ARGUMENT_NAME, "XmNresizable"},
    {tkn_k_class_reason, sym_k_XmNresizeCallback_reason, 17, REASON_NAME, "XmNresizeCallback"},
    {tkn_k_class_argument, sym_k_XmNresizeHeight_arg, 15, ARGUMENT_NAME, "XmNresizeHeight"},
    {tkn_k_class_argument, sym_k_XmNresizePolicy_arg, 15, ARGUMENT_NAME, "XmNresizePolicy"},
    {tkn_k_class_argument, sym_k_XmNresizeToPreferred_arg, 20, ARGUMENT_NAME, "XmNresizeToPreferred"},
    {tkn_k_class_argument, sym_k_XmNresizeWidth_arg, 14, ARGUMENT_NAME, "XmNresizeWidth"},
    {tkn_k_class_argument, sym_k_XmNrgbFile_arg, 10, ARGUMENT_NAME, "XmNrgbFile"},
    {tkn_k_class_argument, sym_k_XmNrightAttachment_arg, 18, ARGUMENT_NAME, "XmNrightAttachment"},
    {tkn_k_class_argument, sym_k_XmNrightOffset_arg, 14, ARGUMENT_NAME, "XmNrightOffset"},
    {tkn_k_class_argument, sym_k_XmNrightPosition_arg, 16, ARGUMENT_NAME, "XmNrightPosition"},
    {tkn_k_class_argument, sym_k_XmNrightWidget_arg, 14, ARGUMENT_NAME, "XmNrightWidget"},
    {tkn_k_class_argument, sym_k_XmNrowColumnType_arg, 16, ARGUMENT_NAME, "XmNrowColumnType"},
    {tkn_k_class_argument, sym_k_XmNrows_arg, 7, ARGUMENT_NAME, "XmNrows"},
    {tkn_k_class_argument, sym_k_XmNrubberPositioning_arg, 20, ARGUMENT_NAME, "XmNrubberPositioning"},
    {tkn_k_class_argument, sym_k_XmNsampleText_arg, 13, ARGUMENT_NAME, "XmNsampleText"},
    {tkn_k_class_argument, sym_k_XmNsashHeight_arg, 13, ARGUMENT_NAME, "XmNsashHeight"},
    {tkn_k_class_argument, sym_k_XmNsashIndent_arg, 13, ARGUMENT_NAME, "XmNsashIndent"},
    {tkn_k_class_argument, sym_k_XmNsashShadowThickness_arg, 22, ARGUMENT_NAME, "XmNsashShadowThickness"},
    {tkn_k_class_argument, sym_k_XmNsashTranslations_arg, 19, ARGUMENT_NAME, "XmNsashTranslations"},
    {tkn_k_class_argument, sym_k_XmNsashWidth_arg, 12, ARGUMENT_NAME, "XmNsashWidth"},
    {tkn_k_class_argument, sym_k_XmNsaveUnder_arg, 12, ARGUMENT_NAME, "XmNsaveUnder"},
    {tkn_k_class_argument, sym_k_XmNscaleHeight_arg, 14, ARGUMENT_NAME, "XmNscaleHeight"},
    {tkn_k_class_argument, sym_k_XmNscaleMultiple_arg, 16, ARGUMENT_NAME, "XmNscaleMultiple"},
    {tkn_k_class_argument, sym_k_XmNscaleWidth_arg, 13, ARGUMENT_NAME, "XmNscaleWidth"},
    {tkn_k_class_argument, sym_k_XmNscalingString_arg, 16, ARGUMENT_NAME, "XmNscalingString"},
    {tkn_k_class_argument, sym_k_XmNscreen_arg, 9, ARGUMENT_NAME, "XmNscreen"},
    {tkn_k_class_argument, sym_k_XmNscrollBarDisplayPolicy_arg, 25, ARGUMENT_NAME, "XmNscrollBarDisplayPolicy"},
    {tkn_k_class_argument, sym_k_XmNscrollBarPlacement_arg, 21, ARGUMENT_NAME, "XmNscrollBarPlacement"},
    {tkn_k_class_argument, sym_k_XmNscrollHorizontal_arg, 19, ARGUMENT_NAME, "XmNscrollHorizontal"},
    {tkn_k_class_argument, sym_k_XmNscrollLeftSide_arg, 17, ARGUMENT_NAME, "XmNscrollLeftSide"},
    {tkn_k_class_argument, sym_k_XmNscrollTopSide_arg, 16, ARGUMENT_NAME, "XmNscrollTopSide"},
    {tkn_k_class_argument, sym_k_XmNscrollVertical_arg, 17, ARGUMENT_NAME, "XmNscrollVertical"},
    {tkn_k_class_argument, sym_k_XmNscrolledWindowChildType_arg, 26, ARGUMENT_NAME, "XmNscrolledWindowChildType"},
    {tkn_k_class_argument, sym_k_XmNscrolledWindowMarginHeight_arg, 29, ARGUMENT_NAME, "XmNscrolledWindowMarginHeight"},
    {tkn_k_class_argument, sym_k_XmNscrolledWindowMarginWidth_arg, 28, ARGUMENT_NAME, "XmNscrolledWindowMarginWidth"},
    {tkn_k_class_argument, sym_k_XmNscrollingPolicy_arg, 18, ARGUMENT_NAME, "XmNscrollingPolicy"},
    {tkn_k_class_reason, sym_k_XmNselectCallback_reason, 17, REASON_NAME, "XmNselectCallback"},
    {tkn_k_class_argument, sym_k_XmNselectColor_arg, 14, ARGUMENT_NAME, "XmNselectColor"},
    {tkn_k_class_argument, sym_k_XmNselectInsensitivePixmap_arg, 26, ARGUMENT_NAME, "XmNselectInsensitivePixmap"},
    {tkn_k_class_argument, sym_k_XmNselectPixmap_arg, 15, ARGUMENT_NAME, "XmNselectPixmap"},
    {tkn_k_class_argument, sym_k_XmNselectThreshold_arg, 18, ARGUMENT_NAME, "XmNselectThreshold"},
    {tkn_k_class_argument, sym_k_XmNselectedColumn_arg, 17, ARGUMENT_NAME, "XmNselectedColumn"},
    {tkn_k_class_argument, sym_k_XmNselectedItem_arg, 15, ARGUMENT_NAME, "XmNselectedItem"},
    {tkn_k_class_argument, sym_k_XmNselectedItemCount_arg, 20, ARGUMENT_NAME, "XmNselectedItemCount"},
    {tkn_k_class_argument, sym_k_XmNselectedItems_arg, 16, ARGUMENT_NAME, "XmNselectedItems"},
    {tkn_k_class_argument, sym_k_XmNselectedPosition_arg, 19, ARGUMENT_NAME, "XmNselectedPosition"},
    {tkn_k_class_argument, sym_k_XmNselectedPositionCount_arg, 24, ARGUMENT_NAME, "XmNselectedPositionCount"},
    {tkn_k_class_argument, sym_k_XmNselectedPositions_arg, 20, ARGUMENT_NAME, "XmNselectedPositions"},
    {tkn_k_class_argument, sym_k_XmNselectionArray_arg, 17, ARGUMENT_NAME, "XmNselectionArray"},
    {tkn_k_class_argument, sym_k_XmNselectionArrayCount_arg, 22, ARGUMENT_NAME, "XmNselectionArrayCount"},
    {tkn_k_class_reason, sym_k_XmNselectionCallback_reason, 20, REASON_NAME, "XmNselectionCallback"},
    {tkn_k_class_argument, sym_k_XmNselectionLabelString_arg, 23, ARGUMENT_NAME, "XmNselectionLabelString"},
    {tkn_k_class_argument, sym_k_XmNselectionMode_arg, 16, ARGUMENT_NAME, "XmNselectionMode"},
    {tkn_k_class_argument, sym_k_XmNselectionPolicy_arg, 18, ARGUMENT_NAME, "XmNselectionPolicy"},
    {tkn_k_class_argument, sym_k_XmNselectionTechnique_arg, 21, ARGUMENT_NAME, "XmNselectionTechnique"},
    {tkn_k_class_argument, sym_k_XmNsensitive_arg, 12, ARGUMENT_NAME, "XmNsensitive"},
    {tkn_k_class_argument, sym_k_XmNseparatorOn_arg, 14, ARGUMENT_NAME, "XmNseparatorOn"},
    {tkn_k_class_argument, sym_k_XmNseparatorType_arg, 16, ARGUMENT_NAME, "XmNseparatorType"},
    {tkn_k_class_argument, sym_k_XmNset_arg, 6, ARGUMENT_NAME, "XmNset"},
    {tkn_k_class_argument, sym_k_XmNshadowThickness_arg, 18, ARGUMENT_NAME, "XmNshadowThickness"},
    {tkn_k_class_argument, sym_k_XmNshadowType_arg, 13, ARGUMENT_NAME, "XmNshadowType"},
    {tkn_k_class_argument, sym_k_XmNshellUnitType_arg, 16, ARGUMENT_NAME, "XmNshellUnitType"},
    {tkn_k_class_argument, sym_k_XmNshowArrows_arg, 13, ARGUMENT_NAME, "XmNshowArrows"},
    {tkn_k_class_argument, sym_k_XmNshowAsDefault_arg, 16, ARGUMENT_NAME, "XmNshowAsDefault"},
    {tkn_k_class_argument, sym_k_XmNshowEntryLabel_arg, 17, ARGUMENT_NAME, "XmNshowEntryLabel"},
    {tkn_k_class_argument, sym_k_XmNshowFind_arg, 11, ARGUMENT_NAME, "XmNshowFind"},
    {tkn_k_class_argument, sym_k_XmNshowFontName_arg, 15, ARGUMENT_NAME, "XmNshowFontName"},
    {tkn_k_class_argument, sym_k_XmNshowLabel_arg, 12, ARGUMENT_NAME, "XmNshowLabel"},
    {tkn_k_class_argument, sym_k_XmNshowNameString_arg, 17, ARGUMENT_NAME, "XmNshowNameString"},
    {tkn_k_class_argument, sym_k_XmNshowSash_arg, 11, ARGUMENT_NAME, "XmNshowSash"},
    {tkn_k_class_argument, sym_k_XmNshowSeparator_arg, 16, ARGUMENT_NAME, "XmNshowSeparator"},
    {tkn_k_class_argument, sym_k_XmNshowValue_arg, 12, ARGUMENT_NAME, "XmNshowValue"},
    {tkn_k_class_reason, sym_k_XmNsimpleCallback_reason, 17, REASON_NAME, "XmNsimpleCallback"},
    {tkn_k_class_reason, sym_k_XmNsingleSelectionCallback_reason, 26, REASON_NAME, "XmNsingleSelectionCallback"},
    {tkn_k_class_argument, sym_k_XmNsizeString_arg, 13, ARGUMENT_NAME, "XmNsizeString"},
    {tkn_k_class_argument, sym_k_XmNskipAdjust_arg, 13, ARGUMENT_NAME, "XmNskipAdjust"},
    {tkn_k_class_argument, sym_k_XmNsliderMark_arg, 13, ARGUMENT_NAME, "XmNsliderMark"},
    {tkn_k_class_argument, sym_k_XmNsliderSize_arg, 13, ARGUMENT_NAME, "XmNsliderSize"},
    {tkn_k_class_argument, sym_k_XmNsliderTogLabel_arg, 17, ARGUMENT_NAME, "XmNsliderTogLabel"},
    {tkn_k_class_argument, sym_k_XmNsliderVisual_arg, 15, ARGUMENT_NAME, "XmNsliderVisual"},
    {tkn_k_class_argument, sym_k_XmNslidingMode_arg, 14, ARGUMENT_NAME, "XmNslidingMode"},
    {tkn_k_class_argument, sym_k_XmNsmallCellHeight_arg, 18, ARGUMENT_NAME, "XmNsmallCellHeight"},
    {tkn_k_class_argument, sym_k_XmNsmallCellWidth_arg, 17, ARGUMENT_NAME, "XmNsmallCellWidth"},
    {tkn_k_class_argument, sym_k_XmNsmallIconMask_arg, 16, ARGUMENT_NAME, "XmNsmallIconMask"},
    {tkn_k_class_argument, sym_k_XmNsmallIconPixmap_arg, 18, ARGUMENT_NAME, "XmNsmallIconPixmap"},
    {tkn_k_class_argument, sym_k_XmNsmallIconX_arg, 13, ARGUMENT_NAME, "XmNsmallIconX"},
    {tkn_k_class_argument, sym_k_XmNsmallIconY_arg, 13, ARGUMENT_NAME, "XmNsmallIconY"},
    {tkn_k_class_argument, sym_k_XmNsnapBackMultiple_arg, 19, ARGUMENT_NAME, "XmNsnapBackMultiple"},
    {tkn_k_class_argument, sym_k_XmNsortFunctions_arg, 16, ARGUMENT_NAME, "XmNsortFunctions"},
    {tkn_k_class_argument, sym_k_XmNsource_arg, 9, ARGUMENT_NAME, "XmNsource"},
    {tkn_k_class_argument, sym_k_XmNspacing_arg, 10, ARGUMENT_NAME, "XmNspacing"},
    {tkn_k_class_argument, sym_k_XmNspatialIncludeModel_arg, 22, ARGUMENT_NAME, "XmNspatialIncludeModel"},
    {tkn_k_class_argument, sym_k_XmNspatialResizeModel_arg, 21, ARGUMENT_NAME, "XmNspatialResizeModel"},
    {tkn_k_class_argument, sym_k_XmNspatialSnapModel_arg, 19, ARGUMENT_NAME, "XmNspatialSnapModel"},
    {tkn_k_class_argument, sym_k_XmNspatialStyle_arg, 15, ARGUMENT_NAME, "XmNspatialStyle"},
    {tkn_k_class_argument, sym_k_XmNspinBoxChildType_arg, 19, ARGUMENT_NAME, "XmNspinBoxChildType"},
    {tkn_k_class_argument, sym_k_XmNstackedEffect_arg, 16, ARGUMENT_NAME, "XmNstackedEffect"},
    {tkn_k_class_argument, sym_k_XmNstretchable_arg, 14, ARGUMENT_NAME, "XmNstretchable"},
    {tkn_k_class_argument, sym_k_XmNstrikethruType_arg, 17, ARGUMENT_NAME, "XmNstrikethruType"},
    {tkn_k_class_argument, sym_k_XmNstringDirection_arg, 18, ARGUMENT_NAME, "XmNstringDirection"},
    {tkn_k_class_argument, sym_k_XmNsubMenuId_arg, 12, ARGUMENT_NAME, "XmNsubMenuId"},
    {tkn_k_class_argument, sym_k_XmNsymbolPixmap_arg, 15, ARGUMENT_NAME, "XmNsymbolPixmap"},
    {tkn_k_class_argument, sym_k_XmNtabAlignment_arg, 15, ARGUMENT_NAME, "XmNtabAlignment"},
    {tkn_k_class_argument, sym_k_XmNtabAutoSelect_arg, 16, ARGUMENT_NAME, "XmNtabAutoSelect"},
    {tkn_k_class_argument, sym_k_XmNtabBackground_arg, 16, ARGUMENT_NAME, "XmNtabBackground"},
    {tkn_k_class_argument, sym_k_XmNtabBackgroundPixmap_arg, 22, ARGUMENT_NAME, "XmNtabBackgroundPixmap"},
    {tkn_k_class_argument, sym_k_XmNtabCornerPercent_arg, 19, ARGUMENT_NAME, "XmNtabCornerPercent"},
    {tkn_k_class_argument, sym_k_XmNtabEdge_arg, 10, ARGUMENT_NAME, "XmNtabEdge"},
    {tkn_k_class_argument, sym_k_XmNtabForeground_arg, 16, ARGUMENT_NAME, "XmNtabForeground"},
    {tkn_k_class_argument, sym_k_XmNtabLabelPixmap_arg, 17, ARGUMENT_NAME, "XmNtabLabelPixmap"},
    {tkn_k_class_argument, sym_k_XmNtabLabelSpacing_arg, 18, ARGUMENT_NAME, "XmNtabLabelSpacing"},
    {tkn_k_class_argument, sym_k_XmNtabLabelString_arg, 17, ARGUMENT_NAME, "XmNtabLabelString"},
    {tkn_k_class_argument, sym_k_XmNtabList_arg, 10, ARGUMENT_NAME, "XmNtabList"},
    {tkn_k_class_argument, sym_k_XmNtabMarginHeight_arg, 18, ARGUMENT_NAME, "XmNtabMarginHeight"},
    {tkn_k_class_argument, sym_k_XmNtabMarginWidth_arg, 17, ARGUMENT_NAME, "XmNtabMarginWidth"},
    {tkn_k_class_argument, sym_k_XmNtabMode_arg, 10, ARGUMENT_NAME, "XmNtabMode"},
    {tkn_k_class_argument, sym_k_XmNtabOffset_arg, 12, ARGUMENT_NAME, "XmNtabOffset"},
    {tkn_k_class_argument, sym_k_XmNtabOrientation_arg, 17, ARGUMENT_NAME, "XmNtabOrientation"},
    {tkn_k_class_argument, sym_k_XmNtabPixmapPlacement_arg, 21, ARGUMENT_NAME, "XmNtabPixmapPlacement"},
    {tkn_k_class_argument, sym_k_XmNtabSelectColor_arg, 17, ARGUMENT_NAME, "XmNtabSelectColor"},
    {tkn_k_class_argument, sym_k_XmNtabSelectPixmap_arg, 18, ARGUMENT_NAME, "XmNtabSelectPixmap"},
    {tkn_k_class_reason, sym_k_XmNtabSelectedCallback_reason, 22, REASON_NAME, "XmNtabSelectedCallback"},
    {tkn_k_class_argument, sym_k_XmNtabSide_arg, 10, ARGUMENT_NAME, "XmNtabSide"},
    {tkn_k_class_argument, sym_k_XmNtabStringDirection_arg, 21, ARGUMENT_NAME, "XmNtabStringDirection"},
    {tkn_k_class_argument, sym_k_XmNtabStyle_arg, 11, ARGUMENT_NAME, "XmNtabStyle"},
    {tkn_k_class_argument, sym_k_XmNtabValue_arg, 11, ARGUMENT_NAME, "XmNtabValue"},
    {tkn_k_class_reason, sym_k_XmNtearOffMenuActivateCallback_reason, 30, REASON_NAME, "XmNtearOffMenuActivateCallback"},
    {tkn_k_class_reason, sym_k_XmNtearOffMenuDeactivateCallback_reason, 32, REASON_NAME, "XmNtearOffMenuDeactivateCallback"},
    {tkn_k_class_argument, sym_k_XmNtearOffModel_arg, 15, ARGUMENT_NAME, "XmNtearOffModel"},
    {tkn_k_class_argument, sym_k_XmNtearOffTitle_arg, 15, ARGUMENT_NAME, "XmNtearOffTitle"},
    {tkn_k_class_argument, sym_k_XmNtextAccelerators_arg, 19, ARGUMENT_NAME, "XmNtextAccelerators"},
    {tkn_k_class_argument, sym_k_XmNtextColumns_arg, 14, ARGUMENT_NAME, "XmNtextColumns"},
    {tkn_k_class_argument, sym_k_XmNtextField_arg, 12, ARGUMENT_NAME, "XmNtextField"},
    {tkn_k_class_argument, sym_k_XmNtextFontList_arg, 15, ARGUMENT_NAME, "XmNtextFontList"},
    {tkn_k_class_argument, sym_k_XmNtextRenderTable_arg, 18, ARGUMENT_NAME, "XmNtextRenderTable"},
    {tkn_k_class_argument, sym_k_XmNtextRows_arg, 11, ARGUMENT_NAME, "XmNtextRows"},
    {tkn_k_class_argument, sym_k_XmNtextString_arg, 13, ARGUMENT_NAME, "XmNtextString"},
    {tkn_k_class_argument, sym_k_XmNtextTranslations_arg, 19, ARGUMENT_NAME, "XmNtextTranslations"},
    {tkn_k_class_argument, sym_k_XmNtitle_arg, 8, ARGUMENT_NAME, "XmNtitle"},
    {tkn_k_class_argument, sym_k_XmNtitleEncoding_arg, 16, ARGUMENT_NAME, "XmNtitleEncoding"},
    {tkn_k_class_argument, sym_k_XmNtitleString_arg, 14, ARGUMENT_NAME, "XmNtitleString"},
    {tkn_k_class_reason, sym_k_XmNtoBottomCallback_reason, 19, REASON_NAME, "XmNtoBottomCallback"},
    {tkn_k_class_reason, sym_k_XmNtoTopCallback_reason, 16, REASON_NAME, "XmNtoTopCallback"},
    {tkn_k_class_argument, sym_k_XmNtoggleMode_arg, 13, ARGUMENT_NAME, "XmNtoggleMode"},
    {tkn_k_class_argument, sym_k_XmNtoolTipEnable_arg, 16, ARGUMENT_NAME, "XmNtoolTipEnable"},
    {tkn_k_class_argument, sym_k_XmNtoolTipPostDelay_arg, 19, ARGUMENT_NAME, "XmNtoolTipPostDelay"},
    {tkn_k_class_argument, sym_k_XmNtoolTipPostDuration_arg, 22, ARGUMENT_NAME, "XmNtoolTipPostDuration"},
    {tkn_k_class_argument, sym_k_XmNtoolTipString_arg, 16, ARGUMENT_NAME, "XmNtoolTipString"},
    {tkn_k_class_argument, sym_k_XmNtopAttachment_arg, 16, ARGUMENT_NAME, "XmNtopAttachment"},
    {tkn_k_class_argument, sym_k_XmNtopCharacter_arg, 15, ARGUMENT_NAME, "XmNtopCharacter"},
    {tkn_k_class_argument, sym_k_XmNtopItemPosition_arg, 18, ARGUMENT_NAME, "XmNtopItemPosition"},
    {tkn_k_class_argument, sym_k_XmNtopOffset_arg, 12, ARGUMENT_NAME, "XmNtopOffset"},
    {tkn_k_class_argument, sym_k_XmNtopPosition_arg, 14, ARGUMENT_NAME, "XmNtopPosition"},
    {tkn_k_class_argument, sym_k_XmNtopShadowColor_arg, 17, ARGUMENT_NAME, "XmNtopShadowColor"},
    {tkn_k_class_argument, sym_k_XmNtopShadowPixmap_arg, 18, ARGUMENT_NAME, "XmNtopShadowPixmap"},
    {tkn_k_class_argument, sym_k_XmNtopWidget_arg, 12, ARGUMENT_NAME, "XmNtopWidget"},
    {tkn_k_class_argument, sym_k_XmNtransient_arg, 12, ARGUMENT_NAME, "XmNtransient"},
    {tkn_k_class_argument, sym_k_XmNtransientFor_arg, 15, ARGUMENT_NAME, "XmNtransientFor"},
    {tkn_k_class_argument, sym_k_XmNtranslations_arg, 15, ARGUMENT_NAME, "XmNtranslations"},
    {tkn_k_class_reason, sym_k_XmNtraversalCallback_reason, 20, REASON_NAME, "XmNtraversalCallback"},
    {tkn_k_class_argument, sym_k_XmNtraversalOn_arg, 14, ARGUMENT_NAME, "XmNtraversalOn"},
    {tkn_k_class_reason, sym_k_XmNtraverseObscuredCallback_reason, 27, REASON_NAME, "XmNtraverseObscuredCallback"},
    {tkn_k_class_argument, sym_k_XmNtroughColor_arg, 14, ARGUMENT_NAME, "XmNtroughColor"},
    {tkn_k_class_argument, sym_k_XmNunderlineType_arg, 16, ARGUMENT_NAME, "XmNunderlineType"},
    {tkn_k_class_argument, sym_k_XmNuniformTabSize_arg, 17, ARGUMENT_NAME, "XmNuniformTabSize"},
    {tkn_k_class_argument, sym_k_XmNunitType_arg, 11, ARGUMENT_NAME, "XmNunitType"},
    {tkn_k_class_reason, sym_k_XmNunmapCallback_reason, 16, REASON_NAME, "XmNunmapCallback"},
    {tkn_k_class_argument, sym_k_XmNunpostBehavior_arg, 17, ARGUMENT_NAME, "XmNunpostBehavior"},
    {tkn_k_class_reason, sym_k_XmNunselectCallback_reason, 19, REASON_NAME, "XmNunselectCallback"},
    {tkn_k_class_argument, sym_k_XmNunselectColor_arg, 16, ARGUMENT_NAME, "XmNunselectColor"},
    {tkn_k_class_reason, sym_k_XmNupdateShellCallback_reason, 22, REASON_NAME, "XmNupdateShellCallback"},
    {tkn_k_class_reason, sym_k_XmNupdateTextCallback_reason, 21, REASON_NAME, "XmNupdateTextCallback"},
    {tkn_k_class_argument, sym_k_XmNuseAsyncGeometry_arg, 19, ARGUMENT_NAME, "XmNuseAsyncGeometry"},
    {tkn_k_class_argument, sym_k_XmNuseImageCache_arg, 16, ARGUMENT_NAME, "XmNuseImageCache"},
    {tkn_k_class_argument, sym_k_XmNuseScaling_arg, 13, ARGUMENT_NAME, "XmNuseScaling"},
    {tkn_k_class_argument, sym_k_XmNuseTextField_arg, 15, ARGUMENT_NAME, "XmNuseTextField"},
    {tkn_k_class_argument, sym_k_XmNuserData_arg, 11, ARGUMENT_NAME, "XmNuserData"},
    {tkn_k_class_reason, sym_k_XmNvalidateCallback_reason, 19, REASON_NAME, "XmNvalidateCallback"},
    {tkn_k_class_argument, sym_k_XmNvalue_arg, 8, ARGUMENT_NAME, "XmNvalue"},
    {tkn_k_class_reason, sym_k_XmNvalueChangedCallback_reason, 23, REASON_NAME, "XmNvalueChangedCallback"},
    {tkn_k_class_argument, sym_k_XmNvalueWcs_arg, 11, ARGUMENT_NAME, "XmNvalueWcs"},
    {tkn_k_class_argument, sym_k_XmNvalues_arg, 9, ARGUMENT_NAME, "XmNvalues"},
    {tkn_k_class_argument, sym_k_XmNverify_arg, 9, ARGUMENT_NAME, "XmNverify"},
    {tkn_k_class_argument, sym_k_XmNverifyBell_arg, 13, ARGUMENT_NAME, "XmNverifyBell"},
    {tkn_k_class_reason, sym_k_XmNverifyTextCallback_reason, 21, REASON_NAME, "XmNverifyTextCallback"},
    {tkn_k_class_argument, sym_k_XmNverticalDelta_arg, 16, ARGUMENT_NAME, "XmNverticalDelta"},
    {tkn_k_class_argument, sym_k_XmNverticalMargin_arg, 17, ARGUMENT_NAME, "XmNverticalMargin"},
    {tkn_k_class_argument, sym_k_XmNverticalNodeSpace_arg, 20, ARGUMENT_NAME, "XmNverticalNodeSpace"},
    {tkn_k_class_argument, sym_k_XmNverticalScrollBar_arg, 20, ARGUMENT_NAME, "XmNverticalScrollBar"},
    {tkn_k_class_argument, sym_k_XmNverticalSpacing_arg, 18, ARGUMENT_NAME, "XmNverticalSpacing"},
    {tkn_k_class_argument, sym_k_XmNviewType_arg, 11, ARGUMENT_NAME, "XmNviewType"},
    {tkn_k_class_argument, sym_k_XmNvisibleItemCount_arg, 19, ARGUMENT_NAME, "XmNvisibleItemCount"},
    {tkn_k_class_argument, sym_k_XmNvisibleWhenOff_arg, 17, ARGUMENT_NAME, "XmNvisibleWhenOff"},
    {tkn_k_class_argument, sym_k_XmNvisual_arg, 9, ARGUMENT_NAME, "XmNvisual"},
    {tkn_k_class_argument, sym_k_XmNvisualEmphasis_arg, 17, ARGUMENT_NAME, "XmNvisualEmphasis"},
    {tkn_k_class_argument, sym_k_XmNvisualPolicy_arg, 15, ARGUMENT_NAME, "XmNvisualPolicy"},
    {tkn_k_class_argument, sym_k_XmNwaitForWm_arg, 12, ARGUMENT_NAME, "XmNwaitForWm"},
    {tkn_k_class_argument, sym_k_XmNwhichButton_arg, 14, ARGUMENT_NAME, "XmNwhichButton"},
    {tkn_k_class_argument, sym_k_XmNwidth_arg, 8, ARGUMENT_NAME, "XmNwidth"},
    {tkn_k_class_argument, sym_k_XmNwidthInc_arg, 11, ARGUMENT_NAME, "XmNwidthInc"},
    {tkn_k_class_argument, sym_k_XmNwinGravity_arg, 13, ARGUMENT_NAME, "XmNwinGravity"},
    {tkn_k_class_argument, sym_k_XmNwindowGroup_arg, 14, ARGUMENT_NAME, "XmNwindowGroup"},
    {tkn_k_class_argument, sym_k_XmNwmTimeout_arg, 12, ARGUMENT_NAME, "XmNwmTimeout"},
    {tkn_k_class_argument, sym_k_XmNwordWrap_arg, 11, ARGUMENT_NAME, "XmNwordWrap"},
    {tkn_k_class_argument, sym_k_XmNworkWindow_arg, 13, ARGUMENT_NAME, "XmNworkWindow"},
    {tkn_k_class_argument, sym_k_XmNwrap_arg, 7, ARGUMENT_NAME, "XmNwrap"},
    {tkn_k_class_argument, sym_k_XmNx_arg, 4, ARGUMENT_NAME, "XmNx"},
    {tkn_k_class_argument, sym_k_XmNxlfdString_arg, 13, ARGUMENT_NAME, "XmNxlfdString"},
    {tkn_k_class_argument, sym_k_XmNy_arg, 4, ARGUMENT_NAME, "XmNy"},
    {tkn_k_class_enumval, sym_k_XmONE_BASED_enumval, 11, ENUMVAL_NAME, "XmONE_BASED"},
    {tkn_k_class_enumval, sym_k_XmONE_OF_MANY_enumval, 13, ENUMVAL_NAME, "XmONE_OF_MANY"},
    {tkn_k_class_enumval, sym_k_XmONE_OF_MANY_DIAMOND_enumval, 21, ENUMVAL_NAME, "XmONE_OF_MANY_DIAMOND"},
    {tkn_k_class_enumval, sym_k_XmONE_OF_MANY_ROUND_enumval, 19, ENUMVAL_NAME, "XmONE_OF_MANY_ROUND"},
    {tkn_k_class_enumval, sym_k_XmOUTLINE_enumval, 9, ENUMVAL_NAME, "XmOUTLINE"},
    {tkn_k_class_enumval, sym_k_XmOUTLINE_BUTTON_ABSENT_enumval, 23, ENUMVAL_NAME, "XmOUTLINE_BUTTON_ABSENT"},
    {tkn_k_class_enumval, sym_k_XmOUTLINE_BUTTON_PRESENT_enumval, 24, ENUMVAL_NAME, "XmOUTLINE_BUTTON_PRESENT"},
    {tkn_k_class_enumval, sym_k_XmOWN_ALWAYS_enumval, 12, ENUMVAL_NAME, "XmOWN_ALWAYS"},
    {tkn_k_class_enumval, sym_k_XmOWN_MULTIPLE_enumval, 14, ENUMVAL_NAME, "XmOWN_MULTIPLE"},
    {tkn_k_class_enumval, sym_k_XmOWN_NEVER_enumval, 11, ENUMVAL_NAME, "XmOWN_NEVER"},
    {tkn_k_class_enumval, sym_k_XmOWN_POSSIBLE_MULTIPLE_enumval, 23, ENUMVAL_NAME, "XmOWN_POSSIBLE_MULTIPLE"},
    {tkn_k_class_enumval, sym_k_XmOpen_enumval, 6, ENUMVAL_NAME, "XmOpen"},
    {tkn_k_class_class, sym_k_XmOptionMenu_object, 12, CLASS_NAME, "XmOptionMenu"},
    {tkn_k_class_class, sym_k_XmOutline_object, 9, CLASS_NAME, "XmOutline"},
    {tkn_k_class_enumval, sym_k_XmPACK_COLUMN_enumval, 13, ENUMVAL_NAME, "XmPACK_COLUMN"},
    {tkn_k_class_enumval, sym_k_XmPACK_NONE_enumval, 11, ENUMVAL_NAME, "XmPACK_NONE"},
    {tkn_k_class_enumval, sym_k_XmPACK_TIGHT_enumval, 12, ENUMVAL_NAME, "XmPACK_TIGHT"},
    {tkn_k_class_enumval, sym_k_XmPAGE_enumval, 6, ENUMVAL_NAME, "XmPAGE"},
    {tkn_k_class_enumval, sym_k_XmPAGE_SCROLLER_enumval, 15, ENUMVAL_NAME, "XmPAGE_SCROLLER"},
    {tkn_k_class_enumval, sym_k_XmPER_SHELL_enumval, 11, ENUMVAL_NAME, "XmPER_SHELL"},
    {tkn_k_class_enumval, sym_k_XmPER_WIDGET_enumval, 12, ENUMVAL_NAME, "XmPER_WIDGET"},
    {tkn_k_class_enumval, sym_k_XmPIXELS_enumval, 8, ENUMVAL_NAME, "XmPIXELS"},
    {tkn_k_class_enumval, sym_k_XmPIXMAP_enumval, 8, ENUMVAL_NAME, "XmPIXMAP"},
    {tkn_k_class_enumval, sym_k_XmPIXMAP_AND_STRING_enumval, 19, ENUMVAL_NAME, "XmPIXMAP_AND_STRING"},
    {tkn_k_class_enumval, sym_k_XmPIXMAP_BOTTOM_enumval, 15, ENUMVAL_NAME, "XmPIXMAP_BOTTOM"},
    {tkn_k_class_enumval, sym_k_XmPIXMAP_LEFT_enumval, 13, ENUMVAL_NAME, "XmPIXMAP_LEFT"},
    {tkn_k_class_enumval, sym_k_XmPIXMAP_NONE_enumval, 13, ENUMVAL_NAME, "XmPIXMAP_NONE"},
    {tkn_k_class_enumval, sym_k_XmPIXMAP_ONLY_enumval, 13, ENUMVAL_NAME, "XmPIXMAP_ONLY"},
    {tkn_k_class_enumval, sym_k_XmPIXMAP_OVERLAP_ONLY_enumval, 21, ENUMVAL_NAME, "XmPIXMAP_OVERLAP_ONLY"},
    {tkn_k_class_enumval, sym_k_XmPIXMAP_RIGHT_enumval, 14, ENUMVAL_NAME, "XmPIXMAP_RIGHT"},
    {tkn_k_class_enumval, sym_k_XmPIXMAP_TOP_enumval, 12, ENUMVAL_NAME, "XmPIXMAP_TOP"},
    {tkn_k_class_enumval, sym_k_XmPLACE_ABOVE_SELECTION_enumval, 23, ENUMVAL_NAME, "XmPLACE_ABOVE_SELECTION"},
    {tkn_k_class_enumval, sym_k_XmPLACE_BELOW_SELECTION_enumval, 23, ENUMVAL_NAME, "XmPLACE_BELOW_SELECTION"},
    {tkn_k_class_enumval, sym_k_XmPLACE_TOP_enumval, 11, ENUMVAL_NAME, "XmPLACE_TOP"},
    {tkn_k_class_enumval, sym_k_XmPOINTER_enumval, 9, ENUMVAL_NAME, "XmPOINTER"},
    {tkn_k_class_enumval, sym_k_XmPOINTS_enumval, 8, ENUMVAL_NAME, "XmPOINTS"},
    {tkn_k_class_enumval, sym_k_XmPOSITION_INDEX_enumval, 16, ENUMVAL_NAME, "XmPOSITION_INDEX"},
    {tkn_k_class_enumval, sym_k_XmPOSITION_VALUE_enumval, 16, ENUMVAL_NAME, "XmPOSITION_VALUE"},
    {tkn_k_class_class, sym_k_XmPaned_object, 7, CLASS_NAME, "XmPaned"},
    {tkn_k_class_class, sym_k_XmPanedWindow_object, 13, CLASS_NAME, "XmPanedWindow"},
    {tkn_k_class_class, sym_k_XmPopupMenu_object, 11, CLASS_NAME, "XmPopupMenu"},
    {tkn_k_class_class, sym_k_XmPromptDialog_object, 14, CLASS_NAME, "XmPromptDialog"},
    {tkn_k_class_class, sym_k_XmPulldownMenu_object, 14, CLASS_NAME, "XmPulldownMenu"},
    {tkn_k_class_class, sym_k_XmPushButton_object, 12, CLASS_NAME, "XmPushButton"},
    {tkn_k_class_class, sym_k_XmPushButtonGadget_object, 18, CLASS_NAME, "XmPushButtonGadget"},
    {tkn_k_class_enumval, sym_k_XmQUICK_NAVIGATE_enumval, 16, ENUMVAL_NAME, "XmQUICK_NAVIGATE"},
    {tkn_k_class_class, sym_k_XmQuestionDialog_object, 16, CLASS_NAME, "XmQuestionDialog"},
    {tkn_k_class_enumval, sym_k_XmRELATIVE_enumval, 10, ENUMVAL_NAME, "XmRELATIVE"},
    {tkn_k_class_enumval, sym_k_XmRESIZE_ANY_enumval, 12, ENUMVAL_NAME, "XmRESIZE_ANY"},
    {tkn_k_class_enumval, sym_k_XmRESIZE_GROW_enumval, 13, ENUMVAL_NAME, "XmRESIZE_GROW"},
    {tkn_k_class_enumval, sym_k_XmRESIZE_IF_POSSIBLE_enumval, 20, ENUMVAL_NAME, "XmRESIZE_IF_POSSIBLE"},
    {tkn_k_class_enumval, sym_k_XmRESIZE_NONE_enumval, 13, ENUMVAL_NAME, "XmRESIZE_NONE"},
    {tkn_k_class_enumval, sym_k_XmRIGHT_TO_LEFT_enumval, 15, ENUMVAL_NAME, "XmRIGHT_TO_LEFT"},
    {tkn_k_class_enumval, sym_k_XmRIGHT_TO_LEFT_BOTTOM_TO_TOP_enumval, 29, ENUMVAL_NAME, "XmRIGHT_TO_LEFT_BOTTOM_TO_TOP"},
    {tkn_k_class_enumval, sym_k_XmRIGHT_TO_LEFT_TOP_TO_BOTTOM_enumval, 29, ENUMVAL_NAME, "XmRIGHT_TO_LEFT_TOP_TO_BOTTOM"},
    {tkn_k_class_enumval, sym_k_XmROUND_MARK_enumval, 12, ENUMVAL_NAME, "XmROUND_MARK"},
    {tkn_k_class_class, sym_k_XmRadioBox_object, 10, CLASS_NAME, "XmRadioBox"},
    {tkn_k_class_class, sym_k_XmRenderTable_object, 13, CLASS_NAME, "XmRenderTable"},
    {tkn_k_class_class, sym_k_XmRendition_object, 11, CLASS_NAME, "XmRendition"},
    {tkn_k_class_class, sym_k_XmRowColumn_object, 11, CLASS_NAME, "XmRowColumn"},
    {tkn_k_class_enumval, sym_k_XmSCROLL_HOR_enumval, 12, ENUMVAL_NAME, "XmSCROLL_HOR"},
    {tkn_k_class_enumval, sym_k_XmSCROLL_VERT_enumval, 13, ENUMVAL_NAME, "XmSCROLL_VERT"},
    {tkn_k_class_enumval, sym_k_XmSELECTED_enumval, 10, ENUMVAL_NAME, "XmSELECTED"},
    {tkn_k_class_enumval, sym_k_XmSELECT_ALL_enumval, 12, ENUMVAL_NAME, "XmSELECT_ALL"},
    {tkn_k_class_enumval, sym_k_XmSELECT_LINE_enumval, 13, ENUMVAL_NAME, "XmSELECT_LINE"},
    {tkn_k_class_enumval, sym_k_XmSELECT_PARAGRAPH_enumval, 18, ENUMVAL_NAME, "XmSELECT_PARAGRAPH"},
    {tkn_k_class_enumval, sym_k_XmSELECT_POSITION_enumval, 17, ENUMVAL_NAME, "XmSELECT_POSITION"},
    {tkn_k_class_enumval, sym_k_XmSELECT_WHITESPACE_enumval, 19, ENUMVAL_NAME, "XmSELECT_WHITESPACE"},
    {tkn_k_class_enumval, sym_k_XmSELECT_WORD_enumval, 13, ENUMVAL_NAME, "XmSELECT_WORD"},
    {tkn_k_class_enumval, sym_k_XmSET_enumval, 5, ENUMVAL_NAME, "XmSET"},
    {tkn_k_class_enumval, sym_k_XmSHADOWED_BACKGROUND_enumval, 21, ENUMVAL_NAME, "XmSHADOWED_BACKGROUND"},
    {tkn_k_class_enumval, sym_k_XmSHADOW_ETCHED_IN_enumval, 18, ENUMVAL_NAME, "XmSHADOW_ETCHED_IN"},
    {tkn_k_class_enumval, sym_k_XmSHADOW_ETCHED_IN_DASH_enumval, 23, ENUMVAL_NAME, "XmSHADOW_ETCHED_IN_DASH"},
    {tkn_k_class_enumval, sym_k_XmSHADOW_ETCHED_OUT_enumval, 19, ENUMVAL_NAME, "XmSHADOW_ETCHED_OUT"},
    {tkn_k_class_enumval, sym_k_XmSHADOW_ETCHED_OUT_DASH_enumval, 24, ENUMVAL_NAME, "XmSHADOW_ETCHED_OUT_DASH"},
    {tkn_k_class_enumval, sym_k_XmSHADOW_IN_enumval, 11, ENUMVAL_NAME, "XmSHADOW_IN"},
    {tkn_k_class_enumval, sym_k_XmSHADOW_OUT_enumval, 12, ENUMVAL_NAME, "XmSHADOW_OUT"},
    {tkn_k_class_enumval, sym_k_XmSINGLE_enumval, 8, ENUMVAL_NAME, "XmSINGLE"},
    {tkn_k_class_enumval, sym_k_XmSINGLE_DASHED_LINE_enumval, 20, ENUMVAL_NAME, "XmSINGLE_DASHED_LINE"},
    {tkn_k_class_enumval, sym_k_XmSINGLE_LINE_enumval, 13, ENUMVAL_NAME, "XmSINGLE_LINE"},
    {tkn_k_class_enumval, sym_k_XmSINGLE_LINE_EDIT_enumval, 18, ENUMVAL_NAME, "XmSINGLE_LINE_EDIT"},
    {tkn_k_class_enumval, sym_k_XmSINGLE_SELECT_enumval, 15, ENUMVAL_NAME, "XmSINGLE_SELECT"},
    {tkn_k_class_enumval, sym_k_XmSLIDER_enumval, 8, ENUMVAL_NAME, "XmSLIDER"},
    {tkn_k_class_enumval, sym_k_XmSMALL_ICON_enumval, 12, ENUMVAL_NAME, "XmSMALL_ICON"},
    {tkn_k_class_enumval, sym_k_XmSNAP_TO_GRID_enumval, 14, ENUMVAL_NAME, "XmSNAP_TO_GRID"},
    {tkn_k_class_enumval, sym_k_XmSOLID_enumval, 7, ENUMVAL_NAME, "XmSOLID"},
    {tkn_k_class_enumval, sym_k_XmSPATIAL_enumval, 9, ENUMVAL_NAME, "XmSPATIAL"},
    {tkn_k_class_enumval, sym_k_XmSPIRAL_enumval, 8, ENUMVAL_NAME, "XmSPIRAL"},
    {tkn_k_class_enumval, sym_k_XmSTATIC_enumval, 8, ENUMVAL_NAME, "XmSTATIC"},
    {tkn_k_class_enumval, sym_k_XmSTATUS_AREA_enumval, 13, ENUMVAL_NAME, "XmSTATUS_AREA"},
    {tkn_k_class_enumval, sym_k_XmSTICKY_TAB_GROUP_enumval, 18, ENUMVAL_NAME, "XmSTICKY_TAB_GROUP"},
    {tkn_k_class_enumval, sym_k_XmSTRING_enumval, 8, ENUMVAL_NAME, "XmSTRING"},
    {tkn_k_class_enumval, sym_k_XmSTRING_COMPONENT_CHARSET_enumval, 26, ENUMVAL_NAME, "XmSTRING_COMPONENT_CHARSET"},
    {tkn_k_class_enumval, sym_k_XmSTRING_COMPONENT_DIRECTION_enumval, 28, ENUMVAL_NAME, "XmSTRING_COMPONENT_DIRECTION"},
    {tkn_k_class_enumval, sym_k_XmSTRING_COMPONENT_LAYOUT_POP_enumval, 29, ENUMVAL_NAME, "XmSTRING_COMPONENT_LAYOUT_POP"},
    {tkn_k_class_enumval, sym_k_XmSTRING_COMPONENT_LAYOUT_PUSH_enumval, 30, ENUMVAL_NAME, "XmSTRING_COMPONENT_LAYOUT_PUSH"},
    {tkn_k_class_enumval, sym_k_XmSTRING_COMPONENT_LOCALE_enumval, 25, ENUMVAL_NAME, "XmSTRING_COMPONENT_LOCALE"},
    {tkn_k_class_enumval, sym_k_XmSTRING_COMPONENT_LOCALE_TEXT_enumval, 30, ENUMVAL_NAME, "XmSTRING_COMPONENT_LOCALE_TEXT"},
    {tkn_k_class_enumval, sym_k_XmSTRING_COMPONENT_RENDITION_BEGIN_enumval, 34, ENUMVAL_NAME, "XmSTRING_COMPONENT_RENDITION_BEGIN"},
    {tkn_k_class_enumval, sym_k_XmSTRING_COMPONENT_RENDITION_END_enumval, 32, ENUMVAL_NAME, "XmSTRING_COMPONENT_RENDITION_END"},
    {tkn_k_class_enumval, sym_k_XmSTRING_COMPONENT_SEPARATOR_enumval, 28, ENUMVAL_NAME, "XmSTRING_COMPONENT_SEPARATOR"},
    {tkn_k_class_enumval, sym_k_XmSTRING_COMPONENT_TAB_enumval, 22, ENUMVAL_NAME, "XmSTRING_COMPONENT_TAB"},
    {tkn_k_class_enumval, sym_k_XmSTRING_COMPONENT_TEXT_enumval, 23, ENUMVAL_NAME, "XmSTRING_COMPONENT_TEXT"},
    {tkn_k_class_enumval, sym_k_XmSTRING_COMPONENT_UNKNOWN_enumval, 26, ENUMVAL_NAME, "XmSTRING_COMPONENT_UNKNOWN"},
    {tkn_k_class_enumval, sym_k_XmSTRING_COMPONENT_WIDECHAR_TEXT_enumval, 32, ENUMVAL_NAME, "XmSTRING_COMPONENT_WIDECHAR_TEXT"},
    {tkn_k_class_enumval, sym_k_XmSTRING_DIRECTION_DEFAULT_enumval, 26, ENUMVAL_NAME, "XmSTRING_DIRECTION_DEFAULT"},
    {tkn_k_class_enumval, sym_k_XmSTRING_DIRECTION_L_TO_R_enumval, 25, ENUMVAL_NAME, "XmSTRING_DIRECTION_L_TO_R"},
    {tkn_k_class_enumval, sym_k_XmSTRING_DIRECTION_R_TO_L_enumval, 25, ENUMVAL_NAME, "XmSTRING_DIRECTION_R_TO_L"},
    {tkn_k_class_enumval, sym_k_XmSTRING_DIRECTION_UNSET_enumval, 24, ENUMVAL_NAME, "XmSTRING_DIRECTION_UNSET"},
    {tkn_k_class_class, sym_k_XmScale_object, 7, CLASS_NAME, "XmScale"},
    {tkn_k_class_enumval, sym_k_XmScaleMode_enumval, 11, ENUMVAL_NAME, "XmScaleMode"},
    {tkn_k_class_class, sym_k_XmScrollBar_object, 11, CLASS_NAME, "XmScrollBar"},
    {tkn_k_class_class, sym_k_XmScrolledList_object, 14, CLASS_NAME, "XmScrolledList"},
    {tkn_k_class_class, sym_k_XmScrolledText_object, 14, CLASS_NAME, "XmScrolledText"},
    {tkn_k_class_class, sym_k_XmScrolledWindow_object, 16, CLASS_NAME, "XmScrolledWindow"},
    {tkn_k_class_class, sym_k_XmSelectionBox_object, 14, CLASS_NAME, "XmSelectionBox"},
    {tkn_k_class_class, sym_k_XmSelectionDialog_object, 17, CLASS_NAME, "XmSelectionDialog"},
    {tkn_k_class_class, sym_k_XmSeparator_object, 11, CLASS_NAME, "XmSeparator"},
    {tkn_k_class_class, sym_k_XmSeparatorGadget_object, 17, CLASS_NAME, "XmSeparatorGadget"},
    {tkn_k_class_class, sym_k_XmSimpleSpinBox_object, 15, CLASS_NAME, "XmSimpleSpinBox"},
    {tkn_k_class_class, sym_k_XmSpinBox_object, 9, CLASS_NAME, "XmSpinBox"},
    {tkn_k_class_argument, sym_k_XmStringComponent_arg, 17, ARGUMENT_NAME, "XmStringComponent"},
    {tkn_k_class_enumval, sym_k_XmTABS_BASIC_enumval, 12, ENUMVAL_NAME, "XmTABS_BASIC"},
    {tkn_k_class_enumval, sym_k_XmTABS_BEVELED_enumval, 14, ENUMVAL_NAME, "XmTABS_BEVELED"},
    {tkn_k_class_enumval, sym_k_XmTABS_BOTTOM_TO_TOP_enumval, 20, ENUMVAL_NAME, "XmTABS_BOTTOM_TO_TOP"},
    {tkn_k_class_enumval, sym_k_XmTABS_LEFT_TO_RIGHT_enumval, 20, ENUMVAL_NAME, "XmTABS_LEFT_TO_RIGHT"},
    {tkn_k_class_enumval, sym_k_XmTABS_ON_BOTTOM_enumval, 16, ENUMVAL_NAME, "XmTABS_ON_BOTTOM"},
    {tkn_k_class_enumval, sym_k_XmTABS_ON_LEFT_enumval, 14, ENUMVAL_NAME, "XmTABS_ON_LEFT"},
    {tkn_k_class_enumval, sym_k_XmTABS_ON_RIGHT_enumval, 15, ENUMVAL_NAME, "XmTABS_ON_RIGHT"},
    {tkn_k_class_enumval, sym_k_XmTABS_ON_TOP_enumval, 13, ENUMVAL_NAME, "XmTABS_ON_TOP"},
    {tkn_k_class_enumval, sym_k_XmTABS_RIGHT_TO_LEFT_enumval, 20, ENUMVAL_NAME, "XmTABS_RIGHT_TO_LEFT"},
    {tkn_k_class_enumval, sym_k_XmTABS_ROUNDED_enumval, 14, ENUMVAL_NAME, "XmTABS_ROUNDED"},
    {tkn_k_class_enumval, sym_k_XmTABS_SQUARED_enumval, 14, ENUMVAL_NAME, "XmTABS_SQUARED"},
    {tkn_k_class_enumval, sym_k_XmTABS_STACKED_enumval, 14, ENUMVAL_NAME, "XmTABS_STACKED"},
    {tkn_k_class_enumval, sym_k_XmTABS_STACKED_STATIC_enumval, 21, ENUMVAL_NAME, "XmTABS_STACKED_STATIC"},
    {tkn_k_class_enumval, sym_k_XmTABS_TOP_TO_BOTTOM_enumval, 20, ENUMVAL_NAME, "XmTABS_TOP_TO_BOTTOM"},
    {tkn_k_class_enumval, sym_k_XmTAB_EDGE_BOTTOM_RIGHT_enumval, 23, ENUMVAL_NAME, "XmTAB_EDGE_BOTTOM_RIGHT"},
    {tkn_k_class_enumval, sym_k_XmTAB_EDGE_TOP_LEFT_enumval, 19, ENUMVAL_NAME, "XmTAB_EDGE_TOP_LEFT"},
    {tkn_k_class_enumval, sym_k_XmTAB_GROUP_enumval, 11, ENUMVAL_NAME, "XmTAB_GROUP"},
    {tkn_k_class_enumval, sym_k_XmTAB_ORIENTATION_DYNAMIC_enumval, 25, ENUMVAL_NAME, "XmTAB_ORIENTATION_DYNAMIC"},
    {tkn_k_class_enumval, sym_k_XmTEAR_OFF_DISABLED_enumval, 19, ENUMVAL_NAME, "XmTEAR_OFF_DISABLED"},
    {tkn_k_class_enumval, sym_k_XmTEAR_OFF_ENABLED_enumval, 18, ENUMVAL_NAME, "XmTEAR_OFF_ENABLED"},
    {tkn_k_class_enumval, sym_k_XmTHERMOMETER_enumval, 13, ENUMVAL_NAME, "XmTHERMOMETER"},
    {tkn_k_class_enumval, sym_k_XmTHUMB_MARK_enumval, 12, ENUMVAL_NAME, "XmTHUMB_MARK"},
    {tkn_k_class_enumval, sym_k_XmTOGGLE_BOOLEAN_enumval, 16, ENUMVAL_NAME, "XmTOGGLE_BOOLEAN"},
    {tkn_k_class_enumval, sym_k_XmTOGGLE_INDETERMINATE_enumval, 22, ENUMVAL_NAME, "XmTOGGLE_INDETERMINATE"},
    {tkn_k_class_enumval, sym_k_XmTOP_LEFT_enumval, 10, ENUMVAL_NAME, "XmTOP_LEFT"},
    {tkn_k_class_enumval, sym_k_XmTOP_RIGHT_enumval, 11, ENUMVAL_NAME, "XmTOP_RIGHT"},
    {tkn_k_class_enumval, sym_k_XmTOP_TO_BOTTOM_enumval, 15, ENUMVAL_NAME, "XmTOP_TO_BOTTOM"},
    {tkn_k_class_enumval, sym_k_XmTOP_TO_BOTTOM_LEFT_TO_RIGHT_enumval, 29, ENUMVAL_NAME, "XmTOP_TO_BOTTOM_LEFT_TO_RIGHT"},
    {tkn_k_class_enumval, sym_k_XmTOP_TO_BOTTOM_RIGHT_TO_LEFT_enumval, 29, ENUMVAL_NAME, "XmTOP_TO_BOTTOM_RIGHT_TO_LEFT"},
    {tkn_k_class_enumval, sym_k_XmTOUCH_ONLY_enumval, 12, ENUMVAL_NAME, "XmTOUCH_ONLY"},
    {tkn_k_class_enumval, sym_k_XmTOUCH_OVER_enumval, 12, ENUMVAL_NAME, "XmTOUCH_OVER"},
    {tkn_k_class_enumval, sym_k_XmTROUGH_COLOR_enumval, 14, ENUMVAL_NAME, "XmTROUGH_COLOR"},
    {tkn_k_class_class, sym_k_XmTab_object, 5, CLASS_NAME, "XmTab"},
    {tkn_k_class_class, sym_k_XmTabBox_object, 8, CLASS_NAME, "XmTabBox"},
    {tkn_k_class_class, sym_k_XmTabList_object, 9, CLASS_NAME, "XmTabList"},
    {tkn_k_class_class, sym_k_XmTabStack_object, 10, CLASS_NAME, "XmTabStack"},
    {tkn_k_class_class, sym_k_XmTearOffButton_object, 15, CLASS_NAME, "XmTearOffButton"},
    {tkn_k_class_class, sym_k_XmTemplateDialog_object, 16, CLASS_NAME, "XmTemplateDialog"},
    {tkn_k_class_class, sym_k_XmText_object, 6, CLASS_NAME, "XmText"},
    {tkn_k_class_class, sym_k_XmTextField_object, 11, CLASS_NAME, "XmTextField"},
    {tkn_k_class_class, sym_k_XmToggleButton_object, 14, CLASS_NAME, "XmToggleButton"},
    {tkn_k_class_class, sym_k_XmToggleButtonGadget_object, 20, CLASS_NAME, "XmToggleButtonGadget"},
    {tkn_k_class_class, sym_k_XmTree_object, 6, CLASS_NAME, "XmTree"},
    {tkn_k_class_enumval, sym_k_XmTreeCompressLeaves_enumval, 20, ENUMVAL_NAME, "XmTreeCompressLeaves"},
    {tkn_k_class_enumval, sym_k_XmTreeCompressNone_enumval, 18, ENUMVAL_NAME, "XmTreeCompressNone"},
    {tkn_k_class_enumval, sym_k_XmTreeDirect_enumval, 12, ENUMVAL_NAME, "XmTreeDirect"},
    {tkn_k_class_enumval, sym_k_XmTreeLadder_enumval, 12, ENUMVAL_NAME, "XmTreeLadder"},
    {tkn_k_class_enumval, sym_k_XmUNMAP_enumval, 7, ENUMVAL_NAME, "XmUNMAP"},
    {tkn_k_class_enumval, sym_k_XmUNPOST_enumval, 8, ENUMVAL_NAME, "XmUNPOST"},
    {tkn_k_class_enumval, sym_k_XmUNPOST_AND_REPLAY_enumval, 19, ENUMVAL_NAME, "XmUNPOST_AND_REPLAY"},
    {tkn_k_class_enumval, sym_k_XmUNSET_enumval, 7, ENUMVAL_NAME, "XmUNSET"},
    {tkn_k_class_enumval, sym_k_XmVARIABLE_enumval, 10, ENUMVAL_NAME, "XmVARIABLE"},
    {tkn_k_class_enumval, sym_k_XmVERTICAL_enumval, 10, ENUMVAL_NAME, "XmVERTICAL"},
    {tkn_k_class_enumval, sym_k_XmVERT_SCROLLBAR_enumval, 16, ENUMVAL_NAME, "XmVERT_SCROLLBAR"},
    {tkn_k_class_enumval, sym_k_XmWORK_AREA_enumval, 11, ENUMVAL_NAME, "XmWORK_AREA"},
    {tkn_k_class_class, sym_k_XmWarningDialog_object, 15, CLASS_NAME, "XmWarningDialog"},
    {tkn_k_class_class, sym_k_XmWorkArea_object, 10, CLASS_NAME, "XmWorkArea"},
    {tkn_k_class_class, sym_k_XmWorkingDialog_object, 15, CLASS_NAME, "XmWorkingDialog"},
    {tkn_k_class_enumval, sym_k_XmZERO_BASED_enumval, 12, ENUMVAL_NAME, "XmZERO_BASED"},
    {tkn_k_class_child, sym_k_Xm_Apply_child, 8, CHILD_NAME, "Xm_Apply"},
    {tkn_k_class_child, sym_k_Xm_Arrow_child, 8, CHILD_NAME, "Xm_Arrow"},
    {tkn_k_class_child, sym_k_Xm_Cancel_child, 9, CHILD_NAME, "Xm_Cancel"},
    {tkn_k_class_child, sym_k_Xm_ColorListToggle_child, 18, CHILD_NAME, "Xm_ColorListToggle"},
    {tkn_k_class_child, sym_k_Xm_ColorSlidersToggle_child, 21, CHILD_NAME, "Xm_ColorSlidersToggle"},
    {tkn_k_class_child, sym_k_Xm_Dir_child, 6, CHILD_NAME, "Xm_Dir"},
    {tkn_k_class_child, sym_k_Xm_DirList_child, 10, CHILD_NAME, "Xm_DirList"},
    {tkn_k_class_child, sym_k_Xm_Filter_child, 9, CHILD_NAME, "Xm_Filter"},
    {tkn_k_class_child, sym_k_Xm_FilterLabel_child, 14, CHILD_NAME, "Xm_FilterLabel"},
    {tkn_k_class_child, sym_k_Xm_FilterText_child, 13, CHILD_NAME, "Xm_FilterText"},
    {tkn_k_class_child, sym_k_Xm_Find_child, 7, CHILD_NAME, "Xm_Find"},
    {tkn_k_class_child, sym_k_Xm_FindText_child, 11, CHILD_NAME, "Xm_FindText"},
    {tkn_k_class_child, sym_k_Xm_Help_child, 7, CHILD_NAME, "Xm_Help"},
    {tkn_k_class_child, sym_k_Xm_HorScrollBar_child, 15, CHILD_NAME, "Xm_HorScrollBar"},
    {tkn_k_class_child, sym_k_Xm_Items_child, 8, CHILD_NAME, "Xm_Items"},
    {tkn_k_class_child, sym_k_Xm_ItemsList_child, 12, CHILD_NAME, "Xm_ItemsList"},
    {tkn_k_class_child, sym_k_Xm_Label_child, 8, CHILD_NAME, "Xm_Label"},
    {tkn_k_class_child, sym_k_Xm_List_child, 7, CHILD_NAME, "Xm_List"},
    {tkn_k_class_child, sym_k_Xm_Message_child, 10, CHILD_NAME, "Xm_Message"},
    {tkn_k_class_child, sym_k_Xm_OK_child, 5, CHILD_NAME, "Xm_OK"},
    {tkn_k_class_child, sym_k_Xm_OptionButton_child, 15, CHILD_NAME, "Xm_OptionButton"},
    {tkn_k_class_child, sym_k_Xm_OptionLabel_child, 14, CHILD_NAME, "Xm_OptionLabel"},
    {tkn_k_class_child, sym_k_Xm_Selection_child, 12, CHILD_NAME, "Xm_Selection"},
    {tkn_k_class_child, sym_k_Xm_Separator_child, 12, CHILD_NAME, "Xm_Separator"},
    {tkn_k_class_child, sym_k_Xm_Separator1_child, 13, CHILD_NAME, "Xm_Separator1"},
    {tkn_k_class_child, sym_k_Xm_Separator2_child, 13, CHILD_NAME, "Xm_Separator2"},
    {tkn_k_class_child, sym_k_Xm_Separator3_child, 13, CHILD_NAME, "Xm_Separator3"},
    {tkn_k_class_child, sym_k_Xm_Symbol_child, 9, CHILD_NAME, "Xm_Symbol"},
    {tkn_k_class_child, sym_k_Xm_TearOffControl_child, 17, CHILD_NAME, "Xm_TearOffControl"},
    {tkn_k_class_child, sym_k_Xm_Text_child, 7, CHILD_NAME, "Xm_Text"},
    {tkn_k_class_child, sym_k_Xm_TextField_child, 12, CHILD_NAME, "Xm_TextField"},
    {tkn_k_class_child, sym_k_Xm_Title_child, 8, CHILD_NAME, "Xm_Title"},
    {tkn_k_class_child, sym_k_Xm_VertScrollBar_child, 16, CHILD_NAME, "Xm_VertScrollBar"},
    {tkn_k_class_charset, sym_k__MOTIF_DEFAULT_LOCALE_charset, 21, CHARSET_NAME, "_MOTIF_DEFAULT_LOCALE"},
    {tkn_k_class_charset, sym_k_ansi_cyrillic_charset, 13, CHARSET_NAME, "ansi_cyrillic"},
    {tkn_k_class_keyword, 0, 3, ANY, "any"},
    {tkn_k_class_keyword, 0, 8, ARGUMENT, "argument"},
    {tkn_k_class_reserved, 0, 9, ARGUMENTS, "arguments"},
    {tkn_k_class_keyword, 0, 18, ASCIZ_STRING_TABLE, "asciz_string_table"},
    {tkn_k_class_keyword, 0, 11, ASCIZ_TABLE, "asciz_table"},
    {tkn_k_class_keyword, 0, 10, BACKGROUND, "background"},
    {tkn_k_class_charset, sym_k_big5_charset, 4, CHARSET_NAME, "big5"},
    {tkn_k_class_keyword, 0, 7, BOOLEAN, "boolean"},
    {tkn_k_class_reserved, 0, 9, CALLBACKS, "callbacks"},
    {tkn_k_class_keyword, 0, 16, CASE_INSENSITIVE, "case_insensitive"},
    {tkn_k_class_keyword, 0, 14, CASE_SENSITIVE, "case_sensitive"},
    {tkn_k_class_keyword, 0, 10, CENTIMETER, "centimeter"},
    {tkn_k_class_keyword, 0, 11, CENTIMETERS, "centimeters"},
    {tkn_k_class_keyword, 0, 13, CHARACTER_SET, "character_set"},
    {tkn_k_class_keyword, 0, 14, CLASS_REC_NAME, "class_rec_name"},
    {tkn_k_class_keyword, 0, 2, CM, "cm"},
    {tkn_k_class_keyword, 0, 5, COLOR, "color"},
    {tkn_k_class_keyword, 0, 11, COLOR_TABLE, "color_table"},
    {tkn_k_class_keyword, 0, 15, COMPOUND_STRING, "compound_string"},
    {tkn_k_class_keyword, 0, 25, COMPOUND_STRING_COMPONENT, "compound_string_component"},
    {tkn_k_class_keyword, 0, 21, COMPOUND_STRING_TABLE, "compound_string_table"},
    {tkn_k_class_reserved, 0, 8, CONTROLS, "controls"},
    {tkn_k_class_charset, sym_k_dos_cyrillic_charset, 12, CHARSET_NAME, "dos_cyrillic"},
    {tkn_k_class_reserved, 0, 3, END, "end"},
    {tkn_k_class_charset, sym_k_euc_charset, 3, CHARSET_NAME, "euc"},
    {tkn_k_class_reserved, 0, 8, EXPORTED, "exported"},
    {tkn_k_class_reserved, 0, 5, UILFALSE, "false"},
    {tkn_k_class_keyword, 0, 4, UILFILE, "file"},
    {tkn_k_class_keyword, 0, 5, FLOAT, "float"},
    {tkn_k_class_keyword, 0, 4, FONT, "font"},
    {tkn_k_class_keyword, 0, 10, FONT_TABLE, "font_table"},
    {tkn_k_class_keyword, 0, 9, FONT_UNIT, "font_unit"},
    {tkn_k_class_keyword, 0, 10, FONT_UNITS, "font_units"},
    {tkn_k_class_keyword, 0, 7, FONTSET, "fontset"},
    {tkn_k_class_keyword, 0, 10, FOREGROUND, "foreground"},
    {tkn_k_class_keyword, 0, 2, FU, "fu"},
    {tkn_k_class_reserved, 0, 6, GADGET, "gadget"},
    {tkn_k_class_charset, sym_k_gb_hanzi_charset, 10, CHARSET_NAME, "gb_chinese"},
    {tkn_k_class_charset, sym_k_gb_hanzi_charset, 8, CHARSET_NAME, "gb_hanzi"},
    {tkn_k_class_charset, sym_k_gb_hanzi_charset, 11, CHARSET_NAME, "gb_hanzi_gl"},
    {tkn_k_class_charset, sym_k_gb_hanzi_gr_charset, 11, CHARSET_NAME, "gb_hanzi_gr"},
    {tkn_k_class_keyword, 0, 4, ICON, "icon"},
    {tkn_k_class_reserved, 0, 10, IDENTIFIER, "identifier"},
    {tkn_k_class_keyword, 0, 8, IMPORTED, "imported"},
    {tkn_k_class_keyword, 0, 2, IN, "in"},
    {tkn_k_class_keyword, 0, 4, INCH, "inch"},
    {tkn_k_class_keyword, 0, 6, INCHES, "inches"},
    {tkn_k_class_reserved, 0, 7, INCLUDE, "include"},
    {tkn_k_class_keyword, 0, 7, INTEGER, "integer"},
    {tkn_k_class_keyword, 0, 13, INTEGER_TABLE, "integer_table"},
    {tkn_k_class_charset, sym_k_iso_arabic_charset, 10, CHARSET_NAME, "iso_arabic"},
    {tkn_k_class_charset, sym_k_iso_arabic_lr_charset, 13, CHARSET_NAME, "iso_arabic_lr"},
    {tkn_k_class_charset, sym_k_iso_cyrillic_charset, 12, CHARSET_NAME, "iso_cyrillic"},
    {tkn_k_class_charset, sym_k_iso_greek_charset, 9, CHARSET_NAME, "iso_greek"},
    {tkn_k_class_charset, sym_k_iso_hebrew_charset, 10, CHARSET_NAME, "iso_hebrew"},
    {tkn_k_class_charset, sym_k_iso_hebrew_lr_charset, 13, CHARSET_NAME, "iso_hebrew_lr"},
    {tkn_k_class_charset, sym_k_iso_ir_111_charset, 10, CHARSET_NAME, "iso_ir_111"},
    {tkn_k_class_charset, sym_k_iso_latin1_charset, 10, CHARSET_NAME, "iso_latin1"},
    {tkn_k_class_charset, sym_k_iso_latin2_charset, 10, CHARSET_NAME, "iso_latin2"},
    {tkn_k_class_charset, sym_k_iso_latin3_charset, 10, CHARSET_NAME, "iso_latin3"},
    {tkn_k_class_charset, sym_k_iso_latin4_charset, 10, CHARSET_NAME, "iso_latin4"},
    {tkn_k_class_charset, sym_k_iso_latin5_charset, 10, CHARSET_NAME, "iso_latin5"},
    {tkn_k_class_charset, sym_k_iso_arabic_charset, 10, CHARSET_NAME, "iso_latin6"},
    {tkn_k_class_charset, sym_k_iso_arabic_lr_charset, 13, CHARSET_NAME, "iso_latin6_lr"},
    {tkn_k_class_charset, sym_k_iso_greek_charset, 10, CHARSET_NAME, "iso_latin7"},
    {tkn_k_class_charset, sym_k_iso_hebrew_charset, 10, CHARSET_NAME, "iso_latin8"},
    {tkn_k_class_charset, sym_k_iso_hebrew_lr_charset, 13, CHARSET_NAME, "iso_latin8_lr"},
    {tkn_k_class_charset, sym_k_jis_kanji_charset, 12, CHARSET_NAME, "jis_japanese"},
    {tkn_k_class_charset, sym_k_jis_kanji_charset, 9, CHARSET_NAME, "jis_kanji"},
    {tkn_k_class_charset, sym_k_jis_kanji_charset, 12, CHARSET_NAME, "jis_kanji_gl"},
    {tkn_k_class_charset, sym_k_jis_kanji_gr_charset, 12, CHARSET_NAME, "jis_kanji_gr"},
    {tkn_k_class_charset, sym_k_jis_katakana_charset, 12, CHARSET_NAME, "jis_katakana"},
    {tkn_k_class_keyword, 0, 6, KEYSYM, "keysym"},
    {tkn_k_class_charset, sym_k_ksc_hangul_charset, 10, CHARSET_NAME, "ksc_hangul"},
    {tkn_k_class_charset, sym_k_ksc_hangul_charset, 13, CHARSET_NAME, "ksc_hangul_gl"},
    {tkn_k_class_charset, sym_k_ksc_hangul_gr_charset, 13, CHARSET_NAME, "ksc_hangul_gr"},
    {tkn_k_class_charset, sym_k_ksc_hangul_charset, 10, CHARSET_NAME, "ksc_korean"},
    {tkn_k_class_reserved, 0, 4, LIST, "list"},
    {tkn_k_class_reserved, 0, 5, MACRO, "macro"},
    {tkn_k_class_keyword, 0, 7, MANAGED, "managed"},
    {tkn_k_class_keyword, 0, 10, MILLIMETER, "millimeter"},
    {tkn_k_class_keyword, 0, 11, MILLIMETERS, "millimeters"},
    {tkn_k_class_keyword, 0, 2, MM, "mm"},
    {tkn_k_class_reserved, 0, 6, MODULE, "module"},
    {tkn_k_class_keyword, 0, 5, NAMES, "names"},
    {tkn_k_class_reserved, 0, 6, OBJECT, "object"},
    {tkn_k_class_keyword, 0, 7, OBJECTS, "objects"},
    {tkn_k_class_reserved, 0, 3, OFF, "off"},
    {tkn_k_class_reserved, 0, 2, ON, "on"},
    {tkn_k_class_keyword, 0, 3, PIX, "pix"},
    {tkn_k_class_keyword, 0, 5, PIXEL, "pixel"},
    {tkn_k_class_keyword, 0, 6, PIXELS, "pixels"},
    {tkn_k_class_keyword, 0, 6, PIXMAP, "pixmap"},
    {tkn_k_class_keyword, 0, 5, POINT, "point"},
    {tkn_k_class_keyword, 0, 6, POINTS, "points"},
    {tkn_k_class_reserved, 0, 7, PRIVATE, "private"},
    {tkn_k_class_reserved, 0, 9, PROCEDURE, "procedure"},
    {tkn_k_class_reserved, 0, 10, PROCEDURES, "procedures"},
    {tkn_k_class_keyword, 0, 2, PT, "pt"},
    {tkn_k_class_keyword, 0, 6, REASON, "reason"},
    {tkn_k_class_keyword, 0, 3, RGB, "rgb"},
    {tkn_k_class_keyword, 0, 13, RIGHT_TO_LEFT, "right_to_left"},
    {tkn_k_class_keyword, 0, 8, SEPARATE, "separate"},
    {tkn_k_class_keyword, 0, 12, SINGLE_FLOAT, "single_float"},
    {tkn_k_class_keyword, 0, 11, SIXTEEN_BIT, "sixteen_bit"},
    {tkn_k_class_keyword, 0, 6, STRING, "string"},
    {tkn_k_class_keyword, 0, 12, STRING_TABLE, "string_table"},
    {tkn_k_class_keyword, 0, 17, TRANSLATION_TABLE, "translation_table"},
    {tkn_k_class_reserved, 0, 4, UILTRUE, "true"},
    {tkn_k_class_keyword, 0, 9, UNMANAGED, "unmanaged"},
    {tkn_k_class_class, sym_k_user_defined_object, 12, CLASS_NAME, "user_defined"},
    {tkn_k_class_charset, sym_k_utf8_charset, 4, CHARSET_NAME, "utf8"},
    {tkn_k_class_reserved, 0, 5, VALUE, "value"},
    {tkn_k_class_keyword, 0, 7, VERSION, "version"},
    {tkn_k_class_keyword, 0, 14, WIDE_CHARACTER, "wide_character"},
    {tkn_k_class_reserved, 0, 6, WIDGET, "widget"},
    {tkn_k_class_keyword, 0, 11, XBITMAPFILE, "xbitmapfile"},
  };
externaldef(uil_sym_glbl) key_keytable_entry_type *key_table =
		key_table_vec;

/*    Maximum length of a keyword, and table size    */
externaldef(uil_sym_glbl) int key_k_keyword_max_length = 35;
externaldef(uil_sym_glbl) int key_k_keyword_count = 1466;

/*    case insensitive keyword table    */
static key_keytable_entry_type key_table_case_ins_vec[] =
  {
    {tkn_k_class_charset, sym_k_dos_cyrillic_charset, 3, CHARSET_NAME, "866"},
    {tkn_k_class_charset, sym_k_iso_latin1_charset, 5, CHARSET_NAME, "88591"},
    {tkn_k_class_charset, sym_k_iso_latin2_charset, 5, CHARSET_NAME, "88592"},
    {tkn_k_class_charset, sym_k_iso_latin3_charset, 5, CHARSET_NAME, "88593"},
    {tkn_k_class_charset, sym_k_iso_latin4_charset, 5, CHARSET_NAME, "88594"},
    {tkn_k_class_charset, sym_k_iso_latin5_charset, 5, CHARSET_NAME, "88595"},
    {tkn_k_class_charset, sym_k_iso_arabic_charset, 5, CHARSET_NAME, "88596"},
    {tkn_k_class_charset, sym_k_iso_greek_charset, 5, CHARSET_NAME, "88597"},
    {tkn_k_class_charset, sym_k_iso_hebrew_charset, 5, CHARSET_NAME, "88598"},
    {tkn_k_class_enumval, sym_k_Always_enumval, 6, ENUMVAL_NAME, "ALWAYS"},
    {tkn_k_class_charset, sym_k_ansi_cyrillic_charset, 9, CHARSET_NAME, "ANSI-1251"},
    {tkn_k_class_charset, sym_k_ansi_cyrillic_charset, 8, CHARSET_NAME, "ANSI1251"},
    {tkn_k_class_charset, sym_k_ansi_cyrillic_charset, 13, CHARSET_NAME, "ANSI_CYRILLIC"},
    {tkn_k_class_keyword, 0, 3, ANY, "ANY"},
    {tkn_k_class_keyword, 0, 8, ARGUMENT, "ARGUMENT"},
    {tkn_k_class_reserved, 0, 9, ARGUMENTS, "ARGUMENTS"},
    {tkn_k_class_charset, sym_k_iso_latin1_charset, 5, CHARSET_NAME, "ASCII"},
    {tkn_k_class_keyword, 0, 18, ASCIZ_STRING_TABLE, "ASCIZ_STRING_TABLE"},
    {tkn_k_class_keyword, 0, 11, ASCIZ_TABLE, "ASCIZ_TABLE"},
    {tkn_k_class_keyword, 0, 10, BACKGROUND, "BACKGROUND"},
    {tkn_k_class_charset, sym_k_big5_charset, 4, CHARSET_NAME, "BIG5"},
    {tkn_k_class_keyword, 0, 7, BOOLEAN, "BOOLEAN"},
    {tkn_k_class_reserved, 0, 9, CALLBACKS, "CALLBACKS"},
    {tkn_k_class_keyword, 0, 16, CASE_INSENSITIVE, "CASE_INSENSITIVE"},
    {tkn_k_class_keyword, 0, 14, CASE_SENSITIVE, "CASE_SENSITIVE"},
    {tkn_k_class_keyword, 0, 10, CENTIMETER, "CENTIMETER"},
    {tkn_k_class_keyword, 0, 11, CENTIMETERS, "CENTIMETERS"},
    {tkn_k_class_keyword, 0, 13, CHARACTER_SET, "CHARACTER_SET"},
    {tkn_k_class_keyword, 0, 14, CLASS_REC_NAME, "CLASS_REC_NAME"},
    {tkn_k_class_keyword, 0, 2, CM, "CM"},
    {tkn_k_class_keyword, 0, 5, COLOR, "COLOR"},
    {tkn_k_class_keyword, 0, 11, COLOR_TABLE, "COLOR_TABLE"},
    {tkn_k_class_keyword, 0, 15, COMPOUND_STRING, "COMPOUND_STRING"},
    {tkn_k_class_keyword, 0, 25, COMPOUND_STRING_COMPONENT, "COMPOUND_STRING_COMPONENT"},
    {tkn_k_class_keyword, 0, 21, COMPOUND_STRING_TABLE, "COMPOUND_STRING_TABLE"},
    {tkn_k_class_reserved, 0, 8, CONTROLS, "CONTROLS"},
    {tkn_k_class_charset, sym_k_dos_cyrillic_charset, 5, CHARSET_NAME, "CP866"},
    {tkn_k_class_charset, sym_k_dos_cyrillic_charset, 12, CHARSET_NAME, "DOS_CYRILLIC"},
    {tkn_k_class_class, sym_k_DtEditor_object, 8, CLASS_NAME, "DTEDITOR"},
    {tkn_k_class_class, sym_k_DtHelpDialog_object, 12, CLASS_NAME, "DTHELPDIALOG"},
    {tkn_k_class_class, sym_k_DtHelpQuickDialog_object, 17, CLASS_NAME, "DTHELPQUICKDIALOG"},
    {tkn_k_class_enumval, sym_k_DtHELP_AS_NEEDED_SCROLLBARS_enumval, 27, ENUMVAL_NAME, "DTHELP_AS_NEEDED_SCROLLBARS"},
    {tkn_k_class_enumval, sym_k_DtHELP_EXECUTE_ALL_enumval, 18, ENUMVAL_NAME, "DTHELP_EXECUTE_ALL"},
    {tkn_k_class_enumval, sym_k_DtHELP_EXECUTE_NONE_enumval, 19, ENUMVAL_NAME, "DTHELP_EXECUTE_NONE"},
    {tkn_k_class_enumval, sym_k_DtHELP_EXECUTE_QUERY_ALL_enumval, 24, ENUMVAL_NAME, "DTHELP_EXECUTE_QUERY_ALL"},
    {tkn_k_class_enumval, sym_k_DtHELP_EXECUTE_QUERY_UNALIASED_enumval, 30, ENUMVAL_NAME, "DTHELP_EXECUTE_QUERY_UNALIASED"},
    {tkn_k_class_enumval, sym_k_DtHELP_NO_SCROLLBARS_enumval, 20, ENUMVAL_NAME, "DTHELP_NO_SCROLLBARS"},
    {tkn_k_class_enumval, sym_k_DtHELP_PAPERSIZE_A4_enumval, 19, ENUMVAL_NAME, "DTHELP_PAPERSIZE_A4"},
    {tkn_k_class_enumval, sym_k_DtHELP_PAPERSIZE_B5_enumval, 19, ENUMVAL_NAME, "DTHELP_PAPERSIZE_B5"},
    {tkn_k_class_enumval, sym_k_DtHELP_PAPERSIZE_EXECUTIVE_enumval, 26, ENUMVAL_NAME, "DTHELP_PAPERSIZE_EXECUTIVE"},
    {tkn_k_class_enumval, sym_k_DtHELP_PAPERSIZE_LEGAL_enumval, 22, ENUMVAL_NAME, "DTHELP_PAPERSIZE_LEGAL"},
    {tkn_k_class_enumval, sym_k_DtHELP_PAPERSIZE_LETTER_enumval, 23, ENUMVAL_NAME, "DTHELP_PAPERSIZE_LETTER"},
    {tkn_k_class_enumval, sym_k_DtHELP_STATIC_SCROLLBARS_enumval, 24, ENUMVAL_NAME, "DTHELP_STATIC_SCROLLBARS"},
    {tkn_k_class_enumval, sym_k_DtHELP_TYPE_DYNAMIC_STRING_enumval, 26, ENUMVAL_NAME, "DTHELP_TYPE_DYNAMIC_STRING"},
    {tkn_k_class_enumval, sym_k_DtHELP_TYPE_FILE_enumval, 16, ENUMVAL_NAME, "DTHELP_TYPE_FILE"},
    {tkn_k_class_enumval, sym_k_DtHELP_TYPE_MAN_PAGE_enumval, 20, ENUMVAL_NAME, "DTHELP_TYPE_MAN_PAGE"},
    {tkn_k_class_enumval, sym_k_DtHELP_TYPE_STRING_enumval, 18, ENUMVAL_NAME, "DTHELP_TYPE_STRING"},
    {tkn_k_class_enumval, sym_k_DtHELP_TYPE_TOPIC_enumval, 17, ENUMVAL_NAME, "DTHELP_TYPE_TOPIC"},
    {tkn_k_class_enumval, sym_k_DtLONG_NAME_enumval, 11, ENUMVAL_NAME, "DTLONG_NAME"},
    {tkn_k_class_enumval, sym_k_DtMEDIUM_NAME_enumval, 13, ENUMVAL_NAME, "DTMEDIUM_NAME"},
    {tkn_k_class_class, sym_k_DtMenuButton_object, 12, CLASS_NAME, "DTMENUBUTTON"},
    {tkn_k_class_argument, sym_k_DtNallowSendEvents_arg, 18, ARGUMENT_NAME, "DTNALLOWSENDEVENTS"},
    {tkn_k_class_argument, sym_k_DtNappCursorDefault_arg, 19, ARGUMENT_NAME, "DTNAPPCURSORDEFAULT"},
    {tkn_k_class_argument, sym_k_DtNappKeypadDefault_arg, 19, ARGUMENT_NAME, "DTNAPPKEYPADDEFAULT"},
    {tkn_k_class_argument, sym_k_DtNautoShowCursorPosition_arg, 25, ARGUMENT_NAME, "DTNAUTOSHOWCURSORPOSITION"},
    {tkn_k_class_argument, sym_k_DtNautoWrap_arg, 11, ARGUMENT_NAME, "DTNAUTOWRAP"},
    {tkn_k_class_argument, sym_k_DtNbackgroundIsSelect_arg, 21, ARGUMENT_NAME, "DTNBACKGROUNDISSELECT"},
    {tkn_k_class_argument, sym_k_DtNbackLabelString_arg, 18, ARGUMENT_NAME, "DTNBACKLABELSTRING"},
    {tkn_k_class_argument, sym_k_DtNbaseHeight_arg, 13, ARGUMENT_NAME, "DTNBASEHEIGHT"},
    {tkn_k_class_argument, sym_k_DtNbaseWidth_arg, 12, ARGUMENT_NAME, "DTNBASEWIDTH"},
    {tkn_k_class_argument, sym_k_DtNblinkRate_arg, 12, ARGUMENT_NAME, "DTNBLINKRATE"},
    {tkn_k_class_argument, sym_k_DtNbuttonFontList_arg, 17, ARGUMENT_NAME, "DTNBUTTONFONTLIST"},
    {tkn_k_class_argument, sym_k_DtNc132_arg, 7, ARGUMENT_NAME, "DTNC132"},
    {tkn_k_class_reason, sym_k_DtNcancelCallback_reason, 17, REASON_NAME, "DTNCANCELCALLBACK"},
    {tkn_k_class_argument, sym_k_DtNcascadePixmap_arg, 16, ARGUMENT_NAME, "DTNCASCADEPIXMAP"},
    {tkn_k_class_reason, sym_k_DtNcascadingCallback_reason, 20, REASON_NAME, "DTNCASCADINGCALLBACK"},
    {tkn_k_class_argument, sym_k_DtNcenterToggleLabel_arg, 20, ARGUMENT_NAME, "DTNCENTERTOGGLELABEL"},
    {tkn_k_class_argument, sym_k_DtNchangeAllButtonLabel_arg, 23, ARGUMENT_NAME, "DTNCHANGEALLBUTTONLABEL"},
    {tkn_k_class_argument, sym_k_DtNchangeButtonLabel_arg, 20, ARGUMENT_NAME, "DTNCHANGEBUTTONLABEL"},
    {tkn_k_class_argument, sym_k_DtNchangeFieldLabel_arg, 19, ARGUMENT_NAME, "DTNCHANGEFIELDLABEL"},
    {tkn_k_class_argument, sym_k_DtNcharCursorStyle_arg, 18, ARGUMENT_NAME, "DTNCHARCURSORSTYLE"},
    {tkn_k_class_reason, sym_k_DtNcloseCallback_reason, 16, REASON_NAME, "DTNCLOSECALLBACK"},
    {tkn_k_class_argument, sym_k_DtNcloseLabelString_arg, 19, ARGUMENT_NAME, "DTNCLOSELABELSTRING"},
    {tkn_k_class_reason, sym_k_DtNclosePrintDisplayCallback_reason, 28, REASON_NAME, "DTNCLOSEPRINTDISPLAYCALLBACK"},
    {tkn_k_class_argument, sym_k_DtNcolumns_arg, 10, ARGUMENT_NAME, "DTNCOLUMNS"},
    {tkn_k_class_argument, sym_k_DtNconsoleMode_arg, 14, ARGUMENT_NAME, "DTNCONSOLEMODE"},
    {tkn_k_class_argument, sym_k_DtNcopies_arg, 9, ARGUMENT_NAME, "DTNCOPIES"},
    {tkn_k_class_argument, sym_k_DtNcsWidth_arg, 10, ARGUMENT_NAME, "DTNCSWIDTH"},
    {tkn_k_class_argument, sym_k_DtNcurrentLineLabel_arg, 19, ARGUMENT_NAME, "DTNCURRENTLINELABEL"},
    {tkn_k_class_argument, sym_k_DtNcursorPosition_arg, 17, ARGUMENT_NAME, "DTNCURSORPOSITION"},
    {tkn_k_class_argument, sym_k_DtNcursorPositionVisible_arg, 24, ARGUMENT_NAME, "DTNCURSORPOSITIONVISIBLE"},
    {tkn_k_class_argument, sym_k_DtNdescription_arg, 14, ARGUMENT_NAME, "DTNDESCRIPTION"},
    {tkn_k_class_argument, sym_k_DtNdialogTitle_arg, 14, ARGUMENT_NAME, "DTNDIALOGTITLE"},
    {tkn_k_class_argument, sym_k_DtNeditable_arg, 11, ARGUMENT_NAME, "DTNEDITABLE"},
    {tkn_k_class_argument, sym_k_DtNemulationId_arg, 14, ARGUMENT_NAME, "DTNEMULATIONID"},
    {tkn_k_class_argument, sym_k_DtNexecutionPolicy_arg, 18, ARGUMENT_NAME, "DTNEXECUTIONPOLICY"},
    {tkn_k_class_argument, sym_k_DtNfileName_arg, 11, ARGUMENT_NAME, "DTNFILENAME"},
    {tkn_k_class_argument, sym_k_DtNfindButtonLabel_arg, 18, ARGUMENT_NAME, "DTNFINDBUTTONLABEL"},
    {tkn_k_class_argument, sym_k_DtNfindChangeDialogTitle_arg, 24, ARGUMENT_NAME, "DTNFINDCHANGEDIALOGTITLE"},
    {tkn_k_class_argument, sym_k_DtNfindFieldLabel_arg, 17, ARGUMENT_NAME, "DTNFINDFIELDLABEL"},
    {tkn_k_class_argument, sym_k_DtNformatAllButtonLabel_arg, 23, ARGUMENT_NAME, "DTNFORMATALLBUTTONLABEL"},
    {tkn_k_class_argument, sym_k_DtNformatParagraphButtonLabel_arg, 29, ARGUMENT_NAME, "DTNFORMATPARAGRAPHBUTTONLABEL"},
    {tkn_k_class_argument, sym_k_DtNformatSettingsDialogTitle_arg, 28, ARGUMENT_NAME, "DTNFORMATSETTINGSDIALOGTITLE"},
    {tkn_k_class_argument, sym_k_DtNheightInc_arg, 12, ARGUMENT_NAME, "DTNHEIGHTINC"},
    {tkn_k_class_argument, sym_k_DtNhelpFile_arg, 11, ARGUMENT_NAME, "DTNHELPFILE"},
    {tkn_k_class_argument, sym_k_DtNhelpLabelString_arg, 18, ARGUMENT_NAME, "DTNHELPLABELSTRING"},
    {tkn_k_class_argument, sym_k_DtNhelpOnHelpVolume_arg, 19, ARGUMENT_NAME, "DTNHELPONHELPVOLUME"},
    {tkn_k_class_argument, sym_k_DtNhelpPrint_arg, 12, ARGUMENT_NAME, "DTNHELPPRINT"},
    {tkn_k_class_argument, sym_k_DtNhelpType_arg, 11, ARGUMENT_NAME, "DTNHELPTYPE"},
    {tkn_k_class_argument, sym_k_DtNhelpVolume_arg, 13, ARGUMENT_NAME, "DTNHELPVOLUME"},
    {tkn_k_class_reason, sym_k_DtNhyperLinkCallback_reason, 20, REASON_NAME, "DTNHYPERLINKCALLBACK"},
    {tkn_k_class_argument, sym_k_DtNinformationDialogTitle_arg, 25, ARGUMENT_NAME, "DTNINFORMATIONDIALOGTITLE"},
    {tkn_k_class_reason, sym_k_DtNinputVerifyCallback_reason, 22, REASON_NAME, "DTNINPUTVERIFYCALLBACK"},
    {tkn_k_class_argument, sym_k_DtNinsertLabel_arg, 14, ARGUMENT_NAME, "DTNINSERTLABEL"},
    {tkn_k_class_argument, sym_k_DtNjumpScroll_arg, 13, ARGUMENT_NAME, "DTNJUMPSCROLL"},
    {tkn_k_class_argument, sym_k_DtNjustifyToggleLabel_arg, 21, ARGUMENT_NAME, "DTNJUSTIFYTOGGLELABEL"},
    {tkn_k_class_argument, sym_k_DtNkshMode_arg, 10, ARGUMENT_NAME, "DTNKSHMODE"},
    {tkn_k_class_argument, sym_k_DtNlabelFontList_arg, 16, ARGUMENT_NAME, "DTNLABELFONTLIST"},
    {tkn_k_class_argument, sym_k_DtNleftAlignToggleLabel_arg, 23, ARGUMENT_NAME, "DTNLEFTALIGNTOGGLELABEL"},
    {tkn_k_class_argument, sym_k_DtNleftMarginFieldLabel_arg, 23, ARGUMENT_NAME, "DTNLEFTMARGINFIELDLABEL"},
    {tkn_k_class_argument, sym_k_DtNlocationId_arg, 13, ARGUMENT_NAME, "DTNLOCATIONID"},
    {tkn_k_class_argument, sym_k_DtNlogFile_arg, 10, ARGUMENT_NAME, "DTNLOGFILE"},
    {tkn_k_class_argument, sym_k_DtNlogging_arg, 10, ARGUMENT_NAME, "DTNLOGGING"},
    {tkn_k_class_argument, sym_k_DtNlogInhibit_arg, 13, ARGUMENT_NAME, "DTNLOGINHIBIT"},
    {tkn_k_class_argument, sym_k_DtNmanPage_arg, 10, ARGUMENT_NAME, "DTNMANPAGE"},
    {tkn_k_class_argument, sym_k_DtNmapOnOutput_arg, 14, ARGUMENT_NAME, "DTNMAPONOUTPUT"},
    {tkn_k_class_argument, sym_k_DtNmapOnOutputDelay_arg, 19, ARGUMENT_NAME, "DTNMAPONOUTPUTDELAY"},
    {tkn_k_class_argument, sym_k_DtNmarginBell_arg, 13, ARGUMENT_NAME, "DTNMARGINBELL"},
    {tkn_k_class_argument, sym_k_DtNmarginHeight_arg, 15, ARGUMENT_NAME, "DTNMARGINHEIGHT"},
    {tkn_k_class_argument, sym_k_DtNmarginWidth_arg, 14, ARGUMENT_NAME, "DTNMARGINWIDTH"},
    {tkn_k_class_argument, sym_k_DtNmaxLength_arg, 12, ARGUMENT_NAME, "DTNMAXLENGTH"},
    {tkn_k_class_argument, sym_k_DtNminimizeButtons_arg, 18, ARGUMENT_NAME, "DTNMINIMIZEBUTTONS"},
    {tkn_k_class_argument, sym_k_DtNmisspelledListLabel_arg, 22, ARGUMENT_NAME, "DTNMISSPELLEDLISTLABEL"},
    {tkn_k_class_argument, sym_k_DtNmoreLabelString_arg, 18, ARGUMENT_NAME, "DTNMORELABELSTRING"},
    {tkn_k_class_argument, sym_k_DtNnMarginBell_arg, 14, ARGUMENT_NAME, "DTNNMARGINBELL"},
    {tkn_k_class_reason, sym_k_DtNoutputLogCallback_reason, 20, REASON_NAME, "DTNOUTPUTLOGCALLBACK"},
    {tkn_k_class_argument, sym_k_DtNoverstrike_arg, 13, ARGUMENT_NAME, "DTNOVERSTRIKE"},
    {tkn_k_class_argument, sym_k_DtNoverstrikeLabel_arg, 18, ARGUMENT_NAME, "DTNOVERSTRIKELABEL"},
    {tkn_k_class_argument, sym_k_DtNpaperSize_arg, 12, ARGUMENT_NAME, "DTNPAPERSIZE"},
    {tkn_k_class_argument, sym_k_DtNpointerBlank_arg, 15, ARGUMENT_NAME, "DTNPOINTERBLANK"},
    {tkn_k_class_argument, sym_k_DtNpointerBlankDelay_arg, 20, ARGUMENT_NAME, "DTNPOINTERBLANKDELAY"},
    {tkn_k_class_argument, sym_k_DtNpointerColor_arg, 15, ARGUMENT_NAME, "DTNPOINTERCOLOR"},
    {tkn_k_class_argument, sym_k_DtNpointerColorBackground_arg, 25, ARGUMENT_NAME, "DTNPOINTERCOLORBACKGROUND"},
    {tkn_k_class_argument, sym_k_DtNpointerShape_arg, 15, ARGUMENT_NAME, "DTNPOINTERSHAPE"},
    {tkn_k_class_reason, sym_k_DtNprintCallback_reason, 16, REASON_NAME, "DTNPRINTCALLBACK"},
    {tkn_k_class_argument, sym_k_DtNprintDestination_arg, 19, ARGUMENT_NAME, "DTNPRINTDESTINATION"},
    {tkn_k_class_argument, sym_k_DtNprinter_arg, 10, ARGUMENT_NAME, "DTNPRINTER"},
    {tkn_k_class_argument, sym_k_DtNprinterInfoProc_arg, 18, ARGUMENT_NAME, "DTNPRINTERINFOPROC"},
    {tkn_k_class_argument, sym_k_DtNprinterName_arg, 14, ARGUMENT_NAME, "DTNPRINTERNAME"},
    {tkn_k_class_argument, sym_k_DtNprintLabelString_arg, 19, ARGUMENT_NAME, "DTNPRINTLABELSTRING"},
    {tkn_k_class_argument, sym_k_DtNprintSetupMode_arg, 17, ARGUMENT_NAME, "DTNPRINTSETUPMODE"},
    {tkn_k_class_argument, sym_k_DtNreverseVideo_arg, 15, ARGUMENT_NAME, "DTNREVERSEVIDEO"},
    {tkn_k_class_argument, sym_k_DtNreverseWrap_arg, 14, ARGUMENT_NAME, "DTNREVERSEWRAP"},
    {tkn_k_class_argument, sym_k_DtNrightAlignToggleLabel_arg, 24, ARGUMENT_NAME, "DTNRIGHTALIGNTOGGLELABEL"},
    {tkn_k_class_argument, sym_k_DtNrightMarginFieldLabel_arg, 24, ARGUMENT_NAME, "DTNRIGHTMARGINFIELDLABEL"},
    {tkn_k_class_argument, sym_k_DtNrows_arg, 7, ARGUMENT_NAME, "DTNROWS"},
    {tkn_k_class_argument, sym_k_DtNsaveLines_arg, 12, ARGUMENT_NAME, "DTNSAVELINES"},
    {tkn_k_class_argument, sym_k_DtNscrollBarPolicy_arg, 18, ARGUMENT_NAME, "DTNSCROLLBARPOLICY"},
    {tkn_k_class_argument, sym_k_DtNscrollHorizontal_arg, 19, ARGUMENT_NAME, "DTNSCROLLHORIZONTAL"},
    {tkn_k_class_argument, sym_k_DtNscrollLeftSide_arg, 17, ARGUMENT_NAME, "DTNSCROLLLEFTSIDE"},
    {tkn_k_class_argument, sym_k_DtNscrollTopSide_arg, 16, ARGUMENT_NAME, "DTNSCROLLTOPSIDE"},
    {tkn_k_class_argument, sym_k_DtNscrollVertical_arg, 17, ARGUMENT_NAME, "DTNSCROLLVERTICAL"},
    {tkn_k_class_argument, sym_k_DtNselectFileProc_arg, 17, ARGUMENT_NAME, "DTNSELECTFILEPROC"},
    {tkn_k_class_argument, sym_k_DtNselectPrinterProc_arg, 20, ARGUMENT_NAME, "DTNSELECTPRINTERPROC"},
    {tkn_k_class_reason, sym_k_DtNsetupCallback_reason, 16, REASON_NAME, "DTNSETUPCALLBACK"},
    {tkn_k_class_argument, sym_k_DtNshadowType_arg, 13, ARGUMENT_NAME, "DTNSHADOWTYPE"},
    {tkn_k_class_argument, sym_k_DtNshowNewWindowButton_arg, 22, ARGUMENT_NAME, "DTNSHOWNEWWINDOWBUTTON"},
    {tkn_k_class_argument, sym_k_DtNshowStatusLine_arg, 17, ARGUMENT_NAME, "DTNSHOWSTATUSLINE"},
    {tkn_k_class_argument, sym_k_DtNspellDialogTitle_arg, 19, ARGUMENT_NAME, "DTNSPELLDIALOGTITLE"},
    {tkn_k_class_argument, sym_k_DtNspellFilter_arg, 14, ARGUMENT_NAME, "DTNSPELLFILTER"},
    {tkn_k_class_reason, sym_k_DtNstatusChangeCallback_reason, 23, REASON_NAME, "DTNSTATUSCHANGECALLBACK"},
    {tkn_k_class_argument, sym_k_DtNstickyNextCursor_arg, 19, ARGUMENT_NAME, "DTNSTICKYNEXTCURSOR"},
    {tkn_k_class_argument, sym_k_DtNstickyPrevCursor_arg, 19, ARGUMENT_NAME, "DTNSTICKYPREVCURSOR"},
    {tkn_k_class_argument, sym_k_DtNstringData_arg, 13, ARGUMENT_NAME, "DTNSTRINGDATA"},
    {tkn_k_class_argument, sym_k_DtNsubMenuId_arg, 12, ARGUMENT_NAME, "DTNSUBMENUID"},
    {tkn_k_class_argument, sym_k_DtNsubprocessArgv_arg, 17, ARGUMENT_NAME, "DTNSUBPROCESSARGV"},
    {tkn_k_class_argument, sym_k_DtNsubprocessCmd_arg, 16, ARGUMENT_NAME, "DTNSUBPROCESSCMD"},
    {tkn_k_class_argument, sym_k_DtNsubprocessExec_arg, 17, ARGUMENT_NAME, "DTNSUBPROCESSEXEC"},
    {tkn_k_class_argument, sym_k_DtNsubprocessLoginShell_arg, 23, ARGUMENT_NAME, "DTNSUBPROCESSLOGINSHELL"},
    {tkn_k_class_argument, sym_k_DtNsubprocessPid_arg, 16, ARGUMENT_NAME, "DTNSUBPROCESSPID"},
    {tkn_k_class_reason, sym_k_DtNsubprocessTerminationCallback_reason, 32, REASON_NAME, "DTNSUBPROCESSTERMINATIONCALLBACK"},
    {tkn_k_class_argument, sym_k_DtNsubprocessTerminationCatch_arg, 29, ARGUMENT_NAME, "DTNSUBPROCESSTERMINATIONCATCH"},
    {tkn_k_class_argument, sym_k_DtNsunFunctionKeys_arg, 18, ARGUMENT_NAME, "DTNSUNFUNCTIONKEYS"},
    {tkn_k_class_argument, sym_k_DtNtermDevice_arg, 13, ARGUMENT_NAME, "DTNTERMDEVICE"},
    {tkn_k_class_argument, sym_k_DtNtermDeviceAllocate_arg, 21, ARGUMENT_NAME, "DTNTERMDEVICEALLOCATE"},
    {tkn_k_class_argument, sym_k_DtNtermId_arg, 9, ARGUMENT_NAME, "DTNTERMID"},
    {tkn_k_class_argument, sym_k_DtNtermName_arg, 11, ARGUMENT_NAME, "DTNTERMNAME"},
    {tkn_k_class_argument, sym_k_DtNtermSlaveName_arg, 16, ARGUMENT_NAME, "DTNTERMSLAVENAME"},
    {tkn_k_class_argument, sym_k_DtNtextBackground_arg, 17, ARGUMENT_NAME, "DTNTEXTBACKGROUND"},
    {tkn_k_class_reason, sym_k_DtNtextDeselectCallback_reason, 23, REASON_NAME, "DTNTEXTDESELECTCALLBACK"},
    {tkn_k_class_argument, sym_k_DtNtextFontList_arg, 15, ARGUMENT_NAME, "DTNTEXTFONTLIST"},
    {tkn_k_class_argument, sym_k_DtNtextForeground_arg, 17, ARGUMENT_NAME, "DTNTEXTFOREGROUND"},
    {tkn_k_class_reason, sym_k_DtNtextSelectCallback_reason, 21, REASON_NAME, "DTNTEXTSELECTCALLBACK"},
    {tkn_k_class_argument, sym_k_DtNtextTranslations_arg, 19, ARGUMENT_NAME, "DTNTEXTTRANSLATIONS"},
    {tkn_k_class_argument, sym_k_DtNtopCharacter_arg, 15, ARGUMENT_NAME, "DTNTOPCHARACTER"},
    {tkn_k_class_argument, sym_k_DtNtopicTitle_arg, 13, ARGUMENT_NAME, "DTNTOPICTITLE"},
    {tkn_k_class_argument, sym_k_DtNtotalLineCountLabel_arg, 22, ARGUMENT_NAME, "DTNTOTALLINECOUNTLABEL"},
    {tkn_k_class_argument, sym_k_DtNttyModes_arg, 11, ARGUMENT_NAME, "DTNTTYMODES"},
    {tkn_k_class_argument, sym_k_DtNuserBoldFont_arg, 15, ARGUMENT_NAME, "DTNUSERBOLDFONT"},
    {tkn_k_class_argument, sym_k_DtNuserFont_arg, 11, ARGUMENT_NAME, "DTNUSERFONT"},
    {tkn_k_class_argument, sym_k_DtNverifyPrinterProc_arg, 20, ARGUMENT_NAME, "DTNVERIFYPRINTERPROC"},
    {tkn_k_class_argument, sym_k_DtNverticalScrollBar_arg, 20, ARGUMENT_NAME, "DTNVERTICALSCROLLBAR"},
    {tkn_k_class_argument, sym_k_DtNvisiblePathCount_arg, 19, ARGUMENT_NAME, "DTNVISIBLEPATHCOUNT"},
    {tkn_k_class_argument, sym_k_DtNvisualBell_arg, 13, ARGUMENT_NAME, "DTNVISUALBELL"},
    {tkn_k_class_argument, sym_k_DtNwidthInc_arg, 11, ARGUMENT_NAME, "DTNWIDTHINC"},
    {tkn_k_class_argument, sym_k_DtNwordWrap_arg, 11, ARGUMENT_NAME, "DTNWORDWRAP"},
    {tkn_k_class_argument, sym_k_DtNworkAreaLocation_arg, 19, ARGUMENT_NAME, "DTNWORKAREALOCATION"},
    {tkn_k_class_class, sym_k_DtPrintSetupBox_object, 15, CLASS_NAME, "DTPRINTSETUPBOX"},
    {tkn_k_class_class, sym_k_DtPrintSetupDialog_object, 18, CLASS_NAME, "DTPRINTSETUPDIALOG"},
    {tkn_k_class_enumval, sym_k_DtPRINT_CLOSE_CONNECTION_enumval, 24, ENUMVAL_NAME, "DTPRINT_CLOSE_CONNECTION"},
    {tkn_k_class_enumval, sym_k_DtPRINT_NO_DESTINATION_enumval, 22, ENUMVAL_NAME, "DTPRINT_NO_DESTINATION"},
    {tkn_k_class_enumval, sym_k_DtPRINT_RELEASE_CONNECTION_enumval, 26, ENUMVAL_NAME, "DTPRINT_RELEASE_CONNECTION"},
    {tkn_k_class_enumval, sym_k_DtPRINT_SETUP_PLAIN_enumval, 19, ENUMVAL_NAME, "DTPRINT_SETUP_PLAIN"},
    {tkn_k_class_enumval, sym_k_DtPRINT_SETUP_XP_enumval, 16, ENUMVAL_NAME, "DTPRINT_SETUP_XP"},
    {tkn_k_class_enumval, sym_k_DtPRINT_TO_FILE_enumval, 15, ENUMVAL_NAME, "DTPRINT_TO_FILE"},
    {tkn_k_class_enumval, sym_k_DtPRINT_TO_PRINTER_enumval, 18, ENUMVAL_NAME, "DTPRINT_TO_PRINTER"},
    {tkn_k_class_enumval, sym_k_DtSHADOW_ETCHED_IN_enumval, 18, ENUMVAL_NAME, "DTSHADOW_ETCHED_IN"},
    {tkn_k_class_enumval, sym_k_DtSHADOW_ETCHED_OUT_enumval, 19, ENUMVAL_NAME, "DTSHADOW_ETCHED_OUT"},
    {tkn_k_class_enumval, sym_k_DtSHADOW_IN_enumval, 11, ENUMVAL_NAME, "DTSHADOW_IN"},
    {tkn_k_class_enumval, sym_k_DtSHADOW_OUT_enumval, 12, ENUMVAL_NAME, "DTSHADOW_OUT"},
    {tkn_k_class_enumval, sym_k_DtSHORT_NAME_enumval, 12, ENUMVAL_NAME, "DTSHORT_NAME"},
    {tkn_k_class_class, sym_k_DtTerm_object, 6, CLASS_NAME, "DTTERM"},
    {tkn_k_class_class, sym_k_DtTermPrimitive_object, 15, CLASS_NAME, "DTTERMPRIMITIVE"},
    {tkn_k_class_enumval, sym_k_DtTERM_CHAR_CURSOR_BAR_enumval, 22, ENUMVAL_NAME, "DTTERM_CHAR_CURSOR_BAR"},
    {tkn_k_class_enumval, sym_k_DtTERM_CHAR_CURSOR_BOX_enumval, 22, ENUMVAL_NAME, "DTTERM_CHAR_CURSOR_BOX"},
    {tkn_k_class_enumval, sym_k_DtTERM_CHAR_CURSOR_INVISIBLE_enumval, 28, ENUMVAL_NAME, "DTTERM_CHAR_CURSOR_INVISIBLE"},
    {tkn_k_class_enumval, sym_k_DtWORK_AREA_BOTTOM_enumval, 18, ENUMVAL_NAME, "DTWORK_AREA_BOTTOM"},
    {tkn_k_class_enumval, sym_k_DtWORK_AREA_NONE_enumval, 16, ENUMVAL_NAME, "DTWORK_AREA_NONE"},
    {tkn_k_class_enumval, sym_k_DtWORK_AREA_TOP_enumval, 15, ENUMVAL_NAME, "DTWORK_AREA_TOP"},
    {tkn_k_class_enumval, sym_k_DtWORK_AREA_TOP_AND_BOTTOM_enumval, 26, ENUMVAL_NAME, "DTWORK_AREA_TOP_AND_BOTTOM"},
    {tkn_k_class_reserved, 0, 3, END, "END"},
    {tkn_k_class_charset, sym_k_euc_charset, 3, CHARSET_NAME, "EUC"},
    {tkn_k_class_reserved, 0, 8, EXPORTED, "EXPORTED"},
    {tkn_k_class_reserved, 0, 5, UILFALSE, "FALSE"},
    {tkn_k_class_enumval, sym_k_FALSE_enumval, 5, ENUMVAL_NAME, "FALSE"},
    {tkn_k_class_keyword, 0, 4, UILFILE, "FILE"},
    {tkn_k_class_keyword, 0, 5, FLOAT, "FLOAT"},
    {tkn_k_class_keyword, 0, 4, FONT, "FONT"},
    {tkn_k_class_keyword, 0, 7, FONTSET, "FONTSET"},
    {tkn_k_class_keyword, 0, 10, FONT_TABLE, "FONT_TABLE"},
    {tkn_k_class_keyword, 0, 9, FONT_UNIT, "FONT_UNIT"},
    {tkn_k_class_keyword, 0, 10, FONT_UNITS, "FONT_UNITS"},
    {tkn_k_class_keyword, 0, 10, FOREGROUND, "FOREGROUND"},
    {tkn_k_class_keyword, 0, 2, FU, "FU"},
    {tkn_k_class_reserved, 0, 6, GADGET, "GADGET"},
    {tkn_k_class_charset, sym_k_gb_hanzi_charset, 10, CHARSET_NAME, "GB_CHINESE"},
    {tkn_k_class_charset, sym_k_gb_hanzi_charset, 8, CHARSET_NAME, "GB_HANZI"},
    {tkn_k_class_charset, sym_k_gb_hanzi_charset, 11, CHARSET_NAME, "GB_HANZI_GL"},
    {tkn_k_class_charset, sym_k_gb_hanzi_gr_charset, 11, CHARSET_NAME, "GB_HANZI_GR"},
    {tkn_k_class_charset, sym_k_dos_cyrillic_charset, 7, CHARSET_NAME, "IBM-866"},
    {tkn_k_class_keyword, 0, 4, ICON, "ICON"},
    {tkn_k_class_enumval, sym_k_IconicState_enumval, 11, ENUMVAL_NAME, "ICONICSTATE"},
    {tkn_k_class_reserved, 0, 10, IDENTIFIER, "IDENTIFIER"},
    {tkn_k_class_keyword, 0, 8, IMPORTED, "IMPORTED"},
    {tkn_k_class_keyword, 0, 2, IN, "IN"},
    {tkn_k_class_keyword, 0, 4, INCH, "INCH"},
    {tkn_k_class_keyword, 0, 6, INCHES, "INCHES"},
    {tkn_k_class_reserved, 0, 7, INCLUDE, "INCLUDE"},
    {tkn_k_class_keyword, 0, 7, INTEGER, "INTEGER"},
    {tkn_k_class_keyword, 0, 13, INTEGER_TABLE, "INTEGER_TABLE"},
    {tkn_k_class_charset, sym_k_iso_cyrillic_charset, 10, CHARSET_NAME, "ISO-8859-5"},
    {tkn_k_class_charset, sym_k_iso_latin1_charset, 9, CHARSET_NAME, "ISOLATIN1"},
    {tkn_k_class_charset, sym_k_iso_latin2_charset, 9, CHARSET_NAME, "ISOLATIN2"},
    {tkn_k_class_charset, sym_k_iso_latin3_charset, 9, CHARSET_NAME, "ISOLATIN3"},
    {tkn_k_class_charset, sym_k_iso_latin4_charset, 9, CHARSET_NAME, "ISOLATIN4"},
    {tkn_k_class_charset, sym_k_iso_latin5_charset, 9, CHARSET_NAME, "ISOLATIN5"},
    {tkn_k_class_charset, sym_k_iso_arabic_charset, 9, CHARSET_NAME, "ISOLATIN6"},
    {tkn_k_class_charset, sym_k_iso_greek_charset, 9, CHARSET_NAME, "ISOLATIN7"},
    {tkn_k_class_charset, sym_k_iso_hebrew_charset, 9, CHARSET_NAME, "ISOLATIN8"},
    {tkn_k_class_charset, sym_k_iso_arabic_charset, 10, CHARSET_NAME, "ISO_ARABIC"},
    {tkn_k_class_charset, sym_k_iso_arabic_lr_charset, 13, CHARSET_NAME, "ISO_ARABIC_LR"},
    {tkn_k_class_charset, sym_k_iso_cyrillic_charset, 12, CHARSET_NAME, "ISO_CYRILLIC"},
    {tkn_k_class_charset, sym_k_iso_greek_charset, 9, CHARSET_NAME, "ISO_GREEK"},
    {tkn_k_class_charset, sym_k_iso_hebrew_charset, 10, CHARSET_NAME, "ISO_HEBREW"},
    {tkn_k_class_charset, sym_k_iso_hebrew_lr_charset, 13, CHARSET_NAME, "ISO_HEBREW_LR"},
    {tkn_k_class_charset, sym_k_iso_ir_111_charset, 10, CHARSET_NAME, "ISO_IR_111"},
    {tkn_k_class_charset, sym_k_iso_latin1_charset, 10, CHARSET_NAME, "ISO_LATIN1"},
    {tkn_k_class_charset, sym_k_iso_latin2_charset, 10, CHARSET_NAME, "ISO_LATIN2"},
    {tkn_k_class_charset, sym_k_iso_latin3_charset, 10, CHARSET_NAME, "ISO_LATIN3"},
    {tkn_k_class_charset, sym_k_iso_latin4_charset, 10, CHARSET_NAME, "ISO_LATIN4"},
    {tkn_k_class_charset, sym_k_iso_latin5_charset, 10, CHARSET_NAME, "ISO_LATIN5"},
    {tkn_k_class_charset, sym_k_iso_arabic_charset, 10, CHARSET_NAME, "ISO_LATIN6"},
    {tkn_k_class_charset, sym_k_iso_arabic_lr_charset, 13, CHARSET_NAME, "ISO_LATIN6_LR"},
    {tkn_k_class_charset, sym_k_iso_greek_charset, 10, CHARSET_NAME, "ISO_LATIN7"},
    {tkn_k_class_charset, sym_k_iso_hebrew_charset, 10, CHARSET_NAME, "ISO_LATIN8"},
    {tkn_k_class_charset, sym_k_iso_hebrew_lr_charset, 13, CHARSET_NAME, "ISO_LATIN8_LR"},
    {tkn_k_class_charset, sym_k_jis_kanji_charset, 12, CHARSET_NAME, "JIS_JAPANESE"},
    {tkn_k_class_charset, sym_k_jis_kanji_charset, 9, CHARSET_NAME, "JIS_KANJI"},
    {tkn_k_class_charset, sym_k_jis_kanji_charset, 12, CHARSET_NAME, "JIS_KANJI_GL"},
    {tkn_k_class_charset, sym_k_jis_kanji_gr_charset, 12, CHARSET_NAME, "JIS_KANJI_GR"},
    {tkn_k_class_charset, sym_k_jis_katakana_charset, 12, CHARSET_NAME, "JIS_KATAKANA"},
    {tkn_k_class_keyword, 0, 6, KEYSYM, "KEYSYM"},
    {tkn_k_class_charset, sym_k_iso_ir_111_charset, 6, CHARSET_NAME, "KOI8-R"},
    {tkn_k_class_charset, sym_k_iso_ir_111_charset, 7, CHARSET_NAME, "KOI8-RU"},
    {tkn_k_class_charset, sym_k_iso_ir_111_charset, 6, CHARSET_NAME, "KOI8-U"},
    {tkn_k_class_charset, sym_k_iso_ir_111_charset, 5, CHARSET_NAME, "KOI8R"},
    {tkn_k_class_charset, sym_k_iso_ir_111_charset, 6, CHARSET_NAME, "KOI8RU"},
    {tkn_k_class_charset, sym_k_iso_ir_111_charset, 5, CHARSET_NAME, "KOI8U"},
    {tkn_k_class_charset, sym_k_ksc_hangul_charset, 10, CHARSET_NAME, "KSC_HANGUL"},
    {tkn_k_class_charset, sym_k_ksc_hangul_charset, 13, CHARSET_NAME, "KSC_HANGUL_GL"},
    {tkn_k_class_charset, sym_k_ksc_hangul_gr_charset, 13, CHARSET_NAME, "KSC_HANGUL_GR"},
    {tkn_k_class_charset, sym_k_ksc_hangul_charset, 10, CHARSET_NAME, "KSC_KOREAN"},
    {tkn_k_class_enumval, sym_k_LineDoubleDash_enumval, 14, ENUMVAL_NAME, "LINEDOUBLEDASH"},
    {tkn_k_class_enumval, sym_k_LineOnOffDash_enumval, 13, ENUMVAL_NAME, "LINEONOFFDASH"},
    {tkn_k_class_enumval, sym_k_LineSolid_enumval, 9, ENUMVAL_NAME, "LINESOLID"},
    {tkn_k_class_reserved, 0, 4, LIST, "LIST"},
    {tkn_k_class_reserved, 0, 5, MACRO, "MACRO"},
    {tkn_k_class_keyword, 0, 7, MANAGED, "MANAGED"},
    {tkn_k_class_keyword, 0, 10, MILLIMETER, "MILLIMETER"},
    {tkn_k_class_keyword, 0, 11, MILLIMETERS, "MILLIMETERS"},
    {tkn_k_class_keyword, 0, 2, MM, "MM"},
    {tkn_k_class_reserved, 0, 6, MODULE, "MODULE"},
    {tkn_k_class_reason, sym_k_MrmNcreateCallback_reason, 18, REASON_NAME, "MRMNCREATECALLBACK"},
    {tkn_k_class_enumval, sym_k_MWM_DECOR_ALL_enumval, 13, ENUMVAL_NAME, "MWM_DECOR_ALL"},
    {tkn_k_class_enumval, sym_k_MWM_DECOR_BORDER_enumval, 16, ENUMVAL_NAME, "MWM_DECOR_BORDER"},
    {tkn_k_class_enumval, sym_k_MWM_DECOR_MAXIMIZE_enumval, 18, ENUMVAL_NAME, "MWM_DECOR_MAXIMIZE"},
    {tkn_k_class_enumval, sym_k_MWM_DECOR_MENU_enumval, 14, ENUMVAL_NAME, "MWM_DECOR_MENU"},
    {tkn_k_class_enumval, sym_k_MWM_DECOR_MINIMIZE_enumval, 18, ENUMVAL_NAME, "MWM_DECOR_MINIMIZE"},
    {tkn_k_class_enumval, sym_k_MWM_DECOR_RESIZEH_enumval, 17, ENUMVAL_NAME, "MWM_DECOR_RESIZEH"},
    {tkn_k_class_enumval, sym_k_MWM_DECOR_TITLE_enumval, 15, ENUMVAL_NAME, "MWM_DECOR_TITLE"},
    {tkn_k_class_enumval, sym_k_MWM_FUNC_ALL_enumval, 12, ENUMVAL_NAME, "MWM_FUNC_ALL"},
    {tkn_k_class_enumval, sym_k_MWM_FUNC_CLOSE_enumval, 14, ENUMVAL_NAME, "MWM_FUNC_CLOSE"},
    {tkn_k_class_enumval, sym_k_MWM_FUNC_MOVE_enumval, 13, ENUMVAL_NAME, "MWM_FUNC_MOVE"},
    {tkn_k_class_enumval, sym_k_MWM_FUNC_RESIZE_enumval, 15, ENUMVAL_NAME, "MWM_FUNC_RESIZE"},
    {tkn_k_class_enumval, sym_k_MWM_INPUT_FULL_APPLICATION_MODAL_enumval, 32, ENUMVAL_NAME, "MWM_INPUT_FULL_APPLICATION_MODAL"},
    {tkn_k_class_enumval, sym_k_MWM_INPUT_MODELESS_enumval, 18, ENUMVAL_NAME, "MWM_INPUT_MODELESS"},
    {tkn_k_class_enumval, sym_k_MWM_INPUT_PRIMARY_APPLICATION_MODAL_enumval, 35, ENUMVAL_NAME, "MWM_INPUT_PRIMARY_APPLICATION_MODAL"},
    {tkn_k_class_enumval, sym_k_MWM_INPUT_SYSTEM_MODAL_enumval, 22, ENUMVAL_NAME, "MWM_INPUT_SYSTEM_MODAL"},
    {tkn_k_class_keyword, 0, 5, NAMES, "NAMES"},
    {tkn_k_class_enumval, sym_k_NormalState_enumval, 11, ENUMVAL_NAME, "NORMALSTATE"},
    {tkn_k_class_enumval, sym_k_NotUseful_enumval, 9, ENUMVAL_NAME, "NOTUSEFUL"},
    {tkn_k_class_reserved, 0, 6, OBJECT, "OBJECT"},
    {tkn_k_class_keyword, 0, 7, OBJECTS, "OBJECTS"},
    {tkn_k_class_reserved, 0, 3, OFF, "OFF"},
    {tkn_k_class_reserved, 0, 2, ON, "ON"},
    {tkn_k_class_keyword, 0, 3, PIX, "PIX"},
    {tkn_k_class_keyword, 0, 5, PIXEL, "PIXEL"},
    {tkn_k_class_keyword, 0, 6, PIXELS, "PIXELS"},
    {tkn_k_class_keyword, 0, 6, PIXMAP, "PIXMAP"},
    {tkn_k_class_keyword, 0, 5, POINT, "POINT"},
    {tkn_k_class_keyword, 0, 6, POINTS, "POINTS"},
    {tkn_k_class_reserved, 0, 7, PRIVATE, "PRIVATE"},
    {tkn_k_class_reserved, 0, 9, PROCEDURE, "PROCEDURE"},
    {tkn_k_class_reserved, 0, 10, PROCEDURES, "PROCEDURES"},
    {tkn_k_class_keyword, 0, 2, PT, "PT"},
    {tkn_k_class_keyword, 0, 6, REASON, "REASON"},
    {tkn_k_class_keyword, 0, 3, RGB, "RGB"},
    {tkn_k_class_keyword, 0, 13, RIGHT_TO_LEFT, "RIGHT_TO_LEFT"},
    {tkn_k_class_keyword, 0, 8, SEPARATE, "SEPARATE"},
    {tkn_k_class_keyword, 0, 12, SINGLE_FLOAT, "SINGLE_FLOAT"},
    {tkn_k_class_keyword, 0, 11, SIXTEEN_BIT, "SIXTEEN_BIT"},
    {tkn_k_class_keyword, 0, 6, STRING, "STRING"},
    {tkn_k_class_keyword, 0, 12, STRING_TABLE, "STRING_TABLE"},
    {tkn_k_class_keyword, 0, 17, TRANSLATION_TABLE, "TRANSLATION_TABLE"},
    {tkn_k_class_reserved, 0, 4, UILTRUE, "TRUE"},
    {tkn_k_class_enumval, sym_k_TRUE_enumval, 4, ENUMVAL_NAME, "TRUE"},
    {tkn_k_class_keyword, 0, 9, UNMANAGED, "UNMANAGED"},
    {tkn_k_class_class, sym_k_user_defined_object, 12, CLASS_NAME, "USER_DEFINED"},
    {tkn_k_class_charset, sym_k_utf8_charset, 4, CHARSET_NAME, "UTF8"},
    {tkn_k_class_reserved, 0, 5, VALUE, "VALUE"},
    {tkn_k_class_keyword, 0, 7, VERSION, "VERSION"},
    {tkn_k_class_enumval, sym_k_WhenMapped_enumval, 10, ENUMVAL_NAME, "WHENMAPPED"},
    {tkn_k_class_keyword, 0, 14, WIDE_CHARACTER, "WIDE_CHARACTER"},
    {tkn_k_class_reserved, 0, 6, WIDGET, "WIDGET"},
    {tkn_k_class_charset, sym_k_ansi_cyrillic_charset, 12, CHARSET_NAME, "WINDOWS-1251"},
    {tkn_k_class_keyword, 0, 11, XBITMAPFILE, "XBITMAPFILE"},
    {tkn_k_class_enumval, sym_k_Xm1000TH_INCHES_enumval, 15, ENUMVAL_NAME, "XM1000TH_INCHES"},
    {tkn_k_class_enumval, sym_k_Xm100TH_FONT_UNITS_enumval, 18, ENUMVAL_NAME, "XM100TH_FONT_UNITS"},
    {tkn_k_class_enumval, sym_k_Xm100TH_MILLIMETERS_enumval, 19, ENUMVAL_NAME, "XM100TH_MILLIMETERS"},
    {tkn_k_class_enumval, sym_k_Xm100TH_POINTS_enumval, 14, ENUMVAL_NAME, "XM100TH_POINTS"},
    {tkn_k_class_enumval, sym_k_XmABSOLUTE_enumval, 10, ENUMVAL_NAME, "XMABSOLUTE"},
    {tkn_k_class_enumval, sym_k_XmADD_MODE_enumval, 10, ENUMVAL_NAME, "XMADD_MODE"},
    {tkn_k_class_enumval, sym_k_XmALIGNMENT_BASELINE_BOTTOM_enumval, 27, ENUMVAL_NAME, "XMALIGNMENT_BASELINE_BOTTOM"},
    {tkn_k_class_enumval, sym_k_XmALIGNMENT_BASELINE_TOP_enumval, 24, ENUMVAL_NAME, "XMALIGNMENT_BASELINE_TOP"},
    {tkn_k_class_enumval, sym_k_XmALIGNMENT_BEGINNING_enumval, 21, ENUMVAL_NAME, "XMALIGNMENT_BEGINNING"},
    {tkn_k_class_enumval, sym_k_XmALIGNMENT_CENTER_enumval, 18, ENUMVAL_NAME, "XMALIGNMENT_CENTER"},
    {tkn_k_class_enumval, sym_k_XmALIGNMENT_CONTENTS_BOTTOM_enumval, 27, ENUMVAL_NAME, "XMALIGNMENT_CONTENTS_BOTTOM"},
    {tkn_k_class_enumval, sym_k_XmALIGNMENT_CONTENTS_TOP_enumval, 24, ENUMVAL_NAME, "XMALIGNMENT_CONTENTS_TOP"},
    {tkn_k_class_enumval, sym_k_XmALIGNMENT_END_enumval, 15, ENUMVAL_NAME, "XMALIGNMENT_END"},
    {tkn_k_class_enumval, sym_k_XmALIGNMENT_UNSPECIFIED_enumval, 23, ENUMVAL_NAME, "XMALIGNMENT_UNSPECIFIED"},
    {tkn_k_class_enumval, sym_k_XmALIGNMENT_WIDGET_BOTTOM_enumval, 25, ENUMVAL_NAME, "XMALIGNMENT_WIDGET_BOTTOM"},
    {tkn_k_class_enumval, sym_k_XmALIGNMENT_WIDGET_TOP_enumval, 22, ENUMVAL_NAME, "XMALIGNMENT_WIDGET_TOP"},
    {tkn_k_class_enumval, sym_k_XmAlwaysOpen_enumval, 12, ENUMVAL_NAME, "XMALWAYSOPEN"},
    {tkn_k_class_enumval, sym_k_XmANY_ICON_enumval, 10, ENUMVAL_NAME, "XMANY_ICON"},
    {tkn_k_class_enumval, sym_k_XmAPPEND_enumval, 8, ENUMVAL_NAME, "XMAPPEND"},
    {tkn_k_class_enumval, sym_k_XmAPPLICATION_DEFINED_enumval, 21, ENUMVAL_NAME, "XMAPPLICATION_DEFINED"},
    {tkn_k_class_class, sym_k_XmArrowButton_object, 13, CLASS_NAME, "XMARROWBUTTON"},
    {tkn_k_class_class, sym_k_XmArrowButtonGadget_object, 19, CLASS_NAME, "XMARROWBUTTONGADGET"},
    {tkn_k_class_enumval, sym_k_XmARROWS_BEGINNING_enumval, 18, ENUMVAL_NAME, "XMARROWS_BEGINNING"},
    {tkn_k_class_enumval, sym_k_XmARROWS_DECREMENT_SENSITIVE_enumval, 28, ENUMVAL_NAME, "XMARROWS_DECREMENT_SENSITIVE"},
    {tkn_k_class_enumval, sym_k_XmARROWS_DEFAULT_SENSITIVITY_enumval, 28, ENUMVAL_NAME, "XMARROWS_DEFAULT_SENSITIVITY"},
    {tkn_k_class_enumval, sym_k_XmARROWS_END_enumval, 12, ENUMVAL_NAME, "XMARROWS_END"},
    {tkn_k_class_enumval, sym_k_XmARROWS_FLAT_BEGINNING_enumval, 23, ENUMVAL_NAME, "XMARROWS_FLAT_BEGINNING"},
    {tkn_k_class_enumval, sym_k_XmARROWS_FLAT_END_enumval, 17, ENUMVAL_NAME, "XMARROWS_FLAT_END"},
    {tkn_k_class_enumval, sym_k_XmARROWS_HORIZONTAL_enumval, 19, ENUMVAL_NAME, "XMARROWS_HORIZONTAL"},
    {tkn_k_class_enumval, sym_k_XmARROWS_INCREMENT_SENSITIVE_enumval, 28, ENUMVAL_NAME, "XMARROWS_INCREMENT_SENSITIVE"},
    {tkn_k_class_enumval, sym_k_XmARROWS_INSENSITIVE_enumval, 20, ENUMVAL_NAME, "XMARROWS_INSENSITIVE"},
    {tkn_k_class_enumval, sym_k_XmARROWS_SENSITIVE_enumval, 18, ENUMVAL_NAME, "XMARROWS_SENSITIVE"},
    {tkn_k_class_enumval, sym_k_XmARROWS_SPLIT_enumval, 14, ENUMVAL_NAME, "XMARROWS_SPLIT"},
    {tkn_k_class_enumval, sym_k_XmARROWS_VERTICAL_enumval, 17, ENUMVAL_NAME, "XMARROWS_VERTICAL"},
    {tkn_k_class_enumval, sym_k_XmARROW_DOWN_enumval, 12, ENUMVAL_NAME, "XMARROW_DOWN"},
    {tkn_k_class_enumval, sym_k_XmARROW_LEFT_enumval, 12, ENUMVAL_NAME, "XMARROW_LEFT"},
    {tkn_k_class_enumval, sym_k_XmARROW_RIGHT_enumval, 13, ENUMVAL_NAME, "XMARROW_RIGHT"},
    {tkn_k_class_enumval, sym_k_XmARROW_UP_enumval, 10, ENUMVAL_NAME, "XMARROW_UP"},
    {tkn_k_class_enumval, sym_k_XmAS_IS_enumval, 7, ENUMVAL_NAME, "XMAS_IS"},
    {tkn_k_class_enumval, sym_k_XmAS_NEEDED_enumval, 11, ENUMVAL_NAME, "XMAS_NEEDED"},
    {tkn_k_class_enumval, sym_k_XmATTACH_FORM_enumval, 13, ENUMVAL_NAME, "XMATTACH_FORM"},
    {tkn_k_class_enumval, sym_k_XmATTACH_NONE_enumval, 13, ENUMVAL_NAME, "XMATTACH_NONE"},
    {tkn_k_class_enumval, sym_k_XmATTACH_OPPOSITE_FORM_enumval, 22, ENUMVAL_NAME, "XMATTACH_OPPOSITE_FORM"},
    {tkn_k_class_enumval, sym_k_XmATTACH_OPPOSITE_WIDGET_enumval, 24, ENUMVAL_NAME, "XMATTACH_OPPOSITE_WIDGET"},
    {tkn_k_class_enumval, sym_k_XmATTACH_POSITION_enumval, 17, ENUMVAL_NAME, "XMATTACH_POSITION"},
    {tkn_k_class_enumval, sym_k_XmATTACH_SELF_enumval, 13, ENUMVAL_NAME, "XMATTACH_SELF"},
    {tkn_k_class_enumval, sym_k_XmATTACH_WIDGET_enumval, 15, ENUMVAL_NAME, "XMATTACH_WIDGET"},
    {tkn_k_class_enumval, sym_k_XmAUTOMATIC_enumval, 11, ENUMVAL_NAME, "XMAUTOMATIC"},
    {tkn_k_class_enumval, sym_k_XmAUTO_DRAG_DISABLED_enumval, 20, ENUMVAL_NAME, "XMAUTO_DRAG_DISABLED"},
    {tkn_k_class_enumval, sym_k_XmAUTO_DRAG_ENABLED_enumval, 19, ENUMVAL_NAME, "XMAUTO_DRAG_ENABLED"},
    {tkn_k_class_enumval, sym_k_XmAUTO_SELECT_enumval, 13, ENUMVAL_NAME, "XMAUTO_SELECT"},
    {tkn_k_class_enumval, sym_k_XmBACKGROUND_COLOR_enumval, 18, ENUMVAL_NAME, "XMBACKGROUND_COLOR"},
    {tkn_k_class_enumval, sym_k_XmBELL_enumval, 6, ENUMVAL_NAME, "XMBELL"},
    {tkn_k_class_enumval, sym_k_XmBOTTOM_LEFT_enumval, 13, ENUMVAL_NAME, "XMBOTTOM_LEFT"},
    {tkn_k_class_enumval, sym_k_XmBOTTOM_RIGHT_enumval, 14, ENUMVAL_NAME, "XMBOTTOM_RIGHT"},
    {tkn_k_class_enumval, sym_k_XmBOTTOM_TO_TOP_enumval, 15, ENUMVAL_NAME, "XMBOTTOM_TO_TOP"},
    {tkn_k_class_enumval, sym_k_XmBOTTOM_TO_TOP_LEFT_TO_RIGHT_enumval, 29, ENUMVAL_NAME, "XMBOTTOM_TO_TOP_LEFT_TO_RIGHT"},
    {tkn_k_class_enumval, sym_k_XmBOTTOM_TO_TOP_RIGHT_TO_LEFT_enumval, 29, ENUMVAL_NAME, "XMBOTTOM_TO_TOP_RIGHT_TO_LEFT"},
    {tkn_k_class_enumval, sym_k_XmBROWSE_SELECT_enumval, 15, ENUMVAL_NAME, "XMBROWSE_SELECT"},
    {tkn_k_class_class, sym_k_XmBulletinBoard_object, 15, CLASS_NAME, "XMBULLETINBOARD"},
    {tkn_k_class_class, sym_k_XmBulletinBoardDialog_object, 21, CLASS_NAME, "XMBULLETINBOARDDIALOG"},
    {tkn_k_class_class, sym_k_XmButtonBox_object, 11, CLASS_NAME, "XMBUTTONBOX"},
    {tkn_k_class_class, sym_k_XmCascadeButton_object, 15, CLASS_NAME, "XMCASCADEBUTTON"},
    {tkn_k_class_class, sym_k_XmCascadeButtonGadget_object, 21, CLASS_NAME, "XMCASCADEBUTTONGADGET"},
    {tkn_k_class_enumval, sym_k_XmCELLS_enumval, 7, ENUMVAL_NAME, "XMCELLS"},
    {tkn_k_class_enumval, sym_k_XmCENTER_enumval, 8, ENUMVAL_NAME, "XMCENTER"},
    {tkn_k_class_enumval, sym_k_XmCENTIMETERS_enumval, 13, ENUMVAL_NAME, "XMCENTIMETERS"},
    {tkn_k_class_class, sym_k_XmCheckBox_object, 10, CLASS_NAME, "XMCHECKBOX"},
    {tkn_k_class_enumval, sym_k_XmCLIP_WINDOW_enumval, 13, ENUMVAL_NAME, "XMCLIP_WINDOW"},
    {tkn_k_class_enumval, sym_k_XmClosed_enumval, 8, ENUMVAL_NAME, "XMCLOSED"},
    {tkn_k_class_enumval, sym_k_XmCLOSEST_enumval, 9, ENUMVAL_NAME, "XMCLOSEST"},
    {tkn_k_class_enumval, sym_k_XmCOLLAPSED_enumval, 11, ENUMVAL_NAME, "XMCOLLAPSED"},
    {tkn_k_class_class, sym_k_XmColorSelector_object, 15, CLASS_NAME, "XMCOLORSELECTOR"},
    {tkn_k_class_class, sym_k_XmColumn_object, 8, CLASS_NAME, "XMCOLUMN"},
    {tkn_k_class_class, sym_k_XmDropDown_object, 17, CLASS_NAME, "XMCOMBINATIONBOX2"},
    {tkn_k_class_class, sym_k_XmComboBox_object, 10, CLASS_NAME, "XMCOMBOBOX"},
    {tkn_k_class_enumval, sym_k_XmCOMBO_BOX_enumval, 11, ENUMVAL_NAME, "XMCOMBO_BOX"},
    {tkn_k_class_class, sym_k_XmCommand_object, 9, CLASS_NAME, "XMCOMMAND"},
    {tkn_k_class_class, sym_k_XmCommandDialog_object, 15, CLASS_NAME, "XMCOMMANDDIALOG"},
    {tkn_k_class_enumval, sym_k_XmCOMMAND_ABOVE_WORKSPACE_enumval, 25, ENUMVAL_NAME, "XMCOMMAND_ABOVE_WORKSPACE"},
    {tkn_k_class_enumval, sym_k_XmCOMMAND_BELOW_WORKSPACE_enumval, 25, ENUMVAL_NAME, "XMCOMMAND_BELOW_WORKSPACE"},
    {tkn_k_class_enumval, sym_k_XmCOMMAND_WINDOW_enumval, 16, ENUMVAL_NAME, "XMCOMMAND_WINDOW"},
    {tkn_k_class_enumval, sym_k_XmCONSTANT_enumval, 10, ENUMVAL_NAME, "XMCONSTANT"},
    {tkn_k_class_class, sym_k_XmContainer_object, 11, CLASS_NAME, "XMCONTAINER"},
    {tkn_k_class_class, sym_k_XmDataField_object, 11, CLASS_NAME, "XMDATAFIELD"},
    {tkn_k_class_enumval, sym_k_XmDEFAULT_DIRECTION_enumval, 19, ENUMVAL_NAME, "XMDEFAULT_DIRECTION"},
    {tkn_k_class_enumval, sym_k_XmDESTROY_enumval, 9, ENUMVAL_NAME, "XMDESTROY"},
    {tkn_k_class_enumval, sym_k_XmDETAIL_enumval, 8, ENUMVAL_NAME, "XMDETAIL"},
    {tkn_k_class_class, sym_k_XmDialogShell_object, 13, CLASS_NAME, "XMDIALOGSHELL"},
    {tkn_k_class_enumval, sym_k_XmDIALOG_APPLICATION_MODAL_enumval, 26, ENUMVAL_NAME, "XMDIALOG_APPLICATION_MODAL"},
    {tkn_k_class_enumval, sym_k_XmDIALOG_CANCEL_BUTTON_enumval, 22, ENUMVAL_NAME, "XMDIALOG_CANCEL_BUTTON"},
    {tkn_k_class_enumval, sym_k_XmDIALOG_COMMAND_enumval, 16, ENUMVAL_NAME, "XMDIALOG_COMMAND"},
    {tkn_k_class_enumval, sym_k_XmDIALOG_DEFAULT_BUTTON_enumval, 23, ENUMVAL_NAME, "XMDIALOG_DEFAULT_BUTTON"},
    {tkn_k_class_enumval, sym_k_XmDIALOG_ERROR_enumval, 14, ENUMVAL_NAME, "XMDIALOG_ERROR"},
    {tkn_k_class_enumval, sym_k_XmDIALOG_FILE_SELECTION_enumval, 23, ENUMVAL_NAME, "XMDIALOG_FILE_SELECTION"},
    {tkn_k_class_enumval, sym_k_XmDIALOG_FULL_APPLICATION_MODAL_enumval, 31, ENUMVAL_NAME, "XMDIALOG_FULL_APPLICATION_MODAL"},
    {tkn_k_class_enumval, sym_k_XmDIALOG_HELP_BUTTON_enumval, 20, ENUMVAL_NAME, "XMDIALOG_HELP_BUTTON"},
    {tkn_k_class_enumval, sym_k_XmDIALOG_INFORMATION_enumval, 20, ENUMVAL_NAME, "XMDIALOG_INFORMATION"},
    {tkn_k_class_enumval, sym_k_XmDIALOG_MESSAGE_enumval, 16, ENUMVAL_NAME, "XMDIALOG_MESSAGE"},
    {tkn_k_class_enumval, sym_k_XmDIALOG_MESSAGE_LABEL_enumval, 22, ENUMVAL_NAME, "XMDIALOG_MESSAGE_LABEL"},
    {tkn_k_class_enumval, sym_k_XmDIALOG_MODELESS_enumval, 17, ENUMVAL_NAME, "XMDIALOG_MODELESS"},
    {tkn_k_class_enumval, sym_k_XmDIALOG_OK_BUTTON_enumval, 18, ENUMVAL_NAME, "XMDIALOG_OK_BUTTON"},
    {tkn_k_class_enumval, sym_k_XmDIALOG_PRIMARY_APPLICATION_MODAL_enumval, 34, ENUMVAL_NAME, "XMDIALOG_PRIMARY_APPLICATION_MODAL"},
    {tkn_k_class_enumval, sym_k_XmDIALOG_PROMPT_enumval, 15, ENUMVAL_NAME, "XMDIALOG_PROMPT"},
    {tkn_k_class_enumval, sym_k_XmDIALOG_QUESTION_enumval, 17, ENUMVAL_NAME, "XMDIALOG_QUESTION"},
    {tkn_k_class_enumval, sym_k_XmDIALOG_SELECTION_enumval, 18, ENUMVAL_NAME, "XMDIALOG_SELECTION"},
    {tkn_k_class_enumval, sym_k_XmDIALOG_SEPARATOR_enumval, 18, ENUMVAL_NAME, "XMDIALOG_SEPARATOR"},
    {tkn_k_class_enumval, sym_k_XmDIALOG_SYMBOL_LABEL_enumval, 21, ENUMVAL_NAME, "XMDIALOG_SYMBOL_LABEL"},
    {tkn_k_class_enumval, sym_k_XmDIALOG_SYSTEM_MODAL_enumval, 21, ENUMVAL_NAME, "XMDIALOG_SYSTEM_MODAL"},
    {tkn_k_class_enumval, sym_k_XmDIALOG_TEMPLATE_enumval, 17, ENUMVAL_NAME, "XMDIALOG_TEMPLATE"},
    {tkn_k_class_enumval, sym_k_XmDIALOG_WARNING_enumval, 16, ENUMVAL_NAME, "XMDIALOG_WARNING"},
    {tkn_k_class_enumval, sym_k_XmDIALOG_WORKING_enumval, 16, ENUMVAL_NAME, "XMDIALOG_WORKING"},
    {tkn_k_class_enumval, sym_k_XmDIALOG_WORK_AREA_enumval, 18, ENUMVAL_NAME, "XMDIALOG_WORK_AREA"},
    {tkn_k_class_enumval, sym_k_XmDISTRIBUTE_SPREAD_enumval, 19, ENUMVAL_NAME, "XMDISTRIBUTE_SPREAD"},
    {tkn_k_class_enumval, sym_k_XmDISTRIBUTE_TIGHT_enumval, 18, ENUMVAL_NAME, "XMDISTRIBUTE_TIGHT"},
    {tkn_k_class_enumval, sym_k_XmDOUBLE_DASHED_LINE_enumval, 20, ENUMVAL_NAME, "XMDOUBLE_DASHED_LINE"},
    {tkn_k_class_enumval, sym_k_XmDOUBLE_LINE_enumval, 13, ENUMVAL_NAME, "XMDOUBLE_LINE"},
    {tkn_k_class_enumval, sym_k_XmDO_NOTHING_enumval, 12, ENUMVAL_NAME, "XMDO_NOTHING"},
    {tkn_k_class_class, sym_k_XmDrawingArea_object, 13, CLASS_NAME, "XMDRAWINGAREA"},
    {tkn_k_class_class, sym_k_XmDrawnButton_object, 13, CLASS_NAME, "XMDRAWNBUTTON"},
    {tkn_k_class_class, sym_k_XmDropDown_object, 10, CLASS_NAME, "XMDROPDOWN"},
    {tkn_k_class_enumval, sym_k_XmDROP_DOWN_COMBO_BOX_enumval, 21, ENUMVAL_NAME, "XMDROP_DOWN_COMBO_BOX"},
    {tkn_k_class_enumval, sym_k_XmDROP_DOWN_LIST_enumval, 16, ENUMVAL_NAME, "XMDROP_DOWN_LIST"},
    {tkn_k_class_enumval, sym_k_XmEACH_SIDE_enumval, 11, ENUMVAL_NAME, "XMEACH_SIDE"},
    {tkn_k_class_class, sym_k_XmErrorDialog_object, 13, CLASS_NAME, "XMERRORDIALOG"},
    {tkn_k_class_enumval, sym_k_XmETCHED_LINE_enumval, 13, ENUMVAL_NAME, "XMETCHED_LINE"},
    {tkn_k_class_enumval, sym_k_XmEXCLUSIVE_TAB_GROUP_enumval, 21, ENUMVAL_NAME, "XMEXCLUSIVE_TAB_GROUP"},
    {tkn_k_class_enumval, sym_k_XmEXPANDED_enumval, 10, ENUMVAL_NAME, "XMEXPANDED"},
    {tkn_k_class_enumval, sym_k_XmEXPLICIT_enumval, 10, ENUMVAL_NAME, "XMEXPLICIT"},
    {tkn_k_class_class, sym_k_XmMultiList_object, 11, CLASS_NAME, "XMEXT18LIST"},
    {tkn_k_class_enumval, sym_k_XmEXTENDED_SELECT_enumval, 17, ENUMVAL_NAME, "XMEXTENDED_SELECT"},
    {tkn_k_class_class, sym_k_XmFileSelectionBox_object, 18, CLASS_NAME, "XMFILESELECTIONBOX"},
    {tkn_k_class_class, sym_k_XmFileSelectionDialog_object, 21, CLASS_NAME, "XMFILESELECTIONDIALOG"},
    {tkn_k_class_enumval, sym_k_XmFILE_ANY_TYPE_enumval, 15, ENUMVAL_NAME, "XMFILE_ANY_TYPE"},
    {tkn_k_class_enumval, sym_k_XmFILE_DIRECTORY_enumval, 16, ENUMVAL_NAME, "XMFILE_DIRECTORY"},
    {tkn_k_class_enumval, sym_k_XmFILE_REGULAR_enumval, 14, ENUMVAL_NAME, "XMFILE_REGULAR"},
    {tkn_k_class_enumval, sym_k_XmFillAll_enumval, 9, ENUMVAL_NAME, "XMFILLALL"},
    {tkn_k_class_enumval, sym_k_XmFillMajor_enumval, 11, ENUMVAL_NAME, "XMFILLMAJOR"},
    {tkn_k_class_enumval, sym_k_XmFillMinor_enumval, 11, ENUMVAL_NAME, "XMFILLMINOR"},
    {tkn_k_class_enumval, sym_k_XmFillNone_enumval, 10, ENUMVAL_NAME, "XMFILLNONE"},
    {tkn_k_class_enumval, sym_k_XmFILL_FLUSH_enumval, 12, ENUMVAL_NAME, "XMFILL_FLUSH"},
    {tkn_k_class_enumval, sym_k_XmFILL_RAGGED_enumval, 13, ENUMVAL_NAME, "XMFILL_RAGGED"},
    {tkn_k_class_enumval, sym_k_XmFILL_UNSPECIFIED_enumval, 18, ENUMVAL_NAME, "XMFILL_UNSPECIFIED"},
    {tkn_k_class_enumval, sym_k_XmFIRST_FIT_enumval, 11, ENUMVAL_NAME, "XMFIRST_FIT"},
    {tkn_k_class_enumval, sym_k_XmFIRST_POSITION_enumval, 16, ENUMVAL_NAME, "XMFIRST_POSITION"},
    {tkn_k_class_charset, sym_k_XmFONTLIST_DEFAULT_TAG_charset, 22, CHARSET_NAME, "XMFONTLIST_DEFAULT_TAG"},
    {tkn_k_class_class, sym_k_XmFontSelector_object, 14, CLASS_NAME, "XMFONTSELECTOR"},
    {tkn_k_class_enumval, sym_k_XmFONT_IS_FONT_enumval, 14, ENUMVAL_NAME, "XMFONT_IS_FONT"},
    {tkn_k_class_enumval, sym_k_XmFONT_IS_FONTSET_enumval, 17, ENUMVAL_NAME, "XMFONT_IS_FONTSET"},
    {tkn_k_class_enumval, sym_k_XmFONT_IS_XFT_enumval, 13, ENUMVAL_NAME, "XMFONT_IS_XFT"},
    {tkn_k_class_enumval, sym_k_XmFONT_UNITS_enumval, 12, ENUMVAL_NAME, "XMFONT_UNITS"},
    {tkn_k_class_enumval, sym_k_XmFOREGROUND_COLOR_enumval, 18, ENUMVAL_NAME, "XMFOREGROUND_COLOR"},
    {tkn_k_class_class, sym_k_XmForm_object, 6, CLASS_NAME, "XMFORM"},
    {tkn_k_class_class, sym_k_XmFormDialog_object, 12, CLASS_NAME, "XMFORMDIALOG"},
    {tkn_k_class_class, sym_k_XmFrame_object, 7, CLASS_NAME, "XMFRAME"},
    {tkn_k_class_enumval, sym_k_XmFRAME_GENERIC_CHILD_enumval, 21, ENUMVAL_NAME, "XMFRAME_GENERIC_CHILD"},
    {tkn_k_class_enumval, sym_k_XmFRAME_TITLE_CHILD_enumval, 19, ENUMVAL_NAME, "XMFRAME_TITLE_CHILD"},
    {tkn_k_class_enumval, sym_k_XmFRAME_WORKAREA_CHILD_enumval, 22, ENUMVAL_NAME, "XMFRAME_WORKAREA_CHILD"},
    {tkn_k_class_enumval, sym_k_XmGENERIC_CHILD_enumval, 15, ENUMVAL_NAME, "XMGENERIC_CHILD"},
    {tkn_k_class_enumval, sym_k_XmGRID_enumval, 6, ENUMVAL_NAME, "XMGRID"},
    {tkn_k_class_enumval, sym_k_XmGROW_BALANCED_enumval, 15, ENUMVAL_NAME, "XMGROW_BALANCED"},
    {tkn_k_class_enumval, sym_k_XmGROW_MAJOR_enumval, 12, ENUMVAL_NAME, "XMGROW_MAJOR"},
    {tkn_k_class_enumval, sym_k_XmGROW_MINOR_enumval, 12, ENUMVAL_NAME, "XMGROW_MINOR"},
    {tkn_k_class_enumval, sym_k_XmHidden_enumval, 8, ENUMVAL_NAME, "XMHIDDEN"},
    {tkn_k_class_enumval, sym_k_XmHORIZONTAL_enumval, 12, ENUMVAL_NAME, "XMHORIZONTAL"},
    {tkn_k_class_enumval, sym_k_XmHOR_SCROLLBAR_enumval, 15, ENUMVAL_NAME, "XMHOR_SCROLLBAR"},
    {tkn_k_class_enumval, sym_k_XmIconBottom_enumval, 12, ENUMVAL_NAME, "XMICONBOTTOM"},
    {tkn_k_class_class, sym_k_XmIconBox_object, 9, CLASS_NAME, "XMICONBOX"},
    {tkn_k_class_class, sym_k_XmIconButton_object, 12, CLASS_NAME, "XMICONBUTTON"},
    {tkn_k_class_class, sym_k_XmIconGadget_object, 12, CLASS_NAME, "XMICONGADGET"},
    {tkn_k_class_enumval, sym_k_XmIconLeft_enumval, 10, ENUMVAL_NAME, "XMICONLEFT"},
    {tkn_k_class_enumval, sym_k_XmIconNone_enumval, 10, ENUMVAL_NAME, "XMICONNONE"},
    {tkn_k_class_enumval, sym_k_XmIconOnly_enumval, 10, ENUMVAL_NAME, "XMICONONLY"},
    {tkn_k_class_enumval, sym_k_XmIconRight_enumval, 11, ENUMVAL_NAME, "XMICONRIGHT"},
    {tkn_k_class_enumval, sym_k_XmIconTop_enumval, 9, ENUMVAL_NAME, "XMICONTOP"},
    {tkn_k_class_enumval, sym_k_XmINCHES_enumval, 8, ENUMVAL_NAME, "XMINCHES"},
    {tkn_k_class_enumval, sym_k_XmINDETERMINATE_enumval, 15, ENUMVAL_NAME, "XMINDETERMINATE"},
    {tkn_k_class_enumval, sym_k_XmINDICATOR_BOX_enumval, 15, ENUMVAL_NAME, "XMINDICATOR_BOX"},
    {tkn_k_class_enumval, sym_k_XmINDICATOR_CHECK_enumval, 17, ENUMVAL_NAME, "XMINDICATOR_CHECK"},
    {tkn_k_class_enumval, sym_k_XmINDICATOR_CHECK_BOX_enumval, 21, ENUMVAL_NAME, "XMINDICATOR_CHECK_BOX"},
    {tkn_k_class_enumval, sym_k_XmINDICATOR_CROSS_enumval, 17, ENUMVAL_NAME, "XMINDICATOR_CROSS"},
    {tkn_k_class_enumval, sym_k_XmINDICATOR_CROSS_BOX_enumval, 21, ENUMVAL_NAME, "XMINDICATOR_CROSS_BOX"},
    {tkn_k_class_enumval, sym_k_XmINDICATOR_FILL_enumval, 16, ENUMVAL_NAME, "XMINDICATOR_FILL"},
    {tkn_k_class_enumval, sym_k_XmINDICATOR_NONE_enumval, 16, ENUMVAL_NAME, "XMINDICATOR_NONE"},
    {tkn_k_class_class, sym_k_XmInformationDialog_object, 19, CLASS_NAME, "XMINFORMATIONDIALOG"},
    {tkn_k_class_enumval, sym_k_XmINHERIT_POLICY_enumval, 16, ENUMVAL_NAME, "XMINHERIT_POLICY"},
    {tkn_k_class_enumval, sym_k_XmINVALID_MATCH_BEHAVIOR_enumval, 24, ENUMVAL_NAME, "XMINVALID_MATCH_BEHAVIOR"},
    {tkn_k_class_class, sym_k_XmLabel_object, 7, CLASS_NAME, "XMLABEL"},
    {tkn_k_class_class, sym_k_XmLabelGadget_object, 13, CLASS_NAME, "XMLABELGADGET"},
    {tkn_k_class_enumval, sym_k_XmLARGE_ICON_enumval, 12, ENUMVAL_NAME, "XMLARGE_ICON"},
    {tkn_k_class_enumval, sym_k_XmLAST_POSITION_enumval, 15, ENUMVAL_NAME, "XMLAST_POSITION"},
    {tkn_k_class_enumval, sym_k_XmLEFT_TO_RIGHT_enumval, 15, ENUMVAL_NAME, "XMLEFT_TO_RIGHT"},
    {tkn_k_class_enumval, sym_k_XmLEFT_TO_RIGHT_BOTTOM_TO_TOP_enumval, 29, ENUMVAL_NAME, "XMLEFT_TO_RIGHT_BOTTOM_TO_TOP"},
    {tkn_k_class_enumval, sym_k_XmLEFT_TO_RIGHT_TOP_TO_BOTTOM_enumval, 29, ENUMVAL_NAME, "XMLEFT_TO_RIGHT_TOP_TO_BOTTOM"},
    {tkn_k_class_class, sym_k_XmList_object, 6, CLASS_NAME, "XMLIST"},
    {tkn_k_class_enumval, sym_k_XmListMode_enumval, 10, ENUMVAL_NAME, "XMLISTMODE"},
    {tkn_k_class_enumval, sym_k_XmLOAD_DEFERRED_enumval, 15, ENUMVAL_NAME, "XMLOAD_DEFERRED"},
    {tkn_k_class_enumval, sym_k_XmLOAD_IMMEDIATE_enumval, 16, ENUMVAL_NAME, "XMLOAD_IMMEDIATE"},
    {tkn_k_class_class, sym_k_XmMainWindow_object, 12, CLASS_NAME, "XMMAINWINDOW"},
    {tkn_k_class_enumval, sym_k_XmMAJOR_TAB_enumval, 11, ENUMVAL_NAME, "XMMAJOR_TAB"},
    {tkn_k_class_enumval, sym_k_XmMARQUEE_enumval, 9, ENUMVAL_NAME, "XMMARQUEE"},
    {tkn_k_class_enumval, sym_k_XmMARQUEE_EXTEND_BOTH_enumval, 21, ENUMVAL_NAME, "XMMARQUEE_EXTEND_BOTH"},
    {tkn_k_class_enumval, sym_k_XmMARQUEE_EXTEND_START_enumval, 22, ENUMVAL_NAME, "XMMARQUEE_EXTEND_START"},
    {tkn_k_class_enumval, sym_k_XmMAX_ON_BOTTOM_enumval, 15, ENUMVAL_NAME, "XMMAX_ON_BOTTOM"},
    {tkn_k_class_enumval, sym_k_XmMAX_ON_LEFT_enumval, 13, ENUMVAL_NAME, "XMMAX_ON_LEFT"},
    {tkn_k_class_enumval, sym_k_XmMAX_ON_RIGHT_enumval, 14, ENUMVAL_NAME, "XMMAX_ON_RIGHT"},
    {tkn_k_class_enumval, sym_k_XmMAX_ON_TOP_enumval, 12, ENUMVAL_NAME, "XMMAX_ON_TOP"},
    {tkn_k_class_enumval, sym_k_XmMAX_SIDE_enumval, 10, ENUMVAL_NAME, "XMMAX_SIDE"},
    {tkn_k_class_class, sym_k_XmMenuBar_object, 9, CLASS_NAME, "XMMENUBAR"},
    {tkn_k_class_class, sym_k_XmMenuShell_object, 11, CLASS_NAME, "XMMENUSHELL"},
    {tkn_k_class_enumval, sym_k_XmMENU_BAR_enumval, 10, ENUMVAL_NAME, "XMMENU_BAR"},
    {tkn_k_class_enumval, sym_k_XmMENU_OPTION_enumval, 13, ENUMVAL_NAME, "XMMENU_OPTION"},
    {tkn_k_class_enumval, sym_k_XmMENU_POPUP_enumval, 12, ENUMVAL_NAME, "XMMENU_POPUP"},
    {tkn_k_class_enumval, sym_k_XmMENU_PULLDOWN_enumval, 15, ENUMVAL_NAME, "XMMENU_PULLDOWN"},
    {tkn_k_class_class, sym_k_XmMessageBox_object, 12, CLASS_NAME, "XMMESSAGEBOX"},
    {tkn_k_class_class, sym_k_XmMessageDialog_object, 15, CLASS_NAME, "XMMESSAGEDIALOG"},
    {tkn_k_class_enumval, sym_k_XmMESSAGE_WINDOW_enumval, 16, ENUMVAL_NAME, "XMMESSAGE_WINDOW"},
    {tkn_k_class_enumval, sym_k_XmMILLIMETERS_enumval, 13, ENUMVAL_NAME, "XMMILLIMETERS"},
    {tkn_k_class_enumval, sym_k_XmMINOR_TAB_enumval, 11, ENUMVAL_NAME, "XMMINOR_TAB"},
    {tkn_k_class_enumval, sym_k_XmMIN_SIDE_enumval, 10, ENUMVAL_NAME, "XMMIN_SIDE"},
    {tkn_k_class_enumval, sym_k_XmMULTICLICK_DISCARD_enumval, 20, ENUMVAL_NAME, "XMMULTICLICK_DISCARD"},
    {tkn_k_class_enumval, sym_k_XmMULTICLICK_KEEP_enumval, 17, ENUMVAL_NAME, "XMMULTICLICK_KEEP"},
    {tkn_k_class_class, sym_k_XmMultiList_object, 11, CLASS_NAME, "XMMULTILIST"},
    {tkn_k_class_enumval, sym_k_XmMULTIPLE_SELECT_enumval, 17, ENUMVAL_NAME, "XMMULTIPLE_SELECT"},
    {tkn_k_class_enumval, sym_k_XmMULTI_LINE_EDIT_enumval, 17, ENUMVAL_NAME, "XMMULTI_LINE_EDIT"},
    {tkn_k_class_argument, sym_k_XmN100DPIstring_arg, 15, ARGUMENT_NAME, "XMN100DPISTRING"},
    {tkn_k_class_argument, sym_k_XmN75DPIstring_arg, 14, ARGUMENT_NAME, "XMN75DPISTRING"},
    {tkn_k_class_argument, sym_k_XmNaccelerator_arg, 14, ARGUMENT_NAME, "XMNACCELERATOR"},
    {tkn_k_class_argument, sym_k_XmNaccelerators_arg, 15, ARGUMENT_NAME, "XMNACCELERATORS"},
    {tkn_k_class_argument, sym_k_XmNacceleratorText_arg, 18, ARGUMENT_NAME, "XMNACCELERATORTEXT"},
    {tkn_k_class_reason, sym_k_XmNactivateCallback_reason, 19, REASON_NAME, "XMNACTIVATECALLBACK"},
    {tkn_k_class_argument, sym_k_XmNadjustLast_arg, 13, ARGUMENT_NAME, "XMNADJUSTLAST"},
    {tkn_k_class_argument, sym_k_XmNadjustMargin_arg, 15, ARGUMENT_NAME, "XMNADJUSTMARGIN"},
    {tkn_k_class_argument, sym_k_XmNalignment_arg, 12, ARGUMENT_NAME, "XMNALIGNMENT"},
    {tkn_k_class_argument, sym_k_XmNallowOverlap_arg, 15, ARGUMENT_NAME, "XMNALLOWOVERLAP"},
    {tkn_k_class_argument, sym_k_XmNallowResize_arg, 14, ARGUMENT_NAME, "XMNALLOWRESIZE"},
    {tkn_k_class_argument, sym_k_XmNallowShellResize_arg, 19, ARGUMENT_NAME, "XMNALLOWSHELLRESIZE"},
    {tkn_k_class_argument, sym_k_XmNallowUnusedSpace_arg, 19, ARGUMENT_NAME, "XMNALLOWUNUSEDSPACE"},
    {tkn_k_class_argument, sym_k_XmNancestorSensitive_arg, 20, ARGUMENT_NAME, "XMNANCESTORSENSITIVE"},
    {tkn_k_class_argument, sym_k_XmNanyLowerString_arg, 17, ARGUMENT_NAME, "XMNANYLOWERSTRING"},
    {tkn_k_class_argument, sym_k_XmNanyString_arg, 12, ARGUMENT_NAME, "XMNANYSTRING"},
    {tkn_k_class_reason, sym_k_XmNapplyCallback_reason, 16, REASON_NAME, "XMNAPPLYCALLBACK"},
    {tkn_k_class_argument, sym_k_XmNapplyLabelString_arg, 19, ARGUMENT_NAME, "XMNAPPLYLABELSTRING"},
    {tkn_k_class_reason, sym_k_XmNarmCallback_reason, 14, REASON_NAME, "XMNARMCALLBACK"},
    {tkn_k_class_argument, sym_k_XmNarmColor_arg, 11, ARGUMENT_NAME, "XMNARMCOLOR"},
    {tkn_k_class_argument, sym_k_XmNarmPixmap_arg, 12, ARGUMENT_NAME, "XMNARMPIXMAP"},
    {tkn_k_class_argument, sym_k_XmNarrowDirection_arg, 17, ARGUMENT_NAME, "XMNARROWDIRECTION"},
    {tkn_k_class_argument, sym_k_XmNarrowLayout_arg, 14, ARGUMENT_NAME, "XMNARROWLAYOUT"},
    {tkn_k_class_argument, sym_k_XmNarrowOrientation_arg, 19, ARGUMENT_NAME, "XMNARROWORIENTATION"},
    {tkn_k_class_argument, sym_k_XmNarrowSensitivity_arg, 19, ARGUMENT_NAME, "XMNARROWSENSITIVITY"},
    {tkn_k_class_argument, sym_k_XmNarrowSize_arg, 12, ARGUMENT_NAME, "XMNARROWSIZE"},
    {tkn_k_class_argument, sym_k_XmNarrowSpacing_arg, 15, ARGUMENT_NAME, "XMNARROWSPACING"},
    {tkn_k_class_argument, sym_k_XmNaudibleWarning_arg, 17, ARGUMENT_NAME, "XMNAUDIBLEWARNING"},
    {tkn_k_class_argument, sym_k_XmNautoClose_arg, 12, ARGUMENT_NAME, "XMNAUTOCLOSE"},
    {tkn_k_class_argument, sym_k_XmNautoDragModel_arg, 16, ARGUMENT_NAME, "XMNAUTODRAGMODEL"},
    {tkn_k_class_argument, sym_k_XmNautoFill_arg, 11, ARGUMENT_NAME, "XMNAUTOFILL"},
    {tkn_k_class_argument, sym_k_XmNautomaticSelection_arg, 21, ARGUMENT_NAME, "XMNAUTOMATICSELECTION"},
    {tkn_k_class_argument, sym_k_XmNautoShowCursorPosition_arg, 25, ARGUMENT_NAME, "XMNAUTOSHOWCURSORPOSITION"},
    {tkn_k_class_argument, sym_k_XmNautoUnmanage_arg, 15, ARGUMENT_NAME, "XMNAUTOUNMANAGE"},
    {tkn_k_class_argument, sym_k_XmNbackground_arg, 13, ARGUMENT_NAME, "XMNBACKGROUND"},
    {tkn_k_class_argument, sym_k_XmNbackgroundPixmap_arg, 19, ARGUMENT_NAME, "XMNBACKGROUNDPIXMAP"},
    {tkn_k_class_argument, sym_k_XmNbackPageBackground_arg, 21, ARGUMENT_NAME, "XMNBACKPAGEBACKGROUND"},
    {tkn_k_class_argument, sym_k_XmNbackPageForeground_arg, 21, ARGUMENT_NAME, "XMNBACKPAGEFOREGROUND"},
    {tkn_k_class_argument, sym_k_XmNbackPageNumber_arg, 17, ARGUMENT_NAME, "XMNBACKPAGENUMBER"},
    {tkn_k_class_argument, sym_k_XmNbackPagePlacement_arg, 20, ARGUMENT_NAME, "XMNBACKPAGEPLACEMENT"},
    {tkn_k_class_argument, sym_k_XmNbackPageSize_arg, 15, ARGUMENT_NAME, "XMNBACKPAGESIZE"},
    {tkn_k_class_argument, sym_k_XmNbaseHeight_arg, 13, ARGUMENT_NAME, "XMNBASEHEIGHT"},
    {tkn_k_class_argument, sym_k_XmNbaseWidth_arg, 12, ARGUMENT_NAME, "XMNBASEWIDTH"},
    {tkn_k_class_argument, sym_k_XmNbindingPixmap_arg, 16, ARGUMENT_NAME, "XMNBINDINGPIXMAP"},
    {tkn_k_class_argument, sym_k_XmNbindingType_arg, 14, ARGUMENT_NAME, "XMNBINDINGTYPE"},
    {tkn_k_class_argument, sym_k_XmNbindingWidth_arg, 15, ARGUMENT_NAME, "XMNBINDINGWIDTH"},
    {tkn_k_class_argument, sym_k_XmNblinkRate_arg, 12, ARGUMENT_NAME, "XMNBLINKRATE"},
    {tkn_k_class_argument, sym_k_XmNblueSliderLabel_arg, 18, ARGUMENT_NAME, "XMNBLUESLIDERLABEL"},
    {tkn_k_class_argument, sym_k_XmNboldString_arg, 13, ARGUMENT_NAME, "XMNBOLDSTRING"},
    {tkn_k_class_argument, sym_k_XmNborderColor_arg, 14, ARGUMENT_NAME, "XMNBORDERCOLOR"},
    {tkn_k_class_argument, sym_k_XmNborderPixmap_arg, 15, ARGUMENT_NAME, "XMNBORDERPIXMAP"},
    {tkn_k_class_argument, sym_k_XmNborderWidth_arg, 14, ARGUMENT_NAME, "XMNBORDERWIDTH"},
    {tkn_k_class_argument, sym_k_XmNbothString_arg, 13, ARGUMENT_NAME, "XMNBOTHSTRING"},
    {tkn_k_class_argument, sym_k_XmNbottomAttachment_arg, 19, ARGUMENT_NAME, "XMNBOTTOMATTACHMENT"},
    {tkn_k_class_argument, sym_k_XmNbottomOffset_arg, 15, ARGUMENT_NAME, "XMNBOTTOMOFFSET"},
    {tkn_k_class_argument, sym_k_XmNbottomPosition_arg, 17, ARGUMENT_NAME, "XMNBOTTOMPOSITION"},
    {tkn_k_class_argument, sym_k_XmNbottomShadowColor_arg, 20, ARGUMENT_NAME, "XMNBOTTOMSHADOWCOLOR"},
    {tkn_k_class_argument, sym_k_XmNbottomShadowPixmap_arg, 21, ARGUMENT_NAME, "XMNBOTTOMSHADOWPIXMAP"},
    {tkn_k_class_argument, sym_k_XmNbottomWidget_arg, 15, ARGUMENT_NAME, "XMNBOTTOMWIDGET"},
    {tkn_k_class_reason, sym_k_XmNbrowseSelectionCallback_reason, 26, REASON_NAME, "XMNBROWSESELECTIONCALLBACK"},
    {tkn_k_class_argument, sym_k_XmNbuttonCount_arg, 14, ARGUMENT_NAME, "XMNBUTTONCOUNT"},
    {tkn_k_class_argument, sym_k_XmNbuttonFontList_arg, 17, ARGUMENT_NAME, "XMNBUTTONFONTLIST"},
    {tkn_k_class_argument, sym_k_XmNbuttonRenderTable_arg, 20, ARGUMENT_NAME, "XMNBUTTONRENDERTABLE"},
    {tkn_k_class_argument, sym_k_XmNbuttons_arg, 10, ARGUMENT_NAME, "XMNBUTTONS"},
    {tkn_k_class_argument, sym_k_XmNcancelButton_arg, 15, ARGUMENT_NAME, "XMNCANCELBUTTON"},
    {tkn_k_class_reason, sym_k_XmNcancelCallback_reason, 17, REASON_NAME, "XMNCANCELCALLBACK"},
    {tkn_k_class_argument, sym_k_XmNcancelLabelString_arg, 20, ARGUMENT_NAME, "XMNCANCELLABELSTRING"},
    {tkn_k_class_argument, sym_k_XmNcascadePixmap_arg, 16, ARGUMENT_NAME, "XMNCASCADEPIXMAP"},
    {tkn_k_class_reason, sym_k_XmNcascadingCallback_reason, 20, REASON_NAME, "XMNCASCADINGCALLBACK"},
    {tkn_k_class_argument, sym_k_XmNcellX_arg, 8, ARGUMENT_NAME, "XMNCELLX"},
    {tkn_k_class_argument, sym_k_XmNcellY_arg, 8, ARGUMENT_NAME, "XMNCELLY"},
    {tkn_k_class_argument, sym_k_XmNchildHorizontalAlignment_arg, 27, ARGUMENT_NAME, "XMNCHILDHORIZONTALALIGNMENT"},
    {tkn_k_class_argument, sym_k_XmNchildHorizontalSpacing_arg, 25, ARGUMENT_NAME, "XMNCHILDHORIZONTALSPACING"},
    {tkn_k_class_argument, sym_k_XmNchildPlacement_arg, 17, ARGUMENT_NAME, "XMNCHILDPLACEMENT"},
    {tkn_k_class_argument, sym_k_XmNchildType_arg, 12, ARGUMENT_NAME, "XMNCHILDTYPE"},
    {tkn_k_class_argument, sym_k_XmNchildVerticalAlignment_arg, 25, ARGUMENT_NAME, "XMNCHILDVERTICALALIGNMENT"},
    {tkn_k_class_argument, sym_k_XmNclipWindow_arg, 13, ARGUMENT_NAME, "XMNCLIPWINDOW"},
    {tkn_k_class_argument, sym_k_XmNcloseFolderPixmap_arg, 20, ARGUMENT_NAME, "XMNCLOSEFOLDERPIXMAP"},
    {tkn_k_class_argument, sym_k_XmNcollapsedStatePixmap_arg, 23, ARGUMENT_NAME, "XMNCOLLAPSEDSTATEPIXMAP"},
    {tkn_k_class_argument, sym_k_XmNcolorListTogLabel_arg, 20, ARGUMENT_NAME, "XMNCOLORLISTTOGLABEL"},
    {tkn_k_class_argument, sym_k_XmNcolormap_arg, 11, ARGUMENT_NAME, "XMNCOLORMAP"},
    {tkn_k_class_argument, sym_k_XmNcolorMode_arg, 12, ARGUMENT_NAME, "XMNCOLORMODE"},
    {tkn_k_class_argument, sym_k_XmNcolorName_arg, 12, ARGUMENT_NAME, "XMNCOLORNAME"},
    {tkn_k_class_argument, sym_k_XmNcolumns_arg, 10, ARGUMENT_NAME, "XMNCOLUMNS"},
    {tkn_k_class_argument, sym_k_XmNcolumnTitles_arg, 15, ARGUMENT_NAME, "XMNCOLUMNTITLES"},
    {tkn_k_class_argument, sym_k_XmNcomboBoxType_arg, 15, ARGUMENT_NAME, "XMNCOMBOBOXTYPE"},
    {tkn_k_class_argument, sym_k_XmNcomboTranslations_arg, 20, ARGUMENT_NAME, "XMNCOMBOTRANSLATIONS"},
    {tkn_k_class_argument, sym_k_XmNcommand_arg, 10, ARGUMENT_NAME, "XMNCOMMAND"},
    {tkn_k_class_reason, sym_k_XmNcommandChangedCallback_reason, 25, REASON_NAME, "XMNCOMMANDCHANGEDCALLBACK"},
    {tkn_k_class_reason, sym_k_XmNcommandEnteredCallback_reason, 25, REASON_NAME, "XMNCOMMANDENTEREDCALLBACK"},
    {tkn_k_class_argument, sym_k_XmNcommandWindow_arg, 16, ARGUMENT_NAME, "XMNCOMMANDWINDOW"},
    {tkn_k_class_argument, sym_k_XmNcommandWindowLocation_arg, 24, ARGUMENT_NAME, "XMNCOMMANDWINDOWLOCATION"},
    {tkn_k_class_argument, sym_k_XmNcompressStyle_arg, 16, ARGUMENT_NAME, "XMNCOMPRESSSTYLE"},
    {tkn_k_class_argument, sym_k_XmNconnectNodes_arg, 15, ARGUMENT_NAME, "XMNCONNECTNODES"},
    {tkn_k_class_argument, sym_k_XmNconnectStyle_arg, 15, ARGUMENT_NAME, "XMNCONNECTSTYLE"},
    {tkn_k_class_argument, sym_k_XmNconstrainWidth_arg, 17, ARGUMENT_NAME, "XMNCONSTRAINWIDTH"},
    {tkn_k_class_reason, sym_k_XmNconvertCallback_reason, 18, REASON_NAME, "XMNCONVERTCALLBACK"},
    {tkn_k_class_argument, sym_k_XmNcreatePopupChildProc_arg, 23, ARGUMENT_NAME, "XMNCREATEPOPUPCHILDPROC"},
    {tkn_k_class_argument, sym_k_XmNcurrentFont_arg, 14, ARGUMENT_NAME, "XMNCURRENTFONT"},
    {tkn_k_class_argument, sym_k_XmNcurrentPageNumber_arg, 20, ARGUMENT_NAME, "XMNCURRENTPAGENUMBER"},
    {tkn_k_class_argument, sym_k_XmNcursor_arg, 9, ARGUMENT_NAME, "XMNCURSOR"},
    {tkn_k_class_argument, sym_k_XmNcursorPosition_arg, 17, ARGUMENT_NAME, "XMNCURSORPOSITION"},
    {tkn_k_class_argument, sym_k_XmNcursorPositionVisible_arg, 24, ARGUMENT_NAME, "XMNCURSORPOSITIONVISIBLE"},
    {tkn_k_class_argument, sym_k_XmNcustomizedCombinationBox_arg, 27, ARGUMENT_NAME, "XMNCUSTOMIZEDCOMBINATIONBOX"},
    {tkn_k_class_argument, sym_k_XmNdarkThreshold_arg, 16, ARGUMENT_NAME, "XMNDARKTHRESHOLD"},
    {tkn_k_class_argument, sym_k_XmNdecimal_arg, 10, ARGUMENT_NAME, "XMNDECIMAL"},
    {tkn_k_class_argument, sym_k_XmNdecimalPoints_arg, 16, ARGUMENT_NAME, "XMNDECIMALPOINTS"},
    {tkn_k_class_reason, sym_k_XmNdecrementCallback_reason, 20, REASON_NAME, "XMNDECREMENTCALLBACK"},
    {tkn_k_class_reason, sym_k_XmNdefaultActionCallback_reason, 24, REASON_NAME, "XMNDEFAULTACTIONCALLBACK"},
    {tkn_k_class_argument, sym_k_XmNdefaultArrowSensitivity_arg, 26, ARGUMENT_NAME, "XMNDEFAULTARROWSENSITIVITY"},
    {tkn_k_class_argument, sym_k_XmNdefaultButton_arg, 16, ARGUMENT_NAME, "XMNDEFAULTBUTTON"},
    {tkn_k_class_argument, sym_k_XmNdefaultButtonShadowThickness_arg, 31, ARGUMENT_NAME, "XMNDEFAULTBUTTONSHADOWTHICKNESS"},
    {tkn_k_class_argument, sym_k_XmNdefaultButtonType_arg, 20, ARGUMENT_NAME, "XMNDEFAULTBUTTONTYPE"},
    {tkn_k_class_argument, sym_k_XmNdefaultEncodingString_arg, 24, ARGUMENT_NAME, "XMNDEFAULTENCODINGSTRING"},
    {tkn_k_class_argument, sym_k_XmNdefaultEntryLabelAlignment_arg, 29, ARGUMENT_NAME, "XMNDEFAULTENTRYLABELALIGNMENT"},
    {tkn_k_class_argument, sym_k_XmNdefaultEntryLabelFontList_arg, 28, ARGUMENT_NAME, "XMNDEFAULTENTRYLABELFONTLIST"},
    {tkn_k_class_argument, sym_k_XmNdefaultEntryLabelRenderTable_arg, 31, ARGUMENT_NAME, "XMNDEFAULTENTRYLABELRENDERTABLE"},
    {tkn_k_class_argument, sym_k_XmNdefaultFillStyle_arg, 19, ARGUMENT_NAME, "XMNDEFAULTFILLSTYLE"},
    {tkn_k_class_argument, sym_k_XmNdefaultFontList_arg, 18, ARGUMENT_NAME, "XMNDEFAULTFONTLIST"},
    {tkn_k_class_argument, sym_k_XmNdefaultPosition_arg, 18, ARGUMENT_NAME, "XMNDEFAULTPOSITION"},
    {tkn_k_class_argument, sym_k_XmNdeleteResponse_arg, 17, ARGUMENT_NAME, "XMNDELETERESPONSE"},
    {tkn_k_class_argument, sym_k_XmNdepth_arg, 8, ARGUMENT_NAME, "XMNDEPTH"},
    {tkn_k_class_reason, sym_k_XmNdestinationCallback_reason, 22, REASON_NAME, "XMNDESTINATIONCALLBACK"},
    {tkn_k_class_reason, sym_k_XmNdestroyCallback_reason, 18, REASON_NAME, "XMNDESTROYCALLBACK"},
    {tkn_k_class_argument, sym_k_XmNdetail_arg, 9, ARGUMENT_NAME, "XMNDETAIL"},
    {tkn_k_class_argument, sym_k_XmNdetailColumnHeading_arg, 22, ARGUMENT_NAME, "XMNDETAILCOLUMNHEADING"},
    {tkn_k_class_argument, sym_k_XmNdetailColumnHeadingCount_arg, 27, ARGUMENT_NAME, "XMNDETAILCOLUMNHEADINGCOUNT"},
    {tkn_k_class_argument, sym_k_XmNdetailCount_arg, 14, ARGUMENT_NAME, "XMNDETAILCOUNT"},
    {tkn_k_class_argument, sym_k_XmNdetailOrder_arg, 14, ARGUMENT_NAME, "XMNDETAILORDER"},
    {tkn_k_class_argument, sym_k_XmNdetailOrderCount_arg, 19, ARGUMENT_NAME, "XMNDETAILORDERCOUNT"},
    {tkn_k_class_argument, sym_k_XmNdetailShadowThickness_arg, 24, ARGUMENT_NAME, "XMNDETAILSHADOWTHICKNESS"},
    {tkn_k_class_argument, sym_k_XmNdetailTabList_arg, 16, ARGUMENT_NAME, "XMNDETAILTABLIST"},
    {tkn_k_class_argument, sym_k_XmNdialogStyle_arg, 14, ARGUMENT_NAME, "XMNDIALOGSTYLE"},
    {tkn_k_class_argument, sym_k_XmNdialogTitle_arg, 14, ARGUMENT_NAME, "XMNDIALOGTITLE"},
    {tkn_k_class_argument, sym_k_XmNdialogType_arg, 13, ARGUMENT_NAME, "XMNDIALOGTYPE"},
    {tkn_k_class_argument, sym_k_XmNdirectory_arg, 12, ARGUMENT_NAME, "XMNDIRECTORY"},
    {tkn_k_class_argument, sym_k_XmNdirectoryValid_arg, 17, ARGUMENT_NAME, "XMNDIRECTORYVALID"},
    {tkn_k_class_argument, sym_k_XmNdirListItemCount_arg, 19, ARGUMENT_NAME, "XMNDIRLISTITEMCOUNT"},
    {tkn_k_class_argument, sym_k_XmNdirListItems_arg, 15, ARGUMENT_NAME, "XMNDIRLISTITEMS"},
    {tkn_k_class_argument, sym_k_XmNdirListLabelString_arg, 21, ARGUMENT_NAME, "XMNDIRLISTLABELSTRING"},
    {tkn_k_class_argument, sym_k_XmNdirMask_arg, 10, ARGUMENT_NAME, "XMNDIRMASK"},
    {tkn_k_class_argument, sym_k_XmNdirSearchProc_arg, 16, ARGUMENT_NAME, "XMNDIRSEARCHPROC"},
    {tkn_k_class_argument, sym_k_XmNdirSpec_arg, 10, ARGUMENT_NAME, "XMNDIRSPEC"},
    {tkn_k_class_reason, sym_k_XmNdisarmCallback_reason, 17, REASON_NAME, "XMNDISARMCALLBACK"},
    {tkn_k_class_argument, sym_k_XmNdistribution_arg, 15, ARGUMENT_NAME, "XMNDISTRIBUTION"},
    {tkn_k_class_reason, sym_k_XmNdoubleClickCallback_reason, 22, REASON_NAME, "XMNDOUBLECLICKCALLBACK"},
    {tkn_k_class_argument, sym_k_XmNdoubleClickInterval_arg, 22, ARGUMENT_NAME, "XMNDOUBLECLICKINTERVAL"},
    {tkn_k_class_reason, sym_k_XmNdragCallback_reason, 15, REASON_NAME, "XMNDRAGCALLBACK"},
    {tkn_k_class_enumval, sym_k_XmNEAR_BORDER_enumval, 13, ENUMVAL_NAME, "XMNEAR_BORDER"},
    {tkn_k_class_enumval, sym_k_XmNEAR_SLIDER_enumval, 13, ENUMVAL_NAME, "XMNEAR_SLIDER"},
    {tkn_k_class_argument, sym_k_XmNeditable_arg, 11, ARGUMENT_NAME, "XMNEDITABLE"},
    {tkn_k_class_argument, sym_k_XmNeditMode_arg, 11, ARGUMENT_NAME, "XMNEDITMODE"},
    {tkn_k_class_argument, sym_k_XmNencodingList_arg, 15, ARGUMENT_NAME, "XMNENCODINGLIST"},
    {tkn_k_class_argument, sym_k_XmNencodingString_arg, 17, ARGUMENT_NAME, "XMNENCODINGSTRING"},
    {tkn_k_class_argument, sym_k_XmNentryAlignment_arg, 17, ARGUMENT_NAME, "XMNENTRYALIGNMENT"},
    {tkn_k_class_argument, sym_k_XmNentryBackground_arg, 18, ARGUMENT_NAME, "XMNENTRYBACKGROUND"},
    {tkn_k_class_argument, sym_k_XmNentryBorder_arg, 14, ARGUMENT_NAME, "XMNENTRYBORDER"},
    {tkn_k_class_reason, sym_k_XmNentryCallback_reason, 16, REASON_NAME, "XMNENTRYCALLBACK"},
    {tkn_k_class_argument, sym_k_XmNentryClass_arg, 13, ARGUMENT_NAME, "XMNENTRYCLASS"},
    {tkn_k_class_argument, sym_k_XmNentryData_arg, 12, ARGUMENT_NAME, "XMNENTRYDATA"},
    {tkn_k_class_argument, sym_k_XmNentryLabelAlignment_arg, 22, ARGUMENT_NAME, "XMNENTRYLABELALIGNMENT"},
    {tkn_k_class_argument, sym_k_XmNentryLabelFontList_arg, 21, ARGUMENT_NAME, "XMNENTRYLABELFONTLIST"},
    {tkn_k_class_argument, sym_k_XmNentryLabelPixmap_arg, 19, ARGUMENT_NAME, "XMNENTRYLABELPIXMAP"},
    {tkn_k_class_argument, sym_k_XmNentryLabelRenderTable_arg, 24, ARGUMENT_NAME, "XMNENTRYLABELRENDERTABLE"},
    {tkn_k_class_argument, sym_k_XmNentryLabelString_arg, 19, ARGUMENT_NAME, "XMNENTRYLABELSTRING"},
    {tkn_k_class_argument, sym_k_XmNentryLabelType_arg, 17, ARGUMENT_NAME, "XMNENTRYLABELTYPE"},
    {tkn_k_class_argument, sym_k_XmNentryParent_arg, 14, ARGUMENT_NAME, "XMNENTRYPARENT"},
    {tkn_k_class_argument, sym_k_XmNentryVerticalAlignment_arg, 25, ARGUMENT_NAME, "XMNENTRYVERTICALALIGNMENT"},
    {tkn_k_class_argument, sym_k_XmNentryViewType_arg, 16, ARGUMENT_NAME, "XMNENTRYVIEWTYPE"},
    {tkn_k_class_argument, sym_k_XmNequalSize_arg, 12, ARGUMENT_NAME, "XMNEQUALSIZE"},
    {tkn_k_class_argument, sym_k_XmNexpandedStatePixmap_arg, 22, ARGUMENT_NAME, "XMNEXPANDEDSTATEPIXMAP"},
    {tkn_k_class_reason, sym_k_XmNexposeCallback_reason, 17, REASON_NAME, "XMNEXPOSECALLBACK"},
    {tkn_k_class_reason, sym_k_XmNextendedSelectionCallback_reason, 28, REASON_NAME, "XMNEXTENDEDSELECTIONCALLBACK"},
    {tkn_k_class_argument, sym_k_XmNfamilyString_arg, 15, ARGUMENT_NAME, "XMNFAMILYSTRING"},
    {tkn_k_class_argument, sym_k_XmNfileListItemCount_arg, 20, ARGUMENT_NAME, "XMNFILELISTITEMCOUNT"},
    {tkn_k_class_argument, sym_k_XmNfileListItems_arg, 16, ARGUMENT_NAME, "XMNFILELISTITEMS"},
    {tkn_k_class_argument, sym_k_XmNfileListLabelString_arg, 22, ARGUMENT_NAME, "XMNFILELISTLABELSTRING"},
    {tkn_k_class_argument, sym_k_XmNfileReadError_arg, 16, ARGUMENT_NAME, "XMNFILEREADERROR"},
    {tkn_k_class_argument, sym_k_XmNfileSearchProc_arg, 17, ARGUMENT_NAME, "XMNFILESEARCHPROC"},
    {tkn_k_class_argument, sym_k_XmNfileTypeMask_arg, 15, ARGUMENT_NAME, "XMNFILETYPEMASK"},
    {tkn_k_class_argument, sym_k_XmNfillOnArm_arg, 12, ARGUMENT_NAME, "XMNFILLONARM"},
    {tkn_k_class_argument, sym_k_XmNfillOnSelect_arg, 15, ARGUMENT_NAME, "XMNFILLONSELECT"},
    {tkn_k_class_argument, sym_k_XmNfillOption_arg, 13, ARGUMENT_NAME, "XMNFILLOPTION"},
    {tkn_k_class_argument, sym_k_XmNfillStyle_arg, 12, ARGUMENT_NAME, "XMNFILLSTYLE"},
    {tkn_k_class_argument, sym_k_XmNfilterLabelString_arg, 20, ARGUMENT_NAME, "XMNFILTERLABELSTRING"},
    {tkn_k_class_argument, sym_k_XmNfindLabel_arg, 12, ARGUMENT_NAME, "XMNFINDLABEL"},
    {tkn_k_class_argument, sym_k_XmNfirstColumn_arg, 14, ARGUMENT_NAME, "XMNFIRSTCOLUMN"},
    {tkn_k_class_argument, sym_k_XmNfirstColumnPixmaps_arg, 21, ARGUMENT_NAME, "XMNFIRSTCOLUMNPIXMAPS"},
    {tkn_k_class_argument, sym_k_XmNfirstPageNumber_arg, 18, ARGUMENT_NAME, "XMNFIRSTPAGENUMBER"},
    {tkn_k_class_argument, sym_k_XmNfirstRow_arg, 11, ARGUMENT_NAME, "XMNFIRSTROW"},
    {tkn_k_class_reason, sym_k_XmNfocusCallback_reason, 16, REASON_NAME, "XMNFOCUSCALLBACK"},
    {tkn_k_class_reason, sym_k_XmNfocusMovedCallback_reason, 21, REASON_NAME, "XMNFOCUSMOVEDCALLBACK"},
    {tkn_k_class_argument, sym_k_XmNfont_arg, 7, ARGUMENT_NAME, "XMNFONT"},
    {tkn_k_class_argument, sym_k_XmNfontEncoding_arg, 15, ARGUMENT_NAME, "XMNFONTENCODING"},
    {tkn_k_class_argument, sym_k_XmNfontFoundry_arg, 14, ARGUMENT_NAME, "XMNFONTFOUNDRY"},
    {tkn_k_class_argument, sym_k_XmNfontList_arg, 11, ARGUMENT_NAME, "XMNFONTLIST"},
    {tkn_k_class_argument, sym_k_XmNfontName_arg, 11, ARGUMENT_NAME, "XMNFONTNAME"},
    {tkn_k_class_argument, sym_k_XmNfontSize_arg, 11, ARGUMENT_NAME, "XMNFONTSIZE"},
    {tkn_k_class_argument, sym_k_XmNfontStyle_arg, 12, ARGUMENT_NAME, "XMNFONTSTYLE"},
    {tkn_k_class_argument, sym_k_XmNfontType_arg, 11, ARGUMENT_NAME, "XMNFONTTYPE"},
    {tkn_k_class_argument, sym_k_XmNforeground_arg, 13, ARGUMENT_NAME, "XMNFOREGROUND"},
    {tkn_k_class_argument, sym_k_XmNforegroundThreshold_arg, 22, ARGUMENT_NAME, "XMNFOREGROUNDTHRESHOLD"},
    {tkn_k_class_argument, sym_k_XmNfractionBase_arg, 15, ARGUMENT_NAME, "XMNFRACTIONBASE"},
    {tkn_k_class_argument, sym_k_XmNframeBackground_arg, 18, ARGUMENT_NAME, "XMNFRAMEBACKGROUND"},
    {tkn_k_class_argument, sym_k_XmNframeChildType_arg, 17, ARGUMENT_NAME, "XMNFRAMECHILDTYPE"},
    {tkn_k_class_argument, sym_k_XmNframeShadowThickness_arg, 23, ARGUMENT_NAME, "XMNFRAMESHADOWTHICKNESS"},
    {tkn_k_class_argument, sym_k_XmNfreeTabPixmap_arg, 16, ARGUMENT_NAME, "XMNFREETABPIXMAP"},
    {tkn_k_class_reason, sym_k_XmNgainPrimaryCallback_reason, 22, REASON_NAME, "XMNGAINPRIMARYCALLBACK"},
    {tkn_k_class_argument, sym_k_XmNgeometry_arg, 11, ARGUMENT_NAME, "XMNGEOMETRY"},
    {tkn_k_class_argument, sym_k_XmNgreenSliderLabel_arg, 19, ARGUMENT_NAME, "XMNGREENSLIDERLABEL"},
    {tkn_k_class_argument, sym_k_XmNheight_arg, 9, ARGUMENT_NAME, "XMNHEIGHT"},
    {tkn_k_class_argument, sym_k_XmNheightInc_arg, 12, ARGUMENT_NAME, "XMNHEIGHTINC"},
    {tkn_k_class_reason, sym_k_XmNhelpCallback_reason, 15, REASON_NAME, "XMNHELPCALLBACK"},
    {tkn_k_class_argument, sym_k_XmNhelpLabelString_arg, 18, ARGUMENT_NAME, "XMNHELPLABELSTRING"},
    {tkn_k_class_argument, sym_k_XmNhighlightColor_arg, 17, ARGUMENT_NAME, "XMNHIGHLIGHTCOLOR"},
    {tkn_k_class_argument, sym_k_XmNhighlightOnEnter_arg, 19, ARGUMENT_NAME, "XMNHIGHLIGHTONENTER"},
    {tkn_k_class_argument, sym_k_XmNhighlightPixmap_arg, 18, ARGUMENT_NAME, "XMNHIGHLIGHTPIXMAP"},
    {tkn_k_class_argument, sym_k_XmNhighlightThickness_arg, 21, ARGUMENT_NAME, "XMNHIGHLIGHTTHICKNESS"},
    {tkn_k_class_argument, sym_k_XmNhistoryItemCount_arg, 19, ARGUMENT_NAME, "XMNHISTORYITEMCOUNT"},
    {tkn_k_class_argument, sym_k_XmNhistoryItems_arg, 15, ARGUMENT_NAME, "XMNHISTORYITEMS"},
    {tkn_k_class_argument, sym_k_XmNhistoryMaxItems_arg, 18, ARGUMENT_NAME, "XMNHISTORYMAXITEMS"},
    {tkn_k_class_argument, sym_k_XmNhistoryVisibleItemCount_arg, 26, ARGUMENT_NAME, "XMNHISTORYVISIBLEITEMCOUNT"},
    {tkn_k_class_argument, sym_k_XmNhorizontalDelta_arg, 18, ARGUMENT_NAME, "XMNHORIZONTALDELTA"},
    {tkn_k_class_argument, sym_k_XmNhorizontalMargin_arg, 19, ARGUMENT_NAME, "XMNHORIZONTALMARGIN"},
    {tkn_k_class_argument, sym_k_XmNhorizontalNodeSpace_arg, 22, ARGUMENT_NAME, "XMNHORIZONTALNODESPACE"},
    {tkn_k_class_argument, sym_k_XmNhorizontalScrollBar_arg, 22, ARGUMENT_NAME, "XMNHORIZONTALSCROLLBAR"},
    {tkn_k_class_argument, sym_k_XmNhorizontalSpacing_arg, 20, ARGUMENT_NAME, "XMNHORIZONTALSPACING"},
    {tkn_k_class_argument, sym_k_XmNiconic_arg, 9, ARGUMENT_NAME, "XMNICONIC"},
    {tkn_k_class_argument, sym_k_XmNiconMask_arg, 11, ARGUMENT_NAME, "XMNICONMASK"},
    {tkn_k_class_argument, sym_k_XmNiconName_arg, 11, ARGUMENT_NAME, "XMNICONNAME"},
    {tkn_k_class_argument, sym_k_XmNiconNameEncoding_arg, 19, ARGUMENT_NAME, "XMNICONNAMEENCODING"},
    {tkn_k_class_argument, sym_k_XmNiconPixmap_arg, 13, ARGUMENT_NAME, "XMNICONPIXMAP"},
    {tkn_k_class_argument, sym_k_XmNiconPlacement_arg, 16, ARGUMENT_NAME, "XMNICONPLACEMENT"},
    {tkn_k_class_argument, sym_k_XmNiconTextPadding_arg, 18, ARGUMENT_NAME, "XMNICONTEXTPADDING"},
    {tkn_k_class_argument, sym_k_XmNiconWindow_arg, 13, ARGUMENT_NAME, "XMNICONWINDOW"},
    {tkn_k_class_argument, sym_k_XmNiconX_arg, 8, ARGUMENT_NAME, "XMNICONX"},
    {tkn_k_class_argument, sym_k_XmNiconY_arg, 8, ARGUMENT_NAME, "XMNICONY"},
    {tkn_k_class_argument, sym_k_XmNincrement_arg, 12, ARGUMENT_NAME, "XMNINCREMENT"},
    {tkn_k_class_reason, sym_k_XmNincrementCallback_reason, 20, REASON_NAME, "XMNINCREMENTCALLBACK"},
    {tkn_k_class_argument, sym_k_XmNincrementValue_arg, 17, ARGUMENT_NAME, "XMNINCREMENTVALUE"},
    {tkn_k_class_argument, sym_k_XmNindentSpace_arg, 14, ARGUMENT_NAME, "XMNINDENTSPACE"},
    {tkn_k_class_argument, sym_k_XmNindeterminateInsensitivePixmap_arg, 33, ARGUMENT_NAME, "XMNINDETERMINATEINSENSITIVEPIXMAP"},
    {tkn_k_class_argument, sym_k_XmNindeterminatePixmap_arg, 22, ARGUMENT_NAME, "XMNINDETERMINATEPIXMAP"},
    {tkn_k_class_argument, sym_k_XmNindicatorOn_arg, 14, ARGUMENT_NAME, "XMNINDICATORON"},
    {tkn_k_class_argument, sym_k_XmNindicatorSize_arg, 16, ARGUMENT_NAME, "XMNINDICATORSIZE"},
    {tkn_k_class_argument, sym_k_XmNindicatorType_arg, 16, ARGUMENT_NAME, "XMNINDICATORTYPE"},
    {tkn_k_class_argument, sym_k_XmNinitialDelay_arg, 15, ARGUMENT_NAME, "XMNINITIALDELAY"},
    {tkn_k_class_argument, sym_k_XmNinitialFocus_arg, 15, ARGUMENT_NAME, "XMNINITIALFOCUS"},
    {tkn_k_class_argument, sym_k_XmNinitialResourcesPersistent_arg, 29, ARGUMENT_NAME, "XMNINITIALRESOURCESPERSISTENT"},
    {tkn_k_class_argument, sym_k_XmNinitialState_arg, 15, ARGUMENT_NAME, "XMNINITIALSTATE"},
    {tkn_k_class_argument, sym_k_XmNinnerMarginHeight_arg, 20, ARGUMENT_NAME, "XMNINNERMARGINHEIGHT"},
    {tkn_k_class_argument, sym_k_XmNinnerMarginWidth_arg, 19, ARGUMENT_NAME, "XMNINNERMARGINWIDTH"},
    {tkn_k_class_argument, sym_k_XmNinput_arg, 8, ARGUMENT_NAME, "XMNINPUT"},
    {tkn_k_class_reason, sym_k_XmNinputCallback_reason, 16, REASON_NAME, "XMNINPUTCALLBACK"},
    {tkn_k_class_argument, sym_k_XmNinputMethod_arg, 14, ARGUMENT_NAME, "XMNINPUTMETHOD"},
    {tkn_k_class_argument, sym_k_XmNinputPolicy_arg, 14, ARGUMENT_NAME, "XMNINPUTPOLICY"},
    {tkn_k_class_argument, sym_k_XmNinsertBefore_arg, 15, ARGUMENT_NAME, "XMNINSERTBEFORE"},
    {tkn_k_class_argument, sym_k_XmNinsertPosition_arg, 17, ARGUMENT_NAME, "XMNINSERTPOSITION"},
    {tkn_k_class_argument, sym_k_XmNisAligned_arg, 12, ARGUMENT_NAME, "XMNISALIGNED"},
    {tkn_k_class_argument, sym_k_XmNisHomogeneous_arg, 16, ARGUMENT_NAME, "XMNISHOMOGENEOUS"},
    {tkn_k_class_argument, sym_k_XmNitalicString_arg, 15, ARGUMENT_NAME, "XMNITALICSTRING"},
    {tkn_k_class_argument, sym_k_XmNitemCount_arg, 12, ARGUMENT_NAME, "XMNITEMCOUNT"},
    {tkn_k_class_reason, sym_k_XmNitemFoundCallback_reason, 20, REASON_NAME, "XMNITEMFOUNDCALLBACK"},
    {tkn_k_class_reason, sym_k_XmNitemNotFoundCallback_reason, 23, REASON_NAME, "XMNITEMNOTFOUNDCALLBACK"},
    {tkn_k_class_argument, sym_k_XmNitems_arg, 8, ARGUMENT_NAME, "XMNITEMS"},
    {tkn_k_class_argument, sym_k_XmNitemSpacing_arg, 14, ARGUMENT_NAME, "XMNITEMSPACING"},
    {tkn_k_class_argument, sym_k_XmNkeyboardFocusPolicy_arg, 22, ARGUMENT_NAME, "XMNKEYBOARDFOCUSPOLICY"},
    {tkn_k_class_argument, sym_k_XmNlabel_arg, 8, ARGUMENT_NAME, "XMNLABEL"},
    {tkn_k_class_argument, sym_k_XmNlabelFontList_arg, 16, ARGUMENT_NAME, "XMNLABELFONTLIST"},
    {tkn_k_class_argument, sym_k_XmNlabelInsensitivePixmap_arg, 25, ARGUMENT_NAME, "XMNLABELINSENSITIVEPIXMAP"},
    {tkn_k_class_argument, sym_k_XmNlabelPixmap_arg, 14, ARGUMENT_NAME, "XMNLABELPIXMAP"},
    {tkn_k_class_argument, sym_k_XmNlabelRenderTable_arg, 19, ARGUMENT_NAME, "XMNLABELRENDERTABLE"},
    {tkn_k_class_argument, sym_k_XmNlabelSpacing_arg, 15, ARGUMENT_NAME, "XMNLABELSPACING"},
    {tkn_k_class_argument, sym_k_XmNlabelString_arg, 14, ARGUMENT_NAME, "XMNLABELSTRING"},
    {tkn_k_class_argument, sym_k_XmNlabelType_arg, 12, ARGUMENT_NAME, "XMNLABELTYPE"},
    {tkn_k_class_argument, sym_k_XmNlargeCellHeight_arg, 18, ARGUMENT_NAME, "XMNLARGECELLHEIGHT"},
    {tkn_k_class_argument, sym_k_XmNlargeCellWidth_arg, 17, ARGUMENT_NAME, "XMNLARGECELLWIDTH"},
    {tkn_k_class_argument, sym_k_XmNlargeIconMask_arg, 16, ARGUMENT_NAME, "XMNLARGEICONMASK"},
    {tkn_k_class_argument, sym_k_XmNlargeIconPixmap_arg, 18, ARGUMENT_NAME, "XMNLARGEICONPIXMAP"},
    {tkn_k_class_argument, sym_k_XmNlargeIconX_arg, 13, ARGUMENT_NAME, "XMNLARGEICONX"},
    {tkn_k_class_argument, sym_k_XmNlargeIconY_arg, 13, ARGUMENT_NAME, "XMNLARGEICONY"},
    {tkn_k_class_argument, sym_k_XmNlastPageNumber_arg, 17, ARGUMENT_NAME, "XMNLASTPAGENUMBER"},
    {tkn_k_class_argument, sym_k_XmNlayoutDirection_arg, 18, ARGUMENT_NAME, "XMNLAYOUTDIRECTION"},
    {tkn_k_class_argument, sym_k_XmNlayoutType_arg, 13, ARGUMENT_NAME, "XMNLAYOUTTYPE"},
    {tkn_k_class_argument, sym_k_XmNleftAttachment_arg, 17, ARGUMENT_NAME, "XMNLEFTATTACHMENT"},
    {tkn_k_class_argument, sym_k_XmNleftOffset_arg, 13, ARGUMENT_NAME, "XMNLEFTOFFSET"},
    {tkn_k_class_argument, sym_k_XmNleftPosition_arg, 15, ARGUMENT_NAME, "XMNLEFTPOSITION"},
    {tkn_k_class_argument, sym_k_XmNleftWidget_arg, 13, ARGUMENT_NAME, "XMNLEFTWIDGET"},
    {tkn_k_class_argument, sym_k_XmNlightThreshold_arg, 17, ARGUMENT_NAME, "XMNLIGHTTHRESHOLD"},
    {tkn_k_class_argument, sym_k_XmNlineBackgroundColor_arg, 22, ARGUMENT_NAME, "XMNLINEBACKGROUNDCOLOR"},
    {tkn_k_class_argument, sym_k_XmNlineColor_arg, 12, ARGUMENT_NAME, "XMNLINECOLOR"},
    {tkn_k_class_argument, sym_k_XmNlineStyle_arg, 12, ARGUMENT_NAME, "XMNLINESTYLE"},
    {tkn_k_class_argument, sym_k_XmNlineWidth_arg, 12, ARGUMENT_NAME, "XMNLINEWIDTH"},
    {tkn_k_class_argument, sym_k_XmNlist_arg, 7, ARGUMENT_NAME, "XMNLIST"},
    {tkn_k_class_argument, sym_k_XmNlistItemCount_arg, 16, ARGUMENT_NAME, "XMNLISTITEMCOUNT"},
    {tkn_k_class_argument, sym_k_XmNlistItems_arg, 12, ARGUMENT_NAME, "XMNLISTITEMS"},
    {tkn_k_class_argument, sym_k_XmNlistLabelString_arg, 18, ARGUMENT_NAME, "XMNLISTLABELSTRING"},
    {tkn_k_class_argument, sym_k_XmNlistMarginHeight_arg, 19, ARGUMENT_NAME, "XMNLISTMARGINHEIGHT"},
    {tkn_k_class_argument, sym_k_XmNlistMarginWidth_arg, 18, ARGUMENT_NAME, "XMNLISTMARGINWIDTH"},
    {tkn_k_class_argument, sym_k_XmNlistSizePolicy_arg, 17, ARGUMENT_NAME, "XMNLISTSIZEPOLICY"},
    {tkn_k_class_argument, sym_k_XmNlistSpacing_arg, 14, ARGUMENT_NAME, "XMNLISTSPACING"},
    {tkn_k_class_argument, sym_k_XmNlistUpdated_arg, 14, ARGUMENT_NAME, "XMNLISTUPDATED"},
    {tkn_k_class_argument, sym_k_XmNlistVisibleItemCount_arg, 23, ARGUMENT_NAME, "XMNLISTVISIBLEITEMCOUNT"},
    {tkn_k_class_argument, sym_k_XmNloadModel_arg, 12, ARGUMENT_NAME, "XMNLOADMODEL"},
    {tkn_k_class_reason, sym_k_XmNlosePrimaryCallback_reason, 22, REASON_NAME, "XMNLOSEPRIMARYCALLBACK"},
    {tkn_k_class_reason, sym_k_XmNlosingFocusCallback_reason, 22, REASON_NAME, "XMNLOSINGFOCUSCALLBACK"},
    {tkn_k_class_argument, sym_k_XmNmainWindowMarginHeight_arg, 25, ARGUMENT_NAME, "XMNMAINWINDOWMARGINHEIGHT"},
    {tkn_k_class_argument, sym_k_XmNmainWindowMarginWidth_arg, 24, ARGUMENT_NAME, "XMNMAINWINDOWMARGINWIDTH"},
    {tkn_k_class_argument, sym_k_XmNmajorTabSpacing_arg, 18, ARGUMENT_NAME, "XMNMAJORTABSPACING"},
    {tkn_k_class_reason, sym_k_XmNmapCallback_reason, 14, REASON_NAME, "XMNMAPCALLBACK"},
    {tkn_k_class_argument, sym_k_XmNmappedWhenManaged_arg, 20, ARGUMENT_NAME, "XMNMAPPEDWHENMANAGED"},
    {tkn_k_class_argument, sym_k_XmNmappingDelay_arg, 15, ARGUMENT_NAME, "XMNMAPPINGDELAY"},
    {tkn_k_class_argument, sym_k_XmNmargin_arg, 9, ARGUMENT_NAME, "XMNMARGIN"},
    {tkn_k_class_argument, sym_k_XmNmarginBottom_arg, 15, ARGUMENT_NAME, "XMNMARGINBOTTOM"},
    {tkn_k_class_argument, sym_k_XmNmarginHeight_arg, 15, ARGUMENT_NAME, "XMNMARGINHEIGHT"},
    {tkn_k_class_argument, sym_k_XmNmarginLeft_arg, 13, ARGUMENT_NAME, "XMNMARGINLEFT"},
    {tkn_k_class_argument, sym_k_XmNmarginRight_arg, 14, ARGUMENT_NAME, "XMNMARGINRIGHT"},
    {tkn_k_class_argument, sym_k_XmNmarginTop_arg, 12, ARGUMENT_NAME, "XMNMARGINTOP"},
    {tkn_k_class_argument, sym_k_XmNmarginWidth_arg, 14, ARGUMENT_NAME, "XMNMARGINWIDTH"},
    {tkn_k_class_argument, sym_k_XmNmatchBehavior_arg, 16, ARGUMENT_NAME, "XMNMATCHBEHAVIOR"},
    {tkn_k_class_argument, sym_k_XmNmaxAspectX_arg, 13, ARGUMENT_NAME, "XMNMAXASPECTX"},
    {tkn_k_class_argument, sym_k_XmNmaxAspectY_arg, 13, ARGUMENT_NAME, "XMNMAXASPECTY"},
    {tkn_k_class_argument, sym_k_XmNmaxHeight_arg, 12, ARGUMENT_NAME, "XMNMAXHEIGHT"},
    {tkn_k_class_argument, sym_k_XmNmaximum_arg, 10, ARGUMENT_NAME, "XMNMAXIMUM"},
    {tkn_k_class_argument, sym_k_XmNmaximumValue_arg, 15, ARGUMENT_NAME, "XMNMAXIMUMVALUE"},
    {tkn_k_class_argument, sym_k_XmNmaxLength_arg, 12, ARGUMENT_NAME, "XMNMAXLENGTH"},
    {tkn_k_class_argument, sym_k_XmNmaxWidth_arg, 11, ARGUMENT_NAME, "XMNMAXWIDTH"},
    {tkn_k_class_argument, sym_k_XmNmenuAccelerator_arg, 18, ARGUMENT_NAME, "XMNMENUACCELERATOR"},
    {tkn_k_class_argument, sym_k_XmNmenuBar_arg, 10, ARGUMENT_NAME, "XMNMENUBAR"},
    {tkn_k_class_argument, sym_k_XmNmenuHelpWidget_arg, 17, ARGUMENT_NAME, "XMNMENUHELPWIDGET"},
    {tkn_k_class_argument, sym_k_XmNmenuHistory_arg, 14, ARGUMENT_NAME, "XMNMENUHISTORY"},
    {tkn_k_class_argument, sym_k_XmNmenuPost_arg, 11, ARGUMENT_NAME, "XMNMENUPOST"},
    {tkn_k_class_argument, sym_k_XmNmessageAlignment_arg, 19, ARGUMENT_NAME, "XMNMESSAGEALIGNMENT"},
    {tkn_k_class_argument, sym_k_XmNmessageString_arg, 16, ARGUMENT_NAME, "XMNMESSAGESTRING"},
    {tkn_k_class_argument, sym_k_XmNmessageWindow_arg, 16, ARGUMENT_NAME, "XMNMESSAGEWINDOW"},
    {tkn_k_class_argument, sym_k_XmNminAspectX_arg, 13, ARGUMENT_NAME, "XMNMINASPECTX"},
    {tkn_k_class_argument, sym_k_XmNminAspectY_arg, 13, ARGUMENT_NAME, "XMNMINASPECTY"},
    {tkn_k_class_argument, sym_k_XmNminHeight_arg, 12, ARGUMENT_NAME, "XMNMINHEIGHT"},
    {tkn_k_class_argument, sym_k_XmNminimizeButtons_arg, 18, ARGUMENT_NAME, "XMNMINIMIZEBUTTONS"},
    {tkn_k_class_argument, sym_k_XmNminimum_arg, 10, ARGUMENT_NAME, "XMNMINIMUM"},
    {tkn_k_class_argument, sym_k_XmNminimumCellHeight_arg, 20, ARGUMENT_NAME, "XMNMINIMUMCELLHEIGHT"},
    {tkn_k_class_argument, sym_k_XmNminimumCellWidth_arg, 19, ARGUMENT_NAME, "XMNMINIMUMCELLWIDTH"},
    {tkn_k_class_argument, sym_k_XmNminimumHorizontalCells_arg, 25, ARGUMENT_NAME, "XMNMINIMUMHORIZONTALCELLS"},
    {tkn_k_class_argument, sym_k_XmNminimumValue_arg, 15, ARGUMENT_NAME, "XMNMINIMUMVALUE"},
    {tkn_k_class_argument, sym_k_XmNminimumVerticalCells_arg, 23, ARGUMENT_NAME, "XMNMINIMUMVERTICALCELLS"},
    {tkn_k_class_argument, sym_k_XmNminorTabSpacing_arg, 18, ARGUMENT_NAME, "XMNMINORTABSPACING"},
    {tkn_k_class_argument, sym_k_XmNminWidth_arg, 11, ARGUMENT_NAME, "XMNMINWIDTH"},
    {tkn_k_class_argument, sym_k_XmNmnemonic_arg, 11, ARGUMENT_NAME, "XMNMNEMONIC"},
    {tkn_k_class_argument, sym_k_XmNmnemonicCharSet_arg, 18, ARGUMENT_NAME, "XMNMNEMONICCHARSET"},
    {tkn_k_class_reason, sym_k_XmNmodifyVerifyCallback_reason, 23, REASON_NAME, "XMNMODIFYVERIFYCALLBACK"},
    {tkn_k_class_reason, sym_k_XmNmodifyVerifyCallbackWcs_reason, 26, REASON_NAME, "XMNMODIFYVERIFYCALLBACKWCS"},
    {tkn_k_class_argument, sym_k_XmNmonoSpaceString_arg, 18, ARGUMENT_NAME, "XMNMONOSPACESTRING"},
    {tkn_k_class_reason, sym_k_XmNmotionVerifyCallback_reason, 23, REASON_NAME, "XMNMOTIONVERIFYCALLBACK"},
    {tkn_k_class_argument, sym_k_XmNmultiClick_arg, 13, ARGUMENT_NAME, "XMNMULTICLICK"},
    {tkn_k_class_reason, sym_k_XmNmultipleSelectionCallback_reason, 28, REASON_NAME, "XMNMULTIPLESELECTIONCALLBACK"},
    {tkn_k_class_argument, sym_k_XmNmustMatch_arg, 12, ARGUMENT_NAME, "XMNMUSTMATCH"},
    {tkn_k_class_argument, sym_k_XmNmwmDecorations_arg, 17, ARGUMENT_NAME, "XMNMWMDECORATIONS"},
    {tkn_k_class_argument, sym_k_XmNmwmFunctions_arg, 15, ARGUMENT_NAME, "XMNMWMFUNCTIONS"},
    {tkn_k_class_argument, sym_k_XmNmwmInputMode_arg, 15, ARGUMENT_NAME, "XMNMWMINPUTMODE"},
    {tkn_k_class_argument, sym_k_XmNmwmMenu_arg, 10, ARGUMENT_NAME, "XMNMWMMENU"},
    {tkn_k_class_argument, sym_k_XmNnavigationType_arg, 17, ARGUMENT_NAME, "XMNNAVIGATIONTYPE"},
    {tkn_k_class_argument, sym_k_XmNnewVisualStyle_arg, 17, ARGUMENT_NAME, "XMNNEWVISUALSTYLE"},
    {tkn_k_class_argument, sym_k_XmNnoCellError_arg, 14, ARGUMENT_NAME, "XMNNOCELLERROR"},
    {tkn_k_class_argument, sym_k_XmNnodeCloseFolderPixmap_arg, 24, ARGUMENT_NAME, "XMNNODECLOSEFOLDERPIXMAP"},
    {tkn_k_class_argument, sym_k_XmNnodeOpenFolderPixmap_arg, 23, ARGUMENT_NAME, "XMNNODEOPENFOLDERPIXMAP"},
    {tkn_k_class_argument, sym_k_XmNnodeState_arg, 12, ARGUMENT_NAME, "XMNNODESTATE"},
    {tkn_k_class_reason, sym_k_XmNnodeStateBegEndCallback_reason, 26, REASON_NAME, "XMNNODESTATEBEGENDCALLBACK"},
    {tkn_k_class_reason, sym_k_XmNnodeStateCallback_reason, 20, REASON_NAME, "XMNNODESTATECALLBACK"},
    {tkn_k_class_reason, sym_k_XmNnodeStateChangedCallback_reason, 27, REASON_NAME, "XMNNODESTATECHANGEDCALLBACK"},
    {tkn_k_class_reason, sym_k_XmNnoMatchCallback_reason, 18, REASON_NAME, "XMNNOMATCHCALLBACK"},
    {tkn_k_class_argument, sym_k_XmNnoMatchString_arg, 16, ARGUMENT_NAME, "XMNNOMATCHSTRING"},
    {tkn_k_class_argument, sym_k_XmNnoResize_arg, 11, ARGUMENT_NAME, "XMNNORESIZE"},
    {tkn_k_class_argument, sym_k_XmNnotebookChildType_arg, 20, ARGUMENT_NAME, "XMNNOTEBOOKCHILDTYPE"},
    {tkn_k_class_argument, sym_k_XmNnumColumns_arg, 13, ARGUMENT_NAME, "XMNNUMCOLUMNS"},
    {tkn_k_class_argument, sym_k_XmNnumRows_arg, 10, ARGUMENT_NAME, "XMNNUMROWS"},
    {tkn_k_class_argument, sym_k_XmNnumStacks_arg, 12, ARGUMENT_NAME, "XMNNUMSTACKS"},
    {tkn_k_class_argument, sym_k_XmNnumValues_arg, 12, ARGUMENT_NAME, "XMNNUMVALUES"},
    {tkn_k_class_argument, sym_k_XmNoffsetModel_arg, 14, ARGUMENT_NAME, "XMNOFFSETMODEL"},
    {tkn_k_class_reason, sym_k_XmNokCallback_reason, 13, REASON_NAME, "XMNOKCALLBACK"},
    {tkn_k_class_argument, sym_k_XmNokLabelString_arg, 16, ARGUMENT_NAME, "XMNOKLABELSTRING"},
    {tkn_k_class_enumval, sym_k_XmNONE_enumval, 6, ENUMVAL_NAME, "XMNONE"},
    {tkn_k_class_argument, sym_k_XmNopenClosePadding_arg, 19, ARGUMENT_NAME, "XMNOPENCLOSEPADDING"},
    {tkn_k_class_argument, sym_k_XmNopenFolderPixmap_arg, 19, ARGUMENT_NAME, "XMNOPENFOLDERPIXMAP"},
    {tkn_k_class_argument, sym_k_XmNoptionString_arg, 15, ARGUMENT_NAME, "XMNOPTIONSTRING"},
    {tkn_k_class_argument, sym_k_XmNorientation_arg, 14, ARGUMENT_NAME, "XMNORIENTATION"},
    {tkn_k_class_enumval, sym_k_XmNORMAL_MODE_enumval, 13, ENUMVAL_NAME, "XMNORMAL_MODE"},
    {tkn_k_class_class, sym_k_XmNotebook_object, 10, CLASS_NAME, "XMNOTEBOOK"},
    {tkn_k_class_argument, sym_k_XmNotherString_arg, 14, ARGUMENT_NAME, "XMNOTHERSTRING"},
    {tkn_k_class_enumval, sym_k_XmNOT_SELECTED_enumval, 14, ENUMVAL_NAME, "XMNOT_SELECTED"},
    {tkn_k_class_argument, sym_k_XmNoutlineButtonPolicy_arg, 22, ARGUMENT_NAME, "XMNOUTLINEBUTTONPOLICY"},
    {tkn_k_class_reason, sym_k_XmNoutlineChangedCallback_reason, 25, REASON_NAME, "XMNOUTLINECHANGEDCALLBACK"},
    {tkn_k_class_argument, sym_k_XmNoutlineColumnWidth_arg, 21, ARGUMENT_NAME, "XMNOUTLINECOLUMNWIDTH"},
    {tkn_k_class_argument, sym_k_XmNoutlineIndentation_arg, 21, ARGUMENT_NAME, "XMNOUTLINEINDENTATION"},
    {tkn_k_class_argument, sym_k_XmNoutlineLineStyle_arg, 19, ARGUMENT_NAME, "XMNOUTLINELINESTYLE"},
    {tkn_k_class_argument, sym_k_XmNoutlineState_arg, 15, ARGUMENT_NAME, "XMNOUTLINESTATE"},
    {tkn_k_class_argument, sym_k_XmNoverrideRedirect_arg, 19, ARGUMENT_NAME, "XMNOVERRIDEREDIRECT"},
    {tkn_k_class_enumval, sym_k_XmNO_AUTO_SELECT_enumval, 16, ENUMVAL_NAME, "XMNO_AUTO_SELECT"},
    {tkn_k_class_enumval, sym_k_XmNO_LINE_enumval, 9, ENUMVAL_NAME, "XMNO_LINE"},
    {tkn_k_class_enumval, sym_k_XmNO_ORIENTATION_enumval, 16, ENUMVAL_NAME, "XMNO_ORIENTATION"},
    {tkn_k_class_enumval, sym_k_XmNO_PACKING_enumval, 12, ENUMVAL_NAME, "XMNO_PACKING"},
    {tkn_k_class_enumval, sym_k_XmNO_SCROLL_enumval, 11, ENUMVAL_NAME, "XMNO_SCROLL"},
    {tkn_k_class_argument, sym_k_XmNpacking_arg, 10, ARGUMENT_NAME, "XMNPACKING"},
    {tkn_k_class_reason, sym_k_XmNpageChangedCallback_reason, 22, REASON_NAME, "XMNPAGECHANGEDCALLBACK"},
    {tkn_k_class_reason, sym_k_XmNpageDecrementCallback_reason, 24, REASON_NAME, "XMNPAGEDECREMENTCALLBACK"},
    {tkn_k_class_argument, sym_k_XmNpageIncrement_arg, 16, ARGUMENT_NAME, "XMNPAGEINCREMENT"},
    {tkn_k_class_reason, sym_k_XmNpageIncrementCallback_reason, 24, REASON_NAME, "XMNPAGEINCREMENTCALLBACK"},
    {tkn_k_class_argument, sym_k_XmNpageNumber_arg, 13, ARGUMENT_NAME, "XMNPAGENUMBER"},
    {tkn_k_class_argument, sym_k_XmNpaneMaximum_arg, 14, ARGUMENT_NAME, "XMNPANEMAXIMUM"},
    {tkn_k_class_argument, sym_k_XmNpaneMinimum_arg, 14, ARGUMENT_NAME, "XMNPANEMINIMUM"},
    {tkn_k_class_argument, sym_k_XmNparentNode_arg, 13, ARGUMENT_NAME, "XMNPARENTNODE"},
    {tkn_k_class_argument, sym_k_XmNpattern_arg, 10, ARGUMENT_NAME, "XMNPATTERN"},
    {tkn_k_class_argument, sym_k_XmNpendingDelete_arg, 16, ARGUMENT_NAME, "XMNPENDINGDELETE"},
    {tkn_k_class_argument, sym_k_XmNpicture_arg, 10, ARGUMENT_NAME, "XMNPICTURE"},
    {tkn_k_class_reason, sym_k_XmNpictureErrorCallback_reason, 23, REASON_NAME, "XMNPICTUREERRORCALLBACK"},
    {tkn_k_class_argument, sym_k_XmNpixmap_arg, 9, ARGUMENT_NAME, "XMNPIXMAP"},
    {tkn_k_class_argument, sym_k_XmNpixmapDepth_arg, 14, ARGUMENT_NAME, "XMNPIXMAPDEPTH"},
    {tkn_k_class_argument, sym_k_XmNpixmapHeight_arg, 15, ARGUMENT_NAME, "XMNPIXMAPHEIGHT"},
    {tkn_k_class_argument, sym_k_XmNpixmapPlacement_arg, 18, ARGUMENT_NAME, "XMNPIXMAPPLACEMENT"},
    {tkn_k_class_argument, sym_k_XmNpixmapTextPadding_arg, 20, ARGUMENT_NAME, "XMNPIXMAPTEXTPADDING"},
    {tkn_k_class_argument, sym_k_XmNpixmapWidth_arg, 14, ARGUMENT_NAME, "XMNPIXMAPWIDTH"},
    {tkn_k_class_reason, sym_k_XmNpopdownCallback_reason, 18, REASON_NAME, "XMNPOPDOWNCALLBACK"},
    {tkn_k_class_reason, sym_k_XmNpopupCallback_reason, 16, REASON_NAME, "XMNPOPUPCALLBACK"},
    {tkn_k_class_argument, sym_k_XmNpopupCursor_arg, 14, ARGUMENT_NAME, "XMNPOPUPCURSOR"},
    {tkn_k_class_argument, sym_k_XmNpopupEnabled_arg, 15, ARGUMENT_NAME, "XMNPOPUPENABLED"},
    {tkn_k_class_reason, sym_k_XmNpopupHandlerCallback_reason, 23, REASON_NAME, "XMNPOPUPHANDLERCALLBACK"},
    {tkn_k_class_argument, sym_k_XmNpopupOffset_arg, 14, ARGUMENT_NAME, "XMNPOPUPOFFSET"},
    {tkn_k_class_argument, sym_k_XmNpopupShellWidget_arg, 19, ARGUMENT_NAME, "XMNPOPUPSHELLWIDGET"},
    {tkn_k_class_argument, sym_k_XmNposition_arg, 11, ARGUMENT_NAME, "XMNPOSITION"},
    {tkn_k_class_argument, sym_k_XmNpositionIndex_arg, 16, ARGUMENT_NAME, "XMNPOSITIONINDEX"},
    {tkn_k_class_argument, sym_k_XmNpositionMode_arg, 15, ARGUMENT_NAME, "XMNPOSITIONMODE"},
    {tkn_k_class_argument, sym_k_XmNpositionType_arg, 15, ARGUMENT_NAME, "XMNPOSITIONTYPE"},
    {tkn_k_class_argument, sym_k_XmNpreeditType_arg, 14, ARGUMENT_NAME, "XMNPREEDITTYPE"},
    {tkn_k_class_argument, sym_k_XmNpreferredPaneSize_arg, 20, ARGUMENT_NAME, "XMNPREFERREDPANESIZE"},
    {tkn_k_class_argument, sym_k_XmNprimaryOwnership_arg, 19, ARGUMENT_NAME, "XMNPRIMARYOWNERSHIP"},
    {tkn_k_class_argument, sym_k_XmNprocessingDirection_arg, 22, ARGUMENT_NAME, "XMNPROCESSINGDIRECTION"},
    {tkn_k_class_argument, sym_k_XmNpromptString_arg, 15, ARGUMENT_NAME, "XMNPROMPTSTRING"},
    {tkn_k_class_argument, sym_k_XmNpropSpaceString_arg, 18, ARGUMENT_NAME, "XMNPROPSPACESTRING"},
    {tkn_k_class_argument, sym_k_XmNpushButtonEnabled_arg, 20, ARGUMENT_NAME, "XMNPUSHBUTTONENABLED"},
    {tkn_k_class_argument, sym_k_XmNqualifySearchDataProc_arg, 24, ARGUMENT_NAME, "XMNQUALIFYSEARCHDATAPROC"},
    {tkn_k_class_argument, sym_k_XmNradioAlwaysOne_arg, 17, ARGUMENT_NAME, "XMNRADIOALWAYSONE"},
    {tkn_k_class_argument, sym_k_XmNradioBehavior_arg, 16, ARGUMENT_NAME, "XMNRADIOBEHAVIOR"},
    {tkn_k_class_reason, sym_k_XmNrealizeCallback_reason, 18, REASON_NAME, "XMNREALIZECALLBACK"},
    {tkn_k_class_argument, sym_k_XmNrecomputeSize_arg, 16, ARGUMENT_NAME, "XMNRECOMPUTESIZE"},
    {tkn_k_class_argument, sym_k_XmNredSliderLabel_arg, 17, ARGUMENT_NAME, "XMNREDSLIDERLABEL"},
    {tkn_k_class_argument, sym_k_XmNrefigureMode_arg, 15, ARGUMENT_NAME, "XMNREFIGUREMODE"},
    {tkn_k_class_argument, sym_k_XmNrenderTable_arg, 14, ARGUMENT_NAME, "XMNRENDERTABLE"},
    {tkn_k_class_argument, sym_k_XmNrenditionBackground_arg, 22, ARGUMENT_NAME, "XMNRENDITIONBACKGROUND"},
    {tkn_k_class_argument, sym_k_XmNrenditionForeground_arg, 22, ARGUMENT_NAME, "XMNRENDITIONFOREGROUND"},
    {tkn_k_class_argument, sym_k_XmNrepeatDelay_arg, 14, ARGUMENT_NAME, "XMNREPEATDELAY"},
    {tkn_k_class_argument, sym_k_XmNresizable_arg, 12, ARGUMENT_NAME, "XMNRESIZABLE"},
    {tkn_k_class_reason, sym_k_XmNresizeCallback_reason, 17, REASON_NAME, "XMNRESIZECALLBACK"},
    {tkn_k_class_argument, sym_k_XmNresizeHeight_arg, 15, ARGUMENT_NAME, "XMNRESIZEHEIGHT"},
    {tkn_k_class_argument, sym_k_XmNresizePolicy_arg, 15, ARGUMENT_NAME, "XMNRESIZEPOLICY"},
    {tkn_k_class_argument, sym_k_XmNresizeToPreferred_arg, 20, ARGUMENT_NAME, "XMNRESIZETOPREFERRED"},
    {tkn_k_class_argument, sym_k_XmNresizeWidth_arg, 14, ARGUMENT_NAME, "XMNRESIZEWIDTH"},
    {tkn_k_class_argument, sym_k_XmNrgbFile_arg, 10, ARGUMENT_NAME, "XMNRGBFILE"},
    {tkn_k_class_argument, sym_k_XmNrightAttachment_arg, 18, ARGUMENT_NAME, "XMNRIGHTATTACHMENT"},
    {tkn_k_class_argument, sym_k_XmNrightOffset_arg, 14, ARGUMENT_NAME, "XMNRIGHTOFFSET"},
    {tkn_k_class_argument, sym_k_XmNrightPosition_arg, 16, ARGUMENT_NAME, "XMNRIGHTPOSITION"},
    {tkn_k_class_argument, sym_k_XmNrightWidget_arg, 14, ARGUMENT_NAME, "XMNRIGHTWIDGET"},
    {tkn_k_class_argument, sym_k_XmNrowColumnType_arg, 16, ARGUMENT_NAME, "XMNROWCOLUMNTYPE"},
    {tkn_k_class_argument, sym_k_XmNrows_arg, 7, ARGUMENT_NAME, "XMNROWS"},
    {tkn_k_class_argument, sym_k_XmNrubberPositioning_arg, 20, ARGUMENT_NAME, "XMNRUBBERPOSITIONING"},
    {tkn_k_class_argument, sym_k_XmNsampleText_arg, 13, ARGUMENT_NAME, "XMNSAMPLETEXT"},
    {tkn_k_class_argument, sym_k_XmNsashHeight_arg, 13, ARGUMENT_NAME, "XMNSASHHEIGHT"},
    {tkn_k_class_argument, sym_k_XmNsashIndent_arg, 13, ARGUMENT_NAME, "XMNSASHINDENT"},
    {tkn_k_class_argument, sym_k_XmNsashShadowThickness_arg, 22, ARGUMENT_NAME, "XMNSASHSHADOWTHICKNESS"},
    {tkn_k_class_argument, sym_k_XmNsashTranslations_arg, 19, ARGUMENT_NAME, "XMNSASHTRANSLATIONS"},
    {tkn_k_class_argument, sym_k_XmNsashWidth_arg, 12, ARGUMENT_NAME, "XMNSASHWIDTH"},
    {tkn_k_class_argument, sym_k_XmNsaveUnder_arg, 12, ARGUMENT_NAME, "XMNSAVEUNDER"},
    {tkn_k_class_argument, sym_k_XmNscaleHeight_arg, 14, ARGUMENT_NAME, "XMNSCALEHEIGHT"},
    {tkn_k_class_argument, sym_k_XmNscaleMultiple_arg, 16, ARGUMENT_NAME, "XMNSCALEMULTIPLE"},
    {tkn_k_class_argument, sym_k_XmNscaleWidth_arg, 13, ARGUMENT_NAME, "XMNSCALEWIDTH"},
    {tkn_k_class_argument, sym_k_XmNscalingString_arg, 16, ARGUMENT_NAME, "XMNSCALINGSTRING"},
    {tkn_k_class_argument, sym_k_XmNscreen_arg, 9, ARGUMENT_NAME, "XMNSCREEN"},
    {tkn_k_class_argument, sym_k_XmNscrollBarDisplayPolicy_arg, 25, ARGUMENT_NAME, "XMNSCROLLBARDISPLAYPOLICY"},
    {tkn_k_class_argument, sym_k_XmNscrollBarPlacement_arg, 21, ARGUMENT_NAME, "XMNSCROLLBARPLACEMENT"},
    {tkn_k_class_argument, sym_k_XmNscrolledWindowChildType_arg, 26, ARGUMENT_NAME, "XMNSCROLLEDWINDOWCHILDTYPE"},
    {tkn_k_class_argument, sym_k_XmNscrolledWindowMarginHeight_arg, 29, ARGUMENT_NAME, "XMNSCROLLEDWINDOWMARGINHEIGHT"},
    {tkn_k_class_argument, sym_k_XmNscrolledWindowMarginWidth_arg, 28, ARGUMENT_NAME, "XMNSCROLLEDWINDOWMARGINWIDTH"},
    {tkn_k_class_argument, sym_k_XmNscrollHorizontal_arg, 19, ARGUMENT_NAME, "XMNSCROLLHORIZONTAL"},
    {tkn_k_class_argument, sym_k_XmNscrollingPolicy_arg, 18, ARGUMENT_NAME, "XMNSCROLLINGPOLICY"},
    {tkn_k_class_argument, sym_k_XmNscrollLeftSide_arg, 17, ARGUMENT_NAME, "XMNSCROLLLEFTSIDE"},
    {tkn_k_class_argument, sym_k_XmNscrollTopSide_arg, 16, ARGUMENT_NAME, "XMNSCROLLTOPSIDE"},
    {tkn_k_class_argument, sym_k_XmNscrollVertical_arg, 17, ARGUMENT_NAME, "XMNSCROLLVERTICAL"},
    {tkn_k_class_reason, sym_k_XmNselectCallback_reason, 17, REASON_NAME, "XMNSELECTCALLBACK"},
    {tkn_k_class_argument, sym_k_XmNselectColor_arg, 14, ARGUMENT_NAME, "XMNSELECTCOLOR"},
    {tkn_k_class_argument, sym_k_XmNselectedColumn_arg, 17, ARGUMENT_NAME, "XMNSELECTEDCOLUMN"},
    {tkn_k_class_argument, sym_k_XmNselectedItem_arg, 15, ARGUMENT_NAME, "XMNSELECTEDITEM"},
    {tkn_k_class_argument, sym_k_XmNselectedItemCount_arg, 20, ARGUMENT_NAME, "XMNSELECTEDITEMCOUNT"},
    {tkn_k_class_argument, sym_k_XmNselectedItems_arg, 16, ARGUMENT_NAME, "XMNSELECTEDITEMS"},
    {tkn_k_class_argument, sym_k_XmNselectedPosition_arg, 19, ARGUMENT_NAME, "XMNSELECTEDPOSITION"},
    {tkn_k_class_argument, sym_k_XmNselectedPositionCount_arg, 24, ARGUMENT_NAME, "XMNSELECTEDPOSITIONCOUNT"},
    {tkn_k_class_argument, sym_k_XmNselectedPositions_arg, 20, ARGUMENT_NAME, "XMNSELECTEDPOSITIONS"},
    {tkn_k_class_argument, sym_k_XmNselectInsensitivePixmap_arg, 26, ARGUMENT_NAME, "XMNSELECTINSENSITIVEPIXMAP"},
    {tkn_k_class_argument, sym_k_XmNselectionArray_arg, 17, ARGUMENT_NAME, "XMNSELECTIONARRAY"},
    {tkn_k_class_argument, sym_k_XmNselectionArrayCount_arg, 22, ARGUMENT_NAME, "XMNSELECTIONARRAYCOUNT"},
    {tkn_k_class_reason, sym_k_XmNselectionCallback_reason, 20, REASON_NAME, "XMNSELECTIONCALLBACK"},
    {tkn_k_class_argument, sym_k_XmNselectionLabelString_arg, 23, ARGUMENT_NAME, "XMNSELECTIONLABELSTRING"},
    {tkn_k_class_argument, sym_k_XmNselectionMode_arg, 16, ARGUMENT_NAME, "XMNSELECTIONMODE"},
    {tkn_k_class_argument, sym_k_XmNselectionPolicy_arg, 18, ARGUMENT_NAME, "XMNSELECTIONPOLICY"},
    {tkn_k_class_argument, sym_k_XmNselectionTechnique_arg, 21, ARGUMENT_NAME, "XMNSELECTIONTECHNIQUE"},
    {tkn_k_class_argument, sym_k_XmNselectPixmap_arg, 15, ARGUMENT_NAME, "XMNSELECTPIXMAP"},
    {tkn_k_class_argument, sym_k_XmNselectThreshold_arg, 18, ARGUMENT_NAME, "XMNSELECTTHRESHOLD"},
    {tkn_k_class_argument, sym_k_XmNsensitive_arg, 12, ARGUMENT_NAME, "XMNSENSITIVE"},
    {tkn_k_class_argument, sym_k_XmNseparatorOn_arg, 14, ARGUMENT_NAME, "XMNSEPARATORON"},
    {tkn_k_class_argument, sym_k_XmNseparatorType_arg, 16, ARGUMENT_NAME, "XMNSEPARATORTYPE"},
    {tkn_k_class_argument, sym_k_XmNset_arg, 6, ARGUMENT_NAME, "XMNSET"},
    {tkn_k_class_argument, sym_k_XmNshadowThickness_arg, 18, ARGUMENT_NAME, "XMNSHADOWTHICKNESS"},
    {tkn_k_class_argument, sym_k_XmNshadowType_arg, 13, ARGUMENT_NAME, "XMNSHADOWTYPE"},
    {tkn_k_class_argument, sym_k_XmNshellUnitType_arg, 16, ARGUMENT_NAME, "XMNSHELLUNITTYPE"},
    {tkn_k_class_argument, sym_k_XmNshowArrows_arg, 13, ARGUMENT_NAME, "XMNSHOWARROWS"},
    {tkn_k_class_argument, sym_k_XmNshowAsDefault_arg, 16, ARGUMENT_NAME, "XMNSHOWASDEFAULT"},
    {tkn_k_class_argument, sym_k_XmNshowEntryLabel_arg, 17, ARGUMENT_NAME, "XMNSHOWENTRYLABEL"},
    {tkn_k_class_argument, sym_k_XmNshowFind_arg, 11, ARGUMENT_NAME, "XMNSHOWFIND"},
    {tkn_k_class_argument, sym_k_XmNshowFontName_arg, 15, ARGUMENT_NAME, "XMNSHOWFONTNAME"},
    {tkn_k_class_argument, sym_k_XmNshowLabel_arg, 12, ARGUMENT_NAME, "XMNSHOWLABEL"},
    {tkn_k_class_argument, sym_k_XmNshowNameString_arg, 17, ARGUMENT_NAME, "XMNSHOWNAMESTRING"},
    {tkn_k_class_argument, sym_k_XmNshowSash_arg, 11, ARGUMENT_NAME, "XMNSHOWSASH"},
    {tkn_k_class_argument, sym_k_XmNshowSeparator_arg, 16, ARGUMENT_NAME, "XMNSHOWSEPARATOR"},
    {tkn_k_class_argument, sym_k_XmNshowValue_arg, 12, ARGUMENT_NAME, "XMNSHOWVALUE"},
    {tkn_k_class_reason, sym_k_XmNsimpleCallback_reason, 17, REASON_NAME, "XMNSIMPLECALLBACK"},
    {tkn_k_class_reason, sym_k_XmNsingleSelectionCallback_reason, 26, REASON_NAME, "XMNSINGLESELECTIONCALLBACK"},
    {tkn_k_class_argument, sym_k_XmNsizeString_arg, 13, ARGUMENT_NAME, "XMNSIZESTRING"},
    {tkn_k_class_argument, sym_k_XmNskipAdjust_arg, 13, ARGUMENT_NAME, "XMNSKIPADJUST"},
    {tkn_k_class_argument, sym_k_XmNsliderMark_arg, 13, ARGUMENT_NAME, "XMNSLIDERMARK"},
    {tkn_k_class_argument, sym_k_XmNsliderSize_arg, 13, ARGUMENT_NAME, "XMNSLIDERSIZE"},
    {tkn_k_class_argument, sym_k_XmNsliderTogLabel_arg, 17, ARGUMENT_NAME, "XMNSLIDERTOGLABEL"},
    {tkn_k_class_argument, sym_k_XmNsliderVisual_arg, 15, ARGUMENT_NAME, "XMNSLIDERVISUAL"},
    {tkn_k_class_argument, sym_k_XmNslidingMode_arg, 14, ARGUMENT_NAME, "XMNSLIDINGMODE"},
    {tkn_k_class_argument, sym_k_XmNsmallCellHeight_arg, 18, ARGUMENT_NAME, "XMNSMALLCELLHEIGHT"},
    {tkn_k_class_argument, sym_k_XmNsmallCellWidth_arg, 17, ARGUMENT_NAME, "XMNSMALLCELLWIDTH"},
    {tkn_k_class_argument, sym_k_XmNsmallIconMask_arg, 16, ARGUMENT_NAME, "XMNSMALLICONMASK"},
    {tkn_k_class_argument, sym_k_XmNsmallIconPixmap_arg, 18, ARGUMENT_NAME, "XMNSMALLICONPIXMAP"},
    {tkn_k_class_argument, sym_k_XmNsmallIconX_arg, 13, ARGUMENT_NAME, "XMNSMALLICONX"},
    {tkn_k_class_argument, sym_k_XmNsmallIconY_arg, 13, ARGUMENT_NAME, "XMNSMALLICONY"},
    {tkn_k_class_argument, sym_k_XmNsnapBackMultiple_arg, 19, ARGUMENT_NAME, "XMNSNAPBACKMULTIPLE"},
    {tkn_k_class_argument, sym_k_XmNsortFunctions_arg, 16, ARGUMENT_NAME, "XMNSORTFUNCTIONS"},
    {tkn_k_class_argument, sym_k_XmNsource_arg, 9, ARGUMENT_NAME, "XMNSOURCE"},
    {tkn_k_class_argument, sym_k_XmNspacing_arg, 10, ARGUMENT_NAME, "XMNSPACING"},
    {tkn_k_class_argument, sym_k_XmNspatialIncludeModel_arg, 22, ARGUMENT_NAME, "XMNSPATIALINCLUDEMODEL"},
    {tkn_k_class_argument, sym_k_XmNspatialResizeModel_arg, 21, ARGUMENT_NAME, "XMNSPATIALRESIZEMODEL"},
    {tkn_k_class_argument, sym_k_XmNspatialSnapModel_arg, 19, ARGUMENT_NAME, "XMNSPATIALSNAPMODEL"},
    {tkn_k_class_argument, sym_k_XmNspatialStyle_arg, 15, ARGUMENT_NAME, "XMNSPATIALSTYLE"},
    {tkn_k_class_argument, sym_k_XmNspinBoxChildType_arg, 19, ARGUMENT_NAME, "XMNSPINBOXCHILDTYPE"},
    {tkn_k_class_argument, sym_k_XmNstackedEffect_arg, 16, ARGUMENT_NAME, "XMNSTACKEDEFFECT"},
    {tkn_k_class_argument, sym_k_XmNstretchable_arg, 14, ARGUMENT_NAME, "XMNSTRETCHABLE"},
    {tkn_k_class_argument, sym_k_XmNstrikethruType_arg, 17, ARGUMENT_NAME, "XMNSTRIKETHRUTYPE"},
    {tkn_k_class_argument, sym_k_XmNstringDirection_arg, 18, ARGUMENT_NAME, "XMNSTRINGDIRECTION"},
    {tkn_k_class_argument, sym_k_XmNsubMenuId_arg, 12, ARGUMENT_NAME, "XMNSUBMENUID"},
    {tkn_k_class_argument, sym_k_XmNsymbolPixmap_arg, 15, ARGUMENT_NAME, "XMNSYMBOLPIXMAP"},
    {tkn_k_class_argument, sym_k_XmNtabAlignment_arg, 15, ARGUMENT_NAME, "XMNTABALIGNMENT"},
    {tkn_k_class_argument, sym_k_XmNtabAutoSelect_arg, 16, ARGUMENT_NAME, "XMNTABAUTOSELECT"},
    {tkn_k_class_argument, sym_k_XmNtabBackground_arg, 16, ARGUMENT_NAME, "XMNTABBACKGROUND"},
    {tkn_k_class_argument, sym_k_XmNtabBackgroundPixmap_arg, 22, ARGUMENT_NAME, "XMNTABBACKGROUNDPIXMAP"},
    {tkn_k_class_argument, sym_k_XmNtabCornerPercent_arg, 19, ARGUMENT_NAME, "XMNTABCORNERPERCENT"},
    {tkn_k_class_argument, sym_k_XmNtabEdge_arg, 10, ARGUMENT_NAME, "XMNTABEDGE"},
    {tkn_k_class_argument, sym_k_XmNtabForeground_arg, 16, ARGUMENT_NAME, "XMNTABFOREGROUND"},
    {tkn_k_class_argument, sym_k_XmNtabLabelPixmap_arg, 17, ARGUMENT_NAME, "XMNTABLABELPIXMAP"},
    {tkn_k_class_argument, sym_k_XmNtabLabelSpacing_arg, 18, ARGUMENT_NAME, "XMNTABLABELSPACING"},
    {tkn_k_class_argument, sym_k_XmNtabLabelString_arg, 17, ARGUMENT_NAME, "XMNTABLABELSTRING"},
    {tkn_k_class_argument, sym_k_XmNtabList_arg, 10, ARGUMENT_NAME, "XMNTABLIST"},
    {tkn_k_class_argument, sym_k_XmNtabMarginHeight_arg, 18, ARGUMENT_NAME, "XMNTABMARGINHEIGHT"},
    {tkn_k_class_argument, sym_k_XmNtabMarginWidth_arg, 17, ARGUMENT_NAME, "XMNTABMARGINWIDTH"},
    {tkn_k_class_argument, sym_k_XmNtabMode_arg, 10, ARGUMENT_NAME, "XMNTABMODE"},
    {tkn_k_class_argument, sym_k_XmNtabOffset_arg, 12, ARGUMENT_NAME, "XMNTABOFFSET"},
    {tkn_k_class_argument, sym_k_XmNtabOrientation_arg, 17, ARGUMENT_NAME, "XMNTABORIENTATION"},
    {tkn_k_class_argument, sym_k_XmNtabPixmapPlacement_arg, 21, ARGUMENT_NAME, "XMNTABPIXMAPPLACEMENT"},
    {tkn_k_class_argument, sym_k_XmNtabSelectColor_arg, 17, ARGUMENT_NAME, "XMNTABSELECTCOLOR"},
    {tkn_k_class_reason, sym_k_XmNtabSelectedCallback_reason, 22, REASON_NAME, "XMNTABSELECTEDCALLBACK"},
    {tkn_k_class_argument, sym_k_XmNtabSelectPixmap_arg, 18, ARGUMENT_NAME, "XMNTABSELECTPIXMAP"},
    {tkn_k_class_argument, sym_k_XmNtabSide_arg, 10, ARGUMENT_NAME, "XMNTABSIDE"},
    {tkn_k_class_argument, sym_k_XmNtabStringDirection_arg, 21, ARGUMENT_NAME, "XMNTABSTRINGDIRECTION"},
    {tkn_k_class_argument, sym_k_XmNtabStyle_arg, 11, ARGUMENT_NAME, "XMNTABSTYLE"},
    {tkn_k_class_argument, sym_k_XmNtabValue_arg, 11, ARGUMENT_NAME, "XMNTABVALUE"},
    {tkn_k_class_reason, sym_k_XmNtearOffMenuActivateCallback_reason, 30, REASON_NAME, "XMNTEAROFFMENUACTIVATECALLBACK"},
    {tkn_k_class_reason, sym_k_XmNtearOffMenuDeactivateCallback_reason, 32, REASON_NAME, "XMNTEAROFFMENUDEACTIVATECALLBACK"},
    {tkn_k_class_argument, sym_k_XmNtearOffModel_arg, 15, ARGUMENT_NAME, "XMNTEAROFFMODEL"},
    {tkn_k_class_argument, sym_k_XmNtearOffTitle_arg, 15, ARGUMENT_NAME, "XMNTEAROFFTITLE"},
    {tkn_k_class_argument, sym_k_XmNtextAccelerators_arg, 19, ARGUMENT_NAME, "XMNTEXTACCELERATORS"},
    {tkn_k_class_argument, sym_k_XmNtextColumns_arg, 14, ARGUMENT_NAME, "XMNTEXTCOLUMNS"},
    {tkn_k_class_argument, sym_k_XmNtextField_arg, 12, ARGUMENT_NAME, "XMNTEXTFIELD"},
    {tkn_k_class_argument, sym_k_XmNtextFontList_arg, 15, ARGUMENT_NAME, "XMNTEXTFONTLIST"},
    {tkn_k_class_argument, sym_k_XmNtextRenderTable_arg, 18, ARGUMENT_NAME, "XMNTEXTRENDERTABLE"},
    {tkn_k_class_argument, sym_k_XmNtextRows_arg, 11, ARGUMENT_NAME, "XMNTEXTROWS"},
    {tkn_k_class_argument, sym_k_XmNtextString_arg, 13, ARGUMENT_NAME, "XMNTEXTSTRING"},
    {tkn_k_class_argument, sym_k_XmNtextTranslations_arg, 19, ARGUMENT_NAME, "XMNTEXTTRANSLATIONS"},
    {tkn_k_class_argument, sym_k_XmNtitle_arg, 8, ARGUMENT_NAME, "XMNTITLE"},
    {tkn_k_class_argument, sym_k_XmNtitleEncoding_arg, 16, ARGUMENT_NAME, "XMNTITLEENCODING"},
    {tkn_k_class_argument, sym_k_XmNtitleString_arg, 14, ARGUMENT_NAME, "XMNTITLESTRING"},
    {tkn_k_class_reason, sym_k_XmNtoBottomCallback_reason, 19, REASON_NAME, "XMNTOBOTTOMCALLBACK"},
    {tkn_k_class_argument, sym_k_XmNtoggleMode_arg, 13, ARGUMENT_NAME, "XMNTOGGLEMODE"},
    {tkn_k_class_argument, sym_k_XmNtoolTipEnable_arg, 16, ARGUMENT_NAME, "XMNTOOLTIPENABLE"},
    {tkn_k_class_argument, sym_k_XmNtoolTipPostDelay_arg, 19, ARGUMENT_NAME, "XMNTOOLTIPPOSTDELAY"},
    {tkn_k_class_argument, sym_k_XmNtoolTipPostDuration_arg, 22, ARGUMENT_NAME, "XMNTOOLTIPPOSTDURATION"},
    {tkn_k_class_argument, sym_k_XmNtoolTipString_arg, 16, ARGUMENT_NAME, "XMNTOOLTIPSTRING"},
    {tkn_k_class_argument, sym_k_XmNtopAttachment_arg, 16, ARGUMENT_NAME, "XMNTOPATTACHMENT"},
    {tkn_k_class_argument, sym_k_XmNtopCharacter_arg, 15, ARGUMENT_NAME, "XMNTOPCHARACTER"},
    {tkn_k_class_argument, sym_k_XmNtopItemPosition_arg, 18, ARGUMENT_NAME, "XMNTOPITEMPOSITION"},
    {tkn_k_class_argument, sym_k_XmNtopOffset_arg, 12, ARGUMENT_NAME, "XMNTOPOFFSET"},
    {tkn_k_class_argument, sym_k_XmNtopPosition_arg, 14, ARGUMENT_NAME, "XMNTOPPOSITION"},
    {tkn_k_class_argument, sym_k_XmNtopShadowColor_arg, 17, ARGUMENT_NAME, "XMNTOPSHADOWCOLOR"},
    {tkn_k_class_argument, sym_k_XmNtopShadowPixmap_arg, 18, ARGUMENT_NAME, "XMNTOPSHADOWPIXMAP"},
    {tkn_k_class_argument, sym_k_XmNtopWidget_arg, 12, ARGUMENT_NAME, "XMNTOPWIDGET"},
    {tkn_k_class_reason, sym_k_XmNtoTopCallback_reason, 16, REASON_NAME, "XMNTOTOPCALLBACK"},
    {tkn_k_class_argument, sym_k_XmNtransient_arg, 12, ARGUMENT_NAME, "XMNTRANSIENT"},
    {tkn_k_class_argument, sym_k_XmNtransientFor_arg, 15, ARGUMENT_NAME, "XMNTRANSIENTFOR"},
    {tkn_k_class_argument, sym_k_XmNtranslations_arg, 15, ARGUMENT_NAME, "XMNTRANSLATIONS"},
    {tkn_k_class_reason, sym_k_XmNtraversalCallback_reason, 20, REASON_NAME, "XMNTRAVERSALCALLBACK"},
    {tkn_k_class_argument, sym_k_XmNtraversalOn_arg, 14, ARGUMENT_NAME, "XMNTRAVERSALON"},
    {tkn_k_class_reason, sym_k_XmNtraverseObscuredCallback_reason, 27, REASON_NAME, "XMNTRAVERSEOBSCUREDCALLBACK"},
    {tkn_k_class_argument, sym_k_XmNtroughColor_arg, 14, ARGUMENT_NAME, "XMNTROUGHCOLOR"},
    {tkn_k_class_enumval, sym_k_XmNUMERIC_enumval, 9, ENUMVAL_NAME, "XMNUMERIC"},
    {tkn_k_class_argument, sym_k_XmNunderlineType_arg, 16, ARGUMENT_NAME, "XMNUNDERLINETYPE"},
    {tkn_k_class_argument, sym_k_XmNuniformTabSize_arg, 17, ARGUMENT_NAME, "XMNUNIFORMTABSIZE"},
    {tkn_k_class_argument, sym_k_XmNunitType_arg, 11, ARGUMENT_NAME, "XMNUNITTYPE"},
    {tkn_k_class_reason, sym_k_XmNunmapCallback_reason, 16, REASON_NAME, "XMNUNMAPCALLBACK"},
    {tkn_k_class_argument, sym_k_XmNunpostBehavior_arg, 17, ARGUMENT_NAME, "XMNUNPOSTBEHAVIOR"},
    {tkn_k_class_reason, sym_k_XmNunselectCallback_reason, 19, REASON_NAME, "XMNUNSELECTCALLBACK"},
    {tkn_k_class_argument, sym_k_XmNunselectColor_arg, 16, ARGUMENT_NAME, "XMNUNSELECTCOLOR"},
    {tkn_k_class_reason, sym_k_XmNupdateShellCallback_reason, 22, REASON_NAME, "XMNUPDATESHELLCALLBACK"},
    {tkn_k_class_reason, sym_k_XmNupdateTextCallback_reason, 21, REASON_NAME, "XMNUPDATETEXTCALLBACK"},
    {tkn_k_class_argument, sym_k_XmNuseAsyncGeometry_arg, 19, ARGUMENT_NAME, "XMNUSEASYNCGEOMETRY"},
    {tkn_k_class_argument, sym_k_XmNuseImageCache_arg, 16, ARGUMENT_NAME, "XMNUSEIMAGECACHE"},
    {tkn_k_class_argument, sym_k_XmNuserData_arg, 11, ARGUMENT_NAME, "XMNUSERDATA"},
    {tkn_k_class_argument, sym_k_XmNuseScaling_arg, 13, ARGUMENT_NAME, "XMNUSESCALING"},
    {tkn_k_class_argument, sym_k_XmNuseTextField_arg, 15, ARGUMENT_NAME, "XMNUSETEXTFIELD"},
    {tkn_k_class_reason, sym_k_XmNvalidateCallback_reason, 19, REASON_NAME, "XMNVALIDATECALLBACK"},
    {tkn_k_class_argument, sym_k_XmNvalue_arg, 8, ARGUMENT_NAME, "XMNVALUE"},
    {tkn_k_class_reason, sym_k_XmNvalueChangedCallback_reason, 23, REASON_NAME, "XMNVALUECHANGEDCALLBACK"},
    {tkn_k_class_argument, sym_k_XmNvalues_arg, 9, ARGUMENT_NAME, "XMNVALUES"},
    {tkn_k_class_argument, sym_k_XmNvalueWcs_arg, 11, ARGUMENT_NAME, "XMNVALUEWCS"},
    {tkn_k_class_argument, sym_k_XmNverify_arg, 9, ARGUMENT_NAME, "XMNVERIFY"},
    {tkn_k_class_argument, sym_k_XmNverifyBell_arg, 13, ARGUMENT_NAME, "XMNVERIFYBELL"},
    {tkn_k_class_reason, sym_k_XmNverifyTextCallback_reason, 21, REASON_NAME, "XMNVERIFYTEXTCALLBACK"},
    {tkn_k_class_argument, sym_k_XmNverticalDelta_arg, 16, ARGUMENT_NAME, "XMNVERTICALDELTA"},
    {tkn_k_class_argument, sym_k_XmNverticalMargin_arg, 17, ARGUMENT_NAME, "XMNVERTICALMARGIN"},
    {tkn_k_class_argument, sym_k_XmNverticalNodeSpace_arg, 20, ARGUMENT_NAME, "XMNVERTICALNODESPACE"},
    {tkn_k_class_argument, sym_k_XmNverticalScrollBar_arg, 20, ARGUMENT_NAME, "XMNVERTICALSCROLLBAR"},
    {tkn_k_class_argument, sym_k_XmNverticalSpacing_arg, 18, ARGUMENT_NAME, "XMNVERTICALSPACING"},
    {tkn_k_class_argument, sym_k_XmNviewType_arg, 11, ARGUMENT_NAME, "XMNVIEWTYPE"},
    {tkn_k_class_argument, sym_k_XmNvisibleItemCount_arg, 19, ARGUMENT_NAME, "XMNVISIBLEITEMCOUNT"},
    {tkn_k_class_argument, sym_k_XmNvisibleWhenOff_arg, 17, ARGUMENT_NAME, "XMNVISIBLEWHENOFF"},
    {tkn_k_class_argument, sym_k_XmNvisual_arg, 9, ARGUMENT_NAME, "XMNVISUAL"},
    {tkn_k_class_argument, sym_k_XmNvisualEmphasis_arg, 17, ARGUMENT_NAME, "XMNVISUALEMPHASIS"},
    {tkn_k_class_argument, sym_k_XmNvisualPolicy_arg, 15, ARGUMENT_NAME, "XMNVISUALPOLICY"},
    {tkn_k_class_argument, sym_k_XmNwaitForWm_arg, 12, ARGUMENT_NAME, "XMNWAITFORWM"},
    {tkn_k_class_argument, sym_k_XmNwhichButton_arg, 14, ARGUMENT_NAME, "XMNWHICHBUTTON"},
    {tkn_k_class_argument, sym_k_XmNwidth_arg, 8, ARGUMENT_NAME, "XMNWIDTH"},
    {tkn_k_class_argument, sym_k_XmNwidthInc_arg, 11, ARGUMENT_NAME, "XMNWIDTHINC"},
    {tkn_k_class_argument, sym_k_XmNwindowGroup_arg, 14, ARGUMENT_NAME, "XMNWINDOWGROUP"},
    {tkn_k_class_argument, sym_k_XmNwinGravity_arg, 13, ARGUMENT_NAME, "XMNWINGRAVITY"},
    {tkn_k_class_argument, sym_k_XmNwmTimeout_arg, 12, ARGUMENT_NAME, "XMNWMTIMEOUT"},
    {tkn_k_class_argument, sym_k_XmNwordWrap_arg, 11, ARGUMENT_NAME, "XMNWORDWRAP"},
    {tkn_k_class_argument, sym_k_XmNworkWindow_arg, 13, ARGUMENT_NAME, "XMNWORKWINDOW"},
    {tkn_k_class_argument, sym_k_XmNwrap_arg, 7, ARGUMENT_NAME, "XMNWRAP"},
    {tkn_k_class_argument, sym_k_XmNx_arg, 4, ARGUMENT_NAME, "XMNX"},
    {tkn_k_class_argument, sym_k_XmNxlfdString_arg, 13, ARGUMENT_NAME, "XMNXLFDSTRING"},
    {tkn_k_class_argument, sym_k_XmNy_arg, 4, ARGUMENT_NAME, "XMNY"},
    {tkn_k_class_enumval, sym_k_XmN_OF_MANY_enumval, 11, ENUMVAL_NAME, "XMN_OF_MANY"},
    {tkn_k_class_enumval, sym_k_XmONE_BASED_enumval, 11, ENUMVAL_NAME, "XMONE_BASED"},
    {tkn_k_class_enumval, sym_k_XmONE_OF_MANY_enumval, 13, ENUMVAL_NAME, "XMONE_OF_MANY"},
    {tkn_k_class_enumval, sym_k_XmONE_OF_MANY_DIAMOND_enumval, 21, ENUMVAL_NAME, "XMONE_OF_MANY_DIAMOND"},
    {tkn_k_class_enumval, sym_k_XmONE_OF_MANY_ROUND_enumval, 19, ENUMVAL_NAME, "XMONE_OF_MANY_ROUND"},
    {tkn_k_class_enumval, sym_k_XmOpen_enumval, 6, ENUMVAL_NAME, "XMOPEN"},
    {tkn_k_class_class, sym_k_XmOptionMenu_object, 12, CLASS_NAME, "XMOPTIONMENU"},
    {tkn_k_class_class, sym_k_XmOutline_object, 9, CLASS_NAME, "XMOUTLINE"},
    {tkn_k_class_enumval, sym_k_XmOUTLINE_enumval, 9, ENUMVAL_NAME, "XMOUTLINE"},
    {tkn_k_class_enumval, sym_k_XmOUTLINE_BUTTON_ABSENT_enumval, 23, ENUMVAL_NAME, "XMOUTLINE_BUTTON_ABSENT"},
    {tkn_k_class_enumval, sym_k_XmOUTLINE_BUTTON_PRESENT_enumval, 24, ENUMVAL_NAME, "XMOUTLINE_BUTTON_PRESENT"},
    {tkn_k_class_enumval, sym_k_XmOWN_ALWAYS_enumval, 12, ENUMVAL_NAME, "XMOWN_ALWAYS"},
    {tkn_k_class_enumval, sym_k_XmOWN_MULTIPLE_enumval, 14, ENUMVAL_NAME, "XMOWN_MULTIPLE"},
    {tkn_k_class_enumval, sym_k_XmOWN_NEVER_enumval, 11, ENUMVAL_NAME, "XMOWN_NEVER"},
    {tkn_k_class_enumval, sym_k_XmOWN_POSSIBLE_MULTIPLE_enumval, 23, ENUMVAL_NAME, "XMOWN_POSSIBLE_MULTIPLE"},
    {tkn_k_class_enumval, sym_k_XmPACK_COLUMN_enumval, 13, ENUMVAL_NAME, "XMPACK_COLUMN"},
    {tkn_k_class_enumval, sym_k_XmPACK_NONE_enumval, 11, ENUMVAL_NAME, "XMPACK_NONE"},
    {tkn_k_class_enumval, sym_k_XmPACK_TIGHT_enumval, 12, ENUMVAL_NAME, "XMPACK_TIGHT"},
    {tkn_k_class_enumval, sym_k_XmPAGE_enumval, 6, ENUMVAL_NAME, "XMPAGE"},
    {tkn_k_class_enumval, sym_k_XmPAGE_SCROLLER_enumval, 15, ENUMVAL_NAME, "XMPAGE_SCROLLER"},
    {tkn_k_class_class, sym_k_XmPaned_object, 7, CLASS_NAME, "XMPANED"},
    {tkn_k_class_class, sym_k_XmPanedWindow_object, 13, CLASS_NAME, "XMPANEDWINDOW"},
    {tkn_k_class_enumval, sym_k_XmPER_SHELL_enumval, 11, ENUMVAL_NAME, "XMPER_SHELL"},
    {tkn_k_class_enumval, sym_k_XmPER_WIDGET_enumval, 12, ENUMVAL_NAME, "XMPER_WIDGET"},
    {tkn_k_class_enumval, sym_k_XmPIXELS_enumval, 8, ENUMVAL_NAME, "XMPIXELS"},
    {tkn_k_class_enumval, sym_k_XmPIXMAP_enumval, 8, ENUMVAL_NAME, "XMPIXMAP"},
    {tkn_k_class_enumval, sym_k_XmPIXMAP_AND_STRING_enumval, 19, ENUMVAL_NAME, "XMPIXMAP_AND_STRING"},
    {tkn_k_class_enumval, sym_k_XmPIXMAP_BOTTOM_enumval, 15, ENUMVAL_NAME, "XMPIXMAP_BOTTOM"},
    {tkn_k_class_enumval, sym_k_XmPIXMAP_LEFT_enumval, 13, ENUMVAL_NAME, "XMPIXMAP_LEFT"},
    {tkn_k_class_enumval, sym_k_XmPIXMAP_NONE_enumval, 13, ENUMVAL_NAME, "XMPIXMAP_NONE"},
    {tkn_k_class_enumval, sym_k_XmPIXMAP_ONLY_enumval, 13, ENUMVAL_NAME, "XMPIXMAP_ONLY"},
    {tkn_k_class_enumval, sym_k_XmPIXMAP_OVERLAP_ONLY_enumval, 21, ENUMVAL_NAME, "XMPIXMAP_OVERLAP_ONLY"},
    {tkn_k_class_enumval, sym_k_XmPIXMAP_RIGHT_enumval, 14, ENUMVAL_NAME, "XMPIXMAP_RIGHT"},
    {tkn_k_class_enumval, sym_k_XmPIXMAP_TOP_enumval, 12, ENUMVAL_NAME, "XMPIXMAP_TOP"},
    {tkn_k_class_enumval, sym_k_XmPLACE_ABOVE_SELECTION_enumval, 23, ENUMVAL_NAME, "XMPLACE_ABOVE_SELECTION"},
    {tkn_k_class_enumval, sym_k_XmPLACE_BELOW_SELECTION_enumval, 23, ENUMVAL_NAME, "XMPLACE_BELOW_SELECTION"},
    {tkn_k_class_enumval, sym_k_XmPLACE_TOP_enumval, 11, ENUMVAL_NAME, "XMPLACE_TOP"},
    {tkn_k_class_enumval, sym_k_XmPOINTER_enumval, 9, ENUMVAL_NAME, "XMPOINTER"},
    {tkn_k_class_enumval, sym_k_XmPOINTS_enumval, 8, ENUMVAL_NAME, "XMPOINTS"},
    {tkn_k_class_class, sym_k_XmPopupMenu_object, 11, CLASS_NAME, "XMPOPUPMENU"},
    {tkn_k_class_enumval, sym_k_XmPOSITION_INDEX_enumval, 16, ENUMVAL_NAME, "XMPOSITION_INDEX"},
    {tkn_k_class_enumval, sym_k_XmPOSITION_VALUE_enumval, 16, ENUMVAL_NAME, "XMPOSITION_VALUE"},
    {tkn_k_class_class, sym_k_XmPromptDialog_object, 14, CLASS_NAME, "XMPROMPTDIALOG"},
    {tkn_k_class_class, sym_k_XmPulldownMenu_object, 14, CLASS_NAME, "XMPULLDOWNMENU"},
    {tkn_k_class_class, sym_k_XmPushButton_object, 12, CLASS_NAME, "XMPUSHBUTTON"},
    {tkn_k_class_class, sym_k_XmPushButtonGadget_object, 18, CLASS_NAME, "XMPUSHBUTTONGADGET"},
    {tkn_k_class_class, sym_k_XmQuestionDialog_object, 16, CLASS_NAME, "XMQUESTIONDIALOG"},
    {tkn_k_class_enumval, sym_k_XmQUICK_NAVIGATE_enumval, 16, ENUMVAL_NAME, "XMQUICK_NAVIGATE"},
    {tkn_k_class_class, sym_k_XmRadioBox_object, 10, CLASS_NAME, "XMRADIOBOX"},
    {tkn_k_class_enumval, sym_k_XmRELATIVE_enumval, 10, ENUMVAL_NAME, "XMRELATIVE"},
    {tkn_k_class_class, sym_k_XmRenderTable_object, 13, CLASS_NAME, "XMRENDERTABLE"},
    {tkn_k_class_class, sym_k_XmRendition_object, 11, CLASS_NAME, "XMRENDITION"},
    {tkn_k_class_enumval, sym_k_XmRESIZE_ANY_enumval, 12, ENUMVAL_NAME, "XMRESIZE_ANY"},
    {tkn_k_class_enumval, sym_k_XmRESIZE_GROW_enumval, 13, ENUMVAL_NAME, "XMRESIZE_GROW"},
    {tkn_k_class_enumval, sym_k_XmRESIZE_IF_POSSIBLE_enumval, 20, ENUMVAL_NAME, "XMRESIZE_IF_POSSIBLE"},
    {tkn_k_class_enumval, sym_k_XmRESIZE_NONE_enumval, 13, ENUMVAL_NAME, "XMRESIZE_NONE"},
    {tkn_k_class_enumval, sym_k_XmRIGHT_TO_LEFT_enumval, 15, ENUMVAL_NAME, "XMRIGHT_TO_LEFT"},
    {tkn_k_class_enumval, sym_k_XmRIGHT_TO_LEFT_BOTTOM_TO_TOP_enumval, 29, ENUMVAL_NAME, "XMRIGHT_TO_LEFT_BOTTOM_TO_TOP"},
    {tkn_k_class_enumval, sym_k_XmRIGHT_TO_LEFT_TOP_TO_BOTTOM_enumval, 29, ENUMVAL_NAME, "XMRIGHT_TO_LEFT_TOP_TO_BOTTOM"},
    {tkn_k_class_enumval, sym_k_XmROUND_MARK_enumval, 12, ENUMVAL_NAME, "XMROUND_MARK"},
    {tkn_k_class_class, sym_k_XmRowColumn_object, 11, CLASS_NAME, "XMROWCOLUMN"},
    {tkn_k_class_class, sym_k_XmScale_object, 7, CLASS_NAME, "XMSCALE"},
    {tkn_k_class_enumval, sym_k_XmScaleMode_enumval, 11, ENUMVAL_NAME, "XMSCALEMODE"},
    {tkn_k_class_class, sym_k_XmScrollBar_object, 11, CLASS_NAME, "XMSCROLLBAR"},
    {tkn_k_class_class, sym_k_XmScrolledList_object, 14, CLASS_NAME, "XMSCROLLEDLIST"},
    {tkn_k_class_class, sym_k_XmScrolledText_object, 14, CLASS_NAME, "XMSCROLLEDTEXT"},
    {tkn_k_class_class, sym_k_XmScrolledWindow_object, 16, CLASS_NAME, "XMSCROLLEDWINDOW"},
    {tkn_k_class_enumval, sym_k_XmSCROLL_HOR_enumval, 12, ENUMVAL_NAME, "XMSCROLL_HOR"},
    {tkn_k_class_enumval, sym_k_XmSCROLL_VERT_enumval, 13, ENUMVAL_NAME, "XMSCROLL_VERT"},
    {tkn_k_class_enumval, sym_k_XmSELECTED_enumval, 10, ENUMVAL_NAME, "XMSELECTED"},
    {tkn_k_class_class, sym_k_XmSelectionBox_object, 14, CLASS_NAME, "XMSELECTIONBOX"},
    {tkn_k_class_class, sym_k_XmSelectionDialog_object, 17, CLASS_NAME, "XMSELECTIONDIALOG"},
    {tkn_k_class_enumval, sym_k_XmSELECT_ALL_enumval, 12, ENUMVAL_NAME, "XMSELECT_ALL"},
    {tkn_k_class_enumval, sym_k_XmSELECT_LINE_enumval, 13, ENUMVAL_NAME, "XMSELECT_LINE"},
    {tkn_k_class_enumval, sym_k_XmSELECT_PARAGRAPH_enumval, 18, ENUMVAL_NAME, "XMSELECT_PARAGRAPH"},
    {tkn_k_class_enumval, sym_k_XmSELECT_POSITION_enumval, 17, ENUMVAL_NAME, "XMSELECT_POSITION"},
    {tkn_k_class_enumval, sym_k_XmSELECT_WHITESPACE_enumval, 19, ENUMVAL_NAME, "XMSELECT_WHITESPACE"},
    {tkn_k_class_enumval, sym_k_XmSELECT_WORD_enumval, 13, ENUMVAL_NAME, "XMSELECT_WORD"},
    {tkn_k_class_class, sym_k_XmSeparator_object, 11, CLASS_NAME, "XMSEPARATOR"},
    {tkn_k_class_class, sym_k_XmSeparatorGadget_object, 17, CLASS_NAME, "XMSEPARATORGADGET"},
    {tkn_k_class_enumval, sym_k_XmSET_enumval, 5, ENUMVAL_NAME, "XMSET"},
    {tkn_k_class_enumval, sym_k_XmSHADOWED_BACKGROUND_enumval, 21, ENUMVAL_NAME, "XMSHADOWED_BACKGROUND"},
    {tkn_k_class_enumval, sym_k_XmSHADOW_ETCHED_IN_enumval, 18, ENUMVAL_NAME, "XMSHADOW_ETCHED_IN"},
    {tkn_k_class_enumval, sym_k_XmSHADOW_ETCHED_IN_DASH_enumval, 23, ENUMVAL_NAME, "XMSHADOW_ETCHED_IN_DASH"},
    {tkn_k_class_enumval, sym_k_XmSHADOW_ETCHED_OUT_enumval, 19, ENUMVAL_NAME, "XMSHADOW_ETCHED_OUT"},
    {tkn_k_class_enumval, sym_k_XmSHADOW_ETCHED_OUT_DASH_enumval, 24, ENUMVAL_NAME, "XMSHADOW_ETCHED_OUT_DASH"},
    {tkn_k_class_enumval, sym_k_XmSHADOW_IN_enumval, 11, ENUMVAL_NAME, "XMSHADOW_IN"},
    {tkn_k_class_enumval, sym_k_XmSHADOW_OUT_enumval, 12, ENUMVAL_NAME, "XMSHADOW_OUT"},
    {tkn_k_class_class, sym_k_XmSimpleSpinBox_object, 15, CLASS_NAME, "XMSIMPLESPINBOX"},
    {tkn_k_class_enumval, sym_k_XmSINGLE_enumval, 8, ENUMVAL_NAME, "XMSINGLE"},
    {tkn_k_class_enumval, sym_k_XmSINGLE_DASHED_LINE_enumval, 20, ENUMVAL_NAME, "XMSINGLE_DASHED_LINE"},
    {tkn_k_class_enumval, sym_k_XmSINGLE_LINE_enumval, 13, ENUMVAL_NAME, "XMSINGLE_LINE"},
    {tkn_k_class_enumval, sym_k_XmSINGLE_LINE_EDIT_enumval, 18, ENUMVAL_NAME, "XMSINGLE_LINE_EDIT"},
    {tkn_k_class_enumval, sym_k_XmSINGLE_SELECT_enumval, 15, ENUMVAL_NAME, "XMSINGLE_SELECT"},
    {tkn_k_class_enumval, sym_k_XmSLIDER_enumval, 8, ENUMVAL_NAME, "XMSLIDER"},
    {tkn_k_class_enumval, sym_k_XmSMALL_ICON_enumval, 12, ENUMVAL_NAME, "XMSMALL_ICON"},
    {tkn_k_class_enumval, sym_k_XmSNAP_TO_GRID_enumval, 14, ENUMVAL_NAME, "XMSNAP_TO_GRID"},
    {tkn_k_class_enumval, sym_k_XmSOLID_enumval, 7, ENUMVAL_NAME, "XMSOLID"},
    {tkn_k_class_enumval, sym_k_XmSPATIAL_enumval, 9, ENUMVAL_NAME, "XMSPATIAL"},
    {tkn_k_class_class, sym_k_XmSpinBox_object, 9, CLASS_NAME, "XMSPINBOX"},
    {tkn_k_class_enumval, sym_k_XmSPIRAL_enumval, 8, ENUMVAL_NAME, "XMSPIRAL"},
    {tkn_k_class_enumval, sym_k_XmSTATIC_enumval, 8, ENUMVAL_NAME, "XMSTATIC"},
    {tkn_k_class_enumval, sym_k_XmSTATUS_AREA_enumval, 13, ENUMVAL_NAME, "XMSTATUS_AREA"},
    {tkn_k_class_enumval, sym_k_XmSTICKY_TAB_GROUP_enumval, 18, ENUMVAL_NAME, "XMSTICKY_TAB_GROUP"},
    {tkn_k_class_enumval, sym_k_XmSTRING_enumval, 8, ENUMVAL_NAME, "XMSTRING"},
    {tkn_k_class_argument, sym_k_XmStringComponent_arg, 17, ARGUMENT_NAME, "XMSTRINGCOMPONENT"},
    {tkn_k_class_enumval, sym_k_XmSTRING_COMPONENT_CHARSET_enumval, 26, ENUMVAL_NAME, "XMSTRING_COMPONENT_CHARSET"},
    {tkn_k_class_enumval, sym_k_XmSTRING_COMPONENT_DIRECTION_enumval, 28, ENUMVAL_NAME, "XMSTRING_COMPONENT_DIRECTION"},
    {tkn_k_class_enumval, sym_k_XmSTRING_COMPONENT_LAYOUT_POP_enumval, 29, ENUMVAL_NAME, "XMSTRING_COMPONENT_LAYOUT_POP"},
    {tkn_k_class_enumval, sym_k_XmSTRING_COMPONENT_LAYOUT_PUSH_enumval, 30, ENUMVAL_NAME, "XMSTRING_COMPONENT_LAYOUT_PUSH"},
    {tkn_k_class_enumval, sym_k_XmSTRING_COMPONENT_LOCALE_enumval, 25, ENUMVAL_NAME, "XMSTRING_COMPONENT_LOCALE"},
    {tkn_k_class_enumval, sym_k_XmSTRING_COMPONENT_LOCALE_TEXT_enumval, 30, ENUMVAL_NAME, "XMSTRING_COMPONENT_LOCALE_TEXT"},
    {tkn_k_class_enumval, sym_k_XmSTRING_COMPONENT_RENDITION_BEGIN_enumval, 34, ENUMVAL_NAME, "XMSTRING_COMPONENT_RENDITION_BEGIN"},
    {tkn_k_class_enumval, sym_k_XmSTRING_COMPONENT_RENDITION_END_enumval, 32, ENUMVAL_NAME, "XMSTRING_COMPONENT_RENDITION_END"},
    {tkn_k_class_enumval, sym_k_XmSTRING_COMPONENT_SEPARATOR_enumval, 28, ENUMVAL_NAME, "XMSTRING_COMPONENT_SEPARATOR"},
    {tkn_k_class_enumval, sym_k_XmSTRING_COMPONENT_TAB_enumval, 22, ENUMVAL_NAME, "XMSTRING_COMPONENT_TAB"},
    {tkn_k_class_enumval, sym_k_XmSTRING_COMPONENT_TEXT_enumval, 23, ENUMVAL_NAME, "XMSTRING_COMPONENT_TEXT"},
    {tkn_k_class_enumval, sym_k_XmSTRING_COMPONENT_UNKNOWN_enumval, 26, ENUMVAL_NAME, "XMSTRING_COMPONENT_UNKNOWN"},
    {tkn_k_class_enumval, sym_k_XmSTRING_COMPONENT_WIDECHAR_TEXT_enumval, 32, ENUMVAL_NAME, "XMSTRING_COMPONENT_WIDECHAR_TEXT"},
    {tkn_k_class_enumval, sym_k_XmSTRING_DIRECTION_DEFAULT_enumval, 26, ENUMVAL_NAME, "XMSTRING_DIRECTION_DEFAULT"},
    {tkn_k_class_enumval, sym_k_XmSTRING_DIRECTION_L_TO_R_enumval, 25, ENUMVAL_NAME, "XMSTRING_DIRECTION_L_TO_R"},
    {tkn_k_class_enumval, sym_k_XmSTRING_DIRECTION_R_TO_L_enumval, 25, ENUMVAL_NAME, "XMSTRING_DIRECTION_R_TO_L"},
    {tkn_k_class_enumval, sym_k_XmSTRING_DIRECTION_UNSET_enumval, 24, ENUMVAL_NAME, "XMSTRING_DIRECTION_UNSET"},
    {tkn_k_class_class, sym_k_XmTab_object, 5, CLASS_NAME, "XMTAB"},
    {tkn_k_class_class, sym_k_XmTabBox_object, 8, CLASS_NAME, "XMTABBOX"},
    {tkn_k_class_class, sym_k_XmTabList_object, 9, CLASS_NAME, "XMTABLIST"},
    {tkn_k_class_class, sym_k_XmTabStack_object, 10, CLASS_NAME, "XMTABSTACK"},
    {tkn_k_class_enumval, sym_k_XmTABS_BASIC_enumval, 12, ENUMVAL_NAME, "XMTABS_BASIC"},
    {tkn_k_class_enumval, sym_k_XmTABS_BEVELED_enumval, 14, ENUMVAL_NAME, "XMTABS_BEVELED"},
    {tkn_k_class_enumval, sym_k_XmTABS_BOTTOM_TO_TOP_enumval, 20, ENUMVAL_NAME, "XMTABS_BOTTOM_TO_TOP"},
    {tkn_k_class_enumval, sym_k_XmTABS_LEFT_TO_RIGHT_enumval, 20, ENUMVAL_NAME, "XMTABS_LEFT_TO_RIGHT"},
    {tkn_k_class_enumval, sym_k_XmTABS_ON_BOTTOM_enumval, 16, ENUMVAL_NAME, "XMTABS_ON_BOTTOM"},
    {tkn_k_class_enumval, sym_k_XmTABS_ON_LEFT_enumval, 14, ENUMVAL_NAME, "XMTABS_ON_LEFT"},
    {tkn_k_class_enumval, sym_k_XmTABS_ON_RIGHT_enumval, 15, ENUMVAL_NAME, "XMTABS_ON_RIGHT"},
    {tkn_k_class_enumval, sym_k_XmTABS_ON_TOP_enumval, 13, ENUMVAL_NAME, "XMTABS_ON_TOP"},
    {tkn_k_class_enumval, sym_k_XmTABS_RIGHT_TO_LEFT_enumval, 20, ENUMVAL_NAME, "XMTABS_RIGHT_TO_LEFT"},
    {tkn_k_class_enumval, sym_k_XmTABS_ROUNDED_enumval, 14, ENUMVAL_NAME, "XMTABS_ROUNDED"},
    {tkn_k_class_enumval, sym_k_XmTABS_SQUARED_enumval, 14, ENUMVAL_NAME, "XMTABS_SQUARED"},
    {tkn_k_class_enumval, sym_k_XmTABS_STACKED_enumval, 14, ENUMVAL_NAME, "XMTABS_STACKED"},
    {tkn_k_class_enumval, sym_k_XmTABS_STACKED_STATIC_enumval, 21, ENUMVAL_NAME, "XMTABS_STACKED_STATIC"},
    {tkn_k_class_enumval, sym_k_XmTABS_TOP_TO_BOTTOM_enumval, 20, ENUMVAL_NAME, "XMTABS_TOP_TO_BOTTOM"},
    {tkn_k_class_enumval, sym_k_XmTAB_EDGE_BOTTOM_RIGHT_enumval, 23, ENUMVAL_NAME, "XMTAB_EDGE_BOTTOM_RIGHT"},
    {tkn_k_class_enumval, sym_k_XmTAB_EDGE_TOP_LEFT_enumval, 19, ENUMVAL_NAME, "XMTAB_EDGE_TOP_LEFT"},
    {tkn_k_class_enumval, sym_k_XmTAB_GROUP_enumval, 11, ENUMVAL_NAME, "XMTAB_GROUP"},
    {tkn_k_class_enumval, sym_k_XmTAB_ORIENTATION_DYNAMIC_enumval, 25, ENUMVAL_NAME, "XMTAB_ORIENTATION_DYNAMIC"},
    {tkn_k_class_class, sym_k_XmTearOffButton_object, 15, CLASS_NAME, "XMTEAROFFBUTTON"},
    {tkn_k_class_enumval, sym_k_XmTEAR_OFF_DISABLED_enumval, 19, ENUMVAL_NAME, "XMTEAR_OFF_DISABLED"},
    {tkn_k_class_enumval, sym_k_XmTEAR_OFF_ENABLED_enumval, 18, ENUMVAL_NAME, "XMTEAR_OFF_ENABLED"},
    {tkn_k_class_class, sym_k_XmTemplateDialog_object, 16, CLASS_NAME, "XMTEMPLATEDIALOG"},
    {tkn_k_class_class, sym_k_XmText_object, 6, CLASS_NAME, "XMTEXT"},
    {tkn_k_class_class, sym_k_XmTextField_object, 11, CLASS_NAME, "XMTEXTFIELD"},
    {tkn_k_class_enumval, sym_k_XmTHERMOMETER_enumval, 13, ENUMVAL_NAME, "XMTHERMOMETER"},
    {tkn_k_class_enumval, sym_k_XmTHUMB_MARK_enumval, 12, ENUMVAL_NAME, "XMTHUMB_MARK"},
    {tkn_k_class_class, sym_k_XmToggleButton_object, 14, CLASS_NAME, "XMTOGGLEBUTTON"},
    {tkn_k_class_class, sym_k_XmToggleButtonGadget_object, 20, CLASS_NAME, "XMTOGGLEBUTTONGADGET"},
    {tkn_k_class_enumval, sym_k_XmTOGGLE_BOOLEAN_enumval, 16, ENUMVAL_NAME, "XMTOGGLE_BOOLEAN"},
    {tkn_k_class_enumval, sym_k_XmTOGGLE_INDETERMINATE_enumval, 22, ENUMVAL_NAME, "XMTOGGLE_INDETERMINATE"},
    {tkn_k_class_enumval, sym_k_XmTOP_LEFT_enumval, 10, ENUMVAL_NAME, "XMTOP_LEFT"},
    {tkn_k_class_enumval, sym_k_XmTOP_RIGHT_enumval, 11, ENUMVAL_NAME, "XMTOP_RIGHT"},
    {tkn_k_class_enumval, sym_k_XmTOP_TO_BOTTOM_enumval, 15, ENUMVAL_NAME, "XMTOP_TO_BOTTOM"},
    {tkn_k_class_enumval, sym_k_XmTOP_TO_BOTTOM_LEFT_TO_RIGHT_enumval, 29, ENUMVAL_NAME, "XMTOP_TO_BOTTOM_LEFT_TO_RIGHT"},
    {tkn_k_class_enumval, sym_k_XmTOP_TO_BOTTOM_RIGHT_TO_LEFT_enumval, 29, ENUMVAL_NAME, "XMTOP_TO_BOTTOM_RIGHT_TO_LEFT"},
    {tkn_k_class_enumval, sym_k_XmTOUCH_ONLY_enumval, 12, ENUMVAL_NAME, "XMTOUCH_ONLY"},
    {tkn_k_class_enumval, sym_k_XmTOUCH_OVER_enumval, 12, ENUMVAL_NAME, "XMTOUCH_OVER"},
    {tkn_k_class_class, sym_k_XmTree_object, 6, CLASS_NAME, "XMTREE"},
    {tkn_k_class_enumval, sym_k_XmTreeCompressLeaves_enumval, 20, ENUMVAL_NAME, "XMTREECOMPRESSLEAVES"},
    {tkn_k_class_enumval, sym_k_XmTreeCompressNone_enumval, 18, ENUMVAL_NAME, "XMTREECOMPRESSNONE"},
    {tkn_k_class_enumval, sym_k_XmTreeDirect_enumval, 12, ENUMVAL_NAME, "XMTREEDIRECT"},
    {tkn_k_class_enumval, sym_k_XmTreeLadder_enumval, 12, ENUMVAL_NAME, "XMTREELADDER"},
    {tkn_k_class_enumval, sym_k_XmTROUGH_COLOR_enumval, 14, ENUMVAL_NAME, "XMTROUGH_COLOR"},
    {tkn_k_class_enumval, sym_k_XmUNMAP_enumval, 7, ENUMVAL_NAME, "XMUNMAP"},
    {tkn_k_class_enumval, sym_k_XmUNPOST_enumval, 8, ENUMVAL_NAME, "XMUNPOST"},
    {tkn_k_class_enumval, sym_k_XmUNPOST_AND_REPLAY_enumval, 19, ENUMVAL_NAME, "XMUNPOST_AND_REPLAY"},
    {tkn_k_class_enumval, sym_k_XmUNSET_enumval, 7, ENUMVAL_NAME, "XMUNSET"},
    {tkn_k_class_enumval, sym_k_XmVARIABLE_enumval, 10, ENUMVAL_NAME, "XMVARIABLE"},
    {tkn_k_class_enumval, sym_k_XmVERTICAL_enumval, 10, ENUMVAL_NAME, "XMVERTICAL"},
    {tkn_k_class_enumval, sym_k_XmVERT_SCROLLBAR_enumval, 16, ENUMVAL_NAME, "XMVERT_SCROLLBAR"},
    {tkn_k_class_class, sym_k_XmWarningDialog_object, 15, CLASS_NAME, "XMWARNINGDIALOG"},
    {tkn_k_class_class, sym_k_XmWorkArea_object, 10, CLASS_NAME, "XMWORKAREA"},
    {tkn_k_class_class, sym_k_XmWorkingDialog_object, 15, CLASS_NAME, "XMWORKINGDIALOG"},
    {tkn_k_class_enumval, sym_k_XmWORK_AREA_enumval, 11, ENUMVAL_NAME, "XMWORK_AREA"},
    {tkn_k_class_enumval, sym_k_XmZERO_BASED_enumval, 12, ENUMVAL_NAME, "XMZERO_BASED"},
    {tkn_k_class_child, sym_k_Xm_Apply_child, 8, CHILD_NAME, "XM_APPLY"},
    {tkn_k_class_child, sym_k_Xm_Arrow_child, 8, CHILD_NAME, "XM_ARROW"},
    {tkn_k_class_child, sym_k_Xm_Cancel_child, 9, CHILD_NAME, "XM_CANCEL"},
    {tkn_k_class_child, sym_k_Xm_ColorListToggle_child, 18, CHILD_NAME, "XM_COLORLISTTOGGLE"},
    {tkn_k_class_child, sym_k_Xm_ColorSlidersToggle_child, 21, CHILD_NAME, "XM_COLORSLIDERSTOGGLE"},
    {tkn_k_class_child, sym_k_Xm_Dir_child, 6, CHILD_NAME, "XM_DIR"},
    {tkn_k_class_child, sym_k_Xm_DirList_child, 10, CHILD_NAME, "XM_DIRLIST"},
    {tkn_k_class_child, sym_k_Xm_Filter_child, 9, CHILD_NAME, "XM_FILTER"},
    {tkn_k_class_child, sym_k_Xm_FilterLabel_child, 14, CHILD_NAME, "XM_FILTERLABEL"},
    {tkn_k_class_child, sym_k_Xm_FilterText_child, 13, CHILD_NAME, "XM_FILTERTEXT"},
    {tkn_k_class_child, sym_k_Xm_Find_child, 7, CHILD_NAME, "XM_FIND"},
    {tkn_k_class_child, sym_k_Xm_FindText_child, 11, CHILD_NAME, "XM_FINDTEXT"},
    {tkn_k_class_child, sym_k_Xm_Help_child, 7, CHILD_NAME, "XM_HELP"},
    {tkn_k_class_child, sym_k_Xm_HorScrollBar_child, 15, CHILD_NAME, "XM_HORSCROLLBAR"},
    {tkn_k_class_child, sym_k_Xm_Items_child, 8, CHILD_NAME, "XM_ITEMS"},
    {tkn_k_class_child, sym_k_Xm_ItemsList_child, 12, CHILD_NAME, "XM_ITEMSLIST"},
    {tkn_k_class_child, sym_k_Xm_Label_child, 8, CHILD_NAME, "XM_LABEL"},
    {tkn_k_class_child, sym_k_Xm_List_child, 7, CHILD_NAME, "XM_LIST"},
    {tkn_k_class_child, sym_k_Xm_Message_child, 10, CHILD_NAME, "XM_MESSAGE"},
    {tkn_k_class_child, sym_k_Xm_OK_child, 5, CHILD_NAME, "XM_OK"},
    {tkn_k_class_child, sym_k_Xm_OptionButton_child, 15, CHILD_NAME, "XM_OPTIONBUTTON"},
    {tkn_k_class_child, sym_k_Xm_OptionLabel_child, 14, CHILD_NAME, "XM_OPTIONLABEL"},
    {tkn_k_class_child, sym_k_Xm_Selection_child, 12, CHILD_NAME, "XM_SELECTION"},
    {tkn_k_class_child, sym_k_Xm_Separator_child, 12, CHILD_NAME, "XM_SEPARATOR"},
    {tkn_k_class_child, sym_k_Xm_Separator1_child, 13, CHILD_NAME, "XM_SEPARATOR1"},
    {tkn_k_class_child, sym_k_Xm_Separator2_child, 13, CHILD_NAME, "XM_SEPARATOR2"},
    {tkn_k_class_child, sym_k_Xm_Separator3_child, 13, CHILD_NAME, "XM_SEPARATOR3"},
    {tkn_k_class_child, sym_k_Xm_Symbol_child, 9, CHILD_NAME, "XM_SYMBOL"},
    {tkn_k_class_child, sym_k_Xm_TearOffControl_child, 17, CHILD_NAME, "XM_TEAROFFCONTROL"},
    {tkn_k_class_child, sym_k_Xm_Text_child, 7, CHILD_NAME, "XM_TEXT"},
    {tkn_k_class_child, sym_k_Xm_TextField_child, 12, CHILD_NAME, "XM_TEXTFIELD"},
    {tkn_k_class_child, sym_k_Xm_Title_child, 8, CHILD_NAME, "XM_TITLE"},
    {tkn_k_class_child, sym_k_Xm_VertScrollBar_child, 16, CHILD_NAME, "XM_VERTSCROLLBAR"},
    {tkn_k_class_charset, sym_k__MOTIF_DEFAULT_LOCALE_charset, 21, CHARSET_NAME, "_MOTIF_DEFAULT_LOCALE"},
  };
externaldef(uil_sym_glbl) key_keytable_entry_type *key_table_case_ins =
		key_table_case_ins_vec;
