/*
**	This file is automatically generated.  Do not edit it by hand.
**/

/*
 * Bit vectors for each argument. The entries in the vector correspond
 * to each class.
 */

/* sym_k_DtNallowSendEvents_arg */
static unsigned char arg_class_vec1[] =
  {
  _BIT_MASK(sym_k_DtTerm_object) |
  0, _BIT_MASK(sym_k_DtTermPrimitive_object) |
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_DtNappCursorDefault_arg */
static unsigned char arg_class_vec2[] =
  {
  _BIT_MASK(sym_k_DtTerm_object) |
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_DtNappKeypadDefault_arg */
static unsigned char arg_class_vec3[] =
  {
  _BIT_MASK(sym_k_DtTerm_object) |
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_DtNautoShowCursorPosition_arg */
static unsigned char arg_class_vec4[] =
  {
  _BIT_MASK(sym_k_DtEditor_object) |
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_DtNautoWrap_arg */
static unsigned char arg_class_vec5[] =
  {
  _BIT_MASK(sym_k_DtTerm_object) |
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_DtNbackLabelString_arg */
static unsigned char arg_class_vec6[] =
  {
  _BIT_MASK(sym_k_DtHelpQuickDialog_object) |
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_DtNbackgroundIsSelect_arg */
static unsigned char arg_class_vec7[] =
  {
  _BIT_MASK(sym_k_DtTerm_object) |
  0, _BIT_MASK(sym_k_DtTermPrimitive_object) |
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_DtNbaseHeight_arg */
static unsigned char arg_class_vec8[] =
  {
  _BIT_MASK(sym_k_DtTerm_object) |
  0, _BIT_MASK(sym_k_DtTermPrimitive_object) |
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_DtNbaseWidth_arg */
static unsigned char arg_class_vec9[] =
  {
  _BIT_MASK(sym_k_DtTerm_object) |
  0, _BIT_MASK(sym_k_DtTermPrimitive_object) |
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_DtNblinkRate_arg */
static unsigned char arg_class_vec10[] =
  {
  _BIT_MASK(sym_k_DtEditor_object) |
  _BIT_MASK(sym_k_DtTerm_object) |
  0, _BIT_MASK(sym_k_DtTermPrimitive_object) |
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_DtNbuttonFontList_arg */
static unsigned char arg_class_vec11[] =
  {
  _BIT_MASK(sym_k_DtEditor_object) |
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_DtNc132_arg */
static unsigned char arg_class_vec12[] =
  {
  _BIT_MASK(sym_k_DtTerm_object) |
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_DtNcascadePixmap_arg */
static unsigned char arg_class_vec13[] =
  {
  _BIT_MASK(sym_k_DtMenuButton_object) |
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_DtNcenterToggleLabel_arg */
static unsigned char arg_class_vec14[] =
  {
  _BIT_MASK(sym_k_DtEditor_object) |
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_DtNchangeAllButtonLabel_arg */
static unsigned char arg_class_vec15[] =
  {
  _BIT_MASK(sym_k_DtEditor_object) |
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_DtNchangeButtonLabel_arg */
static unsigned char arg_class_vec16[] =
  {
  _BIT_MASK(sym_k_DtEditor_object) |
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_DtNchangeFieldLabel_arg */
static unsigned char arg_class_vec17[] =
  {
  _BIT_MASK(sym_k_DtEditor_object) |
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_DtNcharCursorStyle_arg */
static unsigned char arg_class_vec18[] =
  {
  _BIT_MASK(sym_k_DtTerm_object) |
  0, _BIT_MASK(sym_k_DtTermPrimitive_object) |
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_DtNcloseLabelString_arg */
static unsigned char arg_class_vec19[] =
  {
  _BIT_MASK(sym_k_DtHelpQuickDialog_object) |
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_DtNcolumns_arg */
static unsigned char arg_class_vec20[] =
  {
  _BIT_MASK(sym_k_DtEditor_object) |
  _BIT_MASK(sym_k_DtHelpDialog_object) |
  _BIT_MASK(sym_k_DtHelpQuickDialog_object) |
  _BIT_MASK(sym_k_DtTerm_object) |
  0, _BIT_MASK(sym_k_DtTermPrimitive_object) |
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_DtNconsoleMode_arg */
static unsigned char arg_class_vec21[] =
  {
  _BIT_MASK(sym_k_DtTerm_object) |
  0, _BIT_MASK(sym_k_DtTermPrimitive_object) |
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_DtNcopies_arg */
static unsigned char arg_class_vec22[] =
  {
  _BIT_MASK(sym_k_DtPrintSetupBox_object) |
  _BIT_MASK(sym_k_DtPrintSetupDialog_object) |
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_DtNcsWidth_arg */
static unsigned char arg_class_vec23[] =
  {
  _BIT_MASK(sym_k_DtTerm_object) |
  0, _BIT_MASK(sym_k_DtTermPrimitive_object) |
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_DtNcurrentLineLabel_arg */
static unsigned char arg_class_vec24[] =
  {
  _BIT_MASK(sym_k_DtEditor_object) |
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_DtNcursorPosition_arg */
static unsigned char arg_class_vec25[] =
  {
  _BIT_MASK(sym_k_DtEditor_object) |
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_DtNcursorPositionVisible_arg */
static unsigned char arg_class_vec26[] =
  {
  _BIT_MASK(sym_k_DtEditor_object) |
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_DtNdescription_arg */
static unsigned char arg_class_vec27[] =
  {
  _BIT_MASK(sym_k_DtPrintSetupBox_object) |
  _BIT_MASK(sym_k_DtPrintSetupDialog_object) |
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_DtNdialogTitle_arg */
static unsigned char arg_class_vec28[] =
  {
  _BIT_MASK(sym_k_DtEditor_object) |
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_DtNeditable_arg */
static unsigned char arg_class_vec29[] =
  {
  _BIT_MASK(sym_k_DtEditor_object) |
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_DtNemulationId_arg */
static unsigned char arg_class_vec30[] =
  {
  _BIT_MASK(sym_k_DtTerm_object) |
  0, _BIT_MASK(sym_k_DtTermPrimitive_object) |
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_DtNexecutionPolicy_arg */
static unsigned char arg_class_vec31[] =
  {
  _BIT_MASK(sym_k_DtHelpDialog_object) |
  _BIT_MASK(sym_k_DtHelpQuickDialog_object) |
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_DtNfileName_arg */
static unsigned char arg_class_vec32[] =
  {
  _BIT_MASK(sym_k_DtPrintSetupBox_object) |
  _BIT_MASK(sym_k_DtPrintSetupDialog_object) |
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_DtNfindButtonLabel_arg */
static unsigned char arg_class_vec33[] =
  {
  _BIT_MASK(sym_k_DtEditor_object) |
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_DtNfindChangeDialogTitle_arg */
static unsigned char arg_class_vec34[] =
  {
  _BIT_MASK(sym_k_DtEditor_object) |
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_DtNfindFieldLabel_arg */
static unsigned char arg_class_vec35[] =
  {
  _BIT_MASK(sym_k_DtEditor_object) |
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_DtNformatAllButtonLabel_arg */
static unsigned char arg_class_vec36[] =
  {
  _BIT_MASK(sym_k_DtEditor_object) |
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_DtNformatParagraphButtonLabel_arg */
static unsigned char arg_class_vec37[] =
  {
  _BIT_MASK(sym_k_DtEditor_object) |
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_DtNformatSettingsDialogTitle_arg */
static unsigned char arg_class_vec38[] =
  {
  _BIT_MASK(sym_k_DtEditor_object) |
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_DtNheightInc_arg */
static unsigned char arg_class_vec39[] =
  {
  _BIT_MASK(sym_k_DtTerm_object) |
  0, _BIT_MASK(sym_k_DtTermPrimitive_object) |
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_DtNhelpFile_arg */
static unsigned char arg_class_vec40[] =
  {
  _BIT_MASK(sym_k_DtHelpDialog_object) |
  _BIT_MASK(sym_k_DtHelpQuickDialog_object) |
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_DtNhelpLabelString_arg */
static unsigned char arg_class_vec41[] =
  {
  _BIT_MASK(sym_k_DtHelpQuickDialog_object) |
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_DtNhelpOnHelpVolume_arg */
static unsigned char arg_class_vec42[] =
  {
  _BIT_MASK(sym_k_DtHelpDialog_object) |
  _BIT_MASK(sym_k_DtHelpQuickDialog_object) |
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_DtNhelpPrint_arg */
static unsigned char arg_class_vec43[] =
  {
  _BIT_MASK(sym_k_DtHelpDialog_object) |
  _BIT_MASK(sym_k_DtHelpQuickDialog_object) |
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_DtNhelpType_arg */
static unsigned char arg_class_vec44[] =
  {
  _BIT_MASK(sym_k_DtHelpDialog_object) |
  _BIT_MASK(sym_k_DtHelpQuickDialog_object) |
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_DtNhelpVolume_arg */
static unsigned char arg_class_vec45[] =
  {
  _BIT_MASK(sym_k_DtHelpDialog_object) |
  _BIT_MASK(sym_k_DtHelpQuickDialog_object) |
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_DtNinformationDialogTitle_arg */
static unsigned char arg_class_vec46[] =
  {
  _BIT_MASK(sym_k_DtEditor_object) |
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_DtNinsertLabel_arg */
static unsigned char arg_class_vec47[] =
  {
  _BIT_MASK(sym_k_DtEditor_object) |
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_DtNjumpScroll_arg */
static unsigned char arg_class_vec48[] =
  {
  _BIT_MASK(sym_k_DtTerm_object) |
  0, _BIT_MASK(sym_k_DtTermPrimitive_object) |
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_DtNjustifyToggleLabel_arg */
static unsigned char arg_class_vec49[] =
  {
  _BIT_MASK(sym_k_DtEditor_object) |
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_DtNkshMode_arg */
static unsigned char arg_class_vec50[] =
  {
  _BIT_MASK(sym_k_DtTerm_object) |
  0, _BIT_MASK(sym_k_DtTermPrimitive_object) |
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_DtNlabelFontList_arg */
static unsigned char arg_class_vec51[] =
  {
  _BIT_MASK(sym_k_DtEditor_object) |
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_DtNleftAlignToggleLabel_arg */
static unsigned char arg_class_vec52[] =
  {
  _BIT_MASK(sym_k_DtEditor_object) |
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_DtNleftMarginFieldLabel_arg */
static unsigned char arg_class_vec53[] =
  {
  _BIT_MASK(sym_k_DtEditor_object) |
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_DtNlocationId_arg */
static unsigned char arg_class_vec54[] =
  {
  _BIT_MASK(sym_k_DtHelpDialog_object) |
  _BIT_MASK(sym_k_DtHelpQuickDialog_object) |
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_DtNlogFile_arg */
static unsigned char arg_class_vec55[] =
  {
  _BIT_MASK(sym_k_DtTerm_object) |
  0, _BIT_MASK(sym_k_DtTermPrimitive_object) |
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_DtNlogInhibit_arg */
static unsigned char arg_class_vec56[] =
  {
  _BIT_MASK(sym_k_DtTerm_object) |
  0, _BIT_MASK(sym_k_DtTermPrimitive_object) |
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_DtNlogging_arg */
static unsigned char arg_class_vec57[] =
  {
  _BIT_MASK(sym_k_DtTerm_object) |
  0, _BIT_MASK(sym_k_DtTermPrimitive_object) |
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_DtNmanPage_arg */
static unsigned char arg_class_vec58[] =
  {
  _BIT_MASK(sym_k_DtHelpDialog_object) |
  _BIT_MASK(sym_k_DtHelpQuickDialog_object) |
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_DtNmapOnOutput_arg */
static unsigned char arg_class_vec59[] =
  {
  _BIT_MASK(sym_k_DtTerm_object) |
  0, _BIT_MASK(sym_k_DtTermPrimitive_object) |
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_DtNmapOnOutputDelay_arg */
static unsigned char arg_class_vec60[] =
  {
  _BIT_MASK(sym_k_DtTerm_object) |
  0, _BIT_MASK(sym_k_DtTermPrimitive_object) |
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_DtNmarginBell_arg */
static unsigned char arg_class_vec61[] =
  {
  _BIT_MASK(sym_k_DtTerm_object) |
  0, _BIT_MASK(sym_k_DtTermPrimitive_object) |
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_DtNmarginHeight_arg */
static unsigned char arg_class_vec62[] =
  {
  _BIT_MASK(sym_k_DtHelpDialog_object) |
  _BIT_MASK(sym_k_DtTerm_object) |
  0, _BIT_MASK(sym_k_DtTermPrimitive_object) |
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_DtNmarginWidth_arg */
static unsigned char arg_class_vec63[] =
  {
  _BIT_MASK(sym_k_DtHelpDialog_object) |
  _BIT_MASK(sym_k_DtTerm_object) |
  0, _BIT_MASK(sym_k_DtTermPrimitive_object) |
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_DtNmaxLength_arg */
static unsigned char arg_class_vec64[] =
  {
  _BIT_MASK(sym_k_DtEditor_object) |
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_DtNminimizeButtons_arg */
static unsigned char arg_class_vec65[] =
  {
  _BIT_MASK(sym_k_DtHelpQuickDialog_object) |
  _BIT_MASK(sym_k_DtPrintSetupBox_object) |
  _BIT_MASK(sym_k_DtPrintSetupDialog_object) |
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_DtNmisspelledListLabel_arg */
static unsigned char arg_class_vec66[] =
  {
  _BIT_MASK(sym_k_DtEditor_object) |
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_DtNmoreLabelString_arg */
static unsigned char arg_class_vec67[] =
  {
  _BIT_MASK(sym_k_DtHelpQuickDialog_object) |
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_DtNnMarginBell_arg */
static unsigned char arg_class_vec68[] =
  {
  _BIT_MASK(sym_k_DtTerm_object) |
  0, _BIT_MASK(sym_k_DtTermPrimitive_object) |
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_DtNoverstrike_arg */
static unsigned char arg_class_vec69[] =
  {
  _BIT_MASK(sym_k_DtEditor_object) |
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_DtNoverstrikeLabel_arg */
static unsigned char arg_class_vec70[] =
  {
  _BIT_MASK(sym_k_DtEditor_object) |
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_DtNpaperSize_arg */
static unsigned char arg_class_vec71[] =
  {
  _BIT_MASK(sym_k_DtHelpDialog_object) |
  _BIT_MASK(sym_k_DtHelpQuickDialog_object) |
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_DtNpointerBlank_arg */
static unsigned char arg_class_vec72[] =
  {
  _BIT_MASK(sym_k_DtTerm_object) |
  0, _BIT_MASK(sym_k_DtTermPrimitive_object) |
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_DtNpointerBlankDelay_arg */
static unsigned char arg_class_vec73[] =
  {
  _BIT_MASK(sym_k_DtTerm_object) |
  0, _BIT_MASK(sym_k_DtTermPrimitive_object) |
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_DtNpointerColor_arg */
static unsigned char arg_class_vec74[] =
  {
  _BIT_MASK(sym_k_DtTerm_object) |
  0, _BIT_MASK(sym_k_DtTermPrimitive_object) |
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_DtNpointerColorBackground_arg */
static unsigned char arg_class_vec75[] =
  {
  _BIT_MASK(sym_k_DtTerm_object) |
  0, _BIT_MASK(sym_k_DtTermPrimitive_object) |
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_DtNpointerShape_arg */
static unsigned char arg_class_vec76[] =
  {
  _BIT_MASK(sym_k_DtTerm_object) |
  0, _BIT_MASK(sym_k_DtTermPrimitive_object) |
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_DtNprintDestination_arg */
static unsigned char arg_class_vec77[] =
  {
  _BIT_MASK(sym_k_DtPrintSetupBox_object) |
  _BIT_MASK(sym_k_DtPrintSetupDialog_object) |
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_DtNprintLabelString_arg */
static unsigned char arg_class_vec78[] =
  {
  _BIT_MASK(sym_k_DtHelpQuickDialog_object) |
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_DtNprintSetupMode_arg */
static unsigned char arg_class_vec79[] =
  {
  _BIT_MASK(sym_k_DtPrintSetupBox_object) |
  _BIT_MASK(sym_k_DtPrintSetupDialog_object) |
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_DtNprinter_arg */
static unsigned char arg_class_vec80[] =
  {
  _BIT_MASK(sym_k_DtHelpDialog_object) |
  _BIT_MASK(sym_k_DtHelpQuickDialog_object) |
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_DtNprinterInfoProc_arg */
static unsigned char arg_class_vec81[] =
  {
  _BIT_MASK(sym_k_DtPrintSetupBox_object) |
  _BIT_MASK(sym_k_DtPrintSetupDialog_object) |
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_DtNprinterName_arg */
static unsigned char arg_class_vec82[] =
  {
  _BIT_MASK(sym_k_DtPrintSetupBox_object) |
  _BIT_MASK(sym_k_DtPrintSetupDialog_object) |
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_DtNreverseVideo_arg */
static unsigned char arg_class_vec83[] =
  {
  _BIT_MASK(sym_k_DtTerm_object) |
  0, _BIT_MASK(sym_k_DtTermPrimitive_object) |
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_DtNreverseWrap_arg */
static unsigned char arg_class_vec84[] =
  {
  _BIT_MASK(sym_k_DtTerm_object) |
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_DtNrightAlignToggleLabel_arg */
static unsigned char arg_class_vec85[] =
  {
  _BIT_MASK(sym_k_DtEditor_object) |
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_DtNrightMarginFieldLabel_arg */
static unsigned char arg_class_vec86[] =
  {
  _BIT_MASK(sym_k_DtEditor_object) |
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_DtNrows_arg */
static unsigned char arg_class_vec87[] =
  {
  _BIT_MASK(sym_k_DtEditor_object) |
  _BIT_MASK(sym_k_DtHelpDialog_object) |
  _BIT_MASK(sym_k_DtHelpQuickDialog_object) |
  _BIT_MASK(sym_k_DtTerm_object) |
  0, _BIT_MASK(sym_k_DtTermPrimitive_object) |
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_DtNsaveLines_arg */
static unsigned char arg_class_vec88[] =
  {
  _BIT_MASK(sym_k_DtTerm_object) |
  0, _BIT_MASK(sym_k_DtTermPrimitive_object) |
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_DtNscrollBarPolicy_arg */
static unsigned char arg_class_vec89[] =
  {
  _BIT_MASK(sym_k_DtHelpDialog_object) |
  _BIT_MASK(sym_k_DtHelpQuickDialog_object) |
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_DtNscrollHorizontal_arg */
static unsigned char arg_class_vec90[] =
  {
  _BIT_MASK(sym_k_DtEditor_object) |
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_DtNscrollLeftSide_arg */
static unsigned char arg_class_vec91[] =
  {
  _BIT_MASK(sym_k_DtEditor_object) |
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_DtNscrollTopSide_arg */
static unsigned char arg_class_vec92[] =
  {
  _BIT_MASK(sym_k_DtEditor_object) |
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_DtNscrollVertical_arg */
static unsigned char arg_class_vec93[] =
  {
  _BIT_MASK(sym_k_DtEditor_object) |
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_DtNselectFileProc_arg */
static unsigned char arg_class_vec94[] =
  {
  _BIT_MASK(sym_k_DtPrintSetupBox_object) |
  _BIT_MASK(sym_k_DtPrintSetupDialog_object) |
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_DtNselectPrinterProc_arg */
static unsigned char arg_class_vec95[] =
  {
  _BIT_MASK(sym_k_DtPrintSetupBox_object) |
  _BIT_MASK(sym_k_DtPrintSetupDialog_object) |
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_DtNshadowType_arg */
static unsigned char arg_class_vec96[] =
  {
  _BIT_MASK(sym_k_DtTerm_object) |
  0, _BIT_MASK(sym_k_DtTermPrimitive_object) |
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_DtNshowNewWindowButton_arg */
static unsigned char arg_class_vec97[] =
  {
  _BIT_MASK(sym_k_DtHelpDialog_object) |
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_DtNshowStatusLine_arg */
static unsigned char arg_class_vec98[] =
  {
  _BIT_MASK(sym_k_DtEditor_object) |
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_DtNspellDialogTitle_arg */
static unsigned char arg_class_vec99[] =
  {
  _BIT_MASK(sym_k_DtEditor_object) |
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_DtNspellFilter_arg */
static unsigned char arg_class_vec100[] =
  {
  _BIT_MASK(sym_k_DtEditor_object) |
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_DtNstickyNextCursor_arg */
static unsigned char arg_class_vec101[] =
  {
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_DtNstickyPrevCursor_arg */
static unsigned char arg_class_vec102[] =
  {
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_DtNstringData_arg */
static unsigned char arg_class_vec103[] =
  {
  _BIT_MASK(sym_k_DtHelpDialog_object) |
  _BIT_MASK(sym_k_DtHelpQuickDialog_object) |
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_DtNsubMenuId_arg */
static unsigned char arg_class_vec104[] =
  {
  _BIT_MASK(sym_k_DtMenuButton_object) |
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_DtNsubprocessArgv_arg */
static unsigned char arg_class_vec105[] =
  {
  _BIT_MASK(sym_k_DtTerm_object) |
  0, _BIT_MASK(sym_k_DtTermPrimitive_object) |
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_DtNsubprocessCmd_arg */
static unsigned char arg_class_vec106[] =
  {
  _BIT_MASK(sym_k_DtTerm_object) |
  0, _BIT_MASK(sym_k_DtTermPrimitive_object) |
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_DtNsubprocessExec_arg */
static unsigned char arg_class_vec107[] =
  {
  _BIT_MASK(sym_k_DtTerm_object) |
  0, _BIT_MASK(sym_k_DtTermPrimitive_object) |
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_DtNsubprocessLoginShell_arg */
static unsigned char arg_class_vec108[] =
  {
  _BIT_MASK(sym_k_DtTerm_object) |
  0, _BIT_MASK(sym_k_DtTermPrimitive_object) |
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_DtNsubprocessPid_arg */
static unsigned char arg_class_vec109[] =
  {
  _BIT_MASK(sym_k_DtTerm_object) |
  0, _BIT_MASK(sym_k_DtTermPrimitive_object) |
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_DtNsubprocessTerminationCatch_arg */
static unsigned char arg_class_vec110[] =
  {
  _BIT_MASK(sym_k_DtTerm_object) |
  0, _BIT_MASK(sym_k_DtTermPrimitive_object) |
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_DtNsunFunctionKeys_arg */
static unsigned char arg_class_vec111[] =
  {
  _BIT_MASK(sym_k_DtTerm_object) |
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_DtNtermDevice_arg */
static unsigned char arg_class_vec112[] =
  {
  _BIT_MASK(sym_k_DtTerm_object) |
  0, _BIT_MASK(sym_k_DtTermPrimitive_object) |
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_DtNtermDeviceAllocate_arg */
static unsigned char arg_class_vec113[] =
  {
  _BIT_MASK(sym_k_DtTerm_object) |
  0, _BIT_MASK(sym_k_DtTermPrimitive_object) |
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_DtNtermId_arg */
static unsigned char arg_class_vec114[] =
  {
  _BIT_MASK(sym_k_DtTerm_object) |
  0, _BIT_MASK(sym_k_DtTermPrimitive_object) |
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_DtNtermName_arg */
static unsigned char arg_class_vec115[] =
  {
  _BIT_MASK(sym_k_DtTerm_object) |
  0, _BIT_MASK(sym_k_DtTermPrimitive_object) |
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_DtNtermSlaveName_arg */
static unsigned char arg_class_vec116[] =
  {
  _BIT_MASK(sym_k_DtTerm_object) |
  0, _BIT_MASK(sym_k_DtTermPrimitive_object) |
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_DtNtextBackground_arg */
static unsigned char arg_class_vec117[] =
  {
  _BIT_MASK(sym_k_DtEditor_object) |
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_DtNtextFontList_arg */
static unsigned char arg_class_vec118[] =
  {
  _BIT_MASK(sym_k_DtEditor_object) |
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_DtNtextForeground_arg */
static unsigned char arg_class_vec119[] =
  {
  _BIT_MASK(sym_k_DtEditor_object) |
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_DtNtextTranslations_arg */
static unsigned char arg_class_vec120[] =
  {
  _BIT_MASK(sym_k_DtEditor_object) |
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_DtNtopCharacter_arg */
static unsigned char arg_class_vec121[] =
  {
  _BIT_MASK(sym_k_DtEditor_object) |
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_DtNtopicTitle_arg */
static unsigned char arg_class_vec122[] =
  {
  _BIT_MASK(sym_k_DtHelpDialog_object) |
  _BIT_MASK(sym_k_DtHelpQuickDialog_object) |
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_DtNtotalLineCountLabel_arg */
static unsigned char arg_class_vec123[] =
  {
  _BIT_MASK(sym_k_DtEditor_object) |
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_DtNttyModes_arg */
static unsigned char arg_class_vec124[] =
  {
  _BIT_MASK(sym_k_DtTerm_object) |
  0, _BIT_MASK(sym_k_DtTermPrimitive_object) |
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_DtNuserBoldFont_arg */
static unsigned char arg_class_vec125[] =
  {
  _BIT_MASK(sym_k_DtTerm_object) |
  0, _BIT_MASK(sym_k_DtTermPrimitive_object) |
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_DtNuserFont_arg */
static unsigned char arg_class_vec126[] =
  {
  _BIT_MASK(sym_k_DtTerm_object) |
  0, _BIT_MASK(sym_k_DtTermPrimitive_object) |
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_DtNverifyPrinterProc_arg */
static unsigned char arg_class_vec127[] =
  {
  _BIT_MASK(sym_k_DtPrintSetupBox_object) |
  _BIT_MASK(sym_k_DtPrintSetupDialog_object) |
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_DtNverticalScrollBar_arg */
static unsigned char arg_class_vec128[] =
  {
  _BIT_MASK(sym_k_DtTerm_object) |
  0, _BIT_MASK(sym_k_DtTermPrimitive_object) |
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_DtNvisiblePathCount_arg */
static unsigned char arg_class_vec129[] =
  {
  _BIT_MASK(sym_k_DtHelpDialog_object) |
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_DtNvisualBell_arg */
static unsigned char arg_class_vec130[] =
  {
  _BIT_MASK(sym_k_DtTerm_object) |
  0, _BIT_MASK(sym_k_DtTermPrimitive_object) |
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_DtNwidthInc_arg */
static unsigned char arg_class_vec131[] =
  {
  _BIT_MASK(sym_k_DtTerm_object) |
  0, _BIT_MASK(sym_k_DtTermPrimitive_object) |
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_DtNwordWrap_arg */
static unsigned char arg_class_vec132[] =
  {
  _BIT_MASK(sym_k_DtEditor_object) |
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_DtNworkAreaLocation_arg */
static unsigned char arg_class_vec133[] =
  {
  _BIT_MASK(sym_k_DtPrintSetupBox_object) |
  _BIT_MASK(sym_k_DtPrintSetupDialog_object) |
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_XmN100DPIstring_arg */
static unsigned char arg_class_vec134[] =
  {
  0, 0, 0, _BIT_MASK(sym_k_XmFontSelector_object) |
  0, 0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_XmN75DPIstring_arg */
static unsigned char arg_class_vec135[] =
  {
  0, 0, 0, _BIT_MASK(sym_k_XmFontSelector_object) |
  0, 0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_XmNaccelerator_arg */
static unsigned char arg_class_vec136[] =
  {
  _BIT_MASK(sym_k_DtMenuButton_object) |
  0, 0, 0, _BIT_MASK(sym_k_XmDrawnButton_object) |
  0, _BIT_MASK(sym_k_XmLabel_object) |
  0, _BIT_MASK(sym_k_XmLabelGadget_object) |
  0, 0, _BIT_MASK(sym_k_XmPushButton_object) |
  _BIT_MASK(sym_k_XmPushButtonGadget_object) |
  0, 0, _BIT_MASK(sym_k_XmTearOffButton_object) |
  0, _BIT_MASK(sym_k_XmToggleButton_object) |
  _BIT_MASK(sym_k_XmToggleButtonGadget_object) |
  0, 0};

/* sym_k_XmNacceleratorText_arg */
static unsigned char arg_class_vec137[] =
  {
  _BIT_MASK(sym_k_DtMenuButton_object) |
  0, 0, 0, _BIT_MASK(sym_k_XmDrawnButton_object) |
  0, _BIT_MASK(sym_k_XmLabel_object) |
  0, _BIT_MASK(sym_k_XmLabelGadget_object) |
  0, 0, _BIT_MASK(sym_k_XmPushButton_object) |
  _BIT_MASK(sym_k_XmPushButtonGadget_object) |
  0, 0, _BIT_MASK(sym_k_XmTearOffButton_object) |
  0, _BIT_MASK(sym_k_XmToggleButton_object) |
  _BIT_MASK(sym_k_XmToggleButtonGadget_object) |
  0, 0};

/* sym_k_XmNaccelerators_arg */
static unsigned char arg_class_vec138[] =
  {
  _BIT_MASK(sym_k_DtEditor_object) |
  _BIT_MASK(sym_k_DtHelpDialog_object) |
  _BIT_MASK(sym_k_DtHelpQuickDialog_object) |
  _BIT_MASK(sym_k_DtMenuButton_object) |
  _BIT_MASK(sym_k_DtPrintSetupBox_object) |
  _BIT_MASK(sym_k_DtPrintSetupDialog_object) |
  _BIT_MASK(sym_k_DtTerm_object) |
  0, _BIT_MASK(sym_k_DtTermPrimitive_object) |
  _BIT_MASK(sym_k_XmArrowButton_object) |
  _BIT_MASK(sym_k_XmBulletinBoard_object) |
  _BIT_MASK(sym_k_XmBulletinBoardDialog_object) |
  _BIT_MASK(sym_k_XmButtonBox_object) |
  _BIT_MASK(sym_k_XmCascadeButton_object) |
  0, _BIT_MASK(sym_k_XmCheckBox_object) |
  _BIT_MASK(sym_k_XmColorSelector_object) |
  _BIT_MASK(sym_k_XmColumn_object) |
  _BIT_MASK(sym_k_XmComboBox_object) |
  _BIT_MASK(sym_k_XmCommand_object) |
  _BIT_MASK(sym_k_XmCommandDialog_object) |
  _BIT_MASK(sym_k_XmContainer_object) |
  _BIT_MASK(sym_k_XmDataField_object) |
  0, _BIT_MASK(sym_k_XmDialogShell_object) |
  _BIT_MASK(sym_k_XmDrawingArea_object) |
  _BIT_MASK(sym_k_XmDrawnButton_object) |
  _BIT_MASK(sym_k_XmDropDown_object) |
  _BIT_MASK(sym_k_XmErrorDialog_object) |
  _BIT_MASK(sym_k_XmFileSelectionBox_object) |
  _BIT_MASK(sym_k_XmFileSelectionDialog_object) |
  _BIT_MASK(sym_k_XmFontSelector_object) |
  0, _BIT_MASK(sym_k_XmForm_object) |
  _BIT_MASK(sym_k_XmFormDialog_object) |
  _BIT_MASK(sym_k_XmFrame_object) |
  _BIT_MASK(sym_k_XmIconBox_object) |
  _BIT_MASK(sym_k_XmIconButton_object) |
  _BIT_MASK(sym_k_XmInformationDialog_object) |
  _BIT_MASK(sym_k_XmLabel_object) |
  0, _BIT_MASK(sym_k_XmList_object) |
  _BIT_MASK(sym_k_XmMainWindow_object) |
  _BIT_MASK(sym_k_XmMenuBar_object) |
  _BIT_MASK(sym_k_XmMenuShell_object) |
  _BIT_MASK(sym_k_XmMessageBox_object) |
  _BIT_MASK(sym_k_XmMessageDialog_object) |
  _BIT_MASK(sym_k_XmMultiList_object) |
  0, _BIT_MASK(sym_k_XmNotebook_object) |
  _BIT_MASK(sym_k_XmOptionMenu_object) |
  _BIT_MASK(sym_k_XmOutline_object) |
  _BIT_MASK(sym_k_XmPaned_object) |
  _BIT_MASK(sym_k_XmPanedWindow_object) |
  _BIT_MASK(sym_k_XmPopupMenu_object) |
  _BIT_MASK(sym_k_XmPromptDialog_object) |
  _BIT_MASK(sym_k_XmPulldownMenu_object) |
  0, _BIT_MASK(sym_k_XmPushButton_object) |
  _BIT_MASK(sym_k_XmQuestionDialog_object) |
  _BIT_MASK(sym_k_XmRadioBox_object) |
  _BIT_MASK(sym_k_XmRowColumn_object) |
  _BIT_MASK(sym_k_XmScale_object) |
  0, _BIT_MASK(sym_k_XmScrollBar_object) |
  _BIT_MASK(sym_k_XmScrolledList_object) |
  _BIT_MASK(sym_k_XmScrolledText_object) |
  _BIT_MASK(sym_k_XmScrolledWindow_object) |
  _BIT_MASK(sym_k_XmSelectionBox_object) |
  _BIT_MASK(sym_k_XmSelectionDialog_object) |
  _BIT_MASK(sym_k_XmSeparator_object) |
  0, _BIT_MASK(sym_k_XmSimpleSpinBox_object) |
  _BIT_MASK(sym_k_XmSpinBox_object) |
  _BIT_MASK(sym_k_XmTabBox_object) |
  _BIT_MASK(sym_k_XmTabStack_object) |
  _BIT_MASK(sym_k_XmTearOffButton_object) |
  _BIT_MASK(sym_k_XmTemplateDialog_object) |
  0, _BIT_MASK(sym_k_XmText_object) |
  _BIT_MASK(sym_k_XmTextField_object) |
  _BIT_MASK(sym_k_XmToggleButton_object) |
  _BIT_MASK(sym_k_XmTree_object) |
  _BIT_MASK(sym_k_XmWarningDialog_object) |
  _BIT_MASK(sym_k_XmWorkArea_object) |
  _BIT_MASK(sym_k_XmWorkingDialog_object) |
  0, 0};

/* sym_k_XmNadjustLast_arg */
static unsigned char arg_class_vec139[] =
  {
  0, 0, _BIT_MASK(sym_k_XmCheckBox_object) |
  0, 0, 0, _BIT_MASK(sym_k_XmMenuBar_object) |
  0, _BIT_MASK(sym_k_XmOptionMenu_object) |
  _BIT_MASK(sym_k_XmPopupMenu_object) |
  _BIT_MASK(sym_k_XmPulldownMenu_object) |
  0, _BIT_MASK(sym_k_XmRadioBox_object) |
  _BIT_MASK(sym_k_XmRowColumn_object) |
  0, 0, 0, _BIT_MASK(sym_k_XmWorkArea_object) |
  0, 0};

/* sym_k_XmNadjustMargin_arg */
static unsigned char arg_class_vec140[] =
  {
  0, 0, _BIT_MASK(sym_k_XmCheckBox_object) |
  0, 0, 0, _BIT_MASK(sym_k_XmMenuBar_object) |
  0, _BIT_MASK(sym_k_XmOptionMenu_object) |
  _BIT_MASK(sym_k_XmPopupMenu_object) |
  _BIT_MASK(sym_k_XmPulldownMenu_object) |
  0, _BIT_MASK(sym_k_XmRadioBox_object) |
  _BIT_MASK(sym_k_XmRowColumn_object) |
  0, 0, 0, _BIT_MASK(sym_k_XmWorkArea_object) |
  0, 0};

/* sym_k_XmNalignment_arg */
static unsigned char arg_class_vec141[] =
  {
  _BIT_MASK(sym_k_DtMenuButton_object) |
  0, _BIT_MASK(sym_k_XmCascadeButton_object) |
  _BIT_MASK(sym_k_XmCascadeButtonGadget_object) |
  0, _BIT_MASK(sym_k_XmDataField_object) |
  0, _BIT_MASK(sym_k_XmDrawnButton_object) |
  0, _BIT_MASK(sym_k_XmIconButton_object) |
  _BIT_MASK(sym_k_XmIconGadget_object) |
  _BIT_MASK(sym_k_XmLabel_object) |
  0, _BIT_MASK(sym_k_XmLabelGadget_object) |
  _BIT_MASK(sym_k_XmMultiList_object) |
  0, 0, _BIT_MASK(sym_k_XmPushButton_object) |
  _BIT_MASK(sym_k_XmPushButtonGadget_object) |
  0, 0, _BIT_MASK(sym_k_XmTab_object) |
  _BIT_MASK(sym_k_XmTearOffButton_object) |
  0, _BIT_MASK(sym_k_XmToggleButton_object) |
  _BIT_MASK(sym_k_XmToggleButtonGadget_object) |
  0, 0};

/* sym_k_XmNallowOverlap_arg */
static unsigned char arg_class_vec142[] =
  {
  _BIT_MASK(sym_k_DtEditor_object) |
  _BIT_MASK(sym_k_DtHelpDialog_object) |
  _BIT_MASK(sym_k_DtHelpQuickDialog_object) |
  _BIT_MASK(sym_k_DtPrintSetupBox_object) |
  _BIT_MASK(sym_k_DtPrintSetupDialog_object) |
  0, _BIT_MASK(sym_k_XmBulletinBoard_object) |
  _BIT_MASK(sym_k_XmBulletinBoardDialog_object) |
  0, _BIT_MASK(sym_k_XmColumn_object) |
  0, _BIT_MASK(sym_k_XmErrorDialog_object) |
  _BIT_MASK(sym_k_XmFileSelectionBox_object) |
  _BIT_MASK(sym_k_XmFileSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmForm_object) |
  _BIT_MASK(sym_k_XmFormDialog_object) |
  _BIT_MASK(sym_k_XmInformationDialog_object) |
  0, _BIT_MASK(sym_k_XmMessageBox_object) |
  _BIT_MASK(sym_k_XmMessageDialog_object) |
  0, _BIT_MASK(sym_k_XmPromptDialog_object) |
  0, _BIT_MASK(sym_k_XmQuestionDialog_object) |
  0, _BIT_MASK(sym_k_XmSelectionBox_object) |
  _BIT_MASK(sym_k_XmSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmTabStack_object) |
  _BIT_MASK(sym_k_XmTemplateDialog_object) |
  0, _BIT_MASK(sym_k_XmWarningDialog_object) |
  _BIT_MASK(sym_k_XmWorkingDialog_object) |
  0, 0};

/* sym_k_XmNallowResize_arg */
static unsigned char arg_class_vec143[] =
  {
  0, 0, 0, _BIT_MASK(sym_k_XmFontSelector_object) |
  0, 0, 0, _BIT_MASK(sym_k_XmPaned_object) |
  _BIT_MASK(sym_k_XmPanedWindow_object) |
  0, 0, 0, 0, 0, 0};

/* sym_k_XmNallowShellResize_arg */
static unsigned char arg_class_vec144[] =
  {
  _BIT_MASK(sym_k_DtHelpDialog_object) |
  _BIT_MASK(sym_k_DtHelpQuickDialog_object) |
  _BIT_MASK(sym_k_DtPrintSetupDialog_object) |
  0, _BIT_MASK(sym_k_XmBulletinBoardDialog_object) |
  0, _BIT_MASK(sym_k_XmCommandDialog_object) |
  0, _BIT_MASK(sym_k_XmDialogShell_object) |
  _BIT_MASK(sym_k_XmErrorDialog_object) |
  _BIT_MASK(sym_k_XmFileSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmFormDialog_object) |
  _BIT_MASK(sym_k_XmInformationDialog_object) |
  0, _BIT_MASK(sym_k_XmMenuShell_object) |
  _BIT_MASK(sym_k_XmMessageDialog_object) |
  0, _BIT_MASK(sym_k_XmPopupMenu_object) |
  _BIT_MASK(sym_k_XmPromptDialog_object) |
  _BIT_MASK(sym_k_XmPulldownMenu_object) |
  0, _BIT_MASK(sym_k_XmQuestionDialog_object) |
  0, _BIT_MASK(sym_k_XmSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmTemplateDialog_object) |
  0, _BIT_MASK(sym_k_XmWarningDialog_object) |
  _BIT_MASK(sym_k_XmWorkingDialog_object) |
  0, 0};

/* sym_k_XmNallowUnusedSpace_arg */
static unsigned char arg_class_vec145[] =
  {
  0, 0, 0, _BIT_MASK(sym_k_XmFontSelector_object) |
  0, 0, 0, _BIT_MASK(sym_k_XmPaned_object) |
  0, 0, 0, 0, 0, 0};

/* sym_k_XmNancestorSensitive_arg */
static unsigned char arg_class_vec146[] =
  {
  _BIT_MASK(sym_k_DtEditor_object) |
  _BIT_MASK(sym_k_DtHelpDialog_object) |
  _BIT_MASK(sym_k_DtHelpQuickDialog_object) |
  _BIT_MASK(sym_k_DtMenuButton_object) |
  _BIT_MASK(sym_k_DtPrintSetupBox_object) |
  _BIT_MASK(sym_k_DtPrintSetupDialog_object) |
  _BIT_MASK(sym_k_DtTerm_object) |
  0, _BIT_MASK(sym_k_DtTermPrimitive_object) |
  _BIT_MASK(sym_k_XmArrowButton_object) |
  _BIT_MASK(sym_k_XmArrowButtonGadget_object) |
  _BIT_MASK(sym_k_XmBulletinBoard_object) |
  _BIT_MASK(sym_k_XmBulletinBoardDialog_object) |
  _BIT_MASK(sym_k_XmButtonBox_object) |
  _BIT_MASK(sym_k_XmCascadeButton_object) |
  _BIT_MASK(sym_k_XmCascadeButtonGadget_object) |
  0, _BIT_MASK(sym_k_XmCheckBox_object) |
  _BIT_MASK(sym_k_XmColorSelector_object) |
  _BIT_MASK(sym_k_XmColumn_object) |
  _BIT_MASK(sym_k_XmComboBox_object) |
  _BIT_MASK(sym_k_XmCommand_object) |
  _BIT_MASK(sym_k_XmCommandDialog_object) |
  _BIT_MASK(sym_k_XmContainer_object) |
  _BIT_MASK(sym_k_XmDataField_object) |
  0, _BIT_MASK(sym_k_XmDialogShell_object) |
  _BIT_MASK(sym_k_XmDrawingArea_object) |
  _BIT_MASK(sym_k_XmDrawnButton_object) |
  _BIT_MASK(sym_k_XmDropDown_object) |
  _BIT_MASK(sym_k_XmErrorDialog_object) |
  _BIT_MASK(sym_k_XmFileSelectionBox_object) |
  _BIT_MASK(sym_k_XmFileSelectionDialog_object) |
  _BIT_MASK(sym_k_XmFontSelector_object) |
  0, _BIT_MASK(sym_k_XmForm_object) |
  _BIT_MASK(sym_k_XmFormDialog_object) |
  _BIT_MASK(sym_k_XmFrame_object) |
  _BIT_MASK(sym_k_XmIconBox_object) |
  _BIT_MASK(sym_k_XmIconButton_object) |
  _BIT_MASK(sym_k_XmIconGadget_object) |
  _BIT_MASK(sym_k_XmInformationDialog_object) |
  _BIT_MASK(sym_k_XmLabel_object) |
  0, _BIT_MASK(sym_k_XmLabelGadget_object) |
  _BIT_MASK(sym_k_XmList_object) |
  _BIT_MASK(sym_k_XmMainWindow_object) |
  _BIT_MASK(sym_k_XmMenuBar_object) |
  _BIT_MASK(sym_k_XmMenuShell_object) |
  _BIT_MASK(sym_k_XmMessageBox_object) |
  _BIT_MASK(sym_k_XmMessageDialog_object) |
  _BIT_MASK(sym_k_XmMultiList_object) |
  0, _BIT_MASK(sym_k_XmNotebook_object) |
  _BIT_MASK(sym_k_XmOptionMenu_object) |
  _BIT_MASK(sym_k_XmOutline_object) |
  _BIT_MASK(sym_k_XmPaned_object) |
  _BIT_MASK(sym_k_XmPanedWindow_object) |
  _BIT_MASK(sym_k_XmPopupMenu_object) |
  _BIT_MASK(sym_k_XmPromptDialog_object) |
  _BIT_MASK(sym_k_XmPulldownMenu_object) |
  0, _BIT_MASK(sym_k_XmPushButton_object) |
  _BIT_MASK(sym_k_XmPushButtonGadget_object) |
  _BIT_MASK(sym_k_XmQuestionDialog_object) |
  _BIT_MASK(sym_k_XmRadioBox_object) |
  _BIT_MASK(sym_k_XmRowColumn_object) |
  _BIT_MASK(sym_k_XmScale_object) |
  0, _BIT_MASK(sym_k_XmScrollBar_object) |
  _BIT_MASK(sym_k_XmScrolledList_object) |
  _BIT_MASK(sym_k_XmScrolledText_object) |
  _BIT_MASK(sym_k_XmScrolledWindow_object) |
  _BIT_MASK(sym_k_XmSelectionBox_object) |
  _BIT_MASK(sym_k_XmSelectionDialog_object) |
  _BIT_MASK(sym_k_XmSeparator_object) |
  _BIT_MASK(sym_k_XmSeparatorGadget_object) |
  0, _BIT_MASK(sym_k_XmSimpleSpinBox_object) |
  _BIT_MASK(sym_k_XmSpinBox_object) |
  _BIT_MASK(sym_k_XmTabBox_object) |
  _BIT_MASK(sym_k_XmTabStack_object) |
  _BIT_MASK(sym_k_XmTearOffButton_object) |
  _BIT_MASK(sym_k_XmTemplateDialog_object) |
  0, _BIT_MASK(sym_k_XmText_object) |
  _BIT_MASK(sym_k_XmTextField_object) |
  _BIT_MASK(sym_k_XmToggleButton_object) |
  _BIT_MASK(sym_k_XmToggleButtonGadget_object) |
  _BIT_MASK(sym_k_XmTree_object) |
  _BIT_MASK(sym_k_XmWarningDialog_object) |
  _BIT_MASK(sym_k_XmWorkArea_object) |
  _BIT_MASK(sym_k_XmWorkingDialog_object) |
  0, 0};

/* sym_k_XmNanyLowerString_arg */
static unsigned char arg_class_vec147[] =
  {
  0, 0, 0, _BIT_MASK(sym_k_XmFontSelector_object) |
  0, 0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_XmNanyString_arg */
static unsigned char arg_class_vec148[] =
  {
  0, 0, 0, _BIT_MASK(sym_k_XmFontSelector_object) |
  0, 0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_XmNapplyLabelString_arg */
static unsigned char arg_class_vec149[] =
  {
  0, 0, 0, _BIT_MASK(sym_k_XmFileSelectionBox_object) |
  _BIT_MASK(sym_k_XmFileSelectionDialog_object) |
  0, 0, 0, _BIT_MASK(sym_k_XmPromptDialog_object) |
  0, 0, _BIT_MASK(sym_k_XmSelectionBox_object) |
  _BIT_MASK(sym_k_XmSelectionDialog_object) |
  0, 0, 0, 0};

/* sym_k_XmNarmColor_arg */
static unsigned char arg_class_vec150[] =
  {
  0, 0, 0, 0, _BIT_MASK(sym_k_XmIconButton_object) |
  0, 0, 0, _BIT_MASK(sym_k_XmPushButton_object) |
  _BIT_MASK(sym_k_XmPushButtonGadget_object) |
  0, 0, _BIT_MASK(sym_k_XmTearOffButton_object) |
  0, 0, 0};

/* sym_k_XmNarmPixmap_arg */
static unsigned char arg_class_vec151[] =
  {
  0, 0, 0, 0, 0, 0, 0, _BIT_MASK(sym_k_XmPushButton_object) |
  _BIT_MASK(sym_k_XmPushButtonGadget_object) |
  0, 0, _BIT_MASK(sym_k_XmTearOffButton_object) |
  0, 0, 0};

/* sym_k_XmNarrowDirection_arg */
static unsigned char arg_class_vec152[] =
  {
  0, _BIT_MASK(sym_k_XmArrowButton_object) |
  _BIT_MASK(sym_k_XmArrowButtonGadget_object) |
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_XmNarrowLayout_arg */
static unsigned char arg_class_vec153[] =
  {
  0, 0, 0, 0, 0, 0, 0, 0, 0, _BIT_MASK(sym_k_XmSimpleSpinBox_object) |
  _BIT_MASK(sym_k_XmSpinBox_object) |
  0, 0, 0};

/* sym_k_XmNarrowOrientation_arg */
static unsigned char arg_class_vec154[] =
  {
  0, 0, 0, 0, 0, 0, 0, 0, 0, _BIT_MASK(sym_k_XmSimpleSpinBox_object) |
  _BIT_MASK(sym_k_XmSpinBox_object) |
  0, 0, 0};

/* sym_k_XmNarrowSensitivity_arg */
static unsigned char arg_class_vec155[] =
  {
  0, 0, 0, 0, 0, 0, 0, 0, 0, _BIT_MASK(sym_k_XmSimpleSpinBox_object) |
  _BIT_MASK(sym_k_XmSpinBox_object) |
  0, 0, 0};

/* sym_k_XmNarrowSize_arg */
static unsigned char arg_class_vec156[] =
  {
  0, 0, _BIT_MASK(sym_k_XmComboBox_object) |
  0, 0, 0, 0, 0, 0, 0, _BIT_MASK(sym_k_XmSimpleSpinBox_object) |
  _BIT_MASK(sym_k_XmSpinBox_object) |
  0, 0, 0};

/* sym_k_XmNarrowSpacing_arg */
static unsigned char arg_class_vec157[] =
  {
  0, 0, _BIT_MASK(sym_k_XmComboBox_object) |
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_XmNaudibleWarning_arg */
static unsigned char arg_class_vec158[] =
  {
  _BIT_MASK(sym_k_DtHelpDialog_object) |
  _BIT_MASK(sym_k_DtHelpQuickDialog_object) |
  _BIT_MASK(sym_k_DtPrintSetupDialog_object) |
  0, _BIT_MASK(sym_k_XmBulletinBoardDialog_object) |
  0, _BIT_MASK(sym_k_XmCommandDialog_object) |
  0, _BIT_MASK(sym_k_XmDialogShell_object) |
  _BIT_MASK(sym_k_XmErrorDialog_object) |
  _BIT_MASK(sym_k_XmFileSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmFormDialog_object) |
  _BIT_MASK(sym_k_XmInformationDialog_object) |
  0, _BIT_MASK(sym_k_XmMessageDialog_object) |
  0, _BIT_MASK(sym_k_XmPromptDialog_object) |
  0, _BIT_MASK(sym_k_XmQuestionDialog_object) |
  0, _BIT_MASK(sym_k_XmSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmTemplateDialog_object) |
  0, _BIT_MASK(sym_k_XmWarningDialog_object) |
  _BIT_MASK(sym_k_XmWorkingDialog_object) |
  0, 0};

/* sym_k_XmNautoClose_arg */
static unsigned char arg_class_vec159[] =
  {
  0, 0, 0, 0, 0, 0, _BIT_MASK(sym_k_XmOutline_object) |
  0, 0, 0, 0, _BIT_MASK(sym_k_XmTree_object) |
  0, 0};

/* sym_k_XmNautoDragModel_arg */
static unsigned char arg_class_vec160[] =
  {
  0, 0, 0, 0, 0, _BIT_MASK(sym_k_XmMainWindow_object) |
  0, 0, 0, _BIT_MASK(sym_k_XmScrolledList_object) |
  _BIT_MASK(sym_k_XmScrolledText_object) |
  _BIT_MASK(sym_k_XmScrolledWindow_object) |
  0, 0, 0, 0};

/* sym_k_XmNautoFill_arg */
static unsigned char arg_class_vec161[] =
  {
  0, 0, _BIT_MASK(sym_k_XmDataField_object) |
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_XmNautoShowCursorPosition_arg */
static unsigned char arg_class_vec162[] =
  {
  0, 0, 0, 0, 0, 0, 0, 0, _BIT_MASK(sym_k_XmScrolledText_object) |
  0, 0, _BIT_MASK(sym_k_XmText_object) |
  0, 0};

/* sym_k_XmNautoUnmanage_arg */
static unsigned char arg_class_vec163[] =
  {
  _BIT_MASK(sym_k_DtEditor_object) |
  _BIT_MASK(sym_k_DtHelpDialog_object) |
  _BIT_MASK(sym_k_DtHelpQuickDialog_object) |
  _BIT_MASK(sym_k_DtPrintSetupBox_object) |
  _BIT_MASK(sym_k_DtPrintSetupDialog_object) |
  0, _BIT_MASK(sym_k_XmBulletinBoard_object) |
  _BIT_MASK(sym_k_XmBulletinBoardDialog_object) |
  0, _BIT_MASK(sym_k_XmColumn_object) |
  0, _BIT_MASK(sym_k_XmErrorDialog_object) |
  _BIT_MASK(sym_k_XmFileSelectionBox_object) |
  _BIT_MASK(sym_k_XmFileSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmForm_object) |
  _BIT_MASK(sym_k_XmFormDialog_object) |
  _BIT_MASK(sym_k_XmInformationDialog_object) |
  0, _BIT_MASK(sym_k_XmMessageBox_object) |
  _BIT_MASK(sym_k_XmMessageDialog_object) |
  0, _BIT_MASK(sym_k_XmPromptDialog_object) |
  0, _BIT_MASK(sym_k_XmQuestionDialog_object) |
  0, _BIT_MASK(sym_k_XmSelectionBox_object) |
  _BIT_MASK(sym_k_XmSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmTabStack_object) |
  _BIT_MASK(sym_k_XmTemplateDialog_object) |
  0, _BIT_MASK(sym_k_XmWarningDialog_object) |
  _BIT_MASK(sym_k_XmWorkingDialog_object) |
  0, 0};

/* sym_k_XmNautomaticSelection_arg */
static unsigned char arg_class_vec164[] =
  {
  0, 0, _BIT_MASK(sym_k_XmContainer_object) |
  0, 0, 0, _BIT_MASK(sym_k_XmList_object) |
  0, 0, 0, _BIT_MASK(sym_k_XmScrolledList_object) |
  0, 0, 0, 0};

/* sym_k_XmNbackPageBackground_arg */
static unsigned char arg_class_vec165[] =
  {
  0, 0, 0, 0, 0, 0, _BIT_MASK(sym_k_XmNotebook_object) |
  0, 0, 0, 0, 0, 0};

/* sym_k_XmNbackPageForeground_arg */
static unsigned char arg_class_vec166[] =
  {
  0, 0, 0, 0, 0, 0, _BIT_MASK(sym_k_XmNotebook_object) |
  0, 0, 0, 0, 0, 0};

/* sym_k_XmNbackPageNumber_arg */
static unsigned char arg_class_vec167[] =
  {
  0, 0, 0, 0, 0, 0, _BIT_MASK(sym_k_XmNotebook_object) |
  0, 0, 0, 0, 0, 0};

/* sym_k_XmNbackPagePlacement_arg */
static unsigned char arg_class_vec168[] =
  {
  0, 0, 0, 0, 0, 0, _BIT_MASK(sym_k_XmNotebook_object) |
  0, 0, 0, 0, 0, 0};

/* sym_k_XmNbackPageSize_arg */
static unsigned char arg_class_vec169[] =
  {
  0, 0, 0, 0, 0, 0, _BIT_MASK(sym_k_XmNotebook_object) |
  0, 0, 0, 0, 0, 0};

/* sym_k_XmNbackground_arg */
static unsigned char arg_class_vec170[] =
  {
  _BIT_MASK(sym_k_DtEditor_object) |
  _BIT_MASK(sym_k_DtHelpDialog_object) |
  _BIT_MASK(sym_k_DtHelpQuickDialog_object) |
  _BIT_MASK(sym_k_DtMenuButton_object) |
  _BIT_MASK(sym_k_DtPrintSetupBox_object) |
  _BIT_MASK(sym_k_DtPrintSetupDialog_object) |
  _BIT_MASK(sym_k_DtTerm_object) |
  0, _BIT_MASK(sym_k_DtTermPrimitive_object) |
  _BIT_MASK(sym_k_XmArrowButton_object) |
  _BIT_MASK(sym_k_XmArrowButtonGadget_object) |
  _BIT_MASK(sym_k_XmBulletinBoard_object) |
  _BIT_MASK(sym_k_XmBulletinBoardDialog_object) |
  _BIT_MASK(sym_k_XmButtonBox_object) |
  _BIT_MASK(sym_k_XmCascadeButton_object) |
  _BIT_MASK(sym_k_XmCascadeButtonGadget_object) |
  0, _BIT_MASK(sym_k_XmCheckBox_object) |
  _BIT_MASK(sym_k_XmColorSelector_object) |
  _BIT_MASK(sym_k_XmColumn_object) |
  _BIT_MASK(sym_k_XmComboBox_object) |
  _BIT_MASK(sym_k_XmCommand_object) |
  _BIT_MASK(sym_k_XmCommandDialog_object) |
  _BIT_MASK(sym_k_XmContainer_object) |
  _BIT_MASK(sym_k_XmDataField_object) |
  0, _BIT_MASK(sym_k_XmDialogShell_object) |
  _BIT_MASK(sym_k_XmDrawingArea_object) |
  _BIT_MASK(sym_k_XmDrawnButton_object) |
  _BIT_MASK(sym_k_XmDropDown_object) |
  _BIT_MASK(sym_k_XmErrorDialog_object) |
  _BIT_MASK(sym_k_XmFileSelectionBox_object) |
  _BIT_MASK(sym_k_XmFileSelectionDialog_object) |
  _BIT_MASK(sym_k_XmFontSelector_object) |
  0, _BIT_MASK(sym_k_XmForm_object) |
  _BIT_MASK(sym_k_XmFormDialog_object) |
  _BIT_MASK(sym_k_XmFrame_object) |
  _BIT_MASK(sym_k_XmIconBox_object) |
  _BIT_MASK(sym_k_XmIconButton_object) |
  _BIT_MASK(sym_k_XmIconGadget_object) |
  _BIT_MASK(sym_k_XmInformationDialog_object) |
  _BIT_MASK(sym_k_XmLabel_object) |
  0, _BIT_MASK(sym_k_XmLabelGadget_object) |
  _BIT_MASK(sym_k_XmList_object) |
  _BIT_MASK(sym_k_XmMainWindow_object) |
  _BIT_MASK(sym_k_XmMenuBar_object) |
  _BIT_MASK(sym_k_XmMenuShell_object) |
  _BIT_MASK(sym_k_XmMessageBox_object) |
  _BIT_MASK(sym_k_XmMessageDialog_object) |
  _BIT_MASK(sym_k_XmMultiList_object) |
  0, _BIT_MASK(sym_k_XmNotebook_object) |
  _BIT_MASK(sym_k_XmOptionMenu_object) |
  _BIT_MASK(sym_k_XmOutline_object) |
  _BIT_MASK(sym_k_XmPaned_object) |
  _BIT_MASK(sym_k_XmPanedWindow_object) |
  _BIT_MASK(sym_k_XmPopupMenu_object) |
  _BIT_MASK(sym_k_XmPromptDialog_object) |
  _BIT_MASK(sym_k_XmPulldownMenu_object) |
  0, _BIT_MASK(sym_k_XmPushButton_object) |
  _BIT_MASK(sym_k_XmPushButtonGadget_object) |
  _BIT_MASK(sym_k_XmQuestionDialog_object) |
  _BIT_MASK(sym_k_XmRadioBox_object) |
  _BIT_MASK(sym_k_XmRowColumn_object) |
  _BIT_MASK(sym_k_XmScale_object) |
  0, _BIT_MASK(sym_k_XmScrollBar_object) |
  _BIT_MASK(sym_k_XmScrolledList_object) |
  _BIT_MASK(sym_k_XmScrolledText_object) |
  _BIT_MASK(sym_k_XmScrolledWindow_object) |
  _BIT_MASK(sym_k_XmSelectionBox_object) |
  _BIT_MASK(sym_k_XmSelectionDialog_object) |
  _BIT_MASK(sym_k_XmSeparator_object) |
  _BIT_MASK(sym_k_XmSeparatorGadget_object) |
  0, _BIT_MASK(sym_k_XmSimpleSpinBox_object) |
  _BIT_MASK(sym_k_XmSpinBox_object) |
  _BIT_MASK(sym_k_XmTabBox_object) |
  _BIT_MASK(sym_k_XmTabStack_object) |
  _BIT_MASK(sym_k_XmTearOffButton_object) |
  _BIT_MASK(sym_k_XmTemplateDialog_object) |
  0, _BIT_MASK(sym_k_XmText_object) |
  _BIT_MASK(sym_k_XmTextField_object) |
  _BIT_MASK(sym_k_XmToggleButton_object) |
  _BIT_MASK(sym_k_XmToggleButtonGadget_object) |
  _BIT_MASK(sym_k_XmTree_object) |
  _BIT_MASK(sym_k_XmWarningDialog_object) |
  _BIT_MASK(sym_k_XmWorkArea_object) |
  _BIT_MASK(sym_k_XmWorkingDialog_object) |
  0, 0};

/* sym_k_XmNbackgroundPixmap_arg */
static unsigned char arg_class_vec171[] =
  {
  _BIT_MASK(sym_k_DtEditor_object) |
  _BIT_MASK(sym_k_DtHelpDialog_object) |
  _BIT_MASK(sym_k_DtHelpQuickDialog_object) |
  _BIT_MASK(sym_k_DtMenuButton_object) |
  _BIT_MASK(sym_k_DtPrintSetupBox_object) |
  _BIT_MASK(sym_k_DtPrintSetupDialog_object) |
  _BIT_MASK(sym_k_DtTerm_object) |
  0, _BIT_MASK(sym_k_DtTermPrimitive_object) |
  _BIT_MASK(sym_k_XmArrowButton_object) |
  _BIT_MASK(sym_k_XmBulletinBoard_object) |
  _BIT_MASK(sym_k_XmBulletinBoardDialog_object) |
  _BIT_MASK(sym_k_XmButtonBox_object) |
  _BIT_MASK(sym_k_XmCascadeButton_object) |
  0, _BIT_MASK(sym_k_XmCheckBox_object) |
  _BIT_MASK(sym_k_XmColorSelector_object) |
  _BIT_MASK(sym_k_XmColumn_object) |
  _BIT_MASK(sym_k_XmComboBox_object) |
  _BIT_MASK(sym_k_XmCommand_object) |
  _BIT_MASK(sym_k_XmCommandDialog_object) |
  _BIT_MASK(sym_k_XmContainer_object) |
  _BIT_MASK(sym_k_XmDataField_object) |
  0, _BIT_MASK(sym_k_XmDialogShell_object) |
  _BIT_MASK(sym_k_XmDrawingArea_object) |
  _BIT_MASK(sym_k_XmDrawnButton_object) |
  _BIT_MASK(sym_k_XmDropDown_object) |
  _BIT_MASK(sym_k_XmErrorDialog_object) |
  _BIT_MASK(sym_k_XmFileSelectionBox_object) |
  _BIT_MASK(sym_k_XmFileSelectionDialog_object) |
  _BIT_MASK(sym_k_XmFontSelector_object) |
  0, _BIT_MASK(sym_k_XmForm_object) |
  _BIT_MASK(sym_k_XmFormDialog_object) |
  _BIT_MASK(sym_k_XmFrame_object) |
  _BIT_MASK(sym_k_XmIconBox_object) |
  _BIT_MASK(sym_k_XmIconButton_object) |
  _BIT_MASK(sym_k_XmInformationDialog_object) |
  _BIT_MASK(sym_k_XmLabel_object) |
  0, _BIT_MASK(sym_k_XmList_object) |
  _BIT_MASK(sym_k_XmMainWindow_object) |
  _BIT_MASK(sym_k_XmMenuBar_object) |
  _BIT_MASK(sym_k_XmMenuShell_object) |
  _BIT_MASK(sym_k_XmMessageBox_object) |
  _BIT_MASK(sym_k_XmMessageDialog_object) |
  _BIT_MASK(sym_k_XmMultiList_object) |
  0, _BIT_MASK(sym_k_XmNotebook_object) |
  _BIT_MASK(sym_k_XmOptionMenu_object) |
  _BIT_MASK(sym_k_XmOutline_object) |
  _BIT_MASK(sym_k_XmPaned_object) |
  _BIT_MASK(sym_k_XmPanedWindow_object) |
  _BIT_MASK(sym_k_XmPopupMenu_object) |
  _BIT_MASK(sym_k_XmPromptDialog_object) |
  _BIT_MASK(sym_k_XmPulldownMenu_object) |
  0, _BIT_MASK(sym_k_XmPushButton_object) |
  _BIT_MASK(sym_k_XmQuestionDialog_object) |
  _BIT_MASK(sym_k_XmRadioBox_object) |
  _BIT_MASK(sym_k_XmRowColumn_object) |
  _BIT_MASK(sym_k_XmScale_object) |
  0, _BIT_MASK(sym_k_XmScrollBar_object) |
  _BIT_MASK(sym_k_XmScrolledList_object) |
  _BIT_MASK(sym_k_XmScrolledText_object) |
  _BIT_MASK(sym_k_XmScrolledWindow_object) |
  _BIT_MASK(sym_k_XmSelectionBox_object) |
  _BIT_MASK(sym_k_XmSelectionDialog_object) |
  _BIT_MASK(sym_k_XmSeparator_object) |
  0, _BIT_MASK(sym_k_XmSimpleSpinBox_object) |
  _BIT_MASK(sym_k_XmSpinBox_object) |
  _BIT_MASK(sym_k_XmTabBox_object) |
  _BIT_MASK(sym_k_XmTabStack_object) |
  _BIT_MASK(sym_k_XmTearOffButton_object) |
  _BIT_MASK(sym_k_XmTemplateDialog_object) |
  0, _BIT_MASK(sym_k_XmText_object) |
  _BIT_MASK(sym_k_XmTextField_object) |
  _BIT_MASK(sym_k_XmToggleButton_object) |
  _BIT_MASK(sym_k_XmTree_object) |
  _BIT_MASK(sym_k_XmWarningDialog_object) |
  _BIT_MASK(sym_k_XmWorkArea_object) |
  _BIT_MASK(sym_k_XmWorkingDialog_object) |
  0, 0};

/* sym_k_XmNbaseHeight_arg */
static unsigned char arg_class_vec172[] =
  {
  _BIT_MASK(sym_k_DtHelpDialog_object) |
  _BIT_MASK(sym_k_DtHelpQuickDialog_object) |
  _BIT_MASK(sym_k_DtPrintSetupDialog_object) |
  0, _BIT_MASK(sym_k_XmBulletinBoardDialog_object) |
  0, _BIT_MASK(sym_k_XmCommandDialog_object) |
  0, _BIT_MASK(sym_k_XmDialogShell_object) |
  _BIT_MASK(sym_k_XmErrorDialog_object) |
  _BIT_MASK(sym_k_XmFileSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmFormDialog_object) |
  _BIT_MASK(sym_k_XmInformationDialog_object) |
  0, _BIT_MASK(sym_k_XmMessageDialog_object) |
  0, _BIT_MASK(sym_k_XmPromptDialog_object) |
  0, _BIT_MASK(sym_k_XmQuestionDialog_object) |
  0, _BIT_MASK(sym_k_XmSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmTemplateDialog_object) |
  0, _BIT_MASK(sym_k_XmWarningDialog_object) |
  _BIT_MASK(sym_k_XmWorkingDialog_object) |
  0, 0};

/* sym_k_XmNbaseWidth_arg */
static unsigned char arg_class_vec173[] =
  {
  _BIT_MASK(sym_k_DtHelpDialog_object) |
  _BIT_MASK(sym_k_DtHelpQuickDialog_object) |
  _BIT_MASK(sym_k_DtPrintSetupDialog_object) |
  0, _BIT_MASK(sym_k_XmBulletinBoardDialog_object) |
  0, _BIT_MASK(sym_k_XmCommandDialog_object) |
  0, _BIT_MASK(sym_k_XmDialogShell_object) |
  _BIT_MASK(sym_k_XmErrorDialog_object) |
  _BIT_MASK(sym_k_XmFileSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmFormDialog_object) |
  _BIT_MASK(sym_k_XmInformationDialog_object) |
  0, _BIT_MASK(sym_k_XmMessageDialog_object) |
  0, _BIT_MASK(sym_k_XmPromptDialog_object) |
  0, _BIT_MASK(sym_k_XmQuestionDialog_object) |
  0, _BIT_MASK(sym_k_XmSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmTemplateDialog_object) |
  0, _BIT_MASK(sym_k_XmWarningDialog_object) |
  _BIT_MASK(sym_k_XmWorkingDialog_object) |
  0, 0};

/* sym_k_XmNbindingPixmap_arg */
static unsigned char arg_class_vec174[] =
  {
  0, 0, 0, 0, 0, 0, _BIT_MASK(sym_k_XmNotebook_object) |
  0, 0, 0, 0, 0, 0};

/* sym_k_XmNbindingType_arg */
static unsigned char arg_class_vec175[] =
  {
  0, 0, 0, 0, 0, 0, _BIT_MASK(sym_k_XmNotebook_object) |
  0, 0, 0, 0, 0, 0};

/* sym_k_XmNbindingWidth_arg */
static unsigned char arg_class_vec176[] =
  {
  0, 0, 0, 0, 0, 0, _BIT_MASK(sym_k_XmNotebook_object) |
  0, 0, 0, 0, 0, 0};

/* sym_k_XmNblinkRate_arg */
static unsigned char arg_class_vec177[] =
  {
  0, 0, _BIT_MASK(sym_k_XmDataField_object) |
  0, 0, 0, 0, 0, 0, _BIT_MASK(sym_k_XmScrolledText_object) |
  0, 0, _BIT_MASK(sym_k_XmText_object) |
  _BIT_MASK(sym_k_XmTextField_object) |
  0, 0};

/* sym_k_XmNblueSliderLabel_arg */
static unsigned char arg_class_vec178[] =
  {
  0, 0, _BIT_MASK(sym_k_XmColorSelector_object) |
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_XmNboldString_arg */
static unsigned char arg_class_vec179[] =
  {
  0, 0, 0, _BIT_MASK(sym_k_XmFontSelector_object) |
  0, 0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_XmNborderColor_arg */
static unsigned char arg_class_vec180[] =
  {
  _BIT_MASK(sym_k_DtEditor_object) |
  _BIT_MASK(sym_k_DtHelpDialog_object) |
  _BIT_MASK(sym_k_DtHelpQuickDialog_object) |
  _BIT_MASK(sym_k_DtMenuButton_object) |
  _BIT_MASK(sym_k_DtPrintSetupBox_object) |
  _BIT_MASK(sym_k_DtPrintSetupDialog_object) |
  _BIT_MASK(sym_k_DtTerm_object) |
  0, _BIT_MASK(sym_k_DtTermPrimitive_object) |
  _BIT_MASK(sym_k_XmArrowButton_object) |
  _BIT_MASK(sym_k_XmBulletinBoard_object) |
  _BIT_MASK(sym_k_XmBulletinBoardDialog_object) |
  _BIT_MASK(sym_k_XmButtonBox_object) |
  _BIT_MASK(sym_k_XmCascadeButton_object) |
  0, _BIT_MASK(sym_k_XmCheckBox_object) |
  _BIT_MASK(sym_k_XmColorSelector_object) |
  _BIT_MASK(sym_k_XmColumn_object) |
  _BIT_MASK(sym_k_XmComboBox_object) |
  _BIT_MASK(sym_k_XmCommand_object) |
  _BIT_MASK(sym_k_XmCommandDialog_object) |
  _BIT_MASK(sym_k_XmContainer_object) |
  _BIT_MASK(sym_k_XmDataField_object) |
  0, _BIT_MASK(sym_k_XmDialogShell_object) |
  _BIT_MASK(sym_k_XmDrawingArea_object) |
  _BIT_MASK(sym_k_XmDrawnButton_object) |
  _BIT_MASK(sym_k_XmDropDown_object) |
  _BIT_MASK(sym_k_XmErrorDialog_object) |
  _BIT_MASK(sym_k_XmFileSelectionBox_object) |
  _BIT_MASK(sym_k_XmFileSelectionDialog_object) |
  _BIT_MASK(sym_k_XmFontSelector_object) |
  0, _BIT_MASK(sym_k_XmForm_object) |
  _BIT_MASK(sym_k_XmFormDialog_object) |
  _BIT_MASK(sym_k_XmFrame_object) |
  _BIT_MASK(sym_k_XmIconBox_object) |
  _BIT_MASK(sym_k_XmIconButton_object) |
  _BIT_MASK(sym_k_XmInformationDialog_object) |
  _BIT_MASK(sym_k_XmLabel_object) |
  0, _BIT_MASK(sym_k_XmList_object) |
  _BIT_MASK(sym_k_XmMainWindow_object) |
  _BIT_MASK(sym_k_XmMenuBar_object) |
  _BIT_MASK(sym_k_XmMenuShell_object) |
  _BIT_MASK(sym_k_XmMessageBox_object) |
  _BIT_MASK(sym_k_XmMessageDialog_object) |
  _BIT_MASK(sym_k_XmMultiList_object) |
  0, _BIT_MASK(sym_k_XmNotebook_object) |
  _BIT_MASK(sym_k_XmOptionMenu_object) |
  _BIT_MASK(sym_k_XmOutline_object) |
  _BIT_MASK(sym_k_XmPaned_object) |
  _BIT_MASK(sym_k_XmPanedWindow_object) |
  _BIT_MASK(sym_k_XmPopupMenu_object) |
  _BIT_MASK(sym_k_XmPromptDialog_object) |
  _BIT_MASK(sym_k_XmPulldownMenu_object) |
  0, _BIT_MASK(sym_k_XmPushButton_object) |
  _BIT_MASK(sym_k_XmQuestionDialog_object) |
  _BIT_MASK(sym_k_XmRadioBox_object) |
  _BIT_MASK(sym_k_XmRowColumn_object) |
  _BIT_MASK(sym_k_XmScale_object) |
  0, _BIT_MASK(sym_k_XmScrollBar_object) |
  _BIT_MASK(sym_k_XmScrolledList_object) |
  _BIT_MASK(sym_k_XmScrolledText_object) |
  _BIT_MASK(sym_k_XmScrolledWindow_object) |
  _BIT_MASK(sym_k_XmSelectionBox_object) |
  _BIT_MASK(sym_k_XmSelectionDialog_object) |
  _BIT_MASK(sym_k_XmSeparator_object) |
  0, _BIT_MASK(sym_k_XmSimpleSpinBox_object) |
  _BIT_MASK(sym_k_XmSpinBox_object) |
  _BIT_MASK(sym_k_XmTabBox_object) |
  _BIT_MASK(sym_k_XmTabStack_object) |
  _BIT_MASK(sym_k_XmTearOffButton_object) |
  _BIT_MASK(sym_k_XmTemplateDialog_object) |
  0, _BIT_MASK(sym_k_XmText_object) |
  _BIT_MASK(sym_k_XmTextField_object) |
  _BIT_MASK(sym_k_XmToggleButton_object) |
  _BIT_MASK(sym_k_XmTree_object) |
  _BIT_MASK(sym_k_XmWarningDialog_object) |
  _BIT_MASK(sym_k_XmWorkArea_object) |
  _BIT_MASK(sym_k_XmWorkingDialog_object) |
  0, 0};

/* sym_k_XmNborderPixmap_arg */
static unsigned char arg_class_vec181[] =
  {
  _BIT_MASK(sym_k_DtEditor_object) |
  _BIT_MASK(sym_k_DtHelpDialog_object) |
  _BIT_MASK(sym_k_DtHelpQuickDialog_object) |
  _BIT_MASK(sym_k_DtMenuButton_object) |
  _BIT_MASK(sym_k_DtPrintSetupBox_object) |
  _BIT_MASK(sym_k_DtPrintSetupDialog_object) |
  _BIT_MASK(sym_k_DtTerm_object) |
  0, _BIT_MASK(sym_k_DtTermPrimitive_object) |
  _BIT_MASK(sym_k_XmArrowButton_object) |
  _BIT_MASK(sym_k_XmBulletinBoard_object) |
  _BIT_MASK(sym_k_XmBulletinBoardDialog_object) |
  _BIT_MASK(sym_k_XmButtonBox_object) |
  _BIT_MASK(sym_k_XmCascadeButton_object) |
  0, _BIT_MASK(sym_k_XmCheckBox_object) |
  _BIT_MASK(sym_k_XmColorSelector_object) |
  _BIT_MASK(sym_k_XmColumn_object) |
  _BIT_MASK(sym_k_XmComboBox_object) |
  _BIT_MASK(sym_k_XmCommand_object) |
  _BIT_MASK(sym_k_XmCommandDialog_object) |
  _BIT_MASK(sym_k_XmContainer_object) |
  _BIT_MASK(sym_k_XmDataField_object) |
  0, _BIT_MASK(sym_k_XmDialogShell_object) |
  _BIT_MASK(sym_k_XmDrawingArea_object) |
  _BIT_MASK(sym_k_XmDrawnButton_object) |
  _BIT_MASK(sym_k_XmDropDown_object) |
  _BIT_MASK(sym_k_XmErrorDialog_object) |
  _BIT_MASK(sym_k_XmFileSelectionBox_object) |
  _BIT_MASK(sym_k_XmFileSelectionDialog_object) |
  _BIT_MASK(sym_k_XmFontSelector_object) |
  0, _BIT_MASK(sym_k_XmForm_object) |
  _BIT_MASK(sym_k_XmFormDialog_object) |
  _BIT_MASK(sym_k_XmFrame_object) |
  _BIT_MASK(sym_k_XmIconBox_object) |
  _BIT_MASK(sym_k_XmIconButton_object) |
  _BIT_MASK(sym_k_XmInformationDialog_object) |
  _BIT_MASK(sym_k_XmLabel_object) |
  0, _BIT_MASK(sym_k_XmList_object) |
  _BIT_MASK(sym_k_XmMainWindow_object) |
  _BIT_MASK(sym_k_XmMenuBar_object) |
  _BIT_MASK(sym_k_XmMenuShell_object) |
  _BIT_MASK(sym_k_XmMessageBox_object) |
  _BIT_MASK(sym_k_XmMessageDialog_object) |
  _BIT_MASK(sym_k_XmMultiList_object) |
  0, _BIT_MASK(sym_k_XmNotebook_object) |
  _BIT_MASK(sym_k_XmOptionMenu_object) |
  _BIT_MASK(sym_k_XmOutline_object) |
  _BIT_MASK(sym_k_XmPaned_object) |
  _BIT_MASK(sym_k_XmPanedWindow_object) |
  _BIT_MASK(sym_k_XmPopupMenu_object) |
  _BIT_MASK(sym_k_XmPromptDialog_object) |
  _BIT_MASK(sym_k_XmPulldownMenu_object) |
  0, _BIT_MASK(sym_k_XmPushButton_object) |
  _BIT_MASK(sym_k_XmQuestionDialog_object) |
  _BIT_MASK(sym_k_XmRadioBox_object) |
  _BIT_MASK(sym_k_XmRowColumn_object) |
  _BIT_MASK(sym_k_XmScale_object) |
  0, _BIT_MASK(sym_k_XmScrollBar_object) |
  _BIT_MASK(sym_k_XmScrolledList_object) |
  _BIT_MASK(sym_k_XmScrolledText_object) |
  _BIT_MASK(sym_k_XmScrolledWindow_object) |
  _BIT_MASK(sym_k_XmSelectionBox_object) |
  _BIT_MASK(sym_k_XmSelectionDialog_object) |
  _BIT_MASK(sym_k_XmSeparator_object) |
  0, _BIT_MASK(sym_k_XmSimpleSpinBox_object) |
  _BIT_MASK(sym_k_XmSpinBox_object) |
  _BIT_MASK(sym_k_XmTabBox_object) |
  _BIT_MASK(sym_k_XmTabStack_object) |
  _BIT_MASK(sym_k_XmTearOffButton_object) |
  _BIT_MASK(sym_k_XmTemplateDialog_object) |
  0, _BIT_MASK(sym_k_XmText_object) |
  _BIT_MASK(sym_k_XmTextField_object) |
  _BIT_MASK(sym_k_XmToggleButton_object) |
  _BIT_MASK(sym_k_XmTree_object) |
  _BIT_MASK(sym_k_XmWarningDialog_object) |
  _BIT_MASK(sym_k_XmWorkArea_object) |
  _BIT_MASK(sym_k_XmWorkingDialog_object) |
  0, 0};

/* sym_k_XmNborderWidth_arg */
static unsigned char arg_class_vec182[] =
  {
  _BIT_MASK(sym_k_DtEditor_object) |
  _BIT_MASK(sym_k_DtHelpDialog_object) |
  _BIT_MASK(sym_k_DtHelpQuickDialog_object) |
  _BIT_MASK(sym_k_DtMenuButton_object) |
  _BIT_MASK(sym_k_DtPrintSetupBox_object) |
  _BIT_MASK(sym_k_DtPrintSetupDialog_object) |
  _BIT_MASK(sym_k_DtTerm_object) |
  0, _BIT_MASK(sym_k_DtTermPrimitive_object) |
  _BIT_MASK(sym_k_XmArrowButton_object) |
  _BIT_MASK(sym_k_XmArrowButtonGadget_object) |
  _BIT_MASK(sym_k_XmBulletinBoard_object) |
  _BIT_MASK(sym_k_XmBulletinBoardDialog_object) |
  _BIT_MASK(sym_k_XmButtonBox_object) |
  _BIT_MASK(sym_k_XmCascadeButton_object) |
  _BIT_MASK(sym_k_XmCascadeButtonGadget_object) |
  0, _BIT_MASK(sym_k_XmCheckBox_object) |
  _BIT_MASK(sym_k_XmColorSelector_object) |
  _BIT_MASK(sym_k_XmColumn_object) |
  _BIT_MASK(sym_k_XmComboBox_object) |
  _BIT_MASK(sym_k_XmCommand_object) |
  _BIT_MASK(sym_k_XmCommandDialog_object) |
  _BIT_MASK(sym_k_XmContainer_object) |
  _BIT_MASK(sym_k_XmDataField_object) |
  0, _BIT_MASK(sym_k_XmDialogShell_object) |
  _BIT_MASK(sym_k_XmDrawingArea_object) |
  _BIT_MASK(sym_k_XmDrawnButton_object) |
  _BIT_MASK(sym_k_XmDropDown_object) |
  _BIT_MASK(sym_k_XmErrorDialog_object) |
  _BIT_MASK(sym_k_XmFileSelectionBox_object) |
  _BIT_MASK(sym_k_XmFileSelectionDialog_object) |
  _BIT_MASK(sym_k_XmFontSelector_object) |
  0, _BIT_MASK(sym_k_XmForm_object) |
  _BIT_MASK(sym_k_XmFormDialog_object) |
  _BIT_MASK(sym_k_XmFrame_object) |
  _BIT_MASK(sym_k_XmIconBox_object) |
  _BIT_MASK(sym_k_XmIconButton_object) |
  _BIT_MASK(sym_k_XmIconGadget_object) |
  _BIT_MASK(sym_k_XmInformationDialog_object) |
  _BIT_MASK(sym_k_XmLabel_object) |
  0, _BIT_MASK(sym_k_XmLabelGadget_object) |
  _BIT_MASK(sym_k_XmList_object) |
  _BIT_MASK(sym_k_XmMainWindow_object) |
  _BIT_MASK(sym_k_XmMenuBar_object) |
  _BIT_MASK(sym_k_XmMenuShell_object) |
  _BIT_MASK(sym_k_XmMessageBox_object) |
  _BIT_MASK(sym_k_XmMessageDialog_object) |
  _BIT_MASK(sym_k_XmMultiList_object) |
  0, _BIT_MASK(sym_k_XmNotebook_object) |
  _BIT_MASK(sym_k_XmOptionMenu_object) |
  _BIT_MASK(sym_k_XmOutline_object) |
  _BIT_MASK(sym_k_XmPaned_object) |
  _BIT_MASK(sym_k_XmPanedWindow_object) |
  _BIT_MASK(sym_k_XmPopupMenu_object) |
  _BIT_MASK(sym_k_XmPromptDialog_object) |
  _BIT_MASK(sym_k_XmPulldownMenu_object) |
  0, _BIT_MASK(sym_k_XmPushButton_object) |
  _BIT_MASK(sym_k_XmPushButtonGadget_object) |
  _BIT_MASK(sym_k_XmQuestionDialog_object) |
  _BIT_MASK(sym_k_XmRadioBox_object) |
  _BIT_MASK(sym_k_XmRowColumn_object) |
  _BIT_MASK(sym_k_XmScale_object) |
  0, _BIT_MASK(sym_k_XmScrollBar_object) |
  _BIT_MASK(sym_k_XmScrolledList_object) |
  _BIT_MASK(sym_k_XmScrolledText_object) |
  _BIT_MASK(sym_k_XmScrolledWindow_object) |
  _BIT_MASK(sym_k_XmSelectionBox_object) |
  _BIT_MASK(sym_k_XmSelectionDialog_object) |
  _BIT_MASK(sym_k_XmSeparator_object) |
  _BIT_MASK(sym_k_XmSeparatorGadget_object) |
  0, _BIT_MASK(sym_k_XmSimpleSpinBox_object) |
  _BIT_MASK(sym_k_XmSpinBox_object) |
  _BIT_MASK(sym_k_XmTabBox_object) |
  _BIT_MASK(sym_k_XmTabStack_object) |
  _BIT_MASK(sym_k_XmTearOffButton_object) |
  _BIT_MASK(sym_k_XmTemplateDialog_object) |
  0, _BIT_MASK(sym_k_XmText_object) |
  _BIT_MASK(sym_k_XmTextField_object) |
  _BIT_MASK(sym_k_XmToggleButton_object) |
  _BIT_MASK(sym_k_XmToggleButtonGadget_object) |
  _BIT_MASK(sym_k_XmTree_object) |
  _BIT_MASK(sym_k_XmWarningDialog_object) |
  _BIT_MASK(sym_k_XmWorkArea_object) |
  _BIT_MASK(sym_k_XmWorkingDialog_object) |
  0, 0};

/* sym_k_XmNbothString_arg */
static unsigned char arg_class_vec183[] =
  {
  0, 0, 0, _BIT_MASK(sym_k_XmFontSelector_object) |
  0, 0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_XmNbottomAttachment_arg */
static unsigned char arg_class_vec184[] =
  {
  _BIT_MASK(sym_k_DtEditor_object) |
  0, 0, 0, 0, _BIT_MASK(sym_k_XmForm_object) |
  _BIT_MASK(sym_k_XmFormDialog_object) |
  0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_XmNbottomOffset_arg */
static unsigned char arg_class_vec185[] =
  {
  _BIT_MASK(sym_k_DtEditor_object) |
  0, 0, 0, 0, _BIT_MASK(sym_k_XmForm_object) |
  _BIT_MASK(sym_k_XmFormDialog_object) |
  0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_XmNbottomPosition_arg */
static unsigned char arg_class_vec186[] =
  {
  _BIT_MASK(sym_k_DtEditor_object) |
  0, 0, 0, 0, _BIT_MASK(sym_k_XmForm_object) |
  _BIT_MASK(sym_k_XmFormDialog_object) |
  0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_XmNbottomShadowColor_arg */
static unsigned char arg_class_vec187[] =
  {
  _BIT_MASK(sym_k_DtEditor_object) |
  _BIT_MASK(sym_k_DtHelpDialog_object) |
  _BIT_MASK(sym_k_DtHelpQuickDialog_object) |
  _BIT_MASK(sym_k_DtMenuButton_object) |
  _BIT_MASK(sym_k_DtPrintSetupBox_object) |
  _BIT_MASK(sym_k_DtPrintSetupDialog_object) |
  _BIT_MASK(sym_k_DtTerm_object) |
  0, _BIT_MASK(sym_k_DtTermPrimitive_object) |
  _BIT_MASK(sym_k_XmArrowButton_object) |
  _BIT_MASK(sym_k_XmBulletinBoard_object) |
  _BIT_MASK(sym_k_XmBulletinBoardDialog_object) |
  _BIT_MASK(sym_k_XmButtonBox_object) |
  _BIT_MASK(sym_k_XmCascadeButton_object) |
  0, _BIT_MASK(sym_k_XmCheckBox_object) |
  _BIT_MASK(sym_k_XmColorSelector_object) |
  _BIT_MASK(sym_k_XmColumn_object) |
  _BIT_MASK(sym_k_XmComboBox_object) |
  _BIT_MASK(sym_k_XmCommand_object) |
  _BIT_MASK(sym_k_XmCommandDialog_object) |
  _BIT_MASK(sym_k_XmContainer_object) |
  _BIT_MASK(sym_k_XmDataField_object) |
  0, _BIT_MASK(sym_k_XmDrawingArea_object) |
  _BIT_MASK(sym_k_XmDrawnButton_object) |
  _BIT_MASK(sym_k_XmDropDown_object) |
  _BIT_MASK(sym_k_XmErrorDialog_object) |
  _BIT_MASK(sym_k_XmFileSelectionBox_object) |
  _BIT_MASK(sym_k_XmFileSelectionDialog_object) |
  _BIT_MASK(sym_k_XmFontSelector_object) |
  0, _BIT_MASK(sym_k_XmForm_object) |
  _BIT_MASK(sym_k_XmFormDialog_object) |
  _BIT_MASK(sym_k_XmFrame_object) |
  _BIT_MASK(sym_k_XmIconBox_object) |
  _BIT_MASK(sym_k_XmIconButton_object) |
  _BIT_MASK(sym_k_XmInformationDialog_object) |
  _BIT_MASK(sym_k_XmLabel_object) |
  0, _BIT_MASK(sym_k_XmList_object) |
  _BIT_MASK(sym_k_XmMainWindow_object) |
  _BIT_MASK(sym_k_XmMenuBar_object) |
  _BIT_MASK(sym_k_XmMessageBox_object) |
  _BIT_MASK(sym_k_XmMessageDialog_object) |
  _BIT_MASK(sym_k_XmMultiList_object) |
  0, _BIT_MASK(sym_k_XmNotebook_object) |
  _BIT_MASK(sym_k_XmOptionMenu_object) |
  _BIT_MASK(sym_k_XmOutline_object) |
  _BIT_MASK(sym_k_XmPaned_object) |
  _BIT_MASK(sym_k_XmPanedWindow_object) |
  _BIT_MASK(sym_k_XmPopupMenu_object) |
  _BIT_MASK(sym_k_XmPromptDialog_object) |
  _BIT_MASK(sym_k_XmPulldownMenu_object) |
  0, _BIT_MASK(sym_k_XmPushButton_object) |
  _BIT_MASK(sym_k_XmQuestionDialog_object) |
  _BIT_MASK(sym_k_XmRadioBox_object) |
  _BIT_MASK(sym_k_XmRowColumn_object) |
  _BIT_MASK(sym_k_XmScale_object) |
  0, _BIT_MASK(sym_k_XmScrollBar_object) |
  _BIT_MASK(sym_k_XmScrolledList_object) |
  _BIT_MASK(sym_k_XmScrolledText_object) |
  _BIT_MASK(sym_k_XmScrolledWindow_object) |
  _BIT_MASK(sym_k_XmSelectionBox_object) |
  _BIT_MASK(sym_k_XmSelectionDialog_object) |
  _BIT_MASK(sym_k_XmSeparator_object) |
  0, _BIT_MASK(sym_k_XmSimpleSpinBox_object) |
  _BIT_MASK(sym_k_XmSpinBox_object) |
  _BIT_MASK(sym_k_XmTabBox_object) |
  _BIT_MASK(sym_k_XmTabStack_object) |
  _BIT_MASK(sym_k_XmTearOffButton_object) |
  _BIT_MASK(sym_k_XmTemplateDialog_object) |
  0, _BIT_MASK(sym_k_XmText_object) |
  _BIT_MASK(sym_k_XmTextField_object) |
  _BIT_MASK(sym_k_XmToggleButton_object) |
  _BIT_MASK(sym_k_XmTree_object) |
  _BIT_MASK(sym_k_XmWarningDialog_object) |
  _BIT_MASK(sym_k_XmWorkArea_object) |
  _BIT_MASK(sym_k_XmWorkingDialog_object) |
  0, 0};

/* sym_k_XmNbottomShadowPixmap_arg */
static unsigned char arg_class_vec188[] =
  {
  _BIT_MASK(sym_k_DtEditor_object) |
  _BIT_MASK(sym_k_DtHelpDialog_object) |
  _BIT_MASK(sym_k_DtHelpQuickDialog_object) |
  _BIT_MASK(sym_k_DtMenuButton_object) |
  _BIT_MASK(sym_k_DtPrintSetupBox_object) |
  _BIT_MASK(sym_k_DtPrintSetupDialog_object) |
  _BIT_MASK(sym_k_DtTerm_object) |
  0, _BIT_MASK(sym_k_DtTermPrimitive_object) |
  _BIT_MASK(sym_k_XmArrowButton_object) |
  _BIT_MASK(sym_k_XmBulletinBoard_object) |
  _BIT_MASK(sym_k_XmBulletinBoardDialog_object) |
  _BIT_MASK(sym_k_XmButtonBox_object) |
  _BIT_MASK(sym_k_XmCascadeButton_object) |
  0, _BIT_MASK(sym_k_XmCheckBox_object) |
  _BIT_MASK(sym_k_XmColorSelector_object) |
  _BIT_MASK(sym_k_XmColumn_object) |
  _BIT_MASK(sym_k_XmComboBox_object) |
  _BIT_MASK(sym_k_XmCommand_object) |
  _BIT_MASK(sym_k_XmCommandDialog_object) |
  _BIT_MASK(sym_k_XmContainer_object) |
  _BIT_MASK(sym_k_XmDataField_object) |
  0, _BIT_MASK(sym_k_XmDrawingArea_object) |
  _BIT_MASK(sym_k_XmDrawnButton_object) |
  _BIT_MASK(sym_k_XmDropDown_object) |
  _BIT_MASK(sym_k_XmErrorDialog_object) |
  _BIT_MASK(sym_k_XmFileSelectionBox_object) |
  _BIT_MASK(sym_k_XmFileSelectionDialog_object) |
  _BIT_MASK(sym_k_XmFontSelector_object) |
  0, _BIT_MASK(sym_k_XmForm_object) |
  _BIT_MASK(sym_k_XmFormDialog_object) |
  _BIT_MASK(sym_k_XmFrame_object) |
  _BIT_MASK(sym_k_XmIconBox_object) |
  _BIT_MASK(sym_k_XmIconButton_object) |
  _BIT_MASK(sym_k_XmInformationDialog_object) |
  _BIT_MASK(sym_k_XmLabel_object) |
  0, _BIT_MASK(sym_k_XmList_object) |
  _BIT_MASK(sym_k_XmMainWindow_object) |
  _BIT_MASK(sym_k_XmMenuBar_object) |
  _BIT_MASK(sym_k_XmMessageBox_object) |
  _BIT_MASK(sym_k_XmMessageDialog_object) |
  _BIT_MASK(sym_k_XmMultiList_object) |
  0, _BIT_MASK(sym_k_XmNotebook_object) |
  _BIT_MASK(sym_k_XmOptionMenu_object) |
  _BIT_MASK(sym_k_XmOutline_object) |
  _BIT_MASK(sym_k_XmPaned_object) |
  _BIT_MASK(sym_k_XmPanedWindow_object) |
  _BIT_MASK(sym_k_XmPopupMenu_object) |
  _BIT_MASK(sym_k_XmPromptDialog_object) |
  _BIT_MASK(sym_k_XmPulldownMenu_object) |
  0, _BIT_MASK(sym_k_XmPushButton_object) |
  _BIT_MASK(sym_k_XmQuestionDialog_object) |
  _BIT_MASK(sym_k_XmRadioBox_object) |
  _BIT_MASK(sym_k_XmRowColumn_object) |
  _BIT_MASK(sym_k_XmScale_object) |
  0, _BIT_MASK(sym_k_XmScrollBar_object) |
  _BIT_MASK(sym_k_XmScrolledList_object) |
  _BIT_MASK(sym_k_XmScrolledText_object) |
  _BIT_MASK(sym_k_XmScrolledWindow_object) |
  _BIT_MASK(sym_k_XmSelectionBox_object) |
  _BIT_MASK(sym_k_XmSelectionDialog_object) |
  _BIT_MASK(sym_k_XmSeparator_object) |
  0, _BIT_MASK(sym_k_XmSimpleSpinBox_object) |
  _BIT_MASK(sym_k_XmSpinBox_object) |
  _BIT_MASK(sym_k_XmTabBox_object) |
  _BIT_MASK(sym_k_XmTabStack_object) |
  _BIT_MASK(sym_k_XmTearOffButton_object) |
  _BIT_MASK(sym_k_XmTemplateDialog_object) |
  0, _BIT_MASK(sym_k_XmText_object) |
  _BIT_MASK(sym_k_XmTextField_object) |
  _BIT_MASK(sym_k_XmToggleButton_object) |
  _BIT_MASK(sym_k_XmTree_object) |
  _BIT_MASK(sym_k_XmWarningDialog_object) |
  _BIT_MASK(sym_k_XmWorkArea_object) |
  _BIT_MASK(sym_k_XmWorkingDialog_object) |
  0, 0};

/* sym_k_XmNbottomWidget_arg */
static unsigned char arg_class_vec189[] =
  {
  _BIT_MASK(sym_k_DtEditor_object) |
  0, 0, 0, 0, _BIT_MASK(sym_k_XmForm_object) |
  _BIT_MASK(sym_k_XmFormDialog_object) |
  0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_XmNbuttonCount_arg */
static unsigned char arg_class_vec190[] =
  {
  0, 0, _BIT_MASK(sym_k_XmCheckBox_object) |
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_XmNbuttonFontList_arg */
static unsigned char arg_class_vec191[] =
  {
  _BIT_MASK(sym_k_DtEditor_object) |
  _BIT_MASK(sym_k_DtHelpDialog_object) |
  _BIT_MASK(sym_k_DtHelpQuickDialog_object) |
  _BIT_MASK(sym_k_DtPrintSetupBox_object) |
  _BIT_MASK(sym_k_DtPrintSetupDialog_object) |
  0, _BIT_MASK(sym_k_XmBulletinBoard_object) |
  _BIT_MASK(sym_k_XmBulletinBoardDialog_object) |
  0, _BIT_MASK(sym_k_XmColumn_object) |
  0, _BIT_MASK(sym_k_XmDialogShell_object) |
  _BIT_MASK(sym_k_XmErrorDialog_object) |
  _BIT_MASK(sym_k_XmFileSelectionBox_object) |
  _BIT_MASK(sym_k_XmFileSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmForm_object) |
  _BIT_MASK(sym_k_XmFormDialog_object) |
  _BIT_MASK(sym_k_XmInformationDialog_object) |
  0, _BIT_MASK(sym_k_XmMenuShell_object) |
  _BIT_MASK(sym_k_XmMessageBox_object) |
  _BIT_MASK(sym_k_XmMessageDialog_object) |
  0, _BIT_MASK(sym_k_XmPopupMenu_object) |
  _BIT_MASK(sym_k_XmPromptDialog_object) |
  _BIT_MASK(sym_k_XmPulldownMenu_object) |
  0, _BIT_MASK(sym_k_XmQuestionDialog_object) |
  0, _BIT_MASK(sym_k_XmSelectionBox_object) |
  _BIT_MASK(sym_k_XmSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmTabStack_object) |
  _BIT_MASK(sym_k_XmTemplateDialog_object) |
  0, _BIT_MASK(sym_k_XmWarningDialog_object) |
  _BIT_MASK(sym_k_XmWorkingDialog_object) |
  0, 0};

/* sym_k_XmNbuttonRenderTable_arg */
static unsigned char arg_class_vec192[] =
  {
  _BIT_MASK(sym_k_DtEditor_object) |
  _BIT_MASK(sym_k_DtHelpDialog_object) |
  _BIT_MASK(sym_k_DtHelpQuickDialog_object) |
  _BIT_MASK(sym_k_DtPrintSetupBox_object) |
  _BIT_MASK(sym_k_DtPrintSetupDialog_object) |
  0, _BIT_MASK(sym_k_XmBulletinBoard_object) |
  _BIT_MASK(sym_k_XmBulletinBoardDialog_object) |
  0, _BIT_MASK(sym_k_XmColumn_object) |
  _BIT_MASK(sym_k_XmCommand_object) |
  _BIT_MASK(sym_k_XmCommandDialog_object) |
  0, _BIT_MASK(sym_k_XmDialogShell_object) |
  _BIT_MASK(sym_k_XmErrorDialog_object) |
  _BIT_MASK(sym_k_XmFileSelectionBox_object) |
  _BIT_MASK(sym_k_XmFileSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmForm_object) |
  _BIT_MASK(sym_k_XmFormDialog_object) |
  _BIT_MASK(sym_k_XmInformationDialog_object) |
  0, _BIT_MASK(sym_k_XmMenuShell_object) |
  _BIT_MASK(sym_k_XmMessageBox_object) |
  _BIT_MASK(sym_k_XmMessageDialog_object) |
  0, _BIT_MASK(sym_k_XmPopupMenu_object) |
  _BIT_MASK(sym_k_XmPromptDialog_object) |
  _BIT_MASK(sym_k_XmPulldownMenu_object) |
  0, _BIT_MASK(sym_k_XmQuestionDialog_object) |
  0, _BIT_MASK(sym_k_XmSelectionBox_object) |
  _BIT_MASK(sym_k_XmSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmTabStack_object) |
  _BIT_MASK(sym_k_XmTemplateDialog_object) |
  0, _BIT_MASK(sym_k_XmWarningDialog_object) |
  _BIT_MASK(sym_k_XmWorkingDialog_object) |
  0, 0};

/* sym_k_XmNbuttons_arg */
static unsigned char arg_class_vec193[] =
  {
  0, 0, _BIT_MASK(sym_k_XmCheckBox_object) |
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_XmNcancelButton_arg */
static unsigned char arg_class_vec194[] =
  {
  _BIT_MASK(sym_k_DtEditor_object) |
  _BIT_MASK(sym_k_DtHelpDialog_object) |
  _BIT_MASK(sym_k_DtHelpQuickDialog_object) |
  _BIT_MASK(sym_k_DtPrintSetupBox_object) |
  _BIT_MASK(sym_k_DtPrintSetupDialog_object) |
  0, _BIT_MASK(sym_k_XmBulletinBoard_object) |
  _BIT_MASK(sym_k_XmBulletinBoardDialog_object) |
  0, _BIT_MASK(sym_k_XmColumn_object) |
  0, _BIT_MASK(sym_k_XmErrorDialog_object) |
  _BIT_MASK(sym_k_XmFileSelectionBox_object) |
  _BIT_MASK(sym_k_XmFileSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmForm_object) |
  _BIT_MASK(sym_k_XmFormDialog_object) |
  _BIT_MASK(sym_k_XmInformationDialog_object) |
  0, _BIT_MASK(sym_k_XmMessageBox_object) |
  _BIT_MASK(sym_k_XmMessageDialog_object) |
  0, _BIT_MASK(sym_k_XmPromptDialog_object) |
  0, _BIT_MASK(sym_k_XmQuestionDialog_object) |
  0, _BIT_MASK(sym_k_XmSelectionBox_object) |
  _BIT_MASK(sym_k_XmSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmTabStack_object) |
  _BIT_MASK(sym_k_XmTemplateDialog_object) |
  0, _BIT_MASK(sym_k_XmWarningDialog_object) |
  _BIT_MASK(sym_k_XmWorkingDialog_object) |
  0, 0};

/* sym_k_XmNcancelLabelString_arg */
static unsigned char arg_class_vec195[] =
  {
  0, 0, 0, _BIT_MASK(sym_k_XmErrorDialog_object) |
  _BIT_MASK(sym_k_XmFileSelectionBox_object) |
  _BIT_MASK(sym_k_XmFileSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmInformationDialog_object) |
  0, _BIT_MASK(sym_k_XmMessageBox_object) |
  _BIT_MASK(sym_k_XmMessageDialog_object) |
  0, _BIT_MASK(sym_k_XmPromptDialog_object) |
  0, _BIT_MASK(sym_k_XmQuestionDialog_object) |
  0, _BIT_MASK(sym_k_XmSelectionBox_object) |
  _BIT_MASK(sym_k_XmSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmTemplateDialog_object) |
  0, _BIT_MASK(sym_k_XmWarningDialog_object) |
  _BIT_MASK(sym_k_XmWorkingDialog_object) |
  0, 0};

/* sym_k_XmNcascadePixmap_arg */
static unsigned char arg_class_vec196[] =
  {
  0, _BIT_MASK(sym_k_XmCascadeButton_object) |
  _BIT_MASK(sym_k_XmCascadeButtonGadget_object) |
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_XmNcellX_arg */
static unsigned char arg_class_vec197[] =
  {
  0, 0, 0, 0, _BIT_MASK(sym_k_XmIconBox_object) |
  0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_XmNcellY_arg */
static unsigned char arg_class_vec198[] =
  {
  0, 0, 0, 0, _BIT_MASK(sym_k_XmIconBox_object) |
  0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_XmNchildHorizontalAlignment_arg */
static unsigned char arg_class_vec199[] =
  {
  0, 0, 0, 0, _BIT_MASK(sym_k_XmFrame_object) |
  0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_XmNchildHorizontalSpacing_arg */
static unsigned char arg_class_vec200[] =
  {
  0, 0, 0, 0, _BIT_MASK(sym_k_XmFrame_object) |
  0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_XmNchildPlacement_arg */
static unsigned char arg_class_vec201[] =
  {
  0, 0, _BIT_MASK(sym_k_XmCommand_object) |
  _BIT_MASK(sym_k_XmCommandDialog_object) |
  0, _BIT_MASK(sym_k_XmFileSelectionBox_object) |
  _BIT_MASK(sym_k_XmFileSelectionDialog_object) |
  0, 0, 0, _BIT_MASK(sym_k_XmPromptDialog_object) |
  0, 0, _BIT_MASK(sym_k_XmSelectionBox_object) |
  _BIT_MASK(sym_k_XmSelectionDialog_object) |
  0, 0, 0, 0};

/* sym_k_XmNchildType_arg */
static unsigned char arg_class_vec202[] =
  {
  0, 0, 0, 0, _BIT_MASK(sym_k_XmFrame_object) |
  0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_XmNchildVerticalAlignment_arg */
static unsigned char arg_class_vec203[] =
  {
  0, 0, 0, 0, _BIT_MASK(sym_k_XmFrame_object) |
  0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_XmNclipWindow_arg */
static unsigned char arg_class_vec204[] =
  {
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_XmNcloseFolderPixmap_arg */
static unsigned char arg_class_vec205[] =
  {
  0, 0, 0, 0, 0, 0, _BIT_MASK(sym_k_XmOutline_object) |
  0, 0, 0, 0, _BIT_MASK(sym_k_XmTree_object) |
  0, 0};

/* sym_k_XmNcollapsedStatePixmap_arg */
static unsigned char arg_class_vec206[] =
  {
  0, 0, _BIT_MASK(sym_k_XmContainer_object) |
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_XmNcolorListTogLabel_arg */
static unsigned char arg_class_vec207[] =
  {
  0, 0, _BIT_MASK(sym_k_XmColorSelector_object) |
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_XmNcolorMode_arg */
static unsigned char arg_class_vec208[] =
  {
  0, 0, _BIT_MASK(sym_k_XmColorSelector_object) |
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_XmNcolorName_arg */
static unsigned char arg_class_vec209[] =
  {
  0, 0, _BIT_MASK(sym_k_XmColorSelector_object) |
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_XmNcolormap_arg */
static unsigned char arg_class_vec210[] =
  {
  _BIT_MASK(sym_k_DtEditor_object) |
  _BIT_MASK(sym_k_DtHelpDialog_object) |
  _BIT_MASK(sym_k_DtHelpQuickDialog_object) |
  _BIT_MASK(sym_k_DtMenuButton_object) |
  _BIT_MASK(sym_k_DtPrintSetupBox_object) |
  _BIT_MASK(sym_k_DtPrintSetupDialog_object) |
  _BIT_MASK(sym_k_DtTerm_object) |
  0, _BIT_MASK(sym_k_DtTermPrimitive_object) |
  _BIT_MASK(sym_k_XmArrowButton_object) |
  _BIT_MASK(sym_k_XmBulletinBoard_object) |
  _BIT_MASK(sym_k_XmBulletinBoardDialog_object) |
  _BIT_MASK(sym_k_XmButtonBox_object) |
  _BIT_MASK(sym_k_XmCascadeButton_object) |
  0, _BIT_MASK(sym_k_XmCheckBox_object) |
  _BIT_MASK(sym_k_XmColorSelector_object) |
  _BIT_MASK(sym_k_XmColumn_object) |
  _BIT_MASK(sym_k_XmComboBox_object) |
  _BIT_MASK(sym_k_XmCommand_object) |
  _BIT_MASK(sym_k_XmCommandDialog_object) |
  _BIT_MASK(sym_k_XmContainer_object) |
  _BIT_MASK(sym_k_XmDataField_object) |
  0, _BIT_MASK(sym_k_XmDialogShell_object) |
  _BIT_MASK(sym_k_XmDrawingArea_object) |
  _BIT_MASK(sym_k_XmDrawnButton_object) |
  _BIT_MASK(sym_k_XmDropDown_object) |
  _BIT_MASK(sym_k_XmErrorDialog_object) |
  _BIT_MASK(sym_k_XmFileSelectionBox_object) |
  _BIT_MASK(sym_k_XmFileSelectionDialog_object) |
  _BIT_MASK(sym_k_XmFontSelector_object) |
  0, _BIT_MASK(sym_k_XmForm_object) |
  _BIT_MASK(sym_k_XmFormDialog_object) |
  _BIT_MASK(sym_k_XmFrame_object) |
  _BIT_MASK(sym_k_XmIconBox_object) |
  _BIT_MASK(sym_k_XmIconButton_object) |
  _BIT_MASK(sym_k_XmInformationDialog_object) |
  _BIT_MASK(sym_k_XmLabel_object) |
  0, _BIT_MASK(sym_k_XmList_object) |
  _BIT_MASK(sym_k_XmMainWindow_object) |
  _BIT_MASK(sym_k_XmMenuBar_object) |
  _BIT_MASK(sym_k_XmMenuShell_object) |
  _BIT_MASK(sym_k_XmMessageBox_object) |
  _BIT_MASK(sym_k_XmMessageDialog_object) |
  _BIT_MASK(sym_k_XmMultiList_object) |
  0, _BIT_MASK(sym_k_XmNotebook_object) |
  _BIT_MASK(sym_k_XmOptionMenu_object) |
  _BIT_MASK(sym_k_XmOutline_object) |
  _BIT_MASK(sym_k_XmPaned_object) |
  _BIT_MASK(sym_k_XmPanedWindow_object) |
  _BIT_MASK(sym_k_XmPopupMenu_object) |
  _BIT_MASK(sym_k_XmPromptDialog_object) |
  _BIT_MASK(sym_k_XmPulldownMenu_object) |
  0, _BIT_MASK(sym_k_XmPushButton_object) |
  _BIT_MASK(sym_k_XmQuestionDialog_object) |
  _BIT_MASK(sym_k_XmRadioBox_object) |
  _BIT_MASK(sym_k_XmRowColumn_object) |
  _BIT_MASK(sym_k_XmScale_object) |
  0, _BIT_MASK(sym_k_XmScrollBar_object) |
  _BIT_MASK(sym_k_XmScrolledList_object) |
  _BIT_MASK(sym_k_XmScrolledText_object) |
  _BIT_MASK(sym_k_XmScrolledWindow_object) |
  _BIT_MASK(sym_k_XmSelectionBox_object) |
  _BIT_MASK(sym_k_XmSelectionDialog_object) |
  _BIT_MASK(sym_k_XmSeparator_object) |
  0, _BIT_MASK(sym_k_XmSimpleSpinBox_object) |
  _BIT_MASK(sym_k_XmSpinBox_object) |
  _BIT_MASK(sym_k_XmTabBox_object) |
  _BIT_MASK(sym_k_XmTabStack_object) |
  _BIT_MASK(sym_k_XmTearOffButton_object) |
  _BIT_MASK(sym_k_XmTemplateDialog_object) |
  0, _BIT_MASK(sym_k_XmText_object) |
  _BIT_MASK(sym_k_XmTextField_object) |
  _BIT_MASK(sym_k_XmToggleButton_object) |
  _BIT_MASK(sym_k_XmTree_object) |
  _BIT_MASK(sym_k_XmWarningDialog_object) |
  _BIT_MASK(sym_k_XmWorkArea_object) |
  _BIT_MASK(sym_k_XmWorkingDialog_object) |
  0, 0};

/* sym_k_XmNcolumnTitles_arg */
static unsigned char arg_class_vec211[] =
  {
  0, 0, 0, 0, 0, _BIT_MASK(sym_k_XmMultiList_object) |
  0, 0, 0, 0, 0, 0, 0};

/* sym_k_XmNcolumns_arg */
static unsigned char arg_class_vec212[] =
  {
  0, 0, _BIT_MASK(sym_k_XmComboBox_object) |
  _BIT_MASK(sym_k_XmDataField_object) |
  0, 0, 0, 0, 0, 0, _BIT_MASK(sym_k_XmScrolledText_object) |
  0, _BIT_MASK(sym_k_XmSimpleSpinBox_object) |
  0, _BIT_MASK(sym_k_XmText_object) |
  _BIT_MASK(sym_k_XmTextField_object) |
  0, 0};

/* sym_k_XmNcomboBoxType_arg */
static unsigned char arg_class_vec213[] =
  {
  0, 0, _BIT_MASK(sym_k_XmComboBox_object) |
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_XmNcomboTranslations_arg */
static unsigned char arg_class_vec214[] =
  {
  0, 0, 0, _BIT_MASK(sym_k_XmDropDown_object) |
  0, 0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_XmNcommand_arg */
static unsigned char arg_class_vec215[] =
  {
  0, 0, _BIT_MASK(sym_k_XmCommand_object) |
  _BIT_MASK(sym_k_XmCommandDialog_object) |
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_XmNcommandWindow_arg */
static unsigned char arg_class_vec216[] =
  {
  0, 0, 0, 0, 0, _BIT_MASK(sym_k_XmMainWindow_object) |
  0, 0, 0, 0, 0, 0, 0};

/* sym_k_XmNcommandWindowLocation_arg */
static unsigned char arg_class_vec217[] =
  {
  0, 0, 0, 0, 0, _BIT_MASK(sym_k_XmMainWindow_object) |
  0, 0, 0, 0, 0, 0, 0};

/* sym_k_XmNcompressStyle_arg */
static unsigned char arg_class_vec218[] =
  {
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, _BIT_MASK(sym_k_XmTree_object) |
  0, 0};

/* sym_k_XmNconnectNodes_arg */
static unsigned char arg_class_vec219[] =
  {
  0, 0, 0, 0, 0, 0, _BIT_MASK(sym_k_XmOutline_object) |
  0, 0, 0, 0, 0, 0};

/* sym_k_XmNconnectStyle_arg */
static unsigned char arg_class_vec220[] =
  {
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, _BIT_MASK(sym_k_XmTree_object) |
  0, 0};

/* sym_k_XmNconstrainWidth_arg */
static unsigned char arg_class_vec221[] =
  {
  0, 0, 0, 0, 0, 0, _BIT_MASK(sym_k_XmOutline_object) |
  0, 0, 0, 0, 0, 0};

/* sym_k_XmNcreatePopupChildProc_arg */
static unsigned char arg_class_vec222[] =
  {
  _BIT_MASK(sym_k_DtHelpDialog_object) |
  _BIT_MASK(sym_k_DtHelpQuickDialog_object) |
  _BIT_MASK(sym_k_DtPrintSetupDialog_object) |
  0, _BIT_MASK(sym_k_XmBulletinBoardDialog_object) |
  0, _BIT_MASK(sym_k_XmCommandDialog_object) |
  0, _BIT_MASK(sym_k_XmDialogShell_object) |
  _BIT_MASK(sym_k_XmErrorDialog_object) |
  _BIT_MASK(sym_k_XmFileSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmFormDialog_object) |
  _BIT_MASK(sym_k_XmInformationDialog_object) |
  0, _BIT_MASK(sym_k_XmMenuShell_object) |
  _BIT_MASK(sym_k_XmMessageDialog_object) |
  0, _BIT_MASK(sym_k_XmPopupMenu_object) |
  _BIT_MASK(sym_k_XmPromptDialog_object) |
  _BIT_MASK(sym_k_XmPulldownMenu_object) |
  0, _BIT_MASK(sym_k_XmQuestionDialog_object) |
  0, _BIT_MASK(sym_k_XmSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmTemplateDialog_object) |
  0, _BIT_MASK(sym_k_XmWarningDialog_object) |
  _BIT_MASK(sym_k_XmWorkingDialog_object) |
  0, 0};

/* sym_k_XmNcurrentFont_arg */
static unsigned char arg_class_vec223[] =
  {
  0, 0, 0, _BIT_MASK(sym_k_XmFontSelector_object) |
  0, 0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_XmNcurrentPageNumber_arg */
static unsigned char arg_class_vec224[] =
  {
  0, 0, 0, 0, 0, 0, _BIT_MASK(sym_k_XmNotebook_object) |
  0, 0, 0, 0, 0, 0};

/* sym_k_XmNcursor_arg */
static unsigned char arg_class_vec225[] =
  {
  0, 0, 0, _BIT_MASK(sym_k_XmFontSelector_object) |
  0, 0, 0, _BIT_MASK(sym_k_XmPaned_object) |
  0, 0, 0, 0, 0, 0};

/* sym_k_XmNcursorPosition_arg */
static unsigned char arg_class_vec226[] =
  {
  0, 0, _BIT_MASK(sym_k_XmDataField_object) |
  0, 0, 0, 0, 0, 0, _BIT_MASK(sym_k_XmScrolledText_object) |
  0, 0, _BIT_MASK(sym_k_XmText_object) |
  _BIT_MASK(sym_k_XmTextField_object) |
  0, 0};

/* sym_k_XmNcursorPositionVisible_arg */
static unsigned char arg_class_vec227[] =
  {
  0, 0, _BIT_MASK(sym_k_XmDataField_object) |
  0, 0, 0, 0, 0, 0, _BIT_MASK(sym_k_XmScrolledText_object) |
  0, 0, _BIT_MASK(sym_k_XmText_object) |
  _BIT_MASK(sym_k_XmTextField_object) |
  0, 0};

/* sym_k_XmNcustomizedCombinationBox_arg */
static unsigned char arg_class_vec228[] =
  {
  0, 0, 0, _BIT_MASK(sym_k_XmDropDown_object) |
  0, 0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_XmNdarkThreshold_arg */
static unsigned char arg_class_vec229[] =
  {
  _BIT_MASK(sym_k_DtHelpDialog_object) |
  _BIT_MASK(sym_k_DtHelpQuickDialog_object) |
  _BIT_MASK(sym_k_DtPrintSetupDialog_object) |
  0, _BIT_MASK(sym_k_XmBulletinBoardDialog_object) |
  0, _BIT_MASK(sym_k_XmCommandDialog_object) |
  0, _BIT_MASK(sym_k_XmDialogShell_object) |
  _BIT_MASK(sym_k_XmErrorDialog_object) |
  _BIT_MASK(sym_k_XmFileSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmFormDialog_object) |
  _BIT_MASK(sym_k_XmInformationDialog_object) |
  0, _BIT_MASK(sym_k_XmMessageDialog_object) |
  0, _BIT_MASK(sym_k_XmPromptDialog_object) |
  0, _BIT_MASK(sym_k_XmQuestionDialog_object) |
  0, _BIT_MASK(sym_k_XmSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmTemplateDialog_object) |
  0, _BIT_MASK(sym_k_XmWarningDialog_object) |
  _BIT_MASK(sym_k_XmWorkingDialog_object) |
  0, 0};

/* sym_k_XmNdecimal_arg */
static unsigned char arg_class_vec230[] =
  {
  0, 0, 0, 0, 0, 0, 0, 0, 0, _BIT_MASK(sym_k_XmTab_object) |
  0, 0, 0};

/* sym_k_XmNdecimalPoints_arg */
static unsigned char arg_class_vec231[] =
  {
  0, 0, 0, 0, 0, 0, 0, _BIT_MASK(sym_k_XmScale_object) |
  0, 0, _BIT_MASK(sym_k_XmSimpleSpinBox_object) |
  _BIT_MASK(sym_k_XmSpinBox_object) |
  0, 0, 0};

/* sym_k_XmNdefaultArrowSensitivity_arg */
static unsigned char arg_class_vec232[] =
  {
  0, 0, 0, 0, 0, 0, 0, 0, 0, _BIT_MASK(sym_k_XmSimpleSpinBox_object) |
  _BIT_MASK(sym_k_XmSpinBox_object) |
  0, 0, 0};

/* sym_k_XmNdefaultButton_arg */
static unsigned char arg_class_vec233[] =
  {
  _BIT_MASK(sym_k_DtEditor_object) |
  _BIT_MASK(sym_k_DtHelpDialog_object) |
  _BIT_MASK(sym_k_DtHelpQuickDialog_object) |
  _BIT_MASK(sym_k_DtPrintSetupBox_object) |
  _BIT_MASK(sym_k_DtPrintSetupDialog_object) |
  0, _BIT_MASK(sym_k_XmBulletinBoard_object) |
  _BIT_MASK(sym_k_XmBulletinBoardDialog_object) |
  _BIT_MASK(sym_k_XmButtonBox_object) |
  0, _BIT_MASK(sym_k_XmColumn_object) |
  0, _BIT_MASK(sym_k_XmErrorDialog_object) |
  _BIT_MASK(sym_k_XmFileSelectionBox_object) |
  _BIT_MASK(sym_k_XmFileSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmForm_object) |
  _BIT_MASK(sym_k_XmFormDialog_object) |
  _BIT_MASK(sym_k_XmInformationDialog_object) |
  0, _BIT_MASK(sym_k_XmMessageBox_object) |
  _BIT_MASK(sym_k_XmMessageDialog_object) |
  0, _BIT_MASK(sym_k_XmPromptDialog_object) |
  0, _BIT_MASK(sym_k_XmQuestionDialog_object) |
  0, _BIT_MASK(sym_k_XmSelectionBox_object) |
  _BIT_MASK(sym_k_XmSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmTabStack_object) |
  _BIT_MASK(sym_k_XmTemplateDialog_object) |
  0, _BIT_MASK(sym_k_XmWarningDialog_object) |
  _BIT_MASK(sym_k_XmWorkingDialog_object) |
  0, 0};

/* sym_k_XmNdefaultButtonShadowThickness_arg */
static unsigned char arg_class_vec234[] =
  {
  0, 0, 0, 0, 0, 0, 0, _BIT_MASK(sym_k_XmPushButton_object) |
  _BIT_MASK(sym_k_XmPushButtonGadget_object) |
  0, 0, _BIT_MASK(sym_k_XmTearOffButton_object) |
  0, 0, 0};

/* sym_k_XmNdefaultButtonType_arg */
static unsigned char arg_class_vec235[] =
  {
  0, 0, 0, _BIT_MASK(sym_k_XmErrorDialog_object) |
  0, _BIT_MASK(sym_k_XmInformationDialog_object) |
  0, _BIT_MASK(sym_k_XmMessageBox_object) |
  _BIT_MASK(sym_k_XmMessageDialog_object) |
  0, 0, _BIT_MASK(sym_k_XmQuestionDialog_object) |
  0, 0, _BIT_MASK(sym_k_XmTemplateDialog_object) |
  0, _BIT_MASK(sym_k_XmWarningDialog_object) |
  _BIT_MASK(sym_k_XmWorkingDialog_object) |
  0, 0};

/* sym_k_XmNdefaultEncodingString_arg */
static unsigned char arg_class_vec236[] =
  {
  0, 0, 0, _BIT_MASK(sym_k_XmFontSelector_object) |
  0, 0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_XmNdefaultEntryLabelAlignment_arg */
static unsigned char arg_class_vec237[] =
  {
  0, 0, _BIT_MASK(sym_k_XmColumn_object) |
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_XmNdefaultEntryLabelFontList_arg */
static unsigned char arg_class_vec238[] =
  {
  0, 0, _BIT_MASK(sym_k_XmColumn_object) |
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_XmNdefaultEntryLabelRenderTable_arg */
static unsigned char arg_class_vec239[] =
  {
  0, 0, _BIT_MASK(sym_k_XmColumn_object) |
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_XmNdefaultFillStyle_arg */
static unsigned char arg_class_vec240[] =
  {
  0, 0, _BIT_MASK(sym_k_XmColumn_object) |
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_XmNdefaultFontList_arg */
static unsigned char arg_class_vec241[] =
  {
  _BIT_MASK(sym_k_DtHelpDialog_object) |
  _BIT_MASK(sym_k_DtHelpQuickDialog_object) |
  _BIT_MASK(sym_k_DtPrintSetupDialog_object) |
  0, _BIT_MASK(sym_k_XmBulletinBoardDialog_object) |
  0, _BIT_MASK(sym_k_XmCommandDialog_object) |
  0, _BIT_MASK(sym_k_XmDialogShell_object) |
  _BIT_MASK(sym_k_XmErrorDialog_object) |
  _BIT_MASK(sym_k_XmFileSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmFormDialog_object) |
  _BIT_MASK(sym_k_XmInformationDialog_object) |
  0, _BIT_MASK(sym_k_XmMenuShell_object) |
  _BIT_MASK(sym_k_XmMessageDialog_object) |
  0, _BIT_MASK(sym_k_XmPopupMenu_object) |
  _BIT_MASK(sym_k_XmPromptDialog_object) |
  _BIT_MASK(sym_k_XmPulldownMenu_object) |
  0, _BIT_MASK(sym_k_XmQuestionDialog_object) |
  0, _BIT_MASK(sym_k_XmSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmTemplateDialog_object) |
  0, _BIT_MASK(sym_k_XmWarningDialog_object) |
  _BIT_MASK(sym_k_XmWorkingDialog_object) |
  0, 0};

/* sym_k_XmNdefaultPosition_arg */
static unsigned char arg_class_vec242[] =
  {
  _BIT_MASK(sym_k_DtEditor_object) |
  _BIT_MASK(sym_k_DtHelpDialog_object) |
  _BIT_MASK(sym_k_DtHelpQuickDialog_object) |
  _BIT_MASK(sym_k_DtPrintSetupBox_object) |
  _BIT_MASK(sym_k_DtPrintSetupDialog_object) |
  0, _BIT_MASK(sym_k_XmBulletinBoard_object) |
  _BIT_MASK(sym_k_XmBulletinBoardDialog_object) |
  0, _BIT_MASK(sym_k_XmColumn_object) |
  _BIT_MASK(sym_k_XmCommand_object) |
  _BIT_MASK(sym_k_XmCommandDialog_object) |
  0, _BIT_MASK(sym_k_XmErrorDialog_object) |
  _BIT_MASK(sym_k_XmFileSelectionBox_object) |
  _BIT_MASK(sym_k_XmFileSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmForm_object) |
  _BIT_MASK(sym_k_XmFormDialog_object) |
  _BIT_MASK(sym_k_XmInformationDialog_object) |
  0, _BIT_MASK(sym_k_XmMessageBox_object) |
  _BIT_MASK(sym_k_XmMessageDialog_object) |
  0, _BIT_MASK(sym_k_XmPromptDialog_object) |
  0, _BIT_MASK(sym_k_XmQuestionDialog_object) |
  0, _BIT_MASK(sym_k_XmSelectionBox_object) |
  _BIT_MASK(sym_k_XmSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmTabStack_object) |
  _BIT_MASK(sym_k_XmTemplateDialog_object) |
  0, _BIT_MASK(sym_k_XmWarningDialog_object) |
  _BIT_MASK(sym_k_XmWorkingDialog_object) |
  0, 0};

/* sym_k_XmNdeleteResponse_arg */
static unsigned char arg_class_vec243[] =
  {
  _BIT_MASK(sym_k_DtHelpDialog_object) |
  _BIT_MASK(sym_k_DtHelpQuickDialog_object) |
  _BIT_MASK(sym_k_DtPrintSetupDialog_object) |
  0, _BIT_MASK(sym_k_XmBulletinBoardDialog_object) |
  0, _BIT_MASK(sym_k_XmCommandDialog_object) |
  0, _BIT_MASK(sym_k_XmDialogShell_object) |
  _BIT_MASK(sym_k_XmErrorDialog_object) |
  _BIT_MASK(sym_k_XmFileSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmFormDialog_object) |
  _BIT_MASK(sym_k_XmInformationDialog_object) |
  0, _BIT_MASK(sym_k_XmMessageDialog_object) |
  0, _BIT_MASK(sym_k_XmPromptDialog_object) |
  0, _BIT_MASK(sym_k_XmQuestionDialog_object) |
  0, _BIT_MASK(sym_k_XmSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmTemplateDialog_object) |
  0, _BIT_MASK(sym_k_XmWarningDialog_object) |
  _BIT_MASK(sym_k_XmWorkingDialog_object) |
  0, 0};

/* sym_k_XmNdepth_arg */
static unsigned char arg_class_vec244[] =
  {
  _BIT_MASK(sym_k_DtEditor_object) |
  _BIT_MASK(sym_k_DtHelpDialog_object) |
  _BIT_MASK(sym_k_DtHelpQuickDialog_object) |
  _BIT_MASK(sym_k_DtMenuButton_object) |
  _BIT_MASK(sym_k_DtPrintSetupBox_object) |
  _BIT_MASK(sym_k_DtPrintSetupDialog_object) |
  _BIT_MASK(sym_k_DtTerm_object) |
  0, _BIT_MASK(sym_k_DtTermPrimitive_object) |
  _BIT_MASK(sym_k_XmArrowButton_object) |
  _BIT_MASK(sym_k_XmBulletinBoard_object) |
  _BIT_MASK(sym_k_XmBulletinBoardDialog_object) |
  _BIT_MASK(sym_k_XmButtonBox_object) |
  _BIT_MASK(sym_k_XmCascadeButton_object) |
  0, _BIT_MASK(sym_k_XmCheckBox_object) |
  _BIT_MASK(sym_k_XmColorSelector_object) |
  _BIT_MASK(sym_k_XmColumn_object) |
  _BIT_MASK(sym_k_XmComboBox_object) |
  _BIT_MASK(sym_k_XmCommand_object) |
  _BIT_MASK(sym_k_XmCommandDialog_object) |
  _BIT_MASK(sym_k_XmContainer_object) |
  _BIT_MASK(sym_k_XmDataField_object) |
  0, _BIT_MASK(sym_k_XmDialogShell_object) |
  _BIT_MASK(sym_k_XmDrawingArea_object) |
  _BIT_MASK(sym_k_XmDrawnButton_object) |
  _BIT_MASK(sym_k_XmDropDown_object) |
  _BIT_MASK(sym_k_XmErrorDialog_object) |
  _BIT_MASK(sym_k_XmFileSelectionBox_object) |
  _BIT_MASK(sym_k_XmFileSelectionDialog_object) |
  _BIT_MASK(sym_k_XmFontSelector_object) |
  0, _BIT_MASK(sym_k_XmForm_object) |
  _BIT_MASK(sym_k_XmFormDialog_object) |
  _BIT_MASK(sym_k_XmFrame_object) |
  _BIT_MASK(sym_k_XmIconBox_object) |
  _BIT_MASK(sym_k_XmIconButton_object) |
  _BIT_MASK(sym_k_XmInformationDialog_object) |
  _BIT_MASK(sym_k_XmLabel_object) |
  0, _BIT_MASK(sym_k_XmList_object) |
  _BIT_MASK(sym_k_XmMainWindow_object) |
  _BIT_MASK(sym_k_XmMenuBar_object) |
  _BIT_MASK(sym_k_XmMenuShell_object) |
  _BIT_MASK(sym_k_XmMessageBox_object) |
  _BIT_MASK(sym_k_XmMessageDialog_object) |
  _BIT_MASK(sym_k_XmMultiList_object) |
  0, _BIT_MASK(sym_k_XmNotebook_object) |
  _BIT_MASK(sym_k_XmOptionMenu_object) |
  _BIT_MASK(sym_k_XmOutline_object) |
  _BIT_MASK(sym_k_XmPaned_object) |
  _BIT_MASK(sym_k_XmPanedWindow_object) |
  _BIT_MASK(sym_k_XmPopupMenu_object) |
  _BIT_MASK(sym_k_XmPromptDialog_object) |
  _BIT_MASK(sym_k_XmPulldownMenu_object) |
  0, _BIT_MASK(sym_k_XmPushButton_object) |
  _BIT_MASK(sym_k_XmQuestionDialog_object) |
  _BIT_MASK(sym_k_XmRadioBox_object) |
  _BIT_MASK(sym_k_XmRowColumn_object) |
  _BIT_MASK(sym_k_XmScale_object) |
  0, _BIT_MASK(sym_k_XmScrollBar_object) |
  _BIT_MASK(sym_k_XmScrolledList_object) |
  _BIT_MASK(sym_k_XmScrolledText_object) |
  _BIT_MASK(sym_k_XmScrolledWindow_object) |
  _BIT_MASK(sym_k_XmSelectionBox_object) |
  _BIT_MASK(sym_k_XmSelectionDialog_object) |
  _BIT_MASK(sym_k_XmSeparator_object) |
  0, _BIT_MASK(sym_k_XmSimpleSpinBox_object) |
  _BIT_MASK(sym_k_XmSpinBox_object) |
  _BIT_MASK(sym_k_XmTabBox_object) |
  _BIT_MASK(sym_k_XmTabStack_object) |
  _BIT_MASK(sym_k_XmTearOffButton_object) |
  _BIT_MASK(sym_k_XmTemplateDialog_object) |
  0, _BIT_MASK(sym_k_XmText_object) |
  _BIT_MASK(sym_k_XmTextField_object) |
  _BIT_MASK(sym_k_XmToggleButton_object) |
  _BIT_MASK(sym_k_XmTree_object) |
  _BIT_MASK(sym_k_XmWarningDialog_object) |
  _BIT_MASK(sym_k_XmWorkArea_object) |
  _BIT_MASK(sym_k_XmWorkingDialog_object) |
  0, 0};

/* sym_k_XmNdetail_arg */
static unsigned char arg_class_vec245[] =
  {
  0, 0, 0, 0, _BIT_MASK(sym_k_XmIconGadget_object) |
  0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_XmNdetailColumnHeading_arg */
static unsigned char arg_class_vec246[] =
  {
  0, 0, _BIT_MASK(sym_k_XmContainer_object) |
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_XmNdetailColumnHeadingCount_arg */
static unsigned char arg_class_vec247[] =
  {
  0, 0, _BIT_MASK(sym_k_XmContainer_object) |
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_XmNdetailCount_arg */
static unsigned char arg_class_vec248[] =
  {
  0, 0, 0, 0, _BIT_MASK(sym_k_XmIconGadget_object) |
  0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_XmNdetailOrder_arg */
static unsigned char arg_class_vec249[] =
  {
  0, 0, _BIT_MASK(sym_k_XmContainer_object) |
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_XmNdetailOrderCount_arg */
static unsigned char arg_class_vec250[] =
  {
  0, 0, _BIT_MASK(sym_k_XmContainer_object) |
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_XmNdetailShadowThickness_arg */
static unsigned char arg_class_vec251[] =
  {
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, _BIT_MASK(sym_k_XmToggleButton_object) |
  _BIT_MASK(sym_k_XmToggleButtonGadget_object) |
  0, 0};

/* sym_k_XmNdetailTabList_arg */
static unsigned char arg_class_vec252[] =
  {
  0, 0, _BIT_MASK(sym_k_XmContainer_object) |
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_XmNdialogStyle_arg */
static unsigned char arg_class_vec253[] =
  {
  _BIT_MASK(sym_k_DtEditor_object) |
  _BIT_MASK(sym_k_DtHelpDialog_object) |
  _BIT_MASK(sym_k_DtHelpQuickDialog_object) |
  _BIT_MASK(sym_k_DtPrintSetupBox_object) |
  _BIT_MASK(sym_k_DtPrintSetupDialog_object) |
  0, _BIT_MASK(sym_k_XmBulletinBoard_object) |
  _BIT_MASK(sym_k_XmBulletinBoardDialog_object) |
  0, _BIT_MASK(sym_k_XmColumn_object) |
  _BIT_MASK(sym_k_XmCommand_object) |
  _BIT_MASK(sym_k_XmCommandDialog_object) |
  0, _BIT_MASK(sym_k_XmErrorDialog_object) |
  _BIT_MASK(sym_k_XmFileSelectionBox_object) |
  _BIT_MASK(sym_k_XmFileSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmForm_object) |
  _BIT_MASK(sym_k_XmFormDialog_object) |
  _BIT_MASK(sym_k_XmInformationDialog_object) |
  0, _BIT_MASK(sym_k_XmMessageBox_object) |
  _BIT_MASK(sym_k_XmMessageDialog_object) |
  0, _BIT_MASK(sym_k_XmPromptDialog_object) |
  0, _BIT_MASK(sym_k_XmQuestionDialog_object) |
  0, _BIT_MASK(sym_k_XmSelectionBox_object) |
  _BIT_MASK(sym_k_XmSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmTabStack_object) |
  _BIT_MASK(sym_k_XmTemplateDialog_object) |
  0, _BIT_MASK(sym_k_XmWarningDialog_object) |
  _BIT_MASK(sym_k_XmWorkingDialog_object) |
  0, 0};

/* sym_k_XmNdialogTitle_arg */
static unsigned char arg_class_vec254[] =
  {
  _BIT_MASK(sym_k_DtEditor_object) |
  _BIT_MASK(sym_k_DtHelpDialog_object) |
  _BIT_MASK(sym_k_DtHelpQuickDialog_object) |
  _BIT_MASK(sym_k_DtPrintSetupBox_object) |
  _BIT_MASK(sym_k_DtPrintSetupDialog_object) |
  0, _BIT_MASK(sym_k_XmBulletinBoard_object) |
  _BIT_MASK(sym_k_XmBulletinBoardDialog_object) |
  0, _BIT_MASK(sym_k_XmColumn_object) |
  _BIT_MASK(sym_k_XmCommand_object) |
  _BIT_MASK(sym_k_XmCommandDialog_object) |
  0, _BIT_MASK(sym_k_XmErrorDialog_object) |
  _BIT_MASK(sym_k_XmFileSelectionBox_object) |
  _BIT_MASK(sym_k_XmFileSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmForm_object) |
  _BIT_MASK(sym_k_XmFormDialog_object) |
  _BIT_MASK(sym_k_XmInformationDialog_object) |
  0, _BIT_MASK(sym_k_XmMessageBox_object) |
  _BIT_MASK(sym_k_XmMessageDialog_object) |
  0, _BIT_MASK(sym_k_XmPromptDialog_object) |
  0, _BIT_MASK(sym_k_XmQuestionDialog_object) |
  0, _BIT_MASK(sym_k_XmSelectionBox_object) |
  _BIT_MASK(sym_k_XmSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmTabStack_object) |
  _BIT_MASK(sym_k_XmTemplateDialog_object) |
  0, _BIT_MASK(sym_k_XmWarningDialog_object) |
  _BIT_MASK(sym_k_XmWorkingDialog_object) |
  0, 0};

/* sym_k_XmNdialogType_arg */
static unsigned char arg_class_vec255[] =
  {
  0, 0, _BIT_MASK(sym_k_XmCommand_object) |
  _BIT_MASK(sym_k_XmCommandDialog_object) |
  0, _BIT_MASK(sym_k_XmErrorDialog_object) |
  _BIT_MASK(sym_k_XmFileSelectionBox_object) |
  _BIT_MASK(sym_k_XmFileSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmInformationDialog_object) |
  0, _BIT_MASK(sym_k_XmMessageBox_object) |
  _BIT_MASK(sym_k_XmMessageDialog_object) |
  0, _BIT_MASK(sym_k_XmPromptDialog_object) |
  0, _BIT_MASK(sym_k_XmQuestionDialog_object) |
  0, _BIT_MASK(sym_k_XmSelectionBox_object) |
  _BIT_MASK(sym_k_XmSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmTemplateDialog_object) |
  0, _BIT_MASK(sym_k_XmWarningDialog_object) |
  _BIT_MASK(sym_k_XmWorkingDialog_object) |
  0, 0};

/* sym_k_XmNdirListItemCount_arg */
static unsigned char arg_class_vec256[] =
  {
  0, 0, 0, _BIT_MASK(sym_k_XmFileSelectionBox_object) |
  _BIT_MASK(sym_k_XmFileSelectionDialog_object) |
  0, 0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_XmNdirListItems_arg */
static unsigned char arg_class_vec257[] =
  {
  0, 0, 0, _BIT_MASK(sym_k_XmFileSelectionBox_object) |
  _BIT_MASK(sym_k_XmFileSelectionDialog_object) |
  0, 0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_XmNdirListLabelString_arg */
static unsigned char arg_class_vec258[] =
  {
  0, 0, 0, _BIT_MASK(sym_k_XmFileSelectionBox_object) |
  _BIT_MASK(sym_k_XmFileSelectionDialog_object) |
  0, 0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_XmNdirMask_arg */
static unsigned char arg_class_vec259[] =
  {
  0, 0, 0, _BIT_MASK(sym_k_XmFileSelectionBox_object) |
  _BIT_MASK(sym_k_XmFileSelectionDialog_object) |
  0, 0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_XmNdirSearchProc_arg */
static unsigned char arg_class_vec260[] =
  {
  0, 0, 0, _BIT_MASK(sym_k_XmFileSelectionBox_object) |
  _BIT_MASK(sym_k_XmFileSelectionDialog_object) |
  0, 0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_XmNdirSpec_arg */
static unsigned char arg_class_vec261[] =
  {
  0, 0, 0, _BIT_MASK(sym_k_XmFileSelectionBox_object) |
  _BIT_MASK(sym_k_XmFileSelectionDialog_object) |
  0, 0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_XmNdirectory_arg */
static unsigned char arg_class_vec262[] =
  {
  0, 0, 0, _BIT_MASK(sym_k_XmFileSelectionBox_object) |
  _BIT_MASK(sym_k_XmFileSelectionDialog_object) |
  0, 0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_XmNdirectoryValid_arg */
static unsigned char arg_class_vec263[] =
  {
  0, 0, 0, _BIT_MASK(sym_k_XmFileSelectionBox_object) |
  _BIT_MASK(sym_k_XmFileSelectionDialog_object) |
  0, 0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_XmNdistribution_arg */
static unsigned char arg_class_vec264[] =
  {
  0, 0, _BIT_MASK(sym_k_XmColumn_object) |
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_XmNdoubleClickInterval_arg */
static unsigned char arg_class_vec265[] =
  {
  0, 0, 0, 0, 0, _BIT_MASK(sym_k_XmList_object) |
  0, 0, 0, _BIT_MASK(sym_k_XmScrolledList_object) |
  0, 0, 0, 0};

/* sym_k_XmNeditMode_arg */
static unsigned char arg_class_vec266[] =
  {
  0, 0, 0, 0, 0, 0, 0, 0, _BIT_MASK(sym_k_XmScrolledText_object) |
  0, 0, _BIT_MASK(sym_k_XmText_object) |
  0, 0};

/* sym_k_XmNeditable_arg */
static unsigned char arg_class_vec267[] =
  {
  0, 0, _BIT_MASK(sym_k_XmDataField_object) |
  0, _BIT_MASK(sym_k_XmDropDown_object) |
  0, 0, 0, 0, _BIT_MASK(sym_k_XmScale_object) |
  0, _BIT_MASK(sym_k_XmScrollBar_object) |
  _BIT_MASK(sym_k_XmScrolledText_object) |
  0, _BIT_MASK(sym_k_XmSimpleSpinBox_object) |
  0, _BIT_MASK(sym_k_XmText_object) |
  _BIT_MASK(sym_k_XmTextField_object) |
  0, 0};

/* sym_k_XmNencodingList_arg */
static unsigned char arg_class_vec268[] =
  {
  0, 0, 0, _BIT_MASK(sym_k_XmFontSelector_object) |
  0, 0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_XmNencodingString_arg */
static unsigned char arg_class_vec269[] =
  {
  0, 0, 0, _BIT_MASK(sym_k_XmFontSelector_object) |
  0, 0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_XmNentryAlignment_arg */
static unsigned char arg_class_vec270[] =
  {
  0, 0, _BIT_MASK(sym_k_XmCheckBox_object) |
  0, 0, 0, _BIT_MASK(sym_k_XmMenuBar_object) |
  0, _BIT_MASK(sym_k_XmOptionMenu_object) |
  _BIT_MASK(sym_k_XmPopupMenu_object) |
  _BIT_MASK(sym_k_XmPulldownMenu_object) |
  0, _BIT_MASK(sym_k_XmRadioBox_object) |
  _BIT_MASK(sym_k_XmRowColumn_object) |
  0, 0, 0, _BIT_MASK(sym_k_XmWorkArea_object) |
  0, 0};

/* sym_k_XmNentryBackground_arg */
static unsigned char arg_class_vec271[] =
  {
  0, 0, 0, 0, 0, _BIT_MASK(sym_k_XmMultiList_object) |
  0, 0, 0, 0, 0, 0, 0};

/* sym_k_XmNentryBorder_arg */
static unsigned char arg_class_vec272[] =
  {
  0, 0, _BIT_MASK(sym_k_XmCheckBox_object) |
  0, 0, 0, _BIT_MASK(sym_k_XmMenuBar_object) |
  0, _BIT_MASK(sym_k_XmOptionMenu_object) |
  _BIT_MASK(sym_k_XmPopupMenu_object) |
  _BIT_MASK(sym_k_XmPulldownMenu_object) |
  0, _BIT_MASK(sym_k_XmRadioBox_object) |
  _BIT_MASK(sym_k_XmRowColumn_object) |
  0, 0, 0, _BIT_MASK(sym_k_XmWorkArea_object) |
  0, 0};

/* sym_k_XmNentryClass_arg */
static unsigned char arg_class_vec273[] =
  {
  0, 0, _BIT_MASK(sym_k_XmCheckBox_object) |
  0, 0, 0, _BIT_MASK(sym_k_XmMenuBar_object) |
  0, _BIT_MASK(sym_k_XmOptionMenu_object) |
  _BIT_MASK(sym_k_XmPopupMenu_object) |
  _BIT_MASK(sym_k_XmPulldownMenu_object) |
  0, _BIT_MASK(sym_k_XmRadioBox_object) |
  _BIT_MASK(sym_k_XmRowColumn_object) |
  0, 0, 0, _BIT_MASK(sym_k_XmWorkArea_object) |
  0, 0};

/* sym_k_XmNentryData_arg */
static unsigned char arg_class_vec274[] =
  {
  0, 0, 0, 0, 0, _BIT_MASK(sym_k_XmMultiList_object) |
  0, 0, 0, 0, 0, 0, 0};

/* sym_k_XmNentryLabelAlignment_arg */
static unsigned char arg_class_vec275[] =
  {
  0, 0, _BIT_MASK(sym_k_XmColumn_object) |
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_XmNentryLabelFontList_arg */
static unsigned char arg_class_vec276[] =
  {
  0, 0, _BIT_MASK(sym_k_XmColumn_object) |
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_XmNentryLabelPixmap_arg */
static unsigned char arg_class_vec277[] =
  {
  0, 0, _BIT_MASK(sym_k_XmColumn_object) |
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_XmNentryLabelRenderTable_arg */
static unsigned char arg_class_vec278[] =
  {
  0, 0, _BIT_MASK(sym_k_XmColumn_object) |
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_XmNentryLabelString_arg */
static unsigned char arg_class_vec279[] =
  {
  0, 0, _BIT_MASK(sym_k_XmColumn_object) |
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_XmNentryLabelType_arg */
static unsigned char arg_class_vec280[] =
  {
  0, 0, _BIT_MASK(sym_k_XmColumn_object) |
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_XmNentryParent_arg */
static unsigned char arg_class_vec281[] =
  {
  0, 0, _BIT_MASK(sym_k_XmContainer_object) |
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_XmNentryVerticalAlignment_arg */
static unsigned char arg_class_vec282[] =
  {
  0, 0, _BIT_MASK(sym_k_XmCheckBox_object) |
  0, 0, 0, _BIT_MASK(sym_k_XmMenuBar_object) |
  0, _BIT_MASK(sym_k_XmOptionMenu_object) |
  _BIT_MASK(sym_k_XmPopupMenu_object) |
  _BIT_MASK(sym_k_XmPulldownMenu_object) |
  0, _BIT_MASK(sym_k_XmRadioBox_object) |
  _BIT_MASK(sym_k_XmRowColumn_object) |
  0, 0, 0, _BIT_MASK(sym_k_XmWorkArea_object) |
  0, 0};

/* sym_k_XmNentryViewType_arg */
static unsigned char arg_class_vec283[] =
  {
  0, 0, _BIT_MASK(sym_k_XmContainer_object) |
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_XmNequalSize_arg */
static unsigned char arg_class_vec284[] =
  {
  0, _BIT_MASK(sym_k_XmButtonBox_object) |
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_XmNexpandedStatePixmap_arg */
static unsigned char arg_class_vec285[] =
  {
  0, 0, _BIT_MASK(sym_k_XmContainer_object) |
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_XmNfamilyString_arg */
static unsigned char arg_class_vec286[] =
  {
  0, 0, 0, _BIT_MASK(sym_k_XmFontSelector_object) |
  0, 0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_XmNfileListItemCount_arg */
static unsigned char arg_class_vec287[] =
  {
  0, 0, 0, _BIT_MASK(sym_k_XmFileSelectionBox_object) |
  _BIT_MASK(sym_k_XmFileSelectionDialog_object) |
  0, 0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_XmNfileListItems_arg */
static unsigned char arg_class_vec288[] =
  {
  0, 0, 0, _BIT_MASK(sym_k_XmFileSelectionBox_object) |
  _BIT_MASK(sym_k_XmFileSelectionDialog_object) |
  0, 0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_XmNfileListLabelString_arg */
static unsigned char arg_class_vec289[] =
  {
  0, 0, 0, _BIT_MASK(sym_k_XmFileSelectionBox_object) |
  _BIT_MASK(sym_k_XmFileSelectionDialog_object) |
  0, 0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_XmNfileReadError_arg */
static unsigned char arg_class_vec290[] =
  {
  0, 0, _BIT_MASK(sym_k_XmColorSelector_object) |
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_XmNfileSearchProc_arg */
static unsigned char arg_class_vec291[] =
  {
  0, 0, 0, _BIT_MASK(sym_k_XmFileSelectionBox_object) |
  _BIT_MASK(sym_k_XmFileSelectionDialog_object) |
  0, 0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_XmNfileTypeMask_arg */
static unsigned char arg_class_vec292[] =
  {
  0, 0, 0, _BIT_MASK(sym_k_XmFileSelectionBox_object) |
  _BIT_MASK(sym_k_XmFileSelectionDialog_object) |
  0, 0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_XmNfillOnArm_arg */
static unsigned char arg_class_vec293[] =
  {
  0, 0, 0, 0, 0, 0, 0, _BIT_MASK(sym_k_XmPushButton_object) |
  _BIT_MASK(sym_k_XmPushButtonGadget_object) |
  0, 0, _BIT_MASK(sym_k_XmTearOffButton_object) |
  0, 0, 0};

/* sym_k_XmNfillOnSelect_arg */
static unsigned char arg_class_vec294[] =
  {
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, _BIT_MASK(sym_k_XmToggleButton_object) |
  _BIT_MASK(sym_k_XmToggleButtonGadget_object) |
  0, 0};

/* sym_k_XmNfillOption_arg */
static unsigned char arg_class_vec295[] =
  {
  0, _BIT_MASK(sym_k_XmButtonBox_object) |
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_XmNfillStyle_arg */
static unsigned char arg_class_vec296[] =
  {
  0, 0, _BIT_MASK(sym_k_XmColumn_object) |
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_XmNfilterLabelString_arg */
static unsigned char arg_class_vec297[] =
  {
  0, 0, 0, _BIT_MASK(sym_k_XmFileSelectionBox_object) |
  _BIT_MASK(sym_k_XmFileSelectionDialog_object) |
  0, 0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_XmNfindLabel_arg */
static unsigned char arg_class_vec298[] =
  {
  0, 0, 0, 0, 0, _BIT_MASK(sym_k_XmMultiList_object) |
  0, 0, 0, 0, 0, 0, 0};

/* sym_k_XmNfirstColumn_arg */
static unsigned char arg_class_vec299[] =
  {
  0, 0, 0, 0, 0, _BIT_MASK(sym_k_XmMultiList_object) |
  0, 0, 0, 0, 0, 0, 0};

/* sym_k_XmNfirstColumnPixmaps_arg */
static unsigned char arg_class_vec300[] =
  {
  0, 0, 0, 0, 0, _BIT_MASK(sym_k_XmMultiList_object) |
  0, 0, 0, 0, 0, 0, 0};

/* sym_k_XmNfirstPageNumber_arg */
static unsigned char arg_class_vec301[] =
  {
  0, 0, 0, 0, 0, 0, _BIT_MASK(sym_k_XmNotebook_object) |
  0, 0, 0, 0, 0, 0};

/* sym_k_XmNfirstRow_arg */
static unsigned char arg_class_vec302[] =
  {
  0, 0, 0, 0, 0, _BIT_MASK(sym_k_XmMultiList_object) |
  0, 0, 0, 0, 0, 0, 0};

/* sym_k_XmNfont_arg */
static unsigned char arg_class_vec303[] =
  {
  0, 0, 0, 0, 0, 0, 0, _BIT_MASK(sym_k_XmRendition_object) |
  0, 0, 0, 0, 0};

/* sym_k_XmNfontEncoding_arg */
static unsigned char arg_class_vec304[] =
  {
  0, 0, 0, 0, 0, 0, 0, _BIT_MASK(sym_k_XmRendition_object) |
  0, 0, 0, 0, 0};

/* sym_k_XmNfontFoundry_arg */
static unsigned char arg_class_vec305[] =
  {
  0, 0, 0, 0, 0, 0, 0, _BIT_MASK(sym_k_XmRendition_object) |
  0, 0, 0, 0, 0};

/* sym_k_XmNfontList_arg */
static unsigned char arg_class_vec306[] =
  {
  _BIT_MASK(sym_k_DtMenuButton_object) |
  0, _BIT_MASK(sym_k_XmCascadeButton_object) |
  _BIT_MASK(sym_k_XmCascadeButtonGadget_object) |
  0, _BIT_MASK(sym_k_XmColorSelector_object) |
  _BIT_MASK(sym_k_XmComboBox_object) |
  _BIT_MASK(sym_k_XmDataField_object) |
  0, _BIT_MASK(sym_k_XmDrawnButton_object) |
  _BIT_MASK(sym_k_XmDropDown_object) |
  _BIT_MASK(sym_k_XmFontSelector_object) |
  0, _BIT_MASK(sym_k_XmIconButton_object) |
  _BIT_MASK(sym_k_XmIconGadget_object) |
  _BIT_MASK(sym_k_XmLabel_object) |
  0, _BIT_MASK(sym_k_XmLabelGadget_object) |
  _BIT_MASK(sym_k_XmList_object) |
  _BIT_MASK(sym_k_XmMultiList_object) |
  0, 0, _BIT_MASK(sym_k_XmPushButton_object) |
  _BIT_MASK(sym_k_XmPushButtonGadget_object) |
  _BIT_MASK(sym_k_XmScale_object) |
  0, _BIT_MASK(sym_k_XmScrolledList_object) |
  _BIT_MASK(sym_k_XmScrolledText_object) |
  0, _BIT_MASK(sym_k_XmTabBox_object) |
  _BIT_MASK(sym_k_XmTabStack_object) |
  _BIT_MASK(sym_k_XmTearOffButton_object) |
  0, _BIT_MASK(sym_k_XmText_object) |
  _BIT_MASK(sym_k_XmTextField_object) |
  _BIT_MASK(sym_k_XmToggleButton_object) |
  _BIT_MASK(sym_k_XmToggleButtonGadget_object) |
  0, 0};

/* sym_k_XmNfontName_arg */
static unsigned char arg_class_vec307[] =
  {
  0, 0, 0, 0, 0, 0, 0, _BIT_MASK(sym_k_XmRendition_object) |
  0, 0, 0, 0, 0};

/* sym_k_XmNfontSize_arg */
static unsigned char arg_class_vec308[] =
  {
  0, 0, 0, 0, 0, 0, 0, _BIT_MASK(sym_k_XmRendition_object) |
  0, 0, 0, 0, 0};

/* sym_k_XmNfontStyle_arg */
static unsigned char arg_class_vec309[] =
  {
  0, 0, 0, 0, 0, 0, 0, _BIT_MASK(sym_k_XmRendition_object) |
  0, 0, 0, 0, 0};

/* sym_k_XmNfontType_arg */
static unsigned char arg_class_vec310[] =
  {
  0, 0, 0, 0, 0, 0, 0, _BIT_MASK(sym_k_XmRendition_object) |
  0, 0, 0, 0, 0};

/* sym_k_XmNforeground_arg */
static unsigned char arg_class_vec311[] =
  {
  _BIT_MASK(sym_k_DtEditor_object) |
  _BIT_MASK(sym_k_DtHelpDialog_object) |
  _BIT_MASK(sym_k_DtHelpQuickDialog_object) |
  _BIT_MASK(sym_k_DtMenuButton_object) |
  _BIT_MASK(sym_k_DtPrintSetupBox_object) |
  _BIT_MASK(sym_k_DtPrintSetupDialog_object) |
  _BIT_MASK(sym_k_DtTerm_object) |
  0, _BIT_MASK(sym_k_DtTermPrimitive_object) |
  _BIT_MASK(sym_k_XmArrowButton_object) |
  _BIT_MASK(sym_k_XmBulletinBoard_object) |
  _BIT_MASK(sym_k_XmBulletinBoardDialog_object) |
  _BIT_MASK(sym_k_XmButtonBox_object) |
  _BIT_MASK(sym_k_XmCascadeButton_object) |
  0, _BIT_MASK(sym_k_XmCheckBox_object) |
  _BIT_MASK(sym_k_XmColorSelector_object) |
  _BIT_MASK(sym_k_XmColumn_object) |
  _BIT_MASK(sym_k_XmComboBox_object) |
  _BIT_MASK(sym_k_XmCommand_object) |
  _BIT_MASK(sym_k_XmCommandDialog_object) |
  _BIT_MASK(sym_k_XmContainer_object) |
  _BIT_MASK(sym_k_XmDataField_object) |
  0, _BIT_MASK(sym_k_XmDrawingArea_object) |
  _BIT_MASK(sym_k_XmDrawnButton_object) |
  _BIT_MASK(sym_k_XmDropDown_object) |
  _BIT_MASK(sym_k_XmErrorDialog_object) |
  _BIT_MASK(sym_k_XmFileSelectionBox_object) |
  _BIT_MASK(sym_k_XmFileSelectionDialog_object) |
  _BIT_MASK(sym_k_XmFontSelector_object) |
  0, _BIT_MASK(sym_k_XmForm_object) |
  _BIT_MASK(sym_k_XmFormDialog_object) |
  _BIT_MASK(sym_k_XmFrame_object) |
  _BIT_MASK(sym_k_XmIconBox_object) |
  _BIT_MASK(sym_k_XmIconButton_object) |
  _BIT_MASK(sym_k_XmInformationDialog_object) |
  _BIT_MASK(sym_k_XmLabel_object) |
  0, _BIT_MASK(sym_k_XmList_object) |
  _BIT_MASK(sym_k_XmMainWindow_object) |
  _BIT_MASK(sym_k_XmMenuBar_object) |
  _BIT_MASK(sym_k_XmMessageBox_object) |
  _BIT_MASK(sym_k_XmMessageDialog_object) |
  _BIT_MASK(sym_k_XmMultiList_object) |
  0, _BIT_MASK(sym_k_XmNotebook_object) |
  _BIT_MASK(sym_k_XmOptionMenu_object) |
  _BIT_MASK(sym_k_XmOutline_object) |
  _BIT_MASK(sym_k_XmPaned_object) |
  _BIT_MASK(sym_k_XmPanedWindow_object) |
  _BIT_MASK(sym_k_XmPopupMenu_object) |
  _BIT_MASK(sym_k_XmPromptDialog_object) |
  _BIT_MASK(sym_k_XmPulldownMenu_object) |
  0, _BIT_MASK(sym_k_XmPushButton_object) |
  _BIT_MASK(sym_k_XmQuestionDialog_object) |
  _BIT_MASK(sym_k_XmRadioBox_object) |
  _BIT_MASK(sym_k_XmRowColumn_object) |
  _BIT_MASK(sym_k_XmScale_object) |
  0, _BIT_MASK(sym_k_XmScrollBar_object) |
  _BIT_MASK(sym_k_XmScrolledList_object) |
  _BIT_MASK(sym_k_XmScrolledText_object) |
  _BIT_MASK(sym_k_XmScrolledWindow_object) |
  _BIT_MASK(sym_k_XmSelectionBox_object) |
  _BIT_MASK(sym_k_XmSelectionDialog_object) |
  _BIT_MASK(sym_k_XmSeparator_object) |
  0, _BIT_MASK(sym_k_XmSimpleSpinBox_object) |
  _BIT_MASK(sym_k_XmSpinBox_object) |
  _BIT_MASK(sym_k_XmTabBox_object) |
  _BIT_MASK(sym_k_XmTabStack_object) |
  _BIT_MASK(sym_k_XmTearOffButton_object) |
  _BIT_MASK(sym_k_XmTemplateDialog_object) |
  0, _BIT_MASK(sym_k_XmText_object) |
  _BIT_MASK(sym_k_XmTextField_object) |
  _BIT_MASK(sym_k_XmToggleButton_object) |
  _BIT_MASK(sym_k_XmTree_object) |
  _BIT_MASK(sym_k_XmWarningDialog_object) |
  _BIT_MASK(sym_k_XmWorkArea_object) |
  _BIT_MASK(sym_k_XmWorkingDialog_object) |
  0, 0};

/* sym_k_XmNforegroundThreshold_arg */
static unsigned char arg_class_vec312[] =
  {
  _BIT_MASK(sym_k_DtHelpDialog_object) |
  _BIT_MASK(sym_k_DtHelpQuickDialog_object) |
  _BIT_MASK(sym_k_DtPrintSetupDialog_object) |
  0, _BIT_MASK(sym_k_XmBulletinBoardDialog_object) |
  0, _BIT_MASK(sym_k_XmCommandDialog_object) |
  0, _BIT_MASK(sym_k_XmDialogShell_object) |
  _BIT_MASK(sym_k_XmErrorDialog_object) |
  _BIT_MASK(sym_k_XmFileSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmFormDialog_object) |
  _BIT_MASK(sym_k_XmInformationDialog_object) |
  0, _BIT_MASK(sym_k_XmMessageDialog_object) |
  0, _BIT_MASK(sym_k_XmPromptDialog_object) |
  0, _BIT_MASK(sym_k_XmQuestionDialog_object) |
  0, _BIT_MASK(sym_k_XmSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmTemplateDialog_object) |
  0, _BIT_MASK(sym_k_XmWarningDialog_object) |
  _BIT_MASK(sym_k_XmWorkingDialog_object) |
  0, 0};

/* sym_k_XmNfractionBase_arg */
static unsigned char arg_class_vec313[] =
  {
  _BIT_MASK(sym_k_DtEditor_object) |
  0, 0, 0, 0, _BIT_MASK(sym_k_XmForm_object) |
  _BIT_MASK(sym_k_XmFormDialog_object) |
  0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_XmNframeBackground_arg */
static unsigned char arg_class_vec314[] =
  {
  0, 0, 0, 0, 0, 0, _BIT_MASK(sym_k_XmNotebook_object) |
  0, 0, 0, 0, 0, 0};

/* sym_k_XmNframeChildType_arg */
static unsigned char arg_class_vec315[] =
  {
  0, 0, 0, 0, _BIT_MASK(sym_k_XmFrame_object) |
  0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_XmNframeShadowThickness_arg */
static unsigned char arg_class_vec316[] =
  {
  0, 0, 0, 0, 0, 0, _BIT_MASK(sym_k_XmNotebook_object) |
  0, 0, 0, 0, 0, 0};

/* sym_k_XmNfreeTabPixmap_arg */
static unsigned char arg_class_vec317[] =
  {
  0, 0, 0, 0, 0, 0, 0, 0, 0, _BIT_MASK(sym_k_XmTabStack_object) |
  0, 0, 0};

/* sym_k_XmNgeometry_arg */
static unsigned char arg_class_vec318[] =
  {
  _BIT_MASK(sym_k_DtHelpDialog_object) |
  _BIT_MASK(sym_k_DtHelpQuickDialog_object) |
  _BIT_MASK(sym_k_DtPrintSetupDialog_object) |
  0, _BIT_MASK(sym_k_XmBulletinBoardDialog_object) |
  0, _BIT_MASK(sym_k_XmCommandDialog_object) |
  0, _BIT_MASK(sym_k_XmDialogShell_object) |
  _BIT_MASK(sym_k_XmErrorDialog_object) |
  _BIT_MASK(sym_k_XmFileSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmFormDialog_object) |
  _BIT_MASK(sym_k_XmInformationDialog_object) |
  0, _BIT_MASK(sym_k_XmMenuShell_object) |
  _BIT_MASK(sym_k_XmMessageDialog_object) |
  0, _BIT_MASK(sym_k_XmPopupMenu_object) |
  _BIT_MASK(sym_k_XmPromptDialog_object) |
  _BIT_MASK(sym_k_XmPulldownMenu_object) |
  0, _BIT_MASK(sym_k_XmQuestionDialog_object) |
  0, _BIT_MASK(sym_k_XmSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmTemplateDialog_object) |
  0, _BIT_MASK(sym_k_XmWarningDialog_object) |
  _BIT_MASK(sym_k_XmWorkingDialog_object) |
  0, 0};

/* sym_k_XmNgreenSliderLabel_arg */
static unsigned char arg_class_vec319[] =
  {
  0, 0, _BIT_MASK(sym_k_XmColorSelector_object) |
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_XmNheight_arg */
static unsigned char arg_class_vec320[] =
  {
  _BIT_MASK(sym_k_DtEditor_object) |
  _BIT_MASK(sym_k_DtHelpDialog_object) |
  _BIT_MASK(sym_k_DtHelpQuickDialog_object) |
  _BIT_MASK(sym_k_DtMenuButton_object) |
  _BIT_MASK(sym_k_DtPrintSetupBox_object) |
  _BIT_MASK(sym_k_DtPrintSetupDialog_object) |
  _BIT_MASK(sym_k_DtTerm_object) |
  0, _BIT_MASK(sym_k_DtTermPrimitive_object) |
  _BIT_MASK(sym_k_XmArrowButton_object) |
  _BIT_MASK(sym_k_XmArrowButtonGadget_object) |
  _BIT_MASK(sym_k_XmBulletinBoard_object) |
  _BIT_MASK(sym_k_XmBulletinBoardDialog_object) |
  _BIT_MASK(sym_k_XmButtonBox_object) |
  _BIT_MASK(sym_k_XmCascadeButton_object) |
  _BIT_MASK(sym_k_XmCascadeButtonGadget_object) |
  0, _BIT_MASK(sym_k_XmCheckBox_object) |
  _BIT_MASK(sym_k_XmColorSelector_object) |
  _BIT_MASK(sym_k_XmColumn_object) |
  _BIT_MASK(sym_k_XmComboBox_object) |
  _BIT_MASK(sym_k_XmCommand_object) |
  _BIT_MASK(sym_k_XmCommandDialog_object) |
  _BIT_MASK(sym_k_XmContainer_object) |
  _BIT_MASK(sym_k_XmDataField_object) |
  0, _BIT_MASK(sym_k_XmDialogShell_object) |
  _BIT_MASK(sym_k_XmDrawingArea_object) |
  _BIT_MASK(sym_k_XmDrawnButton_object) |
  _BIT_MASK(sym_k_XmDropDown_object) |
  _BIT_MASK(sym_k_XmErrorDialog_object) |
  _BIT_MASK(sym_k_XmFileSelectionBox_object) |
  _BIT_MASK(sym_k_XmFileSelectionDialog_object) |
  _BIT_MASK(sym_k_XmFontSelector_object) |
  0, _BIT_MASK(sym_k_XmForm_object) |
  _BIT_MASK(sym_k_XmFormDialog_object) |
  _BIT_MASK(sym_k_XmFrame_object) |
  _BIT_MASK(sym_k_XmIconBox_object) |
  _BIT_MASK(sym_k_XmIconButton_object) |
  _BIT_MASK(sym_k_XmIconGadget_object) |
  _BIT_MASK(sym_k_XmInformationDialog_object) |
  _BIT_MASK(sym_k_XmLabel_object) |
  0, _BIT_MASK(sym_k_XmLabelGadget_object) |
  _BIT_MASK(sym_k_XmList_object) |
  _BIT_MASK(sym_k_XmMainWindow_object) |
  _BIT_MASK(sym_k_XmMenuBar_object) |
  _BIT_MASK(sym_k_XmMenuShell_object) |
  _BIT_MASK(sym_k_XmMessageBox_object) |
  _BIT_MASK(sym_k_XmMessageDialog_object) |
  _BIT_MASK(sym_k_XmMultiList_object) |
  0, _BIT_MASK(sym_k_XmNotebook_object) |
  _BIT_MASK(sym_k_XmOptionMenu_object) |
  _BIT_MASK(sym_k_XmOutline_object) |
  _BIT_MASK(sym_k_XmPaned_object) |
  _BIT_MASK(sym_k_XmPanedWindow_object) |
  _BIT_MASK(sym_k_XmPopupMenu_object) |
  _BIT_MASK(sym_k_XmPromptDialog_object) |
  _BIT_MASK(sym_k_XmPulldownMenu_object) |
  0, _BIT_MASK(sym_k_XmPushButton_object) |
  _BIT_MASK(sym_k_XmPushButtonGadget_object) |
  _BIT_MASK(sym_k_XmQuestionDialog_object) |
  _BIT_MASK(sym_k_XmRadioBox_object) |
  _BIT_MASK(sym_k_XmRowColumn_object) |
  _BIT_MASK(sym_k_XmScale_object) |
  0, _BIT_MASK(sym_k_XmScrollBar_object) |
  _BIT_MASK(sym_k_XmScrolledList_object) |
  _BIT_MASK(sym_k_XmScrolledText_object) |
  _BIT_MASK(sym_k_XmScrolledWindow_object) |
  _BIT_MASK(sym_k_XmSelectionBox_object) |
  _BIT_MASK(sym_k_XmSelectionDialog_object) |
  _BIT_MASK(sym_k_XmSeparator_object) |
  _BIT_MASK(sym_k_XmSeparatorGadget_object) |
  0, _BIT_MASK(sym_k_XmSimpleSpinBox_object) |
  _BIT_MASK(sym_k_XmSpinBox_object) |
  _BIT_MASK(sym_k_XmTabBox_object) |
  _BIT_MASK(sym_k_XmTabStack_object) |
  _BIT_MASK(sym_k_XmTearOffButton_object) |
  _BIT_MASK(sym_k_XmTemplateDialog_object) |
  0, _BIT_MASK(sym_k_XmText_object) |
  _BIT_MASK(sym_k_XmTextField_object) |
  _BIT_MASK(sym_k_XmToggleButton_object) |
  _BIT_MASK(sym_k_XmToggleButtonGadget_object) |
  _BIT_MASK(sym_k_XmTree_object) |
  _BIT_MASK(sym_k_XmWarningDialog_object) |
  _BIT_MASK(sym_k_XmWorkArea_object) |
  _BIT_MASK(sym_k_XmWorkingDialog_object) |
  0, 0};

/* sym_k_XmNheightInc_arg */
static unsigned char arg_class_vec321[] =
  {
  _BIT_MASK(sym_k_DtHelpDialog_object) |
  _BIT_MASK(sym_k_DtHelpQuickDialog_object) |
  _BIT_MASK(sym_k_DtPrintSetupDialog_object) |
  0, _BIT_MASK(sym_k_XmBulletinBoardDialog_object) |
  0, _BIT_MASK(sym_k_XmCommandDialog_object) |
  0, _BIT_MASK(sym_k_XmDialogShell_object) |
  _BIT_MASK(sym_k_XmErrorDialog_object) |
  _BIT_MASK(sym_k_XmFileSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmFormDialog_object) |
  _BIT_MASK(sym_k_XmInformationDialog_object) |
  0, _BIT_MASK(sym_k_XmMessageDialog_object) |
  0, _BIT_MASK(sym_k_XmPromptDialog_object) |
  0, _BIT_MASK(sym_k_XmQuestionDialog_object) |
  0, _BIT_MASK(sym_k_XmSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmTemplateDialog_object) |
  0, _BIT_MASK(sym_k_XmWarningDialog_object) |
  _BIT_MASK(sym_k_XmWorkingDialog_object) |
  0, 0};

/* sym_k_XmNhelpLabelString_arg */
static unsigned char arg_class_vec322[] =
  {
  0, 0, 0, _BIT_MASK(sym_k_XmErrorDialog_object) |
  _BIT_MASK(sym_k_XmFileSelectionBox_object) |
  _BIT_MASK(sym_k_XmFileSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmInformationDialog_object) |
  0, _BIT_MASK(sym_k_XmMessageBox_object) |
  _BIT_MASK(sym_k_XmMessageDialog_object) |
  0, _BIT_MASK(sym_k_XmPromptDialog_object) |
  0, _BIT_MASK(sym_k_XmQuestionDialog_object) |
  0, _BIT_MASK(sym_k_XmSelectionBox_object) |
  _BIT_MASK(sym_k_XmSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmTemplateDialog_object) |
  0, _BIT_MASK(sym_k_XmWarningDialog_object) |
  _BIT_MASK(sym_k_XmWorkingDialog_object) |
  0, 0};

/* sym_k_XmNhighlightColor_arg */
static unsigned char arg_class_vec323[] =
  {
  _BIT_MASK(sym_k_DtEditor_object) |
  _BIT_MASK(sym_k_DtHelpDialog_object) |
  _BIT_MASK(sym_k_DtHelpQuickDialog_object) |
  _BIT_MASK(sym_k_DtMenuButton_object) |
  _BIT_MASK(sym_k_DtPrintSetupBox_object) |
  _BIT_MASK(sym_k_DtPrintSetupDialog_object) |
  _BIT_MASK(sym_k_DtTerm_object) |
  0, _BIT_MASK(sym_k_DtTermPrimitive_object) |
  _BIT_MASK(sym_k_XmArrowButton_object) |
  _BIT_MASK(sym_k_XmBulletinBoard_object) |
  _BIT_MASK(sym_k_XmBulletinBoardDialog_object) |
  _BIT_MASK(sym_k_XmButtonBox_object) |
  _BIT_MASK(sym_k_XmCascadeButton_object) |
  0, _BIT_MASK(sym_k_XmCheckBox_object) |
  _BIT_MASK(sym_k_XmColorSelector_object) |
  _BIT_MASK(sym_k_XmColumn_object) |
  _BIT_MASK(sym_k_XmComboBox_object) |
  _BIT_MASK(sym_k_XmCommand_object) |
  _BIT_MASK(sym_k_XmCommandDialog_object) |
  _BIT_MASK(sym_k_XmContainer_object) |
  _BIT_MASK(sym_k_XmDataField_object) |
  0, _BIT_MASK(sym_k_XmDrawingArea_object) |
  _BIT_MASK(sym_k_XmDrawnButton_object) |
  _BIT_MASK(sym_k_XmDropDown_object) |
  _BIT_MASK(sym_k_XmErrorDialog_object) |
  _BIT_MASK(sym_k_XmFileSelectionBox_object) |
  _BIT_MASK(sym_k_XmFileSelectionDialog_object) |
  _BIT_MASK(sym_k_XmFontSelector_object) |
  0, _BIT_MASK(sym_k_XmForm_object) |
  _BIT_MASK(sym_k_XmFormDialog_object) |
  _BIT_MASK(sym_k_XmFrame_object) |
  _BIT_MASK(sym_k_XmIconBox_object) |
  _BIT_MASK(sym_k_XmIconButton_object) |
  _BIT_MASK(sym_k_XmInformationDialog_object) |
  _BIT_MASK(sym_k_XmLabel_object) |
  0, _BIT_MASK(sym_k_XmList_object) |
  _BIT_MASK(sym_k_XmMainWindow_object) |
  _BIT_MASK(sym_k_XmMenuBar_object) |
  _BIT_MASK(sym_k_XmMessageBox_object) |
  _BIT_MASK(sym_k_XmMessageDialog_object) |
  _BIT_MASK(sym_k_XmMultiList_object) |
  0, _BIT_MASK(sym_k_XmNotebook_object) |
  _BIT_MASK(sym_k_XmOptionMenu_object) |
  _BIT_MASK(sym_k_XmOutline_object) |
  _BIT_MASK(sym_k_XmPaned_object) |
  _BIT_MASK(sym_k_XmPanedWindow_object) |
  _BIT_MASK(sym_k_XmPopupMenu_object) |
  _BIT_MASK(sym_k_XmPromptDialog_object) |
  _BIT_MASK(sym_k_XmPulldownMenu_object) |
  0, _BIT_MASK(sym_k_XmPushButton_object) |
  _BIT_MASK(sym_k_XmQuestionDialog_object) |
  _BIT_MASK(sym_k_XmRadioBox_object) |
  _BIT_MASK(sym_k_XmRowColumn_object) |
  _BIT_MASK(sym_k_XmScale_object) |
  0, _BIT_MASK(sym_k_XmScrollBar_object) |
  _BIT_MASK(sym_k_XmScrolledList_object) |
  _BIT_MASK(sym_k_XmScrolledText_object) |
  _BIT_MASK(sym_k_XmScrolledWindow_object) |
  _BIT_MASK(sym_k_XmSelectionBox_object) |
  _BIT_MASK(sym_k_XmSelectionDialog_object) |
  _BIT_MASK(sym_k_XmSeparator_object) |
  0, _BIT_MASK(sym_k_XmSimpleSpinBox_object) |
  _BIT_MASK(sym_k_XmSpinBox_object) |
  _BIT_MASK(sym_k_XmTabBox_object) |
  _BIT_MASK(sym_k_XmTabStack_object) |
  _BIT_MASK(sym_k_XmTearOffButton_object) |
  _BIT_MASK(sym_k_XmTemplateDialog_object) |
  0, _BIT_MASK(sym_k_XmText_object) |
  _BIT_MASK(sym_k_XmTextField_object) |
  _BIT_MASK(sym_k_XmToggleButton_object) |
  _BIT_MASK(sym_k_XmTree_object) |
  _BIT_MASK(sym_k_XmWarningDialog_object) |
  _BIT_MASK(sym_k_XmWorkArea_object) |
  _BIT_MASK(sym_k_XmWorkingDialog_object) |
  0, 0};

/* sym_k_XmNhighlightOnEnter_arg */
static unsigned char arg_class_vec324[] =
  {
  _BIT_MASK(sym_k_DtMenuButton_object) |
  _BIT_MASK(sym_k_DtTerm_object) |
  0, _BIT_MASK(sym_k_DtTermPrimitive_object) |
  _BIT_MASK(sym_k_XmArrowButton_object) |
  _BIT_MASK(sym_k_XmArrowButtonGadget_object) |
  _BIT_MASK(sym_k_XmCascadeButton_object) |
  _BIT_MASK(sym_k_XmCascadeButtonGadget_object) |
  0, _BIT_MASK(sym_k_XmDataField_object) |
  0, _BIT_MASK(sym_k_XmDrawnButton_object) |
  0, _BIT_MASK(sym_k_XmIconButton_object) |
  _BIT_MASK(sym_k_XmIconGadget_object) |
  _BIT_MASK(sym_k_XmLabel_object) |
  0, _BIT_MASK(sym_k_XmLabelGadget_object) |
  _BIT_MASK(sym_k_XmList_object) |
  0, 0, _BIT_MASK(sym_k_XmPushButton_object) |
  _BIT_MASK(sym_k_XmPushButtonGadget_object) |
  _BIT_MASK(sym_k_XmScale_object) |
  0, _BIT_MASK(sym_k_XmScrollBar_object) |
  _BIT_MASK(sym_k_XmScrolledList_object) |
  _BIT_MASK(sym_k_XmScrolledText_object) |
  _BIT_MASK(sym_k_XmSeparator_object) |
  _BIT_MASK(sym_k_XmSeparatorGadget_object) |
  0, _BIT_MASK(sym_k_XmTabBox_object) |
  _BIT_MASK(sym_k_XmTearOffButton_object) |
  0, _BIT_MASK(sym_k_XmText_object) |
  _BIT_MASK(sym_k_XmTextField_object) |
  _BIT_MASK(sym_k_XmToggleButton_object) |
  _BIT_MASK(sym_k_XmToggleButtonGadget_object) |
  0, 0};

/* sym_k_XmNhighlightPixmap_arg */
static unsigned char arg_class_vec325[] =
  {
  _BIT_MASK(sym_k_DtEditor_object) |
  _BIT_MASK(sym_k_DtHelpDialog_object) |
  _BIT_MASK(sym_k_DtHelpQuickDialog_object) |
  _BIT_MASK(sym_k_DtMenuButton_object) |
  _BIT_MASK(sym_k_DtPrintSetupBox_object) |
  _BIT_MASK(sym_k_DtPrintSetupDialog_object) |
  _BIT_MASK(sym_k_DtTerm_object) |
  0, _BIT_MASK(sym_k_DtTermPrimitive_object) |
  _BIT_MASK(sym_k_XmArrowButton_object) |
  _BIT_MASK(sym_k_XmBulletinBoard_object) |
  _BIT_MASK(sym_k_XmBulletinBoardDialog_object) |
  _BIT_MASK(sym_k_XmButtonBox_object) |
  _BIT_MASK(sym_k_XmCascadeButton_object) |
  0, _BIT_MASK(sym_k_XmCheckBox_object) |
  _BIT_MASK(sym_k_XmColorSelector_object) |
  _BIT_MASK(sym_k_XmColumn_object) |
  _BIT_MASK(sym_k_XmComboBox_object) |
  _BIT_MASK(sym_k_XmCommand_object) |
  _BIT_MASK(sym_k_XmCommandDialog_object) |
  _BIT_MASK(sym_k_XmContainer_object) |
  _BIT_MASK(sym_k_XmDataField_object) |
  0, _BIT_MASK(sym_k_XmDrawingArea_object) |
  _BIT_MASK(sym_k_XmDrawnButton_object) |
  _BIT_MASK(sym_k_XmDropDown_object) |
  _BIT_MASK(sym_k_XmErrorDialog_object) |
  _BIT_MASK(sym_k_XmFileSelectionBox_object) |
  _BIT_MASK(sym_k_XmFileSelectionDialog_object) |
  _BIT_MASK(sym_k_XmFontSelector_object) |
  0, _BIT_MASK(sym_k_XmForm_object) |
  _BIT_MASK(sym_k_XmFormDialog_object) |
  _BIT_MASK(sym_k_XmFrame_object) |
  _BIT_MASK(sym_k_XmIconBox_object) |
  _BIT_MASK(sym_k_XmIconButton_object) |
  _BIT_MASK(sym_k_XmInformationDialog_object) |
  _BIT_MASK(sym_k_XmLabel_object) |
  0, _BIT_MASK(sym_k_XmList_object) |
  _BIT_MASK(sym_k_XmMainWindow_object) |
  _BIT_MASK(sym_k_XmMenuBar_object) |
  _BIT_MASK(sym_k_XmMessageBox_object) |
  _BIT_MASK(sym_k_XmMessageDialog_object) |
  _BIT_MASK(sym_k_XmMultiList_object) |
  0, _BIT_MASK(sym_k_XmNotebook_object) |
  _BIT_MASK(sym_k_XmOptionMenu_object) |
  _BIT_MASK(sym_k_XmOutline_object) |
  _BIT_MASK(sym_k_XmPaned_object) |
  _BIT_MASK(sym_k_XmPanedWindow_object) |
  _BIT_MASK(sym_k_XmPopupMenu_object) |
  _BIT_MASK(sym_k_XmPromptDialog_object) |
  _BIT_MASK(sym_k_XmPulldownMenu_object) |
  0, _BIT_MASK(sym_k_XmPushButton_object) |
  _BIT_MASK(sym_k_XmQuestionDialog_object) |
  _BIT_MASK(sym_k_XmRadioBox_object) |
  _BIT_MASK(sym_k_XmRowColumn_object) |
  _BIT_MASK(sym_k_XmScale_object) |
  0, _BIT_MASK(sym_k_XmScrollBar_object) |
  _BIT_MASK(sym_k_XmScrolledList_object) |
  _BIT_MASK(sym_k_XmScrolledText_object) |
  _BIT_MASK(sym_k_XmScrolledWindow_object) |
  _BIT_MASK(sym_k_XmSelectionBox_object) |
  _BIT_MASK(sym_k_XmSelectionDialog_object) |
  _BIT_MASK(sym_k_XmSeparator_object) |
  0, _BIT_MASK(sym_k_XmSimpleSpinBox_object) |
  _BIT_MASK(sym_k_XmSpinBox_object) |
  _BIT_MASK(sym_k_XmTabBox_object) |
  _BIT_MASK(sym_k_XmTabStack_object) |
  _BIT_MASK(sym_k_XmTearOffButton_object) |
  _BIT_MASK(sym_k_XmTemplateDialog_object) |
  0, _BIT_MASK(sym_k_XmText_object) |
  _BIT_MASK(sym_k_XmTextField_object) |
  _BIT_MASK(sym_k_XmToggleButton_object) |
  _BIT_MASK(sym_k_XmTree_object) |
  _BIT_MASK(sym_k_XmWarningDialog_object) |
  _BIT_MASK(sym_k_XmWorkArea_object) |
  _BIT_MASK(sym_k_XmWorkingDialog_object) |
  0, 0};

/* sym_k_XmNhighlightThickness_arg */
static unsigned char arg_class_vec326[] =
  {
  _BIT_MASK(sym_k_DtMenuButton_object) |
  _BIT_MASK(sym_k_DtTerm_object) |
  0, _BIT_MASK(sym_k_DtTermPrimitive_object) |
  _BIT_MASK(sym_k_XmArrowButton_object) |
  _BIT_MASK(sym_k_XmArrowButtonGadget_object) |
  _BIT_MASK(sym_k_XmCascadeButton_object) |
  _BIT_MASK(sym_k_XmCascadeButtonGadget_object) |
  0, _BIT_MASK(sym_k_XmComboBox_object) |
  _BIT_MASK(sym_k_XmDataField_object) |
  0, _BIT_MASK(sym_k_XmDrawnButton_object) |
  0, _BIT_MASK(sym_k_XmIconButton_object) |
  _BIT_MASK(sym_k_XmIconGadget_object) |
  _BIT_MASK(sym_k_XmLabel_object) |
  0, _BIT_MASK(sym_k_XmLabelGadget_object) |
  _BIT_MASK(sym_k_XmList_object) |
  0, 0, _BIT_MASK(sym_k_XmPushButton_object) |
  _BIT_MASK(sym_k_XmPushButtonGadget_object) |
  _BIT_MASK(sym_k_XmScale_object) |
  0, _BIT_MASK(sym_k_XmScrollBar_object) |
  _BIT_MASK(sym_k_XmScrolledList_object) |
  _BIT_MASK(sym_k_XmScrolledText_object) |
  _BIT_MASK(sym_k_XmSeparator_object) |
  _BIT_MASK(sym_k_XmSeparatorGadget_object) |
  0, _BIT_MASK(sym_k_XmTabBox_object) |
  _BIT_MASK(sym_k_XmTabStack_object) |
  _BIT_MASK(sym_k_XmTearOffButton_object) |
  0, _BIT_MASK(sym_k_XmText_object) |
  _BIT_MASK(sym_k_XmTextField_object) |
  _BIT_MASK(sym_k_XmToggleButton_object) |
  _BIT_MASK(sym_k_XmToggleButtonGadget_object) |
  0, 0};

/* sym_k_XmNhistoryItemCount_arg */
static unsigned char arg_class_vec327[] =
  {
  0, 0, _BIT_MASK(sym_k_XmCommand_object) |
  _BIT_MASK(sym_k_XmCommandDialog_object) |
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_XmNhistoryItems_arg */
static unsigned char arg_class_vec328[] =
  {
  0, 0, _BIT_MASK(sym_k_XmCommand_object) |
  _BIT_MASK(sym_k_XmCommandDialog_object) |
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_XmNhistoryMaxItems_arg */
static unsigned char arg_class_vec329[] =
  {
  0, 0, _BIT_MASK(sym_k_XmCommand_object) |
  _BIT_MASK(sym_k_XmCommandDialog_object) |
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_XmNhistoryVisibleItemCount_arg */
static unsigned char arg_class_vec330[] =
  {
  0, 0, _BIT_MASK(sym_k_XmCommand_object) |
  _BIT_MASK(sym_k_XmCommandDialog_object) |
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_XmNhorizontalDelta_arg */
static unsigned char arg_class_vec331[] =
  {
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, _BIT_MASK(sym_k_XmTree_object) |
  0, 0};

/* sym_k_XmNhorizontalMargin_arg */
static unsigned char arg_class_vec332[] =
  {
  0, 0, 0, _BIT_MASK(sym_k_XmDropDown_object) |
  0, _BIT_MASK(sym_k_XmIconBox_object) |
  _BIT_MASK(sym_k_XmIconButton_object) |
  0, 0, _BIT_MASK(sym_k_XmOutline_object) |
  0, 0, 0, 0, _BIT_MASK(sym_k_XmTree_object) |
  0, 0};

/* sym_k_XmNhorizontalNodeSpace_arg */
static unsigned char arg_class_vec333[] =
  {
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, _BIT_MASK(sym_k_XmTree_object) |
  0, 0};

/* sym_k_XmNhorizontalScrollBar_arg */
static unsigned char arg_class_vec334[] =
  {
  0, 0, 0, 0, 0, _BIT_MASK(sym_k_XmMainWindow_object) |
  _BIT_MASK(sym_k_XmMultiList_object) |
  0, 0, 0, _BIT_MASK(sym_k_XmScrolledList_object) |
  _BIT_MASK(sym_k_XmScrolledText_object) |
  _BIT_MASK(sym_k_XmScrolledWindow_object) |
  0, 0, 0, 0};

/* sym_k_XmNhorizontalSpacing_arg */
static unsigned char arg_class_vec335[] =
  {
  _BIT_MASK(sym_k_DtEditor_object) |
  0, 0, 0, 0, _BIT_MASK(sym_k_XmForm_object) |
  _BIT_MASK(sym_k_XmFormDialog_object) |
  0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_XmNiconMask_arg */
static unsigned char arg_class_vec336[] =
  {
  _BIT_MASK(sym_k_DtHelpDialog_object) |
  _BIT_MASK(sym_k_DtHelpQuickDialog_object) |
  _BIT_MASK(sym_k_DtPrintSetupDialog_object) |
  0, _BIT_MASK(sym_k_XmBulletinBoardDialog_object) |
  0, _BIT_MASK(sym_k_XmCommandDialog_object) |
  0, _BIT_MASK(sym_k_XmDialogShell_object) |
  _BIT_MASK(sym_k_XmErrorDialog_object) |
  _BIT_MASK(sym_k_XmFileSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmFormDialog_object) |
  _BIT_MASK(sym_k_XmInformationDialog_object) |
  0, _BIT_MASK(sym_k_XmMessageDialog_object) |
  0, _BIT_MASK(sym_k_XmPromptDialog_object) |
  0, _BIT_MASK(sym_k_XmQuestionDialog_object) |
  0, _BIT_MASK(sym_k_XmSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmTemplateDialog_object) |
  0, _BIT_MASK(sym_k_XmWarningDialog_object) |
  _BIT_MASK(sym_k_XmWorkingDialog_object) |
  0, 0};

/* sym_k_XmNiconName_arg */
static unsigned char arg_class_vec337[] =
  {
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_XmNiconNameEncoding_arg */
static unsigned char arg_class_vec338[] =
  {
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_XmNiconPixmap_arg */
static unsigned char arg_class_vec339[] =
  {
  _BIT_MASK(sym_k_DtHelpDialog_object) |
  _BIT_MASK(sym_k_DtHelpQuickDialog_object) |
  _BIT_MASK(sym_k_DtPrintSetupDialog_object) |
  0, _BIT_MASK(sym_k_XmBulletinBoardDialog_object) |
  0, _BIT_MASK(sym_k_XmCommandDialog_object) |
  0, _BIT_MASK(sym_k_XmDialogShell_object) |
  _BIT_MASK(sym_k_XmErrorDialog_object) |
  _BIT_MASK(sym_k_XmFileSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmFormDialog_object) |
  _BIT_MASK(sym_k_XmInformationDialog_object) |
  0, _BIT_MASK(sym_k_XmMessageDialog_object) |
  0, _BIT_MASK(sym_k_XmPromptDialog_object) |
  0, _BIT_MASK(sym_k_XmQuestionDialog_object) |
  0, _BIT_MASK(sym_k_XmSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmTemplateDialog_object) |
  0, _BIT_MASK(sym_k_XmWarningDialog_object) |
  _BIT_MASK(sym_k_XmWorkingDialog_object) |
  0, 0};

/* sym_k_XmNiconPlacement_arg */
static unsigned char arg_class_vec340[] =
  {
  0, 0, 0, 0, _BIT_MASK(sym_k_XmIconButton_object) |
  0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_XmNiconTextPadding_arg */
static unsigned char arg_class_vec341[] =
  {
  0, 0, 0, 0, _BIT_MASK(sym_k_XmIconButton_object) |
  0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_XmNiconWindow_arg */
static unsigned char arg_class_vec342[] =
  {
  _BIT_MASK(sym_k_DtHelpDialog_object) |
  _BIT_MASK(sym_k_DtHelpQuickDialog_object) |
  _BIT_MASK(sym_k_DtPrintSetupDialog_object) |
  0, _BIT_MASK(sym_k_XmBulletinBoardDialog_object) |
  0, _BIT_MASK(sym_k_XmCommandDialog_object) |
  0, _BIT_MASK(sym_k_XmDialogShell_object) |
  _BIT_MASK(sym_k_XmErrorDialog_object) |
  _BIT_MASK(sym_k_XmFileSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmFormDialog_object) |
  _BIT_MASK(sym_k_XmInformationDialog_object) |
  0, _BIT_MASK(sym_k_XmMessageDialog_object) |
  0, _BIT_MASK(sym_k_XmPromptDialog_object) |
  0, _BIT_MASK(sym_k_XmQuestionDialog_object) |
  0, _BIT_MASK(sym_k_XmSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmTemplateDialog_object) |
  0, _BIT_MASK(sym_k_XmWarningDialog_object) |
  _BIT_MASK(sym_k_XmWorkingDialog_object) |
  0, 0};

/* sym_k_XmNiconX_arg */
static unsigned char arg_class_vec343[] =
  {
  _BIT_MASK(sym_k_DtHelpDialog_object) |
  _BIT_MASK(sym_k_DtHelpQuickDialog_object) |
  _BIT_MASK(sym_k_DtPrintSetupDialog_object) |
  0, _BIT_MASK(sym_k_XmBulletinBoardDialog_object) |
  0, _BIT_MASK(sym_k_XmCommandDialog_object) |
  0, _BIT_MASK(sym_k_XmDialogShell_object) |
  _BIT_MASK(sym_k_XmErrorDialog_object) |
  _BIT_MASK(sym_k_XmFileSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmFormDialog_object) |
  _BIT_MASK(sym_k_XmInformationDialog_object) |
  0, _BIT_MASK(sym_k_XmMessageDialog_object) |
  0, _BIT_MASK(sym_k_XmPromptDialog_object) |
  0, _BIT_MASK(sym_k_XmQuestionDialog_object) |
  0, _BIT_MASK(sym_k_XmSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmTemplateDialog_object) |
  0, _BIT_MASK(sym_k_XmWarningDialog_object) |
  _BIT_MASK(sym_k_XmWorkingDialog_object) |
  0, 0};

/* sym_k_XmNiconY_arg */
static unsigned char arg_class_vec344[] =
  {
  _BIT_MASK(sym_k_DtHelpDialog_object) |
  _BIT_MASK(sym_k_DtHelpQuickDialog_object) |
  _BIT_MASK(sym_k_DtPrintSetupDialog_object) |
  0, _BIT_MASK(sym_k_XmBulletinBoardDialog_object) |
  0, _BIT_MASK(sym_k_XmCommandDialog_object) |
  0, _BIT_MASK(sym_k_XmDialogShell_object) |
  _BIT_MASK(sym_k_XmErrorDialog_object) |
  _BIT_MASK(sym_k_XmFileSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmFormDialog_object) |
  _BIT_MASK(sym_k_XmInformationDialog_object) |
  0, _BIT_MASK(sym_k_XmMessageDialog_object) |
  0, _BIT_MASK(sym_k_XmPromptDialog_object) |
  0, _BIT_MASK(sym_k_XmQuestionDialog_object) |
  0, _BIT_MASK(sym_k_XmSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmTemplateDialog_object) |
  0, _BIT_MASK(sym_k_XmWarningDialog_object) |
  _BIT_MASK(sym_k_XmWorkingDialog_object) |
  0, 0};

/* sym_k_XmNiconic_arg */
static unsigned char arg_class_vec345[] =
  {
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_XmNincrement_arg */
static unsigned char arg_class_vec346[] =
  {
  0, 0, 0, 0, 0, 0, 0, 0, _BIT_MASK(sym_k_XmScrollBar_object) |
  0, 0, 0, 0};

/* sym_k_XmNincrementValue_arg */
static unsigned char arg_class_vec347[] =
  {
  0, 0, 0, 0, 0, 0, 0, 0, 0, _BIT_MASK(sym_k_XmSimpleSpinBox_object) |
  _BIT_MASK(sym_k_XmSpinBox_object) |
  0, 0, 0};

/* sym_k_XmNindentSpace_arg */
static unsigned char arg_class_vec348[] =
  {
  0, 0, 0, 0, 0, 0, _BIT_MASK(sym_k_XmOutline_object) |
  0, 0, 0, 0, 0, 0};

/* sym_k_XmNindeterminateInsensitivePixmap_arg */
static unsigned char arg_class_vec349[] =
  {
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, _BIT_MASK(sym_k_XmToggleButton_object) |
  _BIT_MASK(sym_k_XmToggleButtonGadget_object) |
  0, 0};

/* sym_k_XmNindeterminatePixmap_arg */
static unsigned char arg_class_vec350[] =
  {
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, _BIT_MASK(sym_k_XmToggleButton_object) |
  _BIT_MASK(sym_k_XmToggleButtonGadget_object) |
  0, 0};

/* sym_k_XmNindicatorOn_arg */
static unsigned char arg_class_vec351[] =
  {
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, _BIT_MASK(sym_k_XmToggleButton_object) |
  _BIT_MASK(sym_k_XmToggleButtonGadget_object) |
  0, 0};

/* sym_k_XmNindicatorSize_arg */
static unsigned char arg_class_vec352[] =
  {
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, _BIT_MASK(sym_k_XmToggleButton_object) |
  _BIT_MASK(sym_k_XmToggleButtonGadget_object) |
  0, 0};

/* sym_k_XmNindicatorType_arg */
static unsigned char arg_class_vec353[] =
  {
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, _BIT_MASK(sym_k_XmToggleButton_object) |
  _BIT_MASK(sym_k_XmToggleButtonGadget_object) |
  0, 0};

/* sym_k_XmNinitialDelay_arg */
static unsigned char arg_class_vec354[] =
  {
  0, 0, 0, 0, 0, 0, 0, 0, _BIT_MASK(sym_k_XmScrollBar_object) |
  0, _BIT_MASK(sym_k_XmSimpleSpinBox_object) |
  _BIT_MASK(sym_k_XmSpinBox_object) |
  0, 0, 0};

/* sym_k_XmNinitialFocus_arg */
static unsigned char arg_class_vec355[] =
  {
  _BIT_MASK(sym_k_DtEditor_object) |
  _BIT_MASK(sym_k_DtHelpDialog_object) |
  _BIT_MASK(sym_k_DtHelpQuickDialog_object) |
  _BIT_MASK(sym_k_DtPrintSetupBox_object) |
  _BIT_MASK(sym_k_DtPrintSetupDialog_object) |
  0, _BIT_MASK(sym_k_XmBulletinBoard_object) |
  _BIT_MASK(sym_k_XmBulletinBoardDialog_object) |
  _BIT_MASK(sym_k_XmButtonBox_object) |
  0, _BIT_MASK(sym_k_XmCheckBox_object) |
  _BIT_MASK(sym_k_XmColorSelector_object) |
  _BIT_MASK(sym_k_XmColumn_object) |
  _BIT_MASK(sym_k_XmComboBox_object) |
  _BIT_MASK(sym_k_XmCommand_object) |
  _BIT_MASK(sym_k_XmCommandDialog_object) |
  _BIT_MASK(sym_k_XmContainer_object) |
  0, _BIT_MASK(sym_k_XmDrawingArea_object) |
  _BIT_MASK(sym_k_XmDropDown_object) |
  _BIT_MASK(sym_k_XmErrorDialog_object) |
  _BIT_MASK(sym_k_XmFileSelectionBox_object) |
  _BIT_MASK(sym_k_XmFileSelectionDialog_object) |
  _BIT_MASK(sym_k_XmFontSelector_object) |
  0, _BIT_MASK(sym_k_XmForm_object) |
  _BIT_MASK(sym_k_XmFormDialog_object) |
  _BIT_MASK(sym_k_XmFrame_object) |
  _BIT_MASK(sym_k_XmIconBox_object) |
  _BIT_MASK(sym_k_XmInformationDialog_object) |
  0, _BIT_MASK(sym_k_XmMainWindow_object) |
  _BIT_MASK(sym_k_XmMenuBar_object) |
  _BIT_MASK(sym_k_XmMessageBox_object) |
  _BIT_MASK(sym_k_XmMessageDialog_object) |
  _BIT_MASK(sym_k_XmMultiList_object) |
  0, _BIT_MASK(sym_k_XmNotebook_object) |
  _BIT_MASK(sym_k_XmOptionMenu_object) |
  _BIT_MASK(sym_k_XmOutline_object) |
  _BIT_MASK(sym_k_XmPaned_object) |
  _BIT_MASK(sym_k_XmPanedWindow_object) |
  _BIT_MASK(sym_k_XmPopupMenu_object) |
  _BIT_MASK(sym_k_XmPromptDialog_object) |
  _BIT_MASK(sym_k_XmPulldownMenu_object) |
  0, _BIT_MASK(sym_k_XmQuestionDialog_object) |
  _BIT_MASK(sym_k_XmRadioBox_object) |
  _BIT_MASK(sym_k_XmRowColumn_object) |
  _BIT_MASK(sym_k_XmScale_object) |
  0, _BIT_MASK(sym_k_XmScrolledList_object) |
  _BIT_MASK(sym_k_XmScrolledText_object) |
  _BIT_MASK(sym_k_XmScrolledWindow_object) |
  _BIT_MASK(sym_k_XmSelectionBox_object) |
  _BIT_MASK(sym_k_XmSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmSimpleSpinBox_object) |
  _BIT_MASK(sym_k_XmSpinBox_object) |
  _BIT_MASK(sym_k_XmTabStack_object) |
  _BIT_MASK(sym_k_XmTemplateDialog_object) |
  0, _BIT_MASK(sym_k_XmTree_object) |
  _BIT_MASK(sym_k_XmWarningDialog_object) |
  _BIT_MASK(sym_k_XmWorkArea_object) |
  _BIT_MASK(sym_k_XmWorkingDialog_object) |
  0, 0};

/* sym_k_XmNinitialResourcesPersistent_arg */
static unsigned char arg_class_vec356[] =
  {
  _BIT_MASK(sym_k_DtEditor_object) |
  _BIT_MASK(sym_k_DtHelpDialog_object) |
  _BIT_MASK(sym_k_DtHelpQuickDialog_object) |
  _BIT_MASK(sym_k_DtMenuButton_object) |
  _BIT_MASK(sym_k_DtPrintSetupBox_object) |
  _BIT_MASK(sym_k_DtPrintSetupDialog_object) |
  _BIT_MASK(sym_k_DtTerm_object) |
  0, _BIT_MASK(sym_k_DtTermPrimitive_object) |
  _BIT_MASK(sym_k_XmArrowButton_object) |
  _BIT_MASK(sym_k_XmBulletinBoard_object) |
  _BIT_MASK(sym_k_XmBulletinBoardDialog_object) |
  _BIT_MASK(sym_k_XmButtonBox_object) |
  _BIT_MASK(sym_k_XmCascadeButton_object) |
  0, _BIT_MASK(sym_k_XmCheckBox_object) |
  _BIT_MASK(sym_k_XmColorSelector_object) |
  _BIT_MASK(sym_k_XmColumn_object) |
  _BIT_MASK(sym_k_XmComboBox_object) |
  _BIT_MASK(sym_k_XmCommand_object) |
  _BIT_MASK(sym_k_XmCommandDialog_object) |
  _BIT_MASK(sym_k_XmContainer_object) |
  _BIT_MASK(sym_k_XmDataField_object) |
  0, _BIT_MASK(sym_k_XmDialogShell_object) |
  _BIT_MASK(sym_k_XmDrawingArea_object) |
  _BIT_MASK(sym_k_XmDrawnButton_object) |
  _BIT_MASK(sym_k_XmDropDown_object) |
  _BIT_MASK(sym_k_XmErrorDialog_object) |
  _BIT_MASK(sym_k_XmFileSelectionBox_object) |
  _BIT_MASK(sym_k_XmFileSelectionDialog_object) |
  _BIT_MASK(sym_k_XmFontSelector_object) |
  0, _BIT_MASK(sym_k_XmForm_object) |
  _BIT_MASK(sym_k_XmFormDialog_object) |
  _BIT_MASK(sym_k_XmFrame_object) |
  _BIT_MASK(sym_k_XmIconBox_object) |
  _BIT_MASK(sym_k_XmIconButton_object) |
  _BIT_MASK(sym_k_XmInformationDialog_object) |
  _BIT_MASK(sym_k_XmLabel_object) |
  0, _BIT_MASK(sym_k_XmList_object) |
  _BIT_MASK(sym_k_XmMainWindow_object) |
  _BIT_MASK(sym_k_XmMenuBar_object) |
  _BIT_MASK(sym_k_XmMenuShell_object) |
  _BIT_MASK(sym_k_XmMessageBox_object) |
  _BIT_MASK(sym_k_XmMessageDialog_object) |
  _BIT_MASK(sym_k_XmMultiList_object) |
  0, _BIT_MASK(sym_k_XmNotebook_object) |
  _BIT_MASK(sym_k_XmOptionMenu_object) |
  _BIT_MASK(sym_k_XmOutline_object) |
  _BIT_MASK(sym_k_XmPaned_object) |
  _BIT_MASK(sym_k_XmPanedWindow_object) |
  _BIT_MASK(sym_k_XmPopupMenu_object) |
  _BIT_MASK(sym_k_XmPromptDialog_object) |
  _BIT_MASK(sym_k_XmPulldownMenu_object) |
  0, _BIT_MASK(sym_k_XmPushButton_object) |
  _BIT_MASK(sym_k_XmQuestionDialog_object) |
  _BIT_MASK(sym_k_XmRadioBox_object) |
  _BIT_MASK(sym_k_XmRowColumn_object) |
  _BIT_MASK(sym_k_XmScale_object) |
  0, _BIT_MASK(sym_k_XmScrollBar_object) |
  _BIT_MASK(sym_k_XmScrolledList_object) |
  _BIT_MASK(sym_k_XmScrolledText_object) |
  _BIT_MASK(sym_k_XmScrolledWindow_object) |
  _BIT_MASK(sym_k_XmSelectionBox_object) |
  _BIT_MASK(sym_k_XmSelectionDialog_object) |
  _BIT_MASK(sym_k_XmSeparator_object) |
  0, _BIT_MASK(sym_k_XmSimpleSpinBox_object) |
  _BIT_MASK(sym_k_XmSpinBox_object) |
  _BIT_MASK(sym_k_XmTabBox_object) |
  _BIT_MASK(sym_k_XmTabStack_object) |
  _BIT_MASK(sym_k_XmTearOffButton_object) |
  _BIT_MASK(sym_k_XmTemplateDialog_object) |
  0, _BIT_MASK(sym_k_XmText_object) |
  _BIT_MASK(sym_k_XmTextField_object) |
  _BIT_MASK(sym_k_XmToggleButton_object) |
  _BIT_MASK(sym_k_XmTree_object) |
  _BIT_MASK(sym_k_XmWarningDialog_object) |
  _BIT_MASK(sym_k_XmWorkArea_object) |
  _BIT_MASK(sym_k_XmWorkingDialog_object) |
  0, 0};

/* sym_k_XmNinitialState_arg */
static unsigned char arg_class_vec357[] =
  {
  _BIT_MASK(sym_k_DtHelpDialog_object) |
  _BIT_MASK(sym_k_DtHelpQuickDialog_object) |
  _BIT_MASK(sym_k_DtPrintSetupDialog_object) |
  0, _BIT_MASK(sym_k_XmBulletinBoardDialog_object) |
  0, _BIT_MASK(sym_k_XmCommandDialog_object) |
  0, _BIT_MASK(sym_k_XmDialogShell_object) |
  _BIT_MASK(sym_k_XmErrorDialog_object) |
  _BIT_MASK(sym_k_XmFileSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmFormDialog_object) |
  _BIT_MASK(sym_k_XmInformationDialog_object) |
  0, _BIT_MASK(sym_k_XmMessageDialog_object) |
  0, _BIT_MASK(sym_k_XmPromptDialog_object) |
  0, _BIT_MASK(sym_k_XmQuestionDialog_object) |
  0, _BIT_MASK(sym_k_XmSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmTemplateDialog_object) |
  0, _BIT_MASK(sym_k_XmWarningDialog_object) |
  _BIT_MASK(sym_k_XmWorkingDialog_object) |
  0, 0};

/* sym_k_XmNinnerMarginHeight_arg */
static unsigned char arg_class_vec358[] =
  {
  0, 0, 0, 0, 0, 0, _BIT_MASK(sym_k_XmNotebook_object) |
  0, 0, 0, 0, 0, 0};

/* sym_k_XmNinnerMarginWidth_arg */
static unsigned char arg_class_vec359[] =
  {
  0, 0, 0, 0, 0, 0, _BIT_MASK(sym_k_XmNotebook_object) |
  0, 0, 0, 0, 0, 0};

/* sym_k_XmNinput_arg */
static unsigned char arg_class_vec360[] =
  {
  _BIT_MASK(sym_k_DtHelpDialog_object) |
  _BIT_MASK(sym_k_DtHelpQuickDialog_object) |
  _BIT_MASK(sym_k_DtPrintSetupDialog_object) |
  0, _BIT_MASK(sym_k_XmBulletinBoardDialog_object) |
  0, _BIT_MASK(sym_k_XmCommandDialog_object) |
  0, _BIT_MASK(sym_k_XmDialogShell_object) |
  _BIT_MASK(sym_k_XmErrorDialog_object) |
  _BIT_MASK(sym_k_XmFileSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmFormDialog_object) |
  _BIT_MASK(sym_k_XmInformationDialog_object) |
  0, _BIT_MASK(sym_k_XmMessageDialog_object) |
  0, _BIT_MASK(sym_k_XmPromptDialog_object) |
  0, _BIT_MASK(sym_k_XmQuestionDialog_object) |
  0, _BIT_MASK(sym_k_XmSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmTemplateDialog_object) |
  0, _BIT_MASK(sym_k_XmWarningDialog_object) |
  _BIT_MASK(sym_k_XmWorkingDialog_object) |
  0, 0};

/* sym_k_XmNinputMethod_arg */
static unsigned char arg_class_vec361[] =
  {
  _BIT_MASK(sym_k_DtHelpDialog_object) |
  _BIT_MASK(sym_k_DtHelpQuickDialog_object) |
  _BIT_MASK(sym_k_DtPrintSetupDialog_object) |
  0, _BIT_MASK(sym_k_XmBulletinBoardDialog_object) |
  0, _BIT_MASK(sym_k_XmCommandDialog_object) |
  0, _BIT_MASK(sym_k_XmDialogShell_object) |
  _BIT_MASK(sym_k_XmErrorDialog_object) |
  _BIT_MASK(sym_k_XmFileSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmFormDialog_object) |
  _BIT_MASK(sym_k_XmInformationDialog_object) |
  0, _BIT_MASK(sym_k_XmMessageDialog_object) |
  0, _BIT_MASK(sym_k_XmPromptDialog_object) |
  0, _BIT_MASK(sym_k_XmQuestionDialog_object) |
  0, _BIT_MASK(sym_k_XmSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmTemplateDialog_object) |
  0, _BIT_MASK(sym_k_XmWarningDialog_object) |
  _BIT_MASK(sym_k_XmWorkingDialog_object) |
  0, 0};

/* sym_k_XmNinputPolicy_arg */
static unsigned char arg_class_vec362[] =
  {
  _BIT_MASK(sym_k_DtHelpDialog_object) |
  _BIT_MASK(sym_k_DtHelpQuickDialog_object) |
  _BIT_MASK(sym_k_DtPrintSetupDialog_object) |
  0, _BIT_MASK(sym_k_XmBulletinBoardDialog_object) |
  0, _BIT_MASK(sym_k_XmCommandDialog_object) |
  0, _BIT_MASK(sym_k_XmDialogShell_object) |
  _BIT_MASK(sym_k_XmErrorDialog_object) |
  _BIT_MASK(sym_k_XmFileSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmFormDialog_object) |
  _BIT_MASK(sym_k_XmInformationDialog_object) |
  0, _BIT_MASK(sym_k_XmMessageDialog_object) |
  0, _BIT_MASK(sym_k_XmPromptDialog_object) |
  0, _BIT_MASK(sym_k_XmQuestionDialog_object) |
  0, _BIT_MASK(sym_k_XmSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmTemplateDialog_object) |
  0, _BIT_MASK(sym_k_XmWarningDialog_object) |
  _BIT_MASK(sym_k_XmWorkingDialog_object) |
  0, 0};

/* sym_k_XmNinsertBefore_arg */
static unsigned char arg_class_vec363[] =
  {
  0, 0, 0, 0, 0, 0, _BIT_MASK(sym_k_XmOutline_object) |
  0, 0, 0, 0, _BIT_MASK(sym_k_XmTree_object) |
  0, 0};

/* sym_k_XmNinsertPosition_arg */
static unsigned char arg_class_vec364[] =
  {
  _BIT_MASK(sym_k_DtEditor_object) |
  _BIT_MASK(sym_k_DtHelpDialog_object) |
  _BIT_MASK(sym_k_DtHelpQuickDialog_object) |
  _BIT_MASK(sym_k_DtPrintSetupBox_object) |
  _BIT_MASK(sym_k_DtPrintSetupDialog_object) |
  0, _BIT_MASK(sym_k_XmBulletinBoard_object) |
  _BIT_MASK(sym_k_XmBulletinBoardDialog_object) |
  _BIT_MASK(sym_k_XmButtonBox_object) |
  0, _BIT_MASK(sym_k_XmCheckBox_object) |
  _BIT_MASK(sym_k_XmColorSelector_object) |
  _BIT_MASK(sym_k_XmColumn_object) |
  _BIT_MASK(sym_k_XmComboBox_object) |
  _BIT_MASK(sym_k_XmCommand_object) |
  _BIT_MASK(sym_k_XmCommandDialog_object) |
  _BIT_MASK(sym_k_XmContainer_object) |
  0, _BIT_MASK(sym_k_XmDialogShell_object) |
  _BIT_MASK(sym_k_XmDrawingArea_object) |
  _BIT_MASK(sym_k_XmDropDown_object) |
  _BIT_MASK(sym_k_XmErrorDialog_object) |
  _BIT_MASK(sym_k_XmFileSelectionBox_object) |
  _BIT_MASK(sym_k_XmFileSelectionDialog_object) |
  _BIT_MASK(sym_k_XmFontSelector_object) |
  0, _BIT_MASK(sym_k_XmForm_object) |
  _BIT_MASK(sym_k_XmFormDialog_object) |
  _BIT_MASK(sym_k_XmFrame_object) |
  _BIT_MASK(sym_k_XmIconBox_object) |
  _BIT_MASK(sym_k_XmInformationDialog_object) |
  0, _BIT_MASK(sym_k_XmMainWindow_object) |
  _BIT_MASK(sym_k_XmMenuBar_object) |
  _BIT_MASK(sym_k_XmMenuShell_object) |
  _BIT_MASK(sym_k_XmMessageBox_object) |
  _BIT_MASK(sym_k_XmMessageDialog_object) |
  _BIT_MASK(sym_k_XmMultiList_object) |
  0, _BIT_MASK(sym_k_XmNotebook_object) |
  _BIT_MASK(sym_k_XmOptionMenu_object) |
  _BIT_MASK(sym_k_XmOutline_object) |
  _BIT_MASK(sym_k_XmPaned_object) |
  _BIT_MASK(sym_k_XmPanedWindow_object) |
  _BIT_MASK(sym_k_XmPopupMenu_object) |
  _BIT_MASK(sym_k_XmPromptDialog_object) |
  _BIT_MASK(sym_k_XmPulldownMenu_object) |
  0, _BIT_MASK(sym_k_XmQuestionDialog_object) |
  _BIT_MASK(sym_k_XmRadioBox_object) |
  _BIT_MASK(sym_k_XmRowColumn_object) |
  _BIT_MASK(sym_k_XmScale_object) |
  0, _BIT_MASK(sym_k_XmScrolledList_object) |
  _BIT_MASK(sym_k_XmScrolledText_object) |
  _BIT_MASK(sym_k_XmScrolledWindow_object) |
  _BIT_MASK(sym_k_XmSelectionBox_object) |
  _BIT_MASK(sym_k_XmSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmSimpleSpinBox_object) |
  _BIT_MASK(sym_k_XmSpinBox_object) |
  _BIT_MASK(sym_k_XmTabStack_object) |
  _BIT_MASK(sym_k_XmTemplateDialog_object) |
  0, _BIT_MASK(sym_k_XmTree_object) |
  _BIT_MASK(sym_k_XmWarningDialog_object) |
  _BIT_MASK(sym_k_XmWorkArea_object) |
  _BIT_MASK(sym_k_XmWorkingDialog_object) |
  0, 0};

/* sym_k_XmNisAligned_arg */
static unsigned char arg_class_vec365[] =
  {
  0, 0, _BIT_MASK(sym_k_XmCheckBox_object) |
  0, 0, 0, _BIT_MASK(sym_k_XmMenuBar_object) |
  0, _BIT_MASK(sym_k_XmOptionMenu_object) |
  _BIT_MASK(sym_k_XmPopupMenu_object) |
  _BIT_MASK(sym_k_XmPulldownMenu_object) |
  0, _BIT_MASK(sym_k_XmRadioBox_object) |
  _BIT_MASK(sym_k_XmRowColumn_object) |
  0, 0, 0, _BIT_MASK(sym_k_XmWorkArea_object) |
  0, 0};

/* sym_k_XmNisHomogeneous_arg */
static unsigned char arg_class_vec366[] =
  {
  0, 0, _BIT_MASK(sym_k_XmCheckBox_object) |
  0, 0, 0, _BIT_MASK(sym_k_XmMenuBar_object) |
  0, _BIT_MASK(sym_k_XmOptionMenu_object) |
  _BIT_MASK(sym_k_XmPopupMenu_object) |
  _BIT_MASK(sym_k_XmPulldownMenu_object) |
  0, _BIT_MASK(sym_k_XmRadioBox_object) |
  _BIT_MASK(sym_k_XmRowColumn_object) |
  0, 0, 0, _BIT_MASK(sym_k_XmWorkArea_object) |
  0, 0};

/* sym_k_XmNitalicString_arg */
static unsigned char arg_class_vec367[] =
  {
  0, 0, 0, _BIT_MASK(sym_k_XmFontSelector_object) |
  0, 0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_XmNitemCount_arg */
static unsigned char arg_class_vec368[] =
  {
  0, 0, _BIT_MASK(sym_k_XmComboBox_object) |
  0, _BIT_MASK(sym_k_XmDropDown_object) |
  0, 0, _BIT_MASK(sym_k_XmList_object) |
  0, 0, 0, _BIT_MASK(sym_k_XmScrolledList_object) |
  0, 0, 0, 0};

/* sym_k_XmNitemSpacing_arg */
static unsigned char arg_class_vec369[] =
  {
  0, 0, _BIT_MASK(sym_k_XmColumn_object) |
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_XmNitems_arg */
static unsigned char arg_class_vec370[] =
  {
  0, 0, _BIT_MASK(sym_k_XmComboBox_object) |
  0, _BIT_MASK(sym_k_XmDropDown_object) |
  0, 0, _BIT_MASK(sym_k_XmList_object) |
  0, 0, 0, _BIT_MASK(sym_k_XmScrolledList_object) |
  0, 0, 0, 0};

/* sym_k_XmNkeyboardFocusPolicy_arg */
static unsigned char arg_class_vec371[] =
  {
  _BIT_MASK(sym_k_DtHelpDialog_object) |
  _BIT_MASK(sym_k_DtHelpQuickDialog_object) |
  _BIT_MASK(sym_k_DtPrintSetupDialog_object) |
  0, _BIT_MASK(sym_k_XmBulletinBoardDialog_object) |
  0, _BIT_MASK(sym_k_XmCommandDialog_object) |
  0, _BIT_MASK(sym_k_XmDialogShell_object) |
  _BIT_MASK(sym_k_XmErrorDialog_object) |
  _BIT_MASK(sym_k_XmFileSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmFormDialog_object) |
  _BIT_MASK(sym_k_XmInformationDialog_object) |
  0, _BIT_MASK(sym_k_XmMessageDialog_object) |
  0, _BIT_MASK(sym_k_XmPromptDialog_object) |
  0, _BIT_MASK(sym_k_XmQuestionDialog_object) |
  0, _BIT_MASK(sym_k_XmSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmTemplateDialog_object) |
  0, _BIT_MASK(sym_k_XmWarningDialog_object) |
  _BIT_MASK(sym_k_XmWorkingDialog_object) |
  0, 0};

/* sym_k_XmNlabel_arg */
static unsigned char arg_class_vec372[] =
  {
  0, 0, 0, 0, _BIT_MASK(sym_k_XmIconButton_object) |
  0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_XmNlabelFontList_arg */
static unsigned char arg_class_vec373[] =
  {
  _BIT_MASK(sym_k_DtEditor_object) |
  _BIT_MASK(sym_k_DtHelpDialog_object) |
  _BIT_MASK(sym_k_DtHelpQuickDialog_object) |
  _BIT_MASK(sym_k_DtPrintSetupBox_object) |
  _BIT_MASK(sym_k_DtPrintSetupDialog_object) |
  0, _BIT_MASK(sym_k_XmBulletinBoard_object) |
  _BIT_MASK(sym_k_XmBulletinBoardDialog_object) |
  0, _BIT_MASK(sym_k_XmColumn_object) |
  _BIT_MASK(sym_k_XmCommand_object) |
  _BIT_MASK(sym_k_XmCommandDialog_object) |
  0, _BIT_MASK(sym_k_XmDialogShell_object) |
  _BIT_MASK(sym_k_XmErrorDialog_object) |
  _BIT_MASK(sym_k_XmFileSelectionBox_object) |
  _BIT_MASK(sym_k_XmFileSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmForm_object) |
  _BIT_MASK(sym_k_XmFormDialog_object) |
  _BIT_MASK(sym_k_XmInformationDialog_object) |
  0, _BIT_MASK(sym_k_XmMenuShell_object) |
  _BIT_MASK(sym_k_XmMessageBox_object) |
  _BIT_MASK(sym_k_XmMessageDialog_object) |
  0, _BIT_MASK(sym_k_XmPopupMenu_object) |
  _BIT_MASK(sym_k_XmPromptDialog_object) |
  _BIT_MASK(sym_k_XmPulldownMenu_object) |
  0, _BIT_MASK(sym_k_XmQuestionDialog_object) |
  0, _BIT_MASK(sym_k_XmSelectionBox_object) |
  _BIT_MASK(sym_k_XmSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmTabStack_object) |
  _BIT_MASK(sym_k_XmTemplateDialog_object) |
  0, _BIT_MASK(sym_k_XmWarningDialog_object) |
  _BIT_MASK(sym_k_XmWorkingDialog_object) |
  0, 0};

/* sym_k_XmNlabelInsensitivePixmap_arg */
static unsigned char arg_class_vec374[] =
  {
  _BIT_MASK(sym_k_DtMenuButton_object) |
  0, _BIT_MASK(sym_k_XmCascadeButton_object) |
  _BIT_MASK(sym_k_XmCascadeButtonGadget_object) |
  0, 0, _BIT_MASK(sym_k_XmDrawnButton_object) |
  0, _BIT_MASK(sym_k_XmLabel_object) |
  0, _BIT_MASK(sym_k_XmLabelGadget_object) |
  0, 0, _BIT_MASK(sym_k_XmPushButton_object) |
  _BIT_MASK(sym_k_XmPushButtonGadget_object) |
  0, 0, _BIT_MASK(sym_k_XmTearOffButton_object) |
  0, _BIT_MASK(sym_k_XmToggleButton_object) |
  _BIT_MASK(sym_k_XmToggleButtonGadget_object) |
  0, 0};

/* sym_k_XmNlabelPixmap_arg */
static unsigned char arg_class_vec375[] =
  {
  _BIT_MASK(sym_k_DtMenuButton_object) |
  0, _BIT_MASK(sym_k_XmCascadeButton_object) |
  _BIT_MASK(sym_k_XmCascadeButtonGadget_object) |
  0, 0, _BIT_MASK(sym_k_XmDrawnButton_object) |
  _BIT_MASK(sym_k_XmDropDown_object) |
  0, _BIT_MASK(sym_k_XmLabel_object) |
  0, _BIT_MASK(sym_k_XmLabelGadget_object) |
  0, 0, _BIT_MASK(sym_k_XmPushButton_object) |
  _BIT_MASK(sym_k_XmPushButtonGadget_object) |
  0, 0, _BIT_MASK(sym_k_XmTearOffButton_object) |
  0, _BIT_MASK(sym_k_XmToggleButton_object) |
  _BIT_MASK(sym_k_XmToggleButtonGadget_object) |
  0, 0};

/* sym_k_XmNlabelRenderTable_arg */
static unsigned char arg_class_vec376[] =
  {
  _BIT_MASK(sym_k_DtEditor_object) |
  _BIT_MASK(sym_k_DtHelpDialog_object) |
  _BIT_MASK(sym_k_DtHelpQuickDialog_object) |
  _BIT_MASK(sym_k_DtPrintSetupBox_object) |
  _BIT_MASK(sym_k_DtPrintSetupDialog_object) |
  0, _BIT_MASK(sym_k_XmBulletinBoard_object) |
  _BIT_MASK(sym_k_XmBulletinBoardDialog_object) |
  0, _BIT_MASK(sym_k_XmColumn_object) |
  _BIT_MASK(sym_k_XmCommand_object) |
  _BIT_MASK(sym_k_XmCommandDialog_object) |
  0, _BIT_MASK(sym_k_XmDialogShell_object) |
  _BIT_MASK(sym_k_XmErrorDialog_object) |
  _BIT_MASK(sym_k_XmFileSelectionBox_object) |
  _BIT_MASK(sym_k_XmFileSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmForm_object) |
  _BIT_MASK(sym_k_XmFormDialog_object) |
  _BIT_MASK(sym_k_XmInformationDialog_object) |
  0, _BIT_MASK(sym_k_XmMenuShell_object) |
  _BIT_MASK(sym_k_XmMessageBox_object) |
  _BIT_MASK(sym_k_XmMessageDialog_object) |
  0, _BIT_MASK(sym_k_XmPopupMenu_object) |
  _BIT_MASK(sym_k_XmPromptDialog_object) |
  _BIT_MASK(sym_k_XmPulldownMenu_object) |
  0, _BIT_MASK(sym_k_XmQuestionDialog_object) |
  0, _BIT_MASK(sym_k_XmSelectionBox_object) |
  _BIT_MASK(sym_k_XmSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmTabStack_object) |
  _BIT_MASK(sym_k_XmTemplateDialog_object) |
  0, _BIT_MASK(sym_k_XmWarningDialog_object) |
  _BIT_MASK(sym_k_XmWorkingDialog_object) |
  0, 0};

/* sym_k_XmNlabelSpacing_arg */
static unsigned char arg_class_vec377[] =
  {
  0, 0, _BIT_MASK(sym_k_XmColumn_object) |
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_XmNlabelString_arg */
static unsigned char arg_class_vec378[] =
  {
  _BIT_MASK(sym_k_DtMenuButton_object) |
  0, _BIT_MASK(sym_k_XmCascadeButton_object) |
  _BIT_MASK(sym_k_XmCascadeButtonGadget_object) |
  0, _BIT_MASK(sym_k_XmCheckBox_object) |
  0, _BIT_MASK(sym_k_XmDrawnButton_object) |
  _BIT_MASK(sym_k_XmDropDown_object) |
  0, _BIT_MASK(sym_k_XmIconButton_object) |
  _BIT_MASK(sym_k_XmIconGadget_object) |
  _BIT_MASK(sym_k_XmLabel_object) |
  0, _BIT_MASK(sym_k_XmLabelGadget_object) |
  _BIT_MASK(sym_k_XmMenuBar_object) |
  0, _BIT_MASK(sym_k_XmOptionMenu_object) |
  _BIT_MASK(sym_k_XmPopupMenu_object) |
  _BIT_MASK(sym_k_XmPulldownMenu_object) |
  0, _BIT_MASK(sym_k_XmPushButton_object) |
  _BIT_MASK(sym_k_XmPushButtonGadget_object) |
  _BIT_MASK(sym_k_XmRadioBox_object) |
  _BIT_MASK(sym_k_XmRowColumn_object) |
  0, 0, _BIT_MASK(sym_k_XmTearOffButton_object) |
  0, _BIT_MASK(sym_k_XmToggleButton_object) |
  _BIT_MASK(sym_k_XmToggleButtonGadget_object) |
  _BIT_MASK(sym_k_XmWorkArea_object) |
  0, 0};

/* sym_k_XmNlabelType_arg */
static unsigned char arg_class_vec379[] =
  {
  _BIT_MASK(sym_k_DtMenuButton_object) |
  0, _BIT_MASK(sym_k_XmCascadeButton_object) |
  _BIT_MASK(sym_k_XmCascadeButtonGadget_object) |
  0, 0, _BIT_MASK(sym_k_XmDrawnButton_object) |
  _BIT_MASK(sym_k_XmDropDown_object) |
  0, _BIT_MASK(sym_k_XmLabel_object) |
  0, _BIT_MASK(sym_k_XmLabelGadget_object) |
  0, 0, _BIT_MASK(sym_k_XmPushButton_object) |
  _BIT_MASK(sym_k_XmPushButtonGadget_object) |
  0, 0, _BIT_MASK(sym_k_XmTearOffButton_object) |
  0, _BIT_MASK(sym_k_XmToggleButton_object) |
  _BIT_MASK(sym_k_XmToggleButtonGadget_object) |
  0, 0};

/* sym_k_XmNlargeCellHeight_arg */
static unsigned char arg_class_vec380[] =
  {
  0, 0, _BIT_MASK(sym_k_XmContainer_object) |
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_XmNlargeCellWidth_arg */
static unsigned char arg_class_vec381[] =
  {
  0, 0, _BIT_MASK(sym_k_XmContainer_object) |
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_XmNlargeIconMask_arg */
static unsigned char arg_class_vec382[] =
  {
  0, 0, 0, 0, _BIT_MASK(sym_k_XmIconGadget_object) |
  0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_XmNlargeIconPixmap_arg */
static unsigned char arg_class_vec383[] =
  {
  0, 0, 0, 0, _BIT_MASK(sym_k_XmIconGadget_object) |
  0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_XmNlargeIconX_arg */
static unsigned char arg_class_vec384[] =
  {
  0, 0, _BIT_MASK(sym_k_XmContainer_object) |
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_XmNlargeIconY_arg */
static unsigned char arg_class_vec385[] =
  {
  0, 0, _BIT_MASK(sym_k_XmContainer_object) |
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_XmNlastPageNumber_arg */
static unsigned char arg_class_vec386[] =
  {
  0, 0, 0, 0, 0, 0, _BIT_MASK(sym_k_XmNotebook_object) |
  0, 0, 0, 0, 0, 0};

/* sym_k_XmNlayoutDirection_arg */
static unsigned char arg_class_vec387[] =
  {
  _BIT_MASK(sym_k_DtEditor_object) |
  _BIT_MASK(sym_k_DtHelpDialog_object) |
  _BIT_MASK(sym_k_DtHelpQuickDialog_object) |
  _BIT_MASK(sym_k_DtPrintSetupBox_object) |
  _BIT_MASK(sym_k_DtPrintSetupDialog_object) |
  0, _BIT_MASK(sym_k_XmBulletinBoard_object) |
  _BIT_MASK(sym_k_XmBulletinBoardDialog_object) |
  _BIT_MASK(sym_k_XmButtonBox_object) |
  0, _BIT_MASK(sym_k_XmCheckBox_object) |
  _BIT_MASK(sym_k_XmColorSelector_object) |
  _BIT_MASK(sym_k_XmColumn_object) |
  _BIT_MASK(sym_k_XmComboBox_object) |
  _BIT_MASK(sym_k_XmCommand_object) |
  _BIT_MASK(sym_k_XmCommandDialog_object) |
  _BIT_MASK(sym_k_XmContainer_object) |
  0, _BIT_MASK(sym_k_XmDrawingArea_object) |
  _BIT_MASK(sym_k_XmDropDown_object) |
  _BIT_MASK(sym_k_XmErrorDialog_object) |
  _BIT_MASK(sym_k_XmFileSelectionBox_object) |
  _BIT_MASK(sym_k_XmFileSelectionDialog_object) |
  _BIT_MASK(sym_k_XmFontSelector_object) |
  0, _BIT_MASK(sym_k_XmForm_object) |
  _BIT_MASK(sym_k_XmFormDialog_object) |
  _BIT_MASK(sym_k_XmFrame_object) |
  _BIT_MASK(sym_k_XmIconBox_object) |
  _BIT_MASK(sym_k_XmInformationDialog_object) |
  0, _BIT_MASK(sym_k_XmMainWindow_object) |
  _BIT_MASK(sym_k_XmMenuBar_object) |
  _BIT_MASK(sym_k_XmMessageBox_object) |
  _BIT_MASK(sym_k_XmMessageDialog_object) |
  _BIT_MASK(sym_k_XmMultiList_object) |
  0, _BIT_MASK(sym_k_XmNotebook_object) |
  _BIT_MASK(sym_k_XmOptionMenu_object) |
  _BIT_MASK(sym_k_XmOutline_object) |
  _BIT_MASK(sym_k_XmPaned_object) |
  _BIT_MASK(sym_k_XmPanedWindow_object) |
  _BIT_MASK(sym_k_XmPopupMenu_object) |
  _BIT_MASK(sym_k_XmPromptDialog_object) |
  _BIT_MASK(sym_k_XmPulldownMenu_object) |
  0, _BIT_MASK(sym_k_XmQuestionDialog_object) |
  _BIT_MASK(sym_k_XmRadioBox_object) |
  _BIT_MASK(sym_k_XmRowColumn_object) |
  _BIT_MASK(sym_k_XmScale_object) |
  0, _BIT_MASK(sym_k_XmScrolledList_object) |
  _BIT_MASK(sym_k_XmScrolledText_object) |
  _BIT_MASK(sym_k_XmScrolledWindow_object) |
  _BIT_MASK(sym_k_XmSelectionBox_object) |
  _BIT_MASK(sym_k_XmSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmSimpleSpinBox_object) |
  _BIT_MASK(sym_k_XmSpinBox_object) |
  _BIT_MASK(sym_k_XmTabStack_object) |
  _BIT_MASK(sym_k_XmTemplateDialog_object) |
  0, _BIT_MASK(sym_k_XmTree_object) |
  _BIT_MASK(sym_k_XmWarningDialog_object) |
  _BIT_MASK(sym_k_XmWorkArea_object) |
  _BIT_MASK(sym_k_XmWorkingDialog_object) |
  0, 0};

/* sym_k_XmNlayoutType_arg */
static unsigned char arg_class_vec388[] =
  {
  0, 0, _BIT_MASK(sym_k_XmContainer_object) |
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_XmNleftAttachment_arg */
static unsigned char arg_class_vec389[] =
  {
  _BIT_MASK(sym_k_DtEditor_object) |
  0, 0, 0, 0, _BIT_MASK(sym_k_XmForm_object) |
  _BIT_MASK(sym_k_XmFormDialog_object) |
  0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_XmNleftOffset_arg */
static unsigned char arg_class_vec390[] =
  {
  _BIT_MASK(sym_k_DtEditor_object) |
  0, 0, 0, 0, _BIT_MASK(sym_k_XmForm_object) |
  _BIT_MASK(sym_k_XmFormDialog_object) |
  0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_XmNleftPosition_arg */
static unsigned char arg_class_vec391[] =
  {
  _BIT_MASK(sym_k_DtEditor_object) |
  0, 0, 0, 0, _BIT_MASK(sym_k_XmForm_object) |
  _BIT_MASK(sym_k_XmFormDialog_object) |
  0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_XmNleftWidget_arg */
static unsigned char arg_class_vec392[] =
  {
  _BIT_MASK(sym_k_DtEditor_object) |
  0, 0, 0, 0, _BIT_MASK(sym_k_XmForm_object) |
  _BIT_MASK(sym_k_XmFormDialog_object) |
  0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_XmNlightThreshold_arg */
static unsigned char arg_class_vec393[] =
  {
  _BIT_MASK(sym_k_DtHelpDialog_object) |
  _BIT_MASK(sym_k_DtHelpQuickDialog_object) |
  _BIT_MASK(sym_k_DtPrintSetupDialog_object) |
  0, _BIT_MASK(sym_k_XmBulletinBoardDialog_object) |
  0, _BIT_MASK(sym_k_XmCommandDialog_object) |
  0, _BIT_MASK(sym_k_XmDialogShell_object) |
  _BIT_MASK(sym_k_XmErrorDialog_object) |
  _BIT_MASK(sym_k_XmFileSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmFormDialog_object) |
  _BIT_MASK(sym_k_XmInformationDialog_object) |
  0, _BIT_MASK(sym_k_XmMessageDialog_object) |
  0, _BIT_MASK(sym_k_XmPromptDialog_object) |
  0, _BIT_MASK(sym_k_XmQuestionDialog_object) |
  0, _BIT_MASK(sym_k_XmSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmTemplateDialog_object) |
  0, _BIT_MASK(sym_k_XmWarningDialog_object) |
  _BIT_MASK(sym_k_XmWorkingDialog_object) |
  0, 0};

/* sym_k_XmNlineBackgroundColor_arg */
static unsigned char arg_class_vec394[] =
  {
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, _BIT_MASK(sym_k_XmTree_object) |
  0, 0};

/* sym_k_XmNlineColor_arg */
static unsigned char arg_class_vec395[] =
  {
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, _BIT_MASK(sym_k_XmTree_object) |
  0, 0};

/* sym_k_XmNlineStyle_arg */
static unsigned char arg_class_vec396[] =
  {
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, _BIT_MASK(sym_k_XmTree_object) |
  0, 0};

/* sym_k_XmNlineWidth_arg */
static unsigned char arg_class_vec397[] =
  {
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, _BIT_MASK(sym_k_XmTree_object) |
  0, 0};

/* sym_k_XmNlist_arg */
static unsigned char arg_class_vec398[] =
  {
  0, 0, _BIT_MASK(sym_k_XmComboBox_object) |
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_XmNlistItemCount_arg */
static unsigned char arg_class_vec399[] =
  {
  0, 0, _BIT_MASK(sym_k_XmCommand_object) |
  _BIT_MASK(sym_k_XmCommandDialog_object) |
  0, _BIT_MASK(sym_k_XmFileSelectionBox_object) |
  _BIT_MASK(sym_k_XmFileSelectionDialog_object) |
  0, 0, 0, _BIT_MASK(sym_k_XmPromptDialog_object) |
  0, 0, _BIT_MASK(sym_k_XmSelectionBox_object) |
  _BIT_MASK(sym_k_XmSelectionDialog_object) |
  0, 0, 0, 0};

/* sym_k_XmNlistItems_arg */
static unsigned char arg_class_vec400[] =
  {
  0, 0, _BIT_MASK(sym_k_XmCommand_object) |
  _BIT_MASK(sym_k_XmCommandDialog_object) |
  0, _BIT_MASK(sym_k_XmFileSelectionBox_object) |
  _BIT_MASK(sym_k_XmFileSelectionDialog_object) |
  0, 0, 0, _BIT_MASK(sym_k_XmPromptDialog_object) |
  0, 0, _BIT_MASK(sym_k_XmSelectionBox_object) |
  _BIT_MASK(sym_k_XmSelectionDialog_object) |
  0, 0, 0, 0};

/* sym_k_XmNlistLabelString_arg */
static unsigned char arg_class_vec401[] =
  {
  0, 0, 0, _BIT_MASK(sym_k_XmFileSelectionBox_object) |
  _BIT_MASK(sym_k_XmFileSelectionDialog_object) |
  0, 0, 0, _BIT_MASK(sym_k_XmPromptDialog_object) |
  0, 0, _BIT_MASK(sym_k_XmSelectionBox_object) |
  _BIT_MASK(sym_k_XmSelectionDialog_object) |
  0, 0, 0, 0};

/* sym_k_XmNlistMarginHeight_arg */
static unsigned char arg_class_vec402[] =
  {
  0, 0, 0, 0, 0, _BIT_MASK(sym_k_XmList_object) |
  0, 0, 0, _BIT_MASK(sym_k_XmScrolledList_object) |
  0, 0, 0, 0};

/* sym_k_XmNlistMarginWidth_arg */
static unsigned char arg_class_vec403[] =
  {
  0, 0, 0, 0, 0, _BIT_MASK(sym_k_XmList_object) |
  0, 0, 0, _BIT_MASK(sym_k_XmScrolledList_object) |
  0, 0, 0, 0};

/* sym_k_XmNlistSizePolicy_arg */
static unsigned char arg_class_vec404[] =
  {
  0, 0, 0, 0, 0, _BIT_MASK(sym_k_XmList_object) |
  0, 0, 0, _BIT_MASK(sym_k_XmScrolledList_object) |
  0, 0, 0, 0};

/* sym_k_XmNlistSpacing_arg */
static unsigned char arg_class_vec405[] =
  {
  0, 0, 0, 0, 0, _BIT_MASK(sym_k_XmList_object) |
  0, 0, 0, _BIT_MASK(sym_k_XmScrolledList_object) |
  0, 0, 0, 0};

/* sym_k_XmNlistUpdated_arg */
static unsigned char arg_class_vec406[] =
  {
  0, 0, 0, _BIT_MASK(sym_k_XmFileSelectionBox_object) |
  _BIT_MASK(sym_k_XmFileSelectionDialog_object) |
  0, 0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_XmNlistVisibleItemCount_arg */
static unsigned char arg_class_vec407[] =
  {
  0, 0, _BIT_MASK(sym_k_XmCommand_object) |
  _BIT_MASK(sym_k_XmCommandDialog_object) |
  0, _BIT_MASK(sym_k_XmFileSelectionBox_object) |
  _BIT_MASK(sym_k_XmFileSelectionDialog_object) |
  0, 0, 0, _BIT_MASK(sym_k_XmPromptDialog_object) |
  0, 0, _BIT_MASK(sym_k_XmSelectionBox_object) |
  _BIT_MASK(sym_k_XmSelectionDialog_object) |
  0, 0, 0, 0};

/* sym_k_XmNloadModel_arg */
static unsigned char arg_class_vec408[] =
  {
  0, 0, 0, 0, 0, 0, 0, _BIT_MASK(sym_k_XmRendition_object) |
  0, 0, 0, 0, 0};

/* sym_k_XmNmainWindowMarginHeight_arg */
static unsigned char arg_class_vec409[] =
  {
  0, 0, 0, 0, 0, _BIT_MASK(sym_k_XmMainWindow_object) |
  0, 0, 0, 0, 0, 0, 0};

/* sym_k_XmNmainWindowMarginWidth_arg */
static unsigned char arg_class_vec410[] =
  {
  0, 0, 0, 0, 0, _BIT_MASK(sym_k_XmMainWindow_object) |
  0, 0, 0, 0, 0, 0, 0};

/* sym_k_XmNmajorTabSpacing_arg */
static unsigned char arg_class_vec411[] =
  {
  0, 0, 0, 0, 0, 0, _BIT_MASK(sym_k_XmNotebook_object) |
  0, 0, 0, 0, 0, 0};

/* sym_k_XmNmappedWhenManaged_arg */
static unsigned char arg_class_vec412[] =
  {
  _BIT_MASK(sym_k_DtEditor_object) |
  _BIT_MASK(sym_k_DtHelpDialog_object) |
  _BIT_MASK(sym_k_DtHelpQuickDialog_object) |
  _BIT_MASK(sym_k_DtMenuButton_object) |
  _BIT_MASK(sym_k_DtPrintSetupBox_object) |
  _BIT_MASK(sym_k_DtPrintSetupDialog_object) |
  _BIT_MASK(sym_k_DtTerm_object) |
  0, _BIT_MASK(sym_k_DtTermPrimitive_object) |
  _BIT_MASK(sym_k_XmArrowButton_object) |
  _BIT_MASK(sym_k_XmBulletinBoard_object) |
  _BIT_MASK(sym_k_XmBulletinBoardDialog_object) |
  _BIT_MASK(sym_k_XmButtonBox_object) |
  _BIT_MASK(sym_k_XmCascadeButton_object) |
  0, _BIT_MASK(sym_k_XmCheckBox_object) |
  _BIT_MASK(sym_k_XmColorSelector_object) |
  _BIT_MASK(sym_k_XmColumn_object) |
  _BIT_MASK(sym_k_XmComboBox_object) |
  _BIT_MASK(sym_k_XmCommand_object) |
  _BIT_MASK(sym_k_XmCommandDialog_object) |
  _BIT_MASK(sym_k_XmContainer_object) |
  _BIT_MASK(sym_k_XmDataField_object) |
  0, _BIT_MASK(sym_k_XmDialogShell_object) |
  _BIT_MASK(sym_k_XmDrawingArea_object) |
  _BIT_MASK(sym_k_XmDrawnButton_object) |
  _BIT_MASK(sym_k_XmDropDown_object) |
  _BIT_MASK(sym_k_XmErrorDialog_object) |
  _BIT_MASK(sym_k_XmFileSelectionBox_object) |
  _BIT_MASK(sym_k_XmFileSelectionDialog_object) |
  _BIT_MASK(sym_k_XmFontSelector_object) |
  0, _BIT_MASK(sym_k_XmForm_object) |
  _BIT_MASK(sym_k_XmFormDialog_object) |
  _BIT_MASK(sym_k_XmFrame_object) |
  _BIT_MASK(sym_k_XmIconBox_object) |
  _BIT_MASK(sym_k_XmIconButton_object) |
  _BIT_MASK(sym_k_XmInformationDialog_object) |
  _BIT_MASK(sym_k_XmLabel_object) |
  0, _BIT_MASK(sym_k_XmList_object) |
  _BIT_MASK(sym_k_XmMainWindow_object) |
  _BIT_MASK(sym_k_XmMenuBar_object) |
  _BIT_MASK(sym_k_XmMenuShell_object) |
  _BIT_MASK(sym_k_XmMessageBox_object) |
  _BIT_MASK(sym_k_XmMessageDialog_object) |
  _BIT_MASK(sym_k_XmMultiList_object) |
  0, _BIT_MASK(sym_k_XmNotebook_object) |
  _BIT_MASK(sym_k_XmOptionMenu_object) |
  _BIT_MASK(sym_k_XmOutline_object) |
  _BIT_MASK(sym_k_XmPaned_object) |
  _BIT_MASK(sym_k_XmPanedWindow_object) |
  _BIT_MASK(sym_k_XmPopupMenu_object) |
  _BIT_MASK(sym_k_XmPromptDialog_object) |
  _BIT_MASK(sym_k_XmPulldownMenu_object) |
  0, _BIT_MASK(sym_k_XmPushButton_object) |
  _BIT_MASK(sym_k_XmQuestionDialog_object) |
  _BIT_MASK(sym_k_XmRadioBox_object) |
  _BIT_MASK(sym_k_XmRowColumn_object) |
  _BIT_MASK(sym_k_XmScale_object) |
  0, _BIT_MASK(sym_k_XmScrollBar_object) |
  _BIT_MASK(sym_k_XmScrolledList_object) |
  _BIT_MASK(sym_k_XmScrolledText_object) |
  _BIT_MASK(sym_k_XmScrolledWindow_object) |
  _BIT_MASK(sym_k_XmSelectionBox_object) |
  _BIT_MASK(sym_k_XmSelectionDialog_object) |
  _BIT_MASK(sym_k_XmSeparator_object) |
  0, _BIT_MASK(sym_k_XmSimpleSpinBox_object) |
  _BIT_MASK(sym_k_XmSpinBox_object) |
  _BIT_MASK(sym_k_XmTabBox_object) |
  _BIT_MASK(sym_k_XmTabStack_object) |
  _BIT_MASK(sym_k_XmTearOffButton_object) |
  _BIT_MASK(sym_k_XmTemplateDialog_object) |
  0, _BIT_MASK(sym_k_XmText_object) |
  _BIT_MASK(sym_k_XmTextField_object) |
  _BIT_MASK(sym_k_XmToggleButton_object) |
  _BIT_MASK(sym_k_XmTree_object) |
  _BIT_MASK(sym_k_XmWarningDialog_object) |
  _BIT_MASK(sym_k_XmWorkArea_object) |
  _BIT_MASK(sym_k_XmWorkingDialog_object) |
  0, 0};

/* sym_k_XmNmappingDelay_arg */
static unsigned char arg_class_vec413[] =
  {
  0, _BIT_MASK(sym_k_XmCascadeButton_object) |
  _BIT_MASK(sym_k_XmCascadeButtonGadget_object) |
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_XmNmargin_arg */
static unsigned char arg_class_vec414[] =
  {
  0, 0, 0, 0, 0, 0, 0, 0, _BIT_MASK(sym_k_XmSeparator_object) |
  _BIT_MASK(sym_k_XmSeparatorGadget_object) |
  0, _BIT_MASK(sym_k_XmTearOffButton_object) |
  0, 0, 0};

/* sym_k_XmNmarginBottom_arg */
static unsigned char arg_class_vec415[] =
  {
  _BIT_MASK(sym_k_DtMenuButton_object) |
  0, _BIT_MASK(sym_k_XmCascadeButton_object) |
  _BIT_MASK(sym_k_XmCascadeButtonGadget_object) |
  0, 0, _BIT_MASK(sym_k_XmDrawnButton_object) |
  _BIT_MASK(sym_k_XmDropDown_object) |
  0, _BIT_MASK(sym_k_XmLabel_object) |
  0, _BIT_MASK(sym_k_XmLabelGadget_object) |
  0, 0, _BIT_MASK(sym_k_XmPushButton_object) |
  _BIT_MASK(sym_k_XmPushButtonGadget_object) |
  0, 0, _BIT_MASK(sym_k_XmTearOffButton_object) |
  0, _BIT_MASK(sym_k_XmToggleButton_object) |
  _BIT_MASK(sym_k_XmToggleButtonGadget_object) |
  0, 0};

/* sym_k_XmNmarginHeight_arg */
static unsigned char arg_class_vec416[] =
  {
  _BIT_MASK(sym_k_DtEditor_object) |
  _BIT_MASK(sym_k_DtHelpDialog_object) |
  _BIT_MASK(sym_k_DtHelpQuickDialog_object) |
  _BIT_MASK(sym_k_DtMenuButton_object) |
  _BIT_MASK(sym_k_DtPrintSetupBox_object) |
  _BIT_MASK(sym_k_DtPrintSetupDialog_object) |
  0, _BIT_MASK(sym_k_XmBulletinBoard_object) |
  _BIT_MASK(sym_k_XmBulletinBoardDialog_object) |
  _BIT_MASK(sym_k_XmButtonBox_object) |
  _BIT_MASK(sym_k_XmCascadeButton_object) |
  _BIT_MASK(sym_k_XmCascadeButtonGadget_object) |
  0, _BIT_MASK(sym_k_XmCheckBox_object) |
  _BIT_MASK(sym_k_XmColorSelector_object) |
  _BIT_MASK(sym_k_XmColumn_object) |
  _BIT_MASK(sym_k_XmComboBox_object) |
  _BIT_MASK(sym_k_XmCommand_object) |
  _BIT_MASK(sym_k_XmCommandDialog_object) |
  _BIT_MASK(sym_k_XmContainer_object) |
  _BIT_MASK(sym_k_XmDataField_object) |
  0, _BIT_MASK(sym_k_XmDrawingArea_object) |
  _BIT_MASK(sym_k_XmDrawnButton_object) |
  _BIT_MASK(sym_k_XmDropDown_object) |
  _BIT_MASK(sym_k_XmErrorDialog_object) |
  _BIT_MASK(sym_k_XmFileSelectionBox_object) |
  _BIT_MASK(sym_k_XmFileSelectionDialog_object) |
  _BIT_MASK(sym_k_XmFontSelector_object) |
  0, _BIT_MASK(sym_k_XmForm_object) |
  _BIT_MASK(sym_k_XmFormDialog_object) |
  _BIT_MASK(sym_k_XmFrame_object) |
  _BIT_MASK(sym_k_XmIconGadget_object) |
  _BIT_MASK(sym_k_XmInformationDialog_object) |
  _BIT_MASK(sym_k_XmLabel_object) |
  0, _BIT_MASK(sym_k_XmLabelGadget_object) |
  _BIT_MASK(sym_k_XmMenuBar_object) |
  _BIT_MASK(sym_k_XmMessageBox_object) |
  _BIT_MASK(sym_k_XmMessageDialog_object) |
  0, _BIT_MASK(sym_k_XmOptionMenu_object) |
  _BIT_MASK(sym_k_XmPaned_object) |
  _BIT_MASK(sym_k_XmPanedWindow_object) |
  _BIT_MASK(sym_k_XmPopupMenu_object) |
  _BIT_MASK(sym_k_XmPromptDialog_object) |
  _BIT_MASK(sym_k_XmPulldownMenu_object) |
  0, _BIT_MASK(sym_k_XmPushButton_object) |
  _BIT_MASK(sym_k_XmPushButtonGadget_object) |
  _BIT_MASK(sym_k_XmQuestionDialog_object) |
  _BIT_MASK(sym_k_XmRadioBox_object) |
  _BIT_MASK(sym_k_XmRowColumn_object) |
  0, _BIT_MASK(sym_k_XmScrolledText_object) |
  _BIT_MASK(sym_k_XmSelectionBox_object) |
  _BIT_MASK(sym_k_XmSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmSimpleSpinBox_object) |
  _BIT_MASK(sym_k_XmSpinBox_object) |
  _BIT_MASK(sym_k_XmTabStack_object) |
  _BIT_MASK(sym_k_XmTearOffButton_object) |
  _BIT_MASK(sym_k_XmTemplateDialog_object) |
  0, _BIT_MASK(sym_k_XmText_object) |
  _BIT_MASK(sym_k_XmTextField_object) |
  _BIT_MASK(sym_k_XmToggleButton_object) |
  _BIT_MASK(sym_k_XmToggleButtonGadget_object) |
  _BIT_MASK(sym_k_XmWarningDialog_object) |
  _BIT_MASK(sym_k_XmWorkArea_object) |
  _BIT_MASK(sym_k_XmWorkingDialog_object) |
  0, 0};

/* sym_k_XmNmarginLeft_arg */
static unsigned char arg_class_vec417[] =
  {
  _BIT_MASK(sym_k_DtMenuButton_object) |
  0, _BIT_MASK(sym_k_XmCascadeButton_object) |
  _BIT_MASK(sym_k_XmCascadeButtonGadget_object) |
  0, 0, _BIT_MASK(sym_k_XmDrawnButton_object) |
  _BIT_MASK(sym_k_XmDropDown_object) |
  0, _BIT_MASK(sym_k_XmLabel_object) |
  0, _BIT_MASK(sym_k_XmLabelGadget_object) |
  0, 0, _BIT_MASK(sym_k_XmPushButton_object) |
  _BIT_MASK(sym_k_XmPushButtonGadget_object) |
  0, 0, _BIT_MASK(sym_k_XmTearOffButton_object) |
  0, _BIT_MASK(sym_k_XmToggleButton_object) |
  _BIT_MASK(sym_k_XmToggleButtonGadget_object) |
  0, 0};

/* sym_k_XmNmarginRight_arg */
static unsigned char arg_class_vec418[] =
  {
  _BIT_MASK(sym_k_DtMenuButton_object) |
  0, _BIT_MASK(sym_k_XmCascadeButton_object) |
  _BIT_MASK(sym_k_XmCascadeButtonGadget_object) |
  0, 0, _BIT_MASK(sym_k_XmDrawnButton_object) |
  _BIT_MASK(sym_k_XmDropDown_object) |
  0, _BIT_MASK(sym_k_XmLabel_object) |
  0, _BIT_MASK(sym_k_XmLabelGadget_object) |
  0, 0, _BIT_MASK(sym_k_XmPushButton_object) |
  _BIT_MASK(sym_k_XmPushButtonGadget_object) |
  0, 0, _BIT_MASK(sym_k_XmTearOffButton_object) |
  0, _BIT_MASK(sym_k_XmToggleButton_object) |
  _BIT_MASK(sym_k_XmToggleButtonGadget_object) |
  0, 0};

/* sym_k_XmNmarginTop_arg */
static unsigned char arg_class_vec419[] =
  {
  _BIT_MASK(sym_k_DtMenuButton_object) |
  0, _BIT_MASK(sym_k_XmCascadeButton_object) |
  _BIT_MASK(sym_k_XmCascadeButtonGadget_object) |
  0, 0, _BIT_MASK(sym_k_XmDrawnButton_object) |
  _BIT_MASK(sym_k_XmDropDown_object) |
  0, _BIT_MASK(sym_k_XmLabel_object) |
  0, _BIT_MASK(sym_k_XmLabelGadget_object) |
  0, 0, _BIT_MASK(sym_k_XmPushButton_object) |
  _BIT_MASK(sym_k_XmPushButtonGadget_object) |
  0, 0, _BIT_MASK(sym_k_XmTearOffButton_object) |
  0, _BIT_MASK(sym_k_XmToggleButton_object) |
  _BIT_MASK(sym_k_XmToggleButtonGadget_object) |
  0, 0};

/* sym_k_XmNmarginWidth_arg */
static unsigned char arg_class_vec420[] =
  {
  _BIT_MASK(sym_k_DtEditor_object) |
  _BIT_MASK(sym_k_DtHelpDialog_object) |
  _BIT_MASK(sym_k_DtHelpQuickDialog_object) |
  _BIT_MASK(sym_k_DtMenuButton_object) |
  _BIT_MASK(sym_k_DtPrintSetupBox_object) |
  _BIT_MASK(sym_k_DtPrintSetupDialog_object) |
  0, _BIT_MASK(sym_k_XmBulletinBoard_object) |
  _BIT_MASK(sym_k_XmBulletinBoardDialog_object) |
  _BIT_MASK(sym_k_XmButtonBox_object) |
  _BIT_MASK(sym_k_XmCascadeButton_object) |
  _BIT_MASK(sym_k_XmCascadeButtonGadget_object) |
  0, _BIT_MASK(sym_k_XmCheckBox_object) |
  _BIT_MASK(sym_k_XmColorSelector_object) |
  _BIT_MASK(sym_k_XmColumn_object) |
  _BIT_MASK(sym_k_XmComboBox_object) |
  _BIT_MASK(sym_k_XmCommand_object) |
  _BIT_MASK(sym_k_XmCommandDialog_object) |
  _BIT_MASK(sym_k_XmContainer_object) |
  _BIT_MASK(sym_k_XmDataField_object) |
  0, _BIT_MASK(sym_k_XmDrawingArea_object) |
  _BIT_MASK(sym_k_XmDrawnButton_object) |
  _BIT_MASK(sym_k_XmDropDown_object) |
  _BIT_MASK(sym_k_XmErrorDialog_object) |
  _BIT_MASK(sym_k_XmFileSelectionBox_object) |
  _BIT_MASK(sym_k_XmFileSelectionDialog_object) |
  _BIT_MASK(sym_k_XmFontSelector_object) |
  0, _BIT_MASK(sym_k_XmForm_object) |
  _BIT_MASK(sym_k_XmFormDialog_object) |
  _BIT_MASK(sym_k_XmFrame_object) |
  _BIT_MASK(sym_k_XmIconGadget_object) |
  _BIT_MASK(sym_k_XmInformationDialog_object) |
  _BIT_MASK(sym_k_XmLabel_object) |
  0, _BIT_MASK(sym_k_XmLabelGadget_object) |
  _BIT_MASK(sym_k_XmMenuBar_object) |
  _BIT_MASK(sym_k_XmMessageBox_object) |
  _BIT_MASK(sym_k_XmMessageDialog_object) |
  0, _BIT_MASK(sym_k_XmOptionMenu_object) |
  _BIT_MASK(sym_k_XmPaned_object) |
  _BIT_MASK(sym_k_XmPanedWindow_object) |
  _BIT_MASK(sym_k_XmPopupMenu_object) |
  _BIT_MASK(sym_k_XmPromptDialog_object) |
  _BIT_MASK(sym_k_XmPulldownMenu_object) |
  0, _BIT_MASK(sym_k_XmPushButton_object) |
  _BIT_MASK(sym_k_XmPushButtonGadget_object) |
  _BIT_MASK(sym_k_XmQuestionDialog_object) |
  _BIT_MASK(sym_k_XmRadioBox_object) |
  _BIT_MASK(sym_k_XmRowColumn_object) |
  0, _BIT_MASK(sym_k_XmScrolledText_object) |
  _BIT_MASK(sym_k_XmSelectionBox_object) |
  _BIT_MASK(sym_k_XmSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmSimpleSpinBox_object) |
  _BIT_MASK(sym_k_XmSpinBox_object) |
  _BIT_MASK(sym_k_XmTabStack_object) |
  _BIT_MASK(sym_k_XmTearOffButton_object) |
  _BIT_MASK(sym_k_XmTemplateDialog_object) |
  0, _BIT_MASK(sym_k_XmText_object) |
  _BIT_MASK(sym_k_XmTextField_object) |
  _BIT_MASK(sym_k_XmToggleButton_object) |
  _BIT_MASK(sym_k_XmToggleButtonGadget_object) |
  _BIT_MASK(sym_k_XmWarningDialog_object) |
  _BIT_MASK(sym_k_XmWorkArea_object) |
  _BIT_MASK(sym_k_XmWorkingDialog_object) |
  0, 0};

/* sym_k_XmNmatchBehavior_arg */
static unsigned char arg_class_vec421[] =
  {
  0, 0, _BIT_MASK(sym_k_XmComboBox_object) |
  0, 0, 0, _BIT_MASK(sym_k_XmList_object) |
  0, 0, 0, _BIT_MASK(sym_k_XmScrolledList_object) |
  0, 0, 0, 0};

/* sym_k_XmNmaxAspectX_arg */
static unsigned char arg_class_vec422[] =
  {
  _BIT_MASK(sym_k_DtHelpDialog_object) |
  _BIT_MASK(sym_k_DtHelpQuickDialog_object) |
  _BIT_MASK(sym_k_DtPrintSetupDialog_object) |
  0, _BIT_MASK(sym_k_XmBulletinBoardDialog_object) |
  0, _BIT_MASK(sym_k_XmCommandDialog_object) |
  0, _BIT_MASK(sym_k_XmDialogShell_object) |
  _BIT_MASK(sym_k_XmErrorDialog_object) |
  _BIT_MASK(sym_k_XmFileSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmFormDialog_object) |
  _BIT_MASK(sym_k_XmInformationDialog_object) |
  0, _BIT_MASK(sym_k_XmMessageDialog_object) |
  0, _BIT_MASK(sym_k_XmPromptDialog_object) |
  0, _BIT_MASK(sym_k_XmQuestionDialog_object) |
  0, _BIT_MASK(sym_k_XmSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmTemplateDialog_object) |
  0, _BIT_MASK(sym_k_XmWarningDialog_object) |
  _BIT_MASK(sym_k_XmWorkingDialog_object) |
  0, 0};

/* sym_k_XmNmaxAspectY_arg */
static unsigned char arg_class_vec423[] =
  {
  _BIT_MASK(sym_k_DtHelpDialog_object) |
  _BIT_MASK(sym_k_DtHelpQuickDialog_object) |
  _BIT_MASK(sym_k_DtPrintSetupDialog_object) |
  0, _BIT_MASK(sym_k_XmBulletinBoardDialog_object) |
  0, _BIT_MASK(sym_k_XmCommandDialog_object) |
  0, _BIT_MASK(sym_k_XmDialogShell_object) |
  _BIT_MASK(sym_k_XmErrorDialog_object) |
  _BIT_MASK(sym_k_XmFileSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmFormDialog_object) |
  _BIT_MASK(sym_k_XmInformationDialog_object) |
  0, _BIT_MASK(sym_k_XmMessageDialog_object) |
  0, _BIT_MASK(sym_k_XmPromptDialog_object) |
  0, _BIT_MASK(sym_k_XmQuestionDialog_object) |
  0, _BIT_MASK(sym_k_XmSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmTemplateDialog_object) |
  0, _BIT_MASK(sym_k_XmWarningDialog_object) |
  _BIT_MASK(sym_k_XmWorkingDialog_object) |
  0, 0};

/* sym_k_XmNmaxHeight_arg */
static unsigned char arg_class_vec424[] =
  {
  _BIT_MASK(sym_k_DtHelpDialog_object) |
  _BIT_MASK(sym_k_DtHelpQuickDialog_object) |
  _BIT_MASK(sym_k_DtPrintSetupDialog_object) |
  0, _BIT_MASK(sym_k_XmBulletinBoardDialog_object) |
  0, _BIT_MASK(sym_k_XmCommandDialog_object) |
  0, _BIT_MASK(sym_k_XmDialogShell_object) |
  _BIT_MASK(sym_k_XmErrorDialog_object) |
  _BIT_MASK(sym_k_XmFileSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmFormDialog_object) |
  _BIT_MASK(sym_k_XmInformationDialog_object) |
  0, _BIT_MASK(sym_k_XmMessageDialog_object) |
  0, _BIT_MASK(sym_k_XmPromptDialog_object) |
  0, _BIT_MASK(sym_k_XmQuestionDialog_object) |
  0, _BIT_MASK(sym_k_XmSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmTemplateDialog_object) |
  0, _BIT_MASK(sym_k_XmWarningDialog_object) |
  _BIT_MASK(sym_k_XmWorkingDialog_object) |
  0, 0};

/* sym_k_XmNmaxLength_arg */
static unsigned char arg_class_vec425[] =
  {
  0, 0, _BIT_MASK(sym_k_XmDataField_object) |
  0, 0, 0, 0, 0, 0, _BIT_MASK(sym_k_XmScrolledText_object) |
  0, 0, _BIT_MASK(sym_k_XmText_object) |
  _BIT_MASK(sym_k_XmTextField_object) |
  0, 0};

/* sym_k_XmNmaxWidth_arg */
static unsigned char arg_class_vec426[] =
  {
  _BIT_MASK(sym_k_DtHelpDialog_object) |
  _BIT_MASK(sym_k_DtHelpQuickDialog_object) |
  _BIT_MASK(sym_k_DtPrintSetupDialog_object) |
  0, _BIT_MASK(sym_k_XmBulletinBoardDialog_object) |
  0, _BIT_MASK(sym_k_XmCommandDialog_object) |
  0, _BIT_MASK(sym_k_XmDialogShell_object) |
  _BIT_MASK(sym_k_XmErrorDialog_object) |
  _BIT_MASK(sym_k_XmFileSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmFormDialog_object) |
  _BIT_MASK(sym_k_XmInformationDialog_object) |
  0, _BIT_MASK(sym_k_XmMessageDialog_object) |
  0, _BIT_MASK(sym_k_XmPromptDialog_object) |
  0, _BIT_MASK(sym_k_XmQuestionDialog_object) |
  0, _BIT_MASK(sym_k_XmSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmTemplateDialog_object) |
  0, _BIT_MASK(sym_k_XmWarningDialog_object) |
  _BIT_MASK(sym_k_XmWorkingDialog_object) |
  0, 0};

/* sym_k_XmNmaximum_arg */
static unsigned char arg_class_vec427[] =
  {
  0, 0, 0, 0, 0, 0, 0, _BIT_MASK(sym_k_XmScale_object) |
  0, _BIT_MASK(sym_k_XmScrollBar_object) |
  0, 0, 0, 0};

/* sym_k_XmNmaximumValue_arg */
static unsigned char arg_class_vec428[] =
  {
  0, 0, 0, 0, 0, 0, 0, 0, 0, _BIT_MASK(sym_k_XmSimpleSpinBox_object) |
  _BIT_MASK(sym_k_XmSpinBox_object) |
  0, 0, 0};

/* sym_k_XmNmenuAccelerator_arg */
static unsigned char arg_class_vec429[] =
  {
  0, 0, _BIT_MASK(sym_k_XmCheckBox_object) |
  0, 0, 0, _BIT_MASK(sym_k_XmMenuBar_object) |
  0, _BIT_MASK(sym_k_XmOptionMenu_object) |
  _BIT_MASK(sym_k_XmPopupMenu_object) |
  _BIT_MASK(sym_k_XmPulldownMenu_object) |
  0, _BIT_MASK(sym_k_XmRadioBox_object) |
  _BIT_MASK(sym_k_XmRowColumn_object) |
  0, 0, 0, _BIT_MASK(sym_k_XmWorkArea_object) |
  0, 0};

/* sym_k_XmNmenuBar_arg */
static unsigned char arg_class_vec430[] =
  {
  0, 0, 0, 0, 0, _BIT_MASK(sym_k_XmMainWindow_object) |
  0, 0, 0, 0, 0, 0, 0};

/* sym_k_XmNmenuHelpWidget_arg */
static unsigned char arg_class_vec431[] =
  {
  0, 0, _BIT_MASK(sym_k_XmCheckBox_object) |
  0, 0, 0, _BIT_MASK(sym_k_XmMenuBar_object) |
  0, _BIT_MASK(sym_k_XmOptionMenu_object) |
  _BIT_MASK(sym_k_XmPopupMenu_object) |
  _BIT_MASK(sym_k_XmPulldownMenu_object) |
  0, _BIT_MASK(sym_k_XmRadioBox_object) |
  _BIT_MASK(sym_k_XmRowColumn_object) |
  0, 0, 0, _BIT_MASK(sym_k_XmWorkArea_object) |
  0, 0};

/* sym_k_XmNmenuHistory_arg */
static unsigned char arg_class_vec432[] =
  {
  0, 0, _BIT_MASK(sym_k_XmCheckBox_object) |
  0, 0, 0, _BIT_MASK(sym_k_XmMenuBar_object) |
  0, _BIT_MASK(sym_k_XmOptionMenu_object) |
  _BIT_MASK(sym_k_XmPopupMenu_object) |
  _BIT_MASK(sym_k_XmPulldownMenu_object) |
  0, _BIT_MASK(sym_k_XmRadioBox_object) |
  _BIT_MASK(sym_k_XmRowColumn_object) |
  0, 0, 0, _BIT_MASK(sym_k_XmWorkArea_object) |
  0, 0};

/* sym_k_XmNmenuPost_arg */
static unsigned char arg_class_vec433[] =
  {
  0, 0, _BIT_MASK(sym_k_XmCheckBox_object) |
  0, 0, 0, _BIT_MASK(sym_k_XmMenuBar_object) |
  0, _BIT_MASK(sym_k_XmOptionMenu_object) |
  _BIT_MASK(sym_k_XmPopupMenu_object) |
  _BIT_MASK(sym_k_XmPulldownMenu_object) |
  0, _BIT_MASK(sym_k_XmRadioBox_object) |
  _BIT_MASK(sym_k_XmRowColumn_object) |
  0, 0, 0, _BIT_MASK(sym_k_XmWorkArea_object) |
  0, 0};

/* sym_k_XmNmessageAlignment_arg */
static unsigned char arg_class_vec434[] =
  {
  0, 0, 0, _BIT_MASK(sym_k_XmErrorDialog_object) |
  0, _BIT_MASK(sym_k_XmInformationDialog_object) |
  0, _BIT_MASK(sym_k_XmMessageBox_object) |
  _BIT_MASK(sym_k_XmMessageDialog_object) |
  0, 0, _BIT_MASK(sym_k_XmQuestionDialog_object) |
  0, 0, _BIT_MASK(sym_k_XmTemplateDialog_object) |
  0, _BIT_MASK(sym_k_XmWarningDialog_object) |
  _BIT_MASK(sym_k_XmWorkingDialog_object) |
  0, 0};

/* sym_k_XmNmessageString_arg */
static unsigned char arg_class_vec435[] =
  {
  0, 0, 0, _BIT_MASK(sym_k_XmErrorDialog_object) |
  0, _BIT_MASK(sym_k_XmInformationDialog_object) |
  0, _BIT_MASK(sym_k_XmMessageBox_object) |
  _BIT_MASK(sym_k_XmMessageDialog_object) |
  0, 0, _BIT_MASK(sym_k_XmQuestionDialog_object) |
  0, 0, _BIT_MASK(sym_k_XmTemplateDialog_object) |
  0, _BIT_MASK(sym_k_XmWarningDialog_object) |
  _BIT_MASK(sym_k_XmWorkingDialog_object) |
  0, 0};

/* sym_k_XmNmessageWindow_arg */
static unsigned char arg_class_vec436[] =
  {
  0, 0, 0, 0, 0, _BIT_MASK(sym_k_XmMainWindow_object) |
  0, 0, 0, 0, 0, 0, 0};

/* sym_k_XmNminAspectX_arg */
static unsigned char arg_class_vec437[] =
  {
  _BIT_MASK(sym_k_DtHelpDialog_object) |
  _BIT_MASK(sym_k_DtHelpQuickDialog_object) |
  _BIT_MASK(sym_k_DtPrintSetupDialog_object) |
  0, _BIT_MASK(sym_k_XmBulletinBoardDialog_object) |
  0, _BIT_MASK(sym_k_XmCommandDialog_object) |
  0, _BIT_MASK(sym_k_XmDialogShell_object) |
  _BIT_MASK(sym_k_XmErrorDialog_object) |
  _BIT_MASK(sym_k_XmFileSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmFormDialog_object) |
  _BIT_MASK(sym_k_XmInformationDialog_object) |
  0, _BIT_MASK(sym_k_XmMessageDialog_object) |
  0, _BIT_MASK(sym_k_XmPromptDialog_object) |
  0, _BIT_MASK(sym_k_XmQuestionDialog_object) |
  0, _BIT_MASK(sym_k_XmSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmTemplateDialog_object) |
  0, _BIT_MASK(sym_k_XmWarningDialog_object) |
  _BIT_MASK(sym_k_XmWorkingDialog_object) |
  0, 0};

/* sym_k_XmNminAspectY_arg */
static unsigned char arg_class_vec438[] =
  {
  _BIT_MASK(sym_k_DtHelpDialog_object) |
  _BIT_MASK(sym_k_DtHelpQuickDialog_object) |
  _BIT_MASK(sym_k_DtPrintSetupDialog_object) |
  0, _BIT_MASK(sym_k_XmBulletinBoardDialog_object) |
  0, _BIT_MASK(sym_k_XmCommandDialog_object) |
  0, _BIT_MASK(sym_k_XmDialogShell_object) |
  _BIT_MASK(sym_k_XmErrorDialog_object) |
  _BIT_MASK(sym_k_XmFileSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmFormDialog_object) |
  _BIT_MASK(sym_k_XmInformationDialog_object) |
  0, _BIT_MASK(sym_k_XmMessageDialog_object) |
  0, _BIT_MASK(sym_k_XmPromptDialog_object) |
  0, _BIT_MASK(sym_k_XmQuestionDialog_object) |
  0, _BIT_MASK(sym_k_XmSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmTemplateDialog_object) |
  0, _BIT_MASK(sym_k_XmWarningDialog_object) |
  _BIT_MASK(sym_k_XmWorkingDialog_object) |
  0, 0};

/* sym_k_XmNminHeight_arg */
static unsigned char arg_class_vec439[] =
  {
  _BIT_MASK(sym_k_DtHelpDialog_object) |
  _BIT_MASK(sym_k_DtHelpQuickDialog_object) |
  _BIT_MASK(sym_k_DtPrintSetupDialog_object) |
  0, _BIT_MASK(sym_k_XmBulletinBoardDialog_object) |
  0, _BIT_MASK(sym_k_XmCommandDialog_object) |
  0, _BIT_MASK(sym_k_XmDialogShell_object) |
  _BIT_MASK(sym_k_XmErrorDialog_object) |
  _BIT_MASK(sym_k_XmFileSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmFormDialog_object) |
  _BIT_MASK(sym_k_XmInformationDialog_object) |
  0, _BIT_MASK(sym_k_XmMessageDialog_object) |
  0, _BIT_MASK(sym_k_XmPromptDialog_object) |
  0, _BIT_MASK(sym_k_XmQuestionDialog_object) |
  0, _BIT_MASK(sym_k_XmSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmTemplateDialog_object) |
  0, _BIT_MASK(sym_k_XmWarningDialog_object) |
  _BIT_MASK(sym_k_XmWorkingDialog_object) |
  0, 0};

/* sym_k_XmNminWidth_arg */
static unsigned char arg_class_vec440[] =
  {
  _BIT_MASK(sym_k_DtHelpDialog_object) |
  _BIT_MASK(sym_k_DtHelpQuickDialog_object) |
  _BIT_MASK(sym_k_DtPrintSetupDialog_object) |
  0, _BIT_MASK(sym_k_XmBulletinBoardDialog_object) |
  0, _BIT_MASK(sym_k_XmCommandDialog_object) |
  0, _BIT_MASK(sym_k_XmDialogShell_object) |
  _BIT_MASK(sym_k_XmErrorDialog_object) |
  _BIT_MASK(sym_k_XmFileSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmFormDialog_object) |
  _BIT_MASK(sym_k_XmInformationDialog_object) |
  0, _BIT_MASK(sym_k_XmMessageDialog_object) |
  0, _BIT_MASK(sym_k_XmPromptDialog_object) |
  0, _BIT_MASK(sym_k_XmQuestionDialog_object) |
  0, _BIT_MASK(sym_k_XmSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmTemplateDialog_object) |
  0, _BIT_MASK(sym_k_XmWarningDialog_object) |
  _BIT_MASK(sym_k_XmWorkingDialog_object) |
  0, 0};

/* sym_k_XmNminimizeButtons_arg */
static unsigned char arg_class_vec441[] =
  {
  0, 0, 0, _BIT_MASK(sym_k_XmErrorDialog_object) |
  _BIT_MASK(sym_k_XmFileSelectionBox_object) |
  _BIT_MASK(sym_k_XmFileSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmInformationDialog_object) |
  0, _BIT_MASK(sym_k_XmMessageBox_object) |
  _BIT_MASK(sym_k_XmMessageDialog_object) |
  0, _BIT_MASK(sym_k_XmPromptDialog_object) |
  0, _BIT_MASK(sym_k_XmQuestionDialog_object) |
  0, _BIT_MASK(sym_k_XmSelectionBox_object) |
  _BIT_MASK(sym_k_XmSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmTemplateDialog_object) |
  0, _BIT_MASK(sym_k_XmWarningDialog_object) |
  _BIT_MASK(sym_k_XmWorkingDialog_object) |
  0, 0};

/* sym_k_XmNminimum_arg */
static unsigned char arg_class_vec442[] =
  {
  0, 0, 0, 0, 0, 0, 0, _BIT_MASK(sym_k_XmScale_object) |
  0, _BIT_MASK(sym_k_XmScrollBar_object) |
  0, 0, 0, 0};

/* sym_k_XmNminimumCellHeight_arg */
static unsigned char arg_class_vec443[] =
  {
  0, 0, 0, 0, _BIT_MASK(sym_k_XmIconBox_object) |
  0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_XmNminimumCellWidth_arg */
static unsigned char arg_class_vec444[] =
  {
  0, 0, 0, 0, _BIT_MASK(sym_k_XmIconBox_object) |
  0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_XmNminimumHorizontalCells_arg */
static unsigned char arg_class_vec445[] =
  {
  0, 0, 0, 0, _BIT_MASK(sym_k_XmIconBox_object) |
  0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_XmNminimumValue_arg */
static unsigned char arg_class_vec446[] =
  {
  0, 0, 0, 0, 0, 0, 0, 0, 0, _BIT_MASK(sym_k_XmSimpleSpinBox_object) |
  _BIT_MASK(sym_k_XmSpinBox_object) |
  0, 0, 0};

/* sym_k_XmNminimumVerticalCells_arg */
static unsigned char arg_class_vec447[] =
  {
  0, 0, 0, 0, _BIT_MASK(sym_k_XmIconBox_object) |
  0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_XmNminorTabSpacing_arg */
static unsigned char arg_class_vec448[] =
  {
  0, 0, 0, 0, 0, 0, _BIT_MASK(sym_k_XmNotebook_object) |
  0, 0, 0, 0, 0, 0};

/* sym_k_XmNmnemonic_arg */
static unsigned char arg_class_vec449[] =
  {
  _BIT_MASK(sym_k_DtMenuButton_object) |
  0, _BIT_MASK(sym_k_XmCascadeButton_object) |
  _BIT_MASK(sym_k_XmCascadeButtonGadget_object) |
  0, _BIT_MASK(sym_k_XmCheckBox_object) |
  0, _BIT_MASK(sym_k_XmDrawnButton_object) |
  0, _BIT_MASK(sym_k_XmLabel_object) |
  0, _BIT_MASK(sym_k_XmLabelGadget_object) |
  _BIT_MASK(sym_k_XmMenuBar_object) |
  0, _BIT_MASK(sym_k_XmOptionMenu_object) |
  _BIT_MASK(sym_k_XmPopupMenu_object) |
  _BIT_MASK(sym_k_XmPulldownMenu_object) |
  0, _BIT_MASK(sym_k_XmPushButton_object) |
  _BIT_MASK(sym_k_XmPushButtonGadget_object) |
  _BIT_MASK(sym_k_XmRadioBox_object) |
  _BIT_MASK(sym_k_XmRowColumn_object) |
  0, 0, _BIT_MASK(sym_k_XmTearOffButton_object) |
  0, _BIT_MASK(sym_k_XmToggleButton_object) |
  _BIT_MASK(sym_k_XmToggleButtonGadget_object) |
  _BIT_MASK(sym_k_XmWorkArea_object) |
  0, 0};

/* sym_k_XmNmnemonicCharSet_arg */
static unsigned char arg_class_vec450[] =
  {
  _BIT_MASK(sym_k_DtMenuButton_object) |
  0, _BIT_MASK(sym_k_XmCascadeButton_object) |
  _BIT_MASK(sym_k_XmCascadeButtonGadget_object) |
  0, _BIT_MASK(sym_k_XmCheckBox_object) |
  0, _BIT_MASK(sym_k_XmDrawnButton_object) |
  0, _BIT_MASK(sym_k_XmLabel_object) |
  0, _BIT_MASK(sym_k_XmLabelGadget_object) |
  _BIT_MASK(sym_k_XmMenuBar_object) |
  0, _BIT_MASK(sym_k_XmOptionMenu_object) |
  _BIT_MASK(sym_k_XmPopupMenu_object) |
  _BIT_MASK(sym_k_XmPulldownMenu_object) |
  0, _BIT_MASK(sym_k_XmPushButton_object) |
  _BIT_MASK(sym_k_XmPushButtonGadget_object) |
  _BIT_MASK(sym_k_XmRadioBox_object) |
  _BIT_MASK(sym_k_XmRowColumn_object) |
  0, 0, _BIT_MASK(sym_k_XmTearOffButton_object) |
  0, _BIT_MASK(sym_k_XmToggleButton_object) |
  _BIT_MASK(sym_k_XmToggleButtonGadget_object) |
  _BIT_MASK(sym_k_XmWorkArea_object) |
  0, 0};

/* sym_k_XmNmonoSpaceString_arg */
static unsigned char arg_class_vec451[] =
  {
  0, 0, 0, _BIT_MASK(sym_k_XmFontSelector_object) |
  0, 0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_XmNmultiClick_arg */
static unsigned char arg_class_vec452[] =
  {
  0, _BIT_MASK(sym_k_XmArrowButton_object) |
  _BIT_MASK(sym_k_XmArrowButtonGadget_object) |
  0, 0, _BIT_MASK(sym_k_XmDrawnButton_object) |
  0, 0, 0, 0, _BIT_MASK(sym_k_XmPushButton_object) |
  _BIT_MASK(sym_k_XmPushButtonGadget_object) |
  0, 0, _BIT_MASK(sym_k_XmTearOffButton_object) |
  0, 0, 0};

/* sym_k_XmNmustMatch_arg */
static unsigned char arg_class_vec453[] =
  {
  0, 0, 0, _BIT_MASK(sym_k_XmFileSelectionBox_object) |
  _BIT_MASK(sym_k_XmFileSelectionDialog_object) |
  0, 0, 0, _BIT_MASK(sym_k_XmPromptDialog_object) |
  0, 0, _BIT_MASK(sym_k_XmSelectionBox_object) |
  _BIT_MASK(sym_k_XmSelectionDialog_object) |
  0, 0, 0, 0};

/* sym_k_XmNmwmDecorations_arg */
static unsigned char arg_class_vec454[] =
  {
  _BIT_MASK(sym_k_DtHelpDialog_object) |
  _BIT_MASK(sym_k_DtHelpQuickDialog_object) |
  _BIT_MASK(sym_k_DtPrintSetupDialog_object) |
  0, _BIT_MASK(sym_k_XmBulletinBoardDialog_object) |
  0, _BIT_MASK(sym_k_XmCommandDialog_object) |
  0, _BIT_MASK(sym_k_XmDialogShell_object) |
  _BIT_MASK(sym_k_XmErrorDialog_object) |
  _BIT_MASK(sym_k_XmFileSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmFormDialog_object) |
  _BIT_MASK(sym_k_XmInformationDialog_object) |
  0, _BIT_MASK(sym_k_XmMessageDialog_object) |
  0, _BIT_MASK(sym_k_XmPromptDialog_object) |
  0, _BIT_MASK(sym_k_XmQuestionDialog_object) |
  0, _BIT_MASK(sym_k_XmSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmTemplateDialog_object) |
  0, _BIT_MASK(sym_k_XmWarningDialog_object) |
  _BIT_MASK(sym_k_XmWorkingDialog_object) |
  0, 0};

/* sym_k_XmNmwmFunctions_arg */
static unsigned char arg_class_vec455[] =
  {
  _BIT_MASK(sym_k_DtHelpDialog_object) |
  _BIT_MASK(sym_k_DtHelpQuickDialog_object) |
  _BIT_MASK(sym_k_DtPrintSetupDialog_object) |
  0, _BIT_MASK(sym_k_XmBulletinBoardDialog_object) |
  0, _BIT_MASK(sym_k_XmCommandDialog_object) |
  0, _BIT_MASK(sym_k_XmDialogShell_object) |
  _BIT_MASK(sym_k_XmErrorDialog_object) |
  _BIT_MASK(sym_k_XmFileSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmFormDialog_object) |
  _BIT_MASK(sym_k_XmInformationDialog_object) |
  0, _BIT_MASK(sym_k_XmMessageDialog_object) |
  0, _BIT_MASK(sym_k_XmPromptDialog_object) |
  0, _BIT_MASK(sym_k_XmQuestionDialog_object) |
  0, _BIT_MASK(sym_k_XmSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmTemplateDialog_object) |
  0, _BIT_MASK(sym_k_XmWarningDialog_object) |
  _BIT_MASK(sym_k_XmWorkingDialog_object) |
  0, 0};

/* sym_k_XmNmwmInputMode_arg */
static unsigned char arg_class_vec456[] =
  {
  _BIT_MASK(sym_k_DtHelpDialog_object) |
  _BIT_MASK(sym_k_DtHelpQuickDialog_object) |
  _BIT_MASK(sym_k_DtPrintSetupDialog_object) |
  0, _BIT_MASK(sym_k_XmBulletinBoardDialog_object) |
  0, _BIT_MASK(sym_k_XmCommandDialog_object) |
  0, _BIT_MASK(sym_k_XmDialogShell_object) |
  _BIT_MASK(sym_k_XmErrorDialog_object) |
  _BIT_MASK(sym_k_XmFileSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmFormDialog_object) |
  _BIT_MASK(sym_k_XmInformationDialog_object) |
  0, _BIT_MASK(sym_k_XmMessageDialog_object) |
  0, _BIT_MASK(sym_k_XmPromptDialog_object) |
  0, _BIT_MASK(sym_k_XmQuestionDialog_object) |
  0, _BIT_MASK(sym_k_XmSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmTemplateDialog_object) |
  0, _BIT_MASK(sym_k_XmWarningDialog_object) |
  _BIT_MASK(sym_k_XmWorkingDialog_object) |
  0, 0};

/* sym_k_XmNmwmMenu_arg */
static unsigned char arg_class_vec457[] =
  {
  _BIT_MASK(sym_k_DtHelpDialog_object) |
  _BIT_MASK(sym_k_DtHelpQuickDialog_object) |
  _BIT_MASK(sym_k_DtPrintSetupDialog_object) |
  0, _BIT_MASK(sym_k_XmBulletinBoardDialog_object) |
  0, _BIT_MASK(sym_k_XmCommandDialog_object) |
  0, _BIT_MASK(sym_k_XmDialogShell_object) |
  _BIT_MASK(sym_k_XmErrorDialog_object) |
  _BIT_MASK(sym_k_XmFileSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmFormDialog_object) |
  _BIT_MASK(sym_k_XmInformationDialog_object) |
  0, _BIT_MASK(sym_k_XmMessageDialog_object) |
  0, _BIT_MASK(sym_k_XmPromptDialog_object) |
  0, _BIT_MASK(sym_k_XmQuestionDialog_object) |
  0, _BIT_MASK(sym_k_XmSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmTemplateDialog_object) |
  0, _BIT_MASK(sym_k_XmWarningDialog_object) |
  _BIT_MASK(sym_k_XmWorkingDialog_object) |
  0, 0};

/* sym_k_XmNnavigationType_arg */
static unsigned char arg_class_vec458[] =
  {
  _BIT_MASK(sym_k_DtEditor_object) |
  _BIT_MASK(sym_k_DtHelpDialog_object) |
  _BIT_MASK(sym_k_DtHelpQuickDialog_object) |
  _BIT_MASK(sym_k_DtMenuButton_object) |
  _BIT_MASK(sym_k_DtPrintSetupBox_object) |
  _BIT_MASK(sym_k_DtPrintSetupDialog_object) |
  _BIT_MASK(sym_k_DtTerm_object) |
  0, _BIT_MASK(sym_k_DtTermPrimitive_object) |
  _BIT_MASK(sym_k_XmArrowButton_object) |
  _BIT_MASK(sym_k_XmArrowButtonGadget_object) |
  _BIT_MASK(sym_k_XmBulletinBoard_object) |
  _BIT_MASK(sym_k_XmBulletinBoardDialog_object) |
  _BIT_MASK(sym_k_XmButtonBox_object) |
  _BIT_MASK(sym_k_XmCascadeButton_object) |
  _BIT_MASK(sym_k_XmCascadeButtonGadget_object) |
  0, _BIT_MASK(sym_k_XmCheckBox_object) |
  _BIT_MASK(sym_k_XmColorSelector_object) |
  _BIT_MASK(sym_k_XmColumn_object) |
  _BIT_MASK(sym_k_XmComboBox_object) |
  _BIT_MASK(sym_k_XmCommand_object) |
  _BIT_MASK(sym_k_XmCommandDialog_object) |
  _BIT_MASK(sym_k_XmContainer_object) |
  _BIT_MASK(sym_k_XmDataField_object) |
  0, _BIT_MASK(sym_k_XmDrawingArea_object) |
  _BIT_MASK(sym_k_XmDrawnButton_object) |
  _BIT_MASK(sym_k_XmDropDown_object) |
  _BIT_MASK(sym_k_XmErrorDialog_object) |
  _BIT_MASK(sym_k_XmFileSelectionBox_object) |
  _BIT_MASK(sym_k_XmFileSelectionDialog_object) |
  _BIT_MASK(sym_k_XmFontSelector_object) |
  0, _BIT_MASK(sym_k_XmForm_object) |
  _BIT_MASK(sym_k_XmFormDialog_object) |
  _BIT_MASK(sym_k_XmFrame_object) |
  _BIT_MASK(sym_k_XmIconBox_object) |
  _BIT_MASK(sym_k_XmIconButton_object) |
  _BIT_MASK(sym_k_XmIconGadget_object) |
  _BIT_MASK(sym_k_XmInformationDialog_object) |
  _BIT_MASK(sym_k_XmLabel_object) |
  0, _BIT_MASK(sym_k_XmLabelGadget_object) |
  _BIT_MASK(sym_k_XmList_object) |
  _BIT_MASK(sym_k_XmMainWindow_object) |
  _BIT_MASK(sym_k_XmMenuBar_object) |
  _BIT_MASK(sym_k_XmMessageBox_object) |
  _BIT_MASK(sym_k_XmMessageDialog_object) |
  _BIT_MASK(sym_k_XmMultiList_object) |
  0, _BIT_MASK(sym_k_XmNotebook_object) |
  _BIT_MASK(sym_k_XmOptionMenu_object) |
  _BIT_MASK(sym_k_XmOutline_object) |
  _BIT_MASK(sym_k_XmPaned_object) |
  _BIT_MASK(sym_k_XmPanedWindow_object) |
  _BIT_MASK(sym_k_XmPopupMenu_object) |
  _BIT_MASK(sym_k_XmPromptDialog_object) |
  _BIT_MASK(sym_k_XmPulldownMenu_object) |
  0, _BIT_MASK(sym_k_XmPushButton_object) |
  _BIT_MASK(sym_k_XmPushButtonGadget_object) |
  _BIT_MASK(sym_k_XmQuestionDialog_object) |
  _BIT_MASK(sym_k_XmRadioBox_object) |
  _BIT_MASK(sym_k_XmRowColumn_object) |
  _BIT_MASK(sym_k_XmScale_object) |
  0, _BIT_MASK(sym_k_XmScrollBar_object) |
  _BIT_MASK(sym_k_XmScrolledList_object) |
  _BIT_MASK(sym_k_XmScrolledText_object) |
  _BIT_MASK(sym_k_XmScrolledWindow_object) |
  _BIT_MASK(sym_k_XmSelectionBox_object) |
  _BIT_MASK(sym_k_XmSelectionDialog_object) |
  _BIT_MASK(sym_k_XmSeparator_object) |
  _BIT_MASK(sym_k_XmSeparatorGadget_object) |
  0, _BIT_MASK(sym_k_XmSimpleSpinBox_object) |
  _BIT_MASK(sym_k_XmSpinBox_object) |
  _BIT_MASK(sym_k_XmTabBox_object) |
  _BIT_MASK(sym_k_XmTabStack_object) |
  _BIT_MASK(sym_k_XmTearOffButton_object) |
  _BIT_MASK(sym_k_XmTemplateDialog_object) |
  0, _BIT_MASK(sym_k_XmText_object) |
  _BIT_MASK(sym_k_XmTextField_object) |
  _BIT_MASK(sym_k_XmToggleButton_object) |
  _BIT_MASK(sym_k_XmToggleButtonGadget_object) |
  _BIT_MASK(sym_k_XmTree_object) |
  _BIT_MASK(sym_k_XmWarningDialog_object) |
  _BIT_MASK(sym_k_XmWorkArea_object) |
  _BIT_MASK(sym_k_XmWorkingDialog_object) |
  0, 0};

/* sym_k_XmNnewVisualStyle_arg */
static unsigned char arg_class_vec459[] =
  {
  0, 0, 0, _BIT_MASK(sym_k_XmDropDown_object) |
  0, 0, _BIT_MASK(sym_k_XmMultiList_object) |
  0, 0, 0, 0, 0, 0, 0};

/* sym_k_XmNnoCellError_arg */
static unsigned char arg_class_vec460[] =
  {
  0, 0, _BIT_MASK(sym_k_XmColorSelector_object) |
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_XmNnoMatchString_arg */
static unsigned char arg_class_vec461[] =
  {
  0, 0, 0, _BIT_MASK(sym_k_XmFileSelectionBox_object) |
  _BIT_MASK(sym_k_XmFileSelectionDialog_object) |
  0, 0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_XmNnoResize_arg */
static unsigned char arg_class_vec462[] =
  {
  _BIT_MASK(sym_k_DtEditor_object) |
  _BIT_MASK(sym_k_DtHelpDialog_object) |
  _BIT_MASK(sym_k_DtHelpQuickDialog_object) |
  _BIT_MASK(sym_k_DtPrintSetupBox_object) |
  _BIT_MASK(sym_k_DtPrintSetupDialog_object) |
  0, _BIT_MASK(sym_k_XmBulletinBoard_object) |
  _BIT_MASK(sym_k_XmBulletinBoardDialog_object) |
  0, _BIT_MASK(sym_k_XmColumn_object) |
  _BIT_MASK(sym_k_XmCommand_object) |
  _BIT_MASK(sym_k_XmCommandDialog_object) |
  0, _BIT_MASK(sym_k_XmErrorDialog_object) |
  _BIT_MASK(sym_k_XmFileSelectionBox_object) |
  _BIT_MASK(sym_k_XmFileSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmForm_object) |
  _BIT_MASK(sym_k_XmFormDialog_object) |
  _BIT_MASK(sym_k_XmInformationDialog_object) |
  0, _BIT_MASK(sym_k_XmMessageBox_object) |
  _BIT_MASK(sym_k_XmMessageDialog_object) |
  0, _BIT_MASK(sym_k_XmPromptDialog_object) |
  0, _BIT_MASK(sym_k_XmQuestionDialog_object) |
  0, _BIT_MASK(sym_k_XmSelectionBox_object) |
  _BIT_MASK(sym_k_XmSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmTabStack_object) |
  _BIT_MASK(sym_k_XmTemplateDialog_object) |
  0, _BIT_MASK(sym_k_XmWarningDialog_object) |
  _BIT_MASK(sym_k_XmWorkingDialog_object) |
  0, 0};

/* sym_k_XmNnodeCloseFolderPixmap_arg */
static unsigned char arg_class_vec463[] =
  {
  0, 0, 0, 0, 0, 0, _BIT_MASK(sym_k_XmOutline_object) |
  0, 0, 0, 0, _BIT_MASK(sym_k_XmTree_object) |
  0, 0};

/* sym_k_XmNnodeOpenFolderPixmap_arg */
static unsigned char arg_class_vec464[] =
  {
  0, 0, 0, 0, 0, 0, _BIT_MASK(sym_k_XmOutline_object) |
  0, 0, 0, 0, _BIT_MASK(sym_k_XmTree_object) |
  0, 0};

/* sym_k_XmNnodeState_arg */
static unsigned char arg_class_vec465[] =
  {
  0, 0, 0, 0, 0, 0, _BIT_MASK(sym_k_XmOutline_object) |
  0, 0, 0, 0, _BIT_MASK(sym_k_XmTree_object) |
  0, 0};

/* sym_k_XmNnotebookChildType_arg */
static unsigned char arg_class_vec466[] =
  {
  0, 0, 0, 0, 0, 0, _BIT_MASK(sym_k_XmNotebook_object) |
  0, 0, 0, 0, 0, 0};

/* sym_k_XmNnumColumns_arg */
static unsigned char arg_class_vec467[] =
  {
  0, 0, _BIT_MASK(sym_k_XmCheckBox_object) |
  0, 0, 0, _BIT_MASK(sym_k_XmMenuBar_object) |
  _BIT_MASK(sym_k_XmMultiList_object) |
  0, _BIT_MASK(sym_k_XmOptionMenu_object) |
  _BIT_MASK(sym_k_XmPopupMenu_object) |
  _BIT_MASK(sym_k_XmPulldownMenu_object) |
  0, _BIT_MASK(sym_k_XmRadioBox_object) |
  _BIT_MASK(sym_k_XmRowColumn_object) |
  0, 0, 0, _BIT_MASK(sym_k_XmWorkArea_object) |
  0, 0};

/* sym_k_XmNnumRows_arg */
static unsigned char arg_class_vec468[] =
  {
  0, 0, 0, 0, 0, _BIT_MASK(sym_k_XmMultiList_object) |
  0, 0, 0, 0, 0, 0, 0};

/* sym_k_XmNnumStacks_arg */
static unsigned char arg_class_vec469[] =
  {
  0, 0, 0, 0, 0, 0, 0, 0, 0, _BIT_MASK(sym_k_XmTabBox_object) |
  _BIT_MASK(sym_k_XmTabStack_object) |
  0, 0, 0};

/* sym_k_XmNnumValues_arg */
static unsigned char arg_class_vec470[] =
  {
  0, 0, 0, 0, 0, 0, 0, 0, 0, _BIT_MASK(sym_k_XmSimpleSpinBox_object) |
  _BIT_MASK(sym_k_XmSpinBox_object) |
  0, 0, 0};

/* sym_k_XmNoffsetModel_arg */
static unsigned char arg_class_vec471[] =
  {
  0, 0, 0, 0, 0, 0, 0, 0, 0, _BIT_MASK(sym_k_XmTab_object) |
  0, 0, 0};

/* sym_k_XmNokLabelString_arg */
static unsigned char arg_class_vec472[] =
  {
  0, 0, 0, _BIT_MASK(sym_k_XmErrorDialog_object) |
  _BIT_MASK(sym_k_XmFileSelectionBox_object) |
  _BIT_MASK(sym_k_XmFileSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmInformationDialog_object) |
  0, _BIT_MASK(sym_k_XmMessageBox_object) |
  _BIT_MASK(sym_k_XmMessageDialog_object) |
  0, _BIT_MASK(sym_k_XmPromptDialog_object) |
  0, _BIT_MASK(sym_k_XmQuestionDialog_object) |
  0, _BIT_MASK(sym_k_XmSelectionBox_object) |
  _BIT_MASK(sym_k_XmSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmTemplateDialog_object) |
  0, _BIT_MASK(sym_k_XmWarningDialog_object) |
  _BIT_MASK(sym_k_XmWorkingDialog_object) |
  0, 0};

/* sym_k_XmNopenClosePadding_arg */
static unsigned char arg_class_vec473[] =
  {
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, _BIT_MASK(sym_k_XmTree_object) |
  0, 0};

/* sym_k_XmNopenFolderPixmap_arg */
static unsigned char arg_class_vec474[] =
  {
  0, 0, 0, 0, 0, 0, _BIT_MASK(sym_k_XmOutline_object) |
  0, 0, 0, 0, _BIT_MASK(sym_k_XmTree_object) |
  0, 0};

/* sym_k_XmNoptionString_arg */
static unsigned char arg_class_vec475[] =
  {
  0, 0, 0, _BIT_MASK(sym_k_XmFontSelector_object) |
  0, 0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_XmNorientation_arg */
static unsigned char arg_class_vec476[] =
  {
  0, _BIT_MASK(sym_k_XmButtonBox_object) |
  0, _BIT_MASK(sym_k_XmCheckBox_object) |
  _BIT_MASK(sym_k_XmColumn_object) |
  0, _BIT_MASK(sym_k_XmFontSelector_object) |
  0, 0, _BIT_MASK(sym_k_XmMenuBar_object) |
  0, _BIT_MASK(sym_k_XmNotebook_object) |
  _BIT_MASK(sym_k_XmOptionMenu_object) |
  _BIT_MASK(sym_k_XmPaned_object) |
  _BIT_MASK(sym_k_XmPanedWindow_object) |
  _BIT_MASK(sym_k_XmPopupMenu_object) |
  _BIT_MASK(sym_k_XmPulldownMenu_object) |
  0, _BIT_MASK(sym_k_XmRadioBox_object) |
  _BIT_MASK(sym_k_XmRowColumn_object) |
  _BIT_MASK(sym_k_XmScale_object) |
  0, _BIT_MASK(sym_k_XmScrollBar_object) |
  _BIT_MASK(sym_k_XmSeparator_object) |
  _BIT_MASK(sym_k_XmSeparatorGadget_object) |
  0, _BIT_MASK(sym_k_XmTabBox_object) |
  0, _BIT_MASK(sym_k_XmTree_object) |
  _BIT_MASK(sym_k_XmWorkArea_object) |
  0, 0};

/* sym_k_XmNotherString_arg */
static unsigned char arg_class_vec477[] =
  {
  0, 0, 0, _BIT_MASK(sym_k_XmFontSelector_object) |
  0, 0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_XmNoutlineButtonPolicy_arg */
static unsigned char arg_class_vec478[] =
  {
  0, 0, _BIT_MASK(sym_k_XmContainer_object) |
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_XmNoutlineColumnWidth_arg */
static unsigned char arg_class_vec479[] =
  {
  0, 0, _BIT_MASK(sym_k_XmContainer_object) |
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_XmNoutlineIndentation_arg */
static unsigned char arg_class_vec480[] =
  {
  0, 0, _BIT_MASK(sym_k_XmContainer_object) |
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_XmNoutlineLineStyle_arg */
static unsigned char arg_class_vec481[] =
  {
  0, 0, _BIT_MASK(sym_k_XmContainer_object) |
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_XmNoutlineState_arg */
static unsigned char arg_class_vec482[] =
  {
  0, 0, _BIT_MASK(sym_k_XmContainer_object) |
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_XmNoverrideRedirect_arg */
static unsigned char arg_class_vec483[] =
  {
  _BIT_MASK(sym_k_DtHelpDialog_object) |
  _BIT_MASK(sym_k_DtHelpQuickDialog_object) |
  _BIT_MASK(sym_k_DtPrintSetupDialog_object) |
  0, _BIT_MASK(sym_k_XmBulletinBoardDialog_object) |
  0, _BIT_MASK(sym_k_XmCommandDialog_object) |
  0, _BIT_MASK(sym_k_XmDialogShell_object) |
  _BIT_MASK(sym_k_XmErrorDialog_object) |
  _BIT_MASK(sym_k_XmFileSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmFormDialog_object) |
  _BIT_MASK(sym_k_XmInformationDialog_object) |
  0, _BIT_MASK(sym_k_XmMenuShell_object) |
  _BIT_MASK(sym_k_XmMessageDialog_object) |
  0, _BIT_MASK(sym_k_XmPopupMenu_object) |
  _BIT_MASK(sym_k_XmPromptDialog_object) |
  _BIT_MASK(sym_k_XmPulldownMenu_object) |
  0, _BIT_MASK(sym_k_XmQuestionDialog_object) |
  0, _BIT_MASK(sym_k_XmSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmTemplateDialog_object) |
  0, _BIT_MASK(sym_k_XmWarningDialog_object) |
  _BIT_MASK(sym_k_XmWorkingDialog_object) |
  0, 0};

/* sym_k_XmNpacking_arg */
static unsigned char arg_class_vec484[] =
  {
  0, 0, _BIT_MASK(sym_k_XmCheckBox_object) |
  0, 0, 0, _BIT_MASK(sym_k_XmMenuBar_object) |
  0, _BIT_MASK(sym_k_XmOptionMenu_object) |
  _BIT_MASK(sym_k_XmPopupMenu_object) |
  _BIT_MASK(sym_k_XmPulldownMenu_object) |
  0, _BIT_MASK(sym_k_XmRadioBox_object) |
  _BIT_MASK(sym_k_XmRowColumn_object) |
  0, 0, 0, _BIT_MASK(sym_k_XmWorkArea_object) |
  0, 0};

/* sym_k_XmNpageIncrement_arg */
static unsigned char arg_class_vec485[] =
  {
  0, 0, 0, 0, 0, 0, 0, 0, _BIT_MASK(sym_k_XmScrollBar_object) |
  0, 0, 0, 0};

/* sym_k_XmNpageNumber_arg */
static unsigned char arg_class_vec486[] =
  {
  0, 0, 0, 0, 0, 0, _BIT_MASK(sym_k_XmNotebook_object) |
  0, 0, 0, 0, 0, 0};

/* sym_k_XmNpaneMaximum_arg */
static unsigned char arg_class_vec487[] =
  {
  0, 0, 0, _BIT_MASK(sym_k_XmFontSelector_object) |
  0, 0, 0, _BIT_MASK(sym_k_XmPaned_object) |
  _BIT_MASK(sym_k_XmPanedWindow_object) |
  0, 0, 0, 0, 0, 0};

/* sym_k_XmNpaneMinimum_arg */
static unsigned char arg_class_vec488[] =
  {
  0, 0, 0, _BIT_MASK(sym_k_XmFontSelector_object) |
  0, 0, 0, _BIT_MASK(sym_k_XmPaned_object) |
  _BIT_MASK(sym_k_XmPanedWindow_object) |
  0, 0, 0, 0, 0, 0};

/* sym_k_XmNparentNode_arg */
static unsigned char arg_class_vec489[] =
  {
  0, 0, 0, 0, 0, 0, _BIT_MASK(sym_k_XmOutline_object) |
  0, 0, 0, 0, _BIT_MASK(sym_k_XmTree_object) |
  0, 0};

/* sym_k_XmNpattern_arg */
static unsigned char arg_class_vec490[] =
  {
  0, 0, 0, _BIT_MASK(sym_k_XmFileSelectionBox_object) |
  _BIT_MASK(sym_k_XmFileSelectionDialog_object) |
  0, 0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_XmNpendingDelete_arg */
static unsigned char arg_class_vec491[] =
  {
  0, 0, _BIT_MASK(sym_k_XmDataField_object) |
  0, 0, 0, 0, 0, 0, _BIT_MASK(sym_k_XmScrolledText_object) |
  0, 0, _BIT_MASK(sym_k_XmText_object) |
  _BIT_MASK(sym_k_XmTextField_object) |
  0, 0};

/* sym_k_XmNpicture_arg */
static unsigned char arg_class_vec492[] =
  {
  0, 0, _BIT_MASK(sym_k_XmDataField_object) |
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_XmNpixmap_arg */
static unsigned char arg_class_vec493[] =
  {
  0, 0, 0, 0, _BIT_MASK(sym_k_XmIconButton_object) |
  0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_XmNpixmapDepth_arg */
static unsigned char arg_class_vec494[] =
  {
  0, 0, 0, 0, _BIT_MASK(sym_k_XmIconButton_object) |
  0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_XmNpixmapHeight_arg */
static unsigned char arg_class_vec495[] =
  {
  0, 0, 0, 0, _BIT_MASK(sym_k_XmIconButton_object) |
  0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_XmNpixmapPlacement_arg */
static unsigned char arg_class_vec496[] =
  {
  _BIT_MASK(sym_k_DtMenuButton_object) |
  0, _BIT_MASK(sym_k_XmCascadeButton_object) |
  _BIT_MASK(sym_k_XmCascadeButtonGadget_object) |
  0, 0, _BIT_MASK(sym_k_XmDrawnButton_object) |
  0, _BIT_MASK(sym_k_XmLabel_object) |
  0, _BIT_MASK(sym_k_XmLabelGadget_object) |
  0, 0, _BIT_MASK(sym_k_XmPushButton_object) |
  _BIT_MASK(sym_k_XmPushButtonGadget_object) |
  0, 0, _BIT_MASK(sym_k_XmTearOffButton_object) |
  0, _BIT_MASK(sym_k_XmToggleButton_object) |
  _BIT_MASK(sym_k_XmToggleButtonGadget_object) |
  0, 0};

/* sym_k_XmNpixmapTextPadding_arg */
static unsigned char arg_class_vec497[] =
  {
  _BIT_MASK(sym_k_DtMenuButton_object) |
  0, _BIT_MASK(sym_k_XmCascadeButton_object) |
  _BIT_MASK(sym_k_XmCascadeButtonGadget_object) |
  0, 0, _BIT_MASK(sym_k_XmDrawnButton_object) |
  0, _BIT_MASK(sym_k_XmLabel_object) |
  0, _BIT_MASK(sym_k_XmLabelGadget_object) |
  0, 0, _BIT_MASK(sym_k_XmPushButton_object) |
  _BIT_MASK(sym_k_XmPushButtonGadget_object) |
  0, 0, _BIT_MASK(sym_k_XmTearOffButton_object) |
  0, _BIT_MASK(sym_k_XmToggleButton_object) |
  _BIT_MASK(sym_k_XmToggleButtonGadget_object) |
  0, 0};

/* sym_k_XmNpixmapWidth_arg */
static unsigned char arg_class_vec498[] =
  {
  0, 0, 0, 0, _BIT_MASK(sym_k_XmIconButton_object) |
  0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_XmNpopupCursor_arg */
static unsigned char arg_class_vec499[] =
  {
  0, 0, 0, _BIT_MASK(sym_k_XmDropDown_object) |
  0, 0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_XmNpopupEnabled_arg */
static unsigned char arg_class_vec500[] =
  {
  0, 0, _BIT_MASK(sym_k_XmCheckBox_object) |
  0, 0, 0, _BIT_MASK(sym_k_XmMenuBar_object) |
  0, _BIT_MASK(sym_k_XmOptionMenu_object) |
  _BIT_MASK(sym_k_XmPopupMenu_object) |
  _BIT_MASK(sym_k_XmPulldownMenu_object) |
  0, _BIT_MASK(sym_k_XmRadioBox_object) |
  _BIT_MASK(sym_k_XmRowColumn_object) |
  0, 0, 0, _BIT_MASK(sym_k_XmWorkArea_object) |
  0, 0};

/* sym_k_XmNpopupOffset_arg */
static unsigned char arg_class_vec501[] =
  {
  0, 0, 0, _BIT_MASK(sym_k_XmDropDown_object) |
  0, 0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_XmNpopupShellWidget_arg */
static unsigned char arg_class_vec502[] =
  {
  0, 0, 0, _BIT_MASK(sym_k_XmDropDown_object) |
  0, 0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_XmNposition_arg */
static unsigned char arg_class_vec503[] =
  {
  0, 0, 0, 0, 0, 0, 0, 0, 0, _BIT_MASK(sym_k_XmSimpleSpinBox_object) |
  _BIT_MASK(sym_k_XmSpinBox_object) |
  0, 0, 0};

/* sym_k_XmNpositionIndex_arg */
static unsigned char arg_class_vec504[] =
  {
  0, 0, _BIT_MASK(sym_k_XmCheckBox_object) |
  _BIT_MASK(sym_k_XmContainer_object) |
  0, 0, 0, _BIT_MASK(sym_k_XmMenuBar_object) |
  0, _BIT_MASK(sym_k_XmOptionMenu_object) |
  _BIT_MASK(sym_k_XmPanedWindow_object) |
  _BIT_MASK(sym_k_XmPopupMenu_object) |
  _BIT_MASK(sym_k_XmPulldownMenu_object) |
  0, _BIT_MASK(sym_k_XmRadioBox_object) |
  _BIT_MASK(sym_k_XmRowColumn_object) |
  0, 0, 0, _BIT_MASK(sym_k_XmWorkArea_object) |
  0, 0};

/* sym_k_XmNpositionMode_arg */
static unsigned char arg_class_vec505[] =
  {
  0, 0, _BIT_MASK(sym_k_XmComboBox_object) |
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_XmNpositionType_arg */
static unsigned char arg_class_vec506[] =
  {
  0, 0, 0, 0, 0, 0, 0, 0, 0, _BIT_MASK(sym_k_XmSimpleSpinBox_object) |
  _BIT_MASK(sym_k_XmSpinBox_object) |
  0, 0, 0};

/* sym_k_XmNpreeditType_arg */
static unsigned char arg_class_vec507[] =
  {
  _BIT_MASK(sym_k_DtHelpDialog_object) |
  _BIT_MASK(sym_k_DtHelpQuickDialog_object) |
  _BIT_MASK(sym_k_DtPrintSetupDialog_object) |
  0, _BIT_MASK(sym_k_XmBulletinBoardDialog_object) |
  0, _BIT_MASK(sym_k_XmCommandDialog_object) |
  0, _BIT_MASK(sym_k_XmDialogShell_object) |
  _BIT_MASK(sym_k_XmErrorDialog_object) |
  _BIT_MASK(sym_k_XmFileSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmFormDialog_object) |
  _BIT_MASK(sym_k_XmInformationDialog_object) |
  0, _BIT_MASK(sym_k_XmMessageDialog_object) |
  0, _BIT_MASK(sym_k_XmPromptDialog_object) |
  0, _BIT_MASK(sym_k_XmQuestionDialog_object) |
  0, _BIT_MASK(sym_k_XmSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmTemplateDialog_object) |
  0, _BIT_MASK(sym_k_XmWarningDialog_object) |
  _BIT_MASK(sym_k_XmWorkingDialog_object) |
  0, 0};

/* sym_k_XmNpreferredPaneSize_arg */
static unsigned char arg_class_vec508[] =
  {
  0, 0, 0, _BIT_MASK(sym_k_XmFontSelector_object) |
  0, 0, 0, _BIT_MASK(sym_k_XmPaned_object) |
  0, 0, 0, 0, 0, 0};

/* sym_k_XmNprimaryOwnership_arg */
static unsigned char arg_class_vec509[] =
  {
  0, 0, _BIT_MASK(sym_k_XmContainer_object) |
  0, 0, 0, _BIT_MASK(sym_k_XmList_object) |
  0, 0, 0, _BIT_MASK(sym_k_XmScrolledList_object) |
  0, 0, 0, 0};

/* sym_k_XmNprocessingDirection_arg */
static unsigned char arg_class_vec510[] =
  {
  0, 0, 0, 0, 0, 0, 0, _BIT_MASK(sym_k_XmScale_object) |
  0, _BIT_MASK(sym_k_XmScrollBar_object) |
  0, 0, 0, 0};

/* sym_k_XmNpromptString_arg */
static unsigned char arg_class_vec511[] =
  {
  0, 0, _BIT_MASK(sym_k_XmCommand_object) |
  _BIT_MASK(sym_k_XmCommandDialog_object) |
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_XmNpropSpaceString_arg */
static unsigned char arg_class_vec512[] =
  {
  0, 0, 0, _BIT_MASK(sym_k_XmFontSelector_object) |
  0, 0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_XmNpushButtonEnabled_arg */
static unsigned char arg_class_vec513[] =
  {
  0, 0, 0, _BIT_MASK(sym_k_XmDrawnButton_object) |
  0, 0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_XmNqualifySearchDataProc_arg */
static unsigned char arg_class_vec514[] =
  {
  0, 0, 0, _BIT_MASK(sym_k_XmFileSelectionBox_object) |
  _BIT_MASK(sym_k_XmFileSelectionDialog_object) |
  0, 0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_XmNradioAlwaysOne_arg */
static unsigned char arg_class_vec515[] =
  {
  0, 0, _BIT_MASK(sym_k_XmCheckBox_object) |
  0, 0, 0, _BIT_MASK(sym_k_XmMenuBar_object) |
  0, _BIT_MASK(sym_k_XmOptionMenu_object) |
  _BIT_MASK(sym_k_XmPopupMenu_object) |
  _BIT_MASK(sym_k_XmPulldownMenu_object) |
  0, _BIT_MASK(sym_k_XmRadioBox_object) |
  _BIT_MASK(sym_k_XmRowColumn_object) |
  0, 0, 0, _BIT_MASK(sym_k_XmWorkArea_object) |
  0, 0};

/* sym_k_XmNradioBehavior_arg */
static unsigned char arg_class_vec516[] =
  {
  0, 0, _BIT_MASK(sym_k_XmCheckBox_object) |
  0, 0, 0, _BIT_MASK(sym_k_XmMenuBar_object) |
  0, _BIT_MASK(sym_k_XmOptionMenu_object) |
  _BIT_MASK(sym_k_XmPopupMenu_object) |
  _BIT_MASK(sym_k_XmPulldownMenu_object) |
  0, _BIT_MASK(sym_k_XmRadioBox_object) |
  _BIT_MASK(sym_k_XmRowColumn_object) |
  0, 0, 0, _BIT_MASK(sym_k_XmWorkArea_object) |
  0, 0};

/* sym_k_XmNrecomputeSize_arg */
static unsigned char arg_class_vec517[] =
  {
  _BIT_MASK(sym_k_DtMenuButton_object) |
  0, _BIT_MASK(sym_k_XmCascadeButton_object) |
  _BIT_MASK(sym_k_XmCascadeButtonGadget_object) |
  0, 0, _BIT_MASK(sym_k_XmDrawnButton_object) |
  _BIT_MASK(sym_k_XmDropDown_object) |
  0, _BIT_MASK(sym_k_XmIconButton_object) |
  _BIT_MASK(sym_k_XmIconGadget_object) |
  _BIT_MASK(sym_k_XmLabel_object) |
  0, _BIT_MASK(sym_k_XmLabelGadget_object) |
  0, 0, _BIT_MASK(sym_k_XmPushButton_object) |
  _BIT_MASK(sym_k_XmPushButtonGadget_object) |
  0, 0, _BIT_MASK(sym_k_XmTearOffButton_object) |
  0, _BIT_MASK(sym_k_XmToggleButton_object) |
  _BIT_MASK(sym_k_XmToggleButtonGadget_object) |
  0, 0};

/* sym_k_XmNredSliderLabel_arg */
static unsigned char arg_class_vec518[] =
  {
  0, 0, _BIT_MASK(sym_k_XmColorSelector_object) |
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_XmNrefigureMode_arg */
static unsigned char arg_class_vec519[] =
  {
  0, 0, 0, _BIT_MASK(sym_k_XmFontSelector_object) |
  0, 0, 0, _BIT_MASK(sym_k_XmOutline_object) |
  _BIT_MASK(sym_k_XmPaned_object) |
  _BIT_MASK(sym_k_XmPanedWindow_object) |
  0, 0, 0, 0, _BIT_MASK(sym_k_XmTree_object) |
  0, 0};

/* sym_k_XmNrenderTable_arg */
static unsigned char arg_class_vec520[] =
  {
  _BIT_MASK(sym_k_DtMenuButton_object) |
  0, _BIT_MASK(sym_k_XmCascadeButton_object) |
  _BIT_MASK(sym_k_XmCascadeButtonGadget_object) |
  0, _BIT_MASK(sym_k_XmComboBox_object) |
  _BIT_MASK(sym_k_XmContainer_object) |
  _BIT_MASK(sym_k_XmDataField_object) |
  0, _BIT_MASK(sym_k_XmDrawnButton_object) |
  0, _BIT_MASK(sym_k_XmIconButton_object) |
  _BIT_MASK(sym_k_XmIconGadget_object) |
  _BIT_MASK(sym_k_XmLabel_object) |
  0, _BIT_MASK(sym_k_XmLabelGadget_object) |
  _BIT_MASK(sym_k_XmList_object) |
  _BIT_MASK(sym_k_XmMultiList_object) |
  0, 0, _BIT_MASK(sym_k_XmPushButton_object) |
  _BIT_MASK(sym_k_XmPushButtonGadget_object) |
  _BIT_MASK(sym_k_XmScale_object) |
  0, _BIT_MASK(sym_k_XmScrolledList_object) |
  _BIT_MASK(sym_k_XmScrolledText_object) |
  0, _BIT_MASK(sym_k_XmTabBox_object) |
  _BIT_MASK(sym_k_XmTabStack_object) |
  _BIT_MASK(sym_k_XmTearOffButton_object) |
  0, _BIT_MASK(sym_k_XmText_object) |
  _BIT_MASK(sym_k_XmTextField_object) |
  _BIT_MASK(sym_k_XmToggleButton_object) |
  _BIT_MASK(sym_k_XmToggleButtonGadget_object) |
  0, 0};

/* sym_k_XmNrenditionBackground_arg */
static unsigned char arg_class_vec521[] =
  {
  0, 0, 0, 0, 0, 0, 0, _BIT_MASK(sym_k_XmRendition_object) |
  0, 0, 0, 0, 0};

/* sym_k_XmNrenditionForeground_arg */
static unsigned char arg_class_vec522[] =
  {
  0, 0, 0, 0, 0, 0, 0, _BIT_MASK(sym_k_XmRendition_object) |
  0, 0, 0, 0, 0};

/* sym_k_XmNrepeatDelay_arg */
static unsigned char arg_class_vec523[] =
  {
  0, 0, 0, 0, 0, 0, 0, 0, _BIT_MASK(sym_k_XmScrollBar_object) |
  0, _BIT_MASK(sym_k_XmSimpleSpinBox_object) |
  _BIT_MASK(sym_k_XmSpinBox_object) |
  0, 0, 0};

/* sym_k_XmNresizable_arg */
static unsigned char arg_class_vec524[] =
  {
  _BIT_MASK(sym_k_DtEditor_object) |
  0, 0, 0, 0, _BIT_MASK(sym_k_XmForm_object) |
  _BIT_MASK(sym_k_XmFormDialog_object) |
  0, 0, _BIT_MASK(sym_k_XmNotebook_object) |
  0, 0, 0, 0, 0, 0};

/* sym_k_XmNresizeHeight_arg */
static unsigned char arg_class_vec525[] =
  {
  0, 0, _BIT_MASK(sym_k_XmCheckBox_object) |
  _BIT_MASK(sym_k_XmContainer_object) |
  _BIT_MASK(sym_k_XmDataField_object) |
  0, 0, 0, _BIT_MASK(sym_k_XmMenuBar_object) |
  0, _BIT_MASK(sym_k_XmOptionMenu_object) |
  _BIT_MASK(sym_k_XmPopupMenu_object) |
  _BIT_MASK(sym_k_XmPulldownMenu_object) |
  0, _BIT_MASK(sym_k_XmRadioBox_object) |
  _BIT_MASK(sym_k_XmRowColumn_object) |
  0, _BIT_MASK(sym_k_XmScrolledText_object) |
  0, 0, _BIT_MASK(sym_k_XmText_object) |
  _BIT_MASK(sym_k_XmTextField_object) |
  _BIT_MASK(sym_k_XmWorkArea_object) |
  0, 0};

/* sym_k_XmNresizePolicy_arg */
static unsigned char arg_class_vec526[] =
  {
  _BIT_MASK(sym_k_DtEditor_object) |
  _BIT_MASK(sym_k_DtHelpDialog_object) |
  _BIT_MASK(sym_k_DtHelpQuickDialog_object) |
  _BIT_MASK(sym_k_DtPrintSetupBox_object) |
  _BIT_MASK(sym_k_DtPrintSetupDialog_object) |
  0, _BIT_MASK(sym_k_XmBulletinBoard_object) |
  _BIT_MASK(sym_k_XmBulletinBoardDialog_object) |
  0, _BIT_MASK(sym_k_XmColumn_object) |
  _BIT_MASK(sym_k_XmCommand_object) |
  _BIT_MASK(sym_k_XmCommandDialog_object) |
  0, _BIT_MASK(sym_k_XmDrawingArea_object) |
  _BIT_MASK(sym_k_XmErrorDialog_object) |
  _BIT_MASK(sym_k_XmFileSelectionBox_object) |
  _BIT_MASK(sym_k_XmFileSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmForm_object) |
  _BIT_MASK(sym_k_XmFormDialog_object) |
  _BIT_MASK(sym_k_XmInformationDialog_object) |
  0, _BIT_MASK(sym_k_XmMessageBox_object) |
  _BIT_MASK(sym_k_XmMessageDialog_object) |
  0, _BIT_MASK(sym_k_XmPromptDialog_object) |
  0, _BIT_MASK(sym_k_XmQuestionDialog_object) |
  0, _BIT_MASK(sym_k_XmSelectionBox_object) |
  _BIT_MASK(sym_k_XmSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmTabStack_object) |
  _BIT_MASK(sym_k_XmTemplateDialog_object) |
  0, _BIT_MASK(sym_k_XmWarningDialog_object) |
  _BIT_MASK(sym_k_XmWorkingDialog_object) |
  0, 0};

/* sym_k_XmNresizeToPreferred_arg */
static unsigned char arg_class_vec527[] =
  {
  0, 0, 0, _BIT_MASK(sym_k_XmFontSelector_object) |
  0, 0, 0, _BIT_MASK(sym_k_XmPaned_object) |
  0, 0, 0, 0, 0, 0};

/* sym_k_XmNresizeWidth_arg */
static unsigned char arg_class_vec528[] =
  {
  0, 0, _BIT_MASK(sym_k_XmCheckBox_object) |
  _BIT_MASK(sym_k_XmContainer_object) |
  _BIT_MASK(sym_k_XmDataField_object) |
  0, 0, 0, _BIT_MASK(sym_k_XmMenuBar_object) |
  0, _BIT_MASK(sym_k_XmOptionMenu_object) |
  _BIT_MASK(sym_k_XmPopupMenu_object) |
  _BIT_MASK(sym_k_XmPulldownMenu_object) |
  0, _BIT_MASK(sym_k_XmRadioBox_object) |
  _BIT_MASK(sym_k_XmRowColumn_object) |
  0, _BIT_MASK(sym_k_XmScrolledText_object) |
  0, 0, _BIT_MASK(sym_k_XmText_object) |
  _BIT_MASK(sym_k_XmTextField_object) |
  _BIT_MASK(sym_k_XmWorkArea_object) |
  0, 0};

/* sym_k_XmNrgbFile_arg */
static unsigned char arg_class_vec529[] =
  {
  0, 0, _BIT_MASK(sym_k_XmColorSelector_object) |
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_XmNrightAttachment_arg */
static unsigned char arg_class_vec530[] =
  {
  _BIT_MASK(sym_k_DtEditor_object) |
  0, 0, 0, 0, _BIT_MASK(sym_k_XmForm_object) |
  _BIT_MASK(sym_k_XmFormDialog_object) |
  0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_XmNrightOffset_arg */
static unsigned char arg_class_vec531[] =
  {
  _BIT_MASK(sym_k_DtEditor_object) |
  0, 0, 0, 0, _BIT_MASK(sym_k_XmForm_object) |
  _BIT_MASK(sym_k_XmFormDialog_object) |
  0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_XmNrightPosition_arg */
static unsigned char arg_class_vec532[] =
  {
  _BIT_MASK(sym_k_DtEditor_object) |
  0, 0, 0, 0, _BIT_MASK(sym_k_XmForm_object) |
  _BIT_MASK(sym_k_XmFormDialog_object) |
  0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_XmNrightWidget_arg */
static unsigned char arg_class_vec533[] =
  {
  _BIT_MASK(sym_k_DtEditor_object) |
  0, 0, 0, 0, _BIT_MASK(sym_k_XmForm_object) |
  _BIT_MASK(sym_k_XmFormDialog_object) |
  0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_XmNrowColumnType_arg */
static unsigned char arg_class_vec534[] =
  {
  0, 0, _BIT_MASK(sym_k_XmCheckBox_object) |
  0, 0, 0, _BIT_MASK(sym_k_XmMenuBar_object) |
  0, _BIT_MASK(sym_k_XmOptionMenu_object) |
  _BIT_MASK(sym_k_XmPopupMenu_object) |
  _BIT_MASK(sym_k_XmPulldownMenu_object) |
  0, _BIT_MASK(sym_k_XmRadioBox_object) |
  _BIT_MASK(sym_k_XmRowColumn_object) |
  0, 0, 0, _BIT_MASK(sym_k_XmWorkArea_object) |
  0, 0};

/* sym_k_XmNrows_arg */
static unsigned char arg_class_vec535[] =
  {
  0, 0, _BIT_MASK(sym_k_XmDataField_object) |
  0, 0, 0, 0, 0, 0, _BIT_MASK(sym_k_XmScrolledText_object) |
  0, 0, _BIT_MASK(sym_k_XmText_object) |
  _BIT_MASK(sym_k_XmTextField_object) |
  0, 0};

/* sym_k_XmNrubberPositioning_arg */
static unsigned char arg_class_vec536[] =
  {
  _BIT_MASK(sym_k_DtEditor_object) |
  0, 0, 0, 0, _BIT_MASK(sym_k_XmForm_object) |
  _BIT_MASK(sym_k_XmFormDialog_object) |
  0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_XmNsampleText_arg */
static unsigned char arg_class_vec537[] =
  {
  0, 0, 0, _BIT_MASK(sym_k_XmFontSelector_object) |
  0, 0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_XmNsashHeight_arg */
static unsigned char arg_class_vec538[] =
  {
  0, 0, 0, _BIT_MASK(sym_k_XmFontSelector_object) |
  0, 0, 0, _BIT_MASK(sym_k_XmPaned_object) |
  _BIT_MASK(sym_k_XmPanedWindow_object) |
  0, 0, 0, 0, 0, 0};

/* sym_k_XmNsashIndent_arg */
static unsigned char arg_class_vec539[] =
  {
  0, 0, 0, _BIT_MASK(sym_k_XmFontSelector_object) |
  0, 0, 0, _BIT_MASK(sym_k_XmPaned_object) |
  _BIT_MASK(sym_k_XmPanedWindow_object) |
  0, 0, 0, 0, 0, 0};

/* sym_k_XmNsashShadowThickness_arg */
static unsigned char arg_class_vec540[] =
  {
  0, 0, 0, _BIT_MASK(sym_k_XmFontSelector_object) |
  0, 0, 0, _BIT_MASK(sym_k_XmPaned_object) |
  _BIT_MASK(sym_k_XmPanedWindow_object) |
  0, 0, 0, 0, 0, 0};

/* sym_k_XmNsashTranslations_arg */
static unsigned char arg_class_vec541[] =
  {
  0, 0, 0, _BIT_MASK(sym_k_XmFontSelector_object) |
  0, 0, 0, _BIT_MASK(sym_k_XmPaned_object) |
  0, 0, 0, 0, 0, 0};

/* sym_k_XmNsashWidth_arg */
static unsigned char arg_class_vec542[] =
  {
  0, 0, 0, _BIT_MASK(sym_k_XmFontSelector_object) |
  0, 0, 0, _BIT_MASK(sym_k_XmPaned_object) |
  _BIT_MASK(sym_k_XmPanedWindow_object) |
  0, 0, 0, 0, 0, 0};

/* sym_k_XmNsaveUnder_arg */
static unsigned char arg_class_vec543[] =
  {
  _BIT_MASK(sym_k_DtHelpDialog_object) |
  _BIT_MASK(sym_k_DtHelpQuickDialog_object) |
  _BIT_MASK(sym_k_DtPrintSetupDialog_object) |
  0, _BIT_MASK(sym_k_XmBulletinBoardDialog_object) |
  0, _BIT_MASK(sym_k_XmCommandDialog_object) |
  0, _BIT_MASK(sym_k_XmDialogShell_object) |
  _BIT_MASK(sym_k_XmErrorDialog_object) |
  _BIT_MASK(sym_k_XmFileSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmFormDialog_object) |
  _BIT_MASK(sym_k_XmInformationDialog_object) |
  0, _BIT_MASK(sym_k_XmMenuShell_object) |
  _BIT_MASK(sym_k_XmMessageDialog_object) |
  0, _BIT_MASK(sym_k_XmPopupMenu_object) |
  _BIT_MASK(sym_k_XmPromptDialog_object) |
  _BIT_MASK(sym_k_XmPulldownMenu_object) |
  0, _BIT_MASK(sym_k_XmQuestionDialog_object) |
  0, _BIT_MASK(sym_k_XmSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmTemplateDialog_object) |
  0, _BIT_MASK(sym_k_XmWarningDialog_object) |
  _BIT_MASK(sym_k_XmWorkingDialog_object) |
  0, 0};

/* sym_k_XmNscaleHeight_arg */
static unsigned char arg_class_vec544[] =
  {
  0, 0, 0, 0, 0, 0, 0, _BIT_MASK(sym_k_XmScale_object) |
  0, 0, 0, 0, 0};

/* sym_k_XmNscaleMultiple_arg */
static unsigned char arg_class_vec545[] =
  {
  0, 0, 0, 0, 0, 0, 0, _BIT_MASK(sym_k_XmScale_object) |
  0, 0, 0, 0, 0};

/* sym_k_XmNscaleWidth_arg */
static unsigned char arg_class_vec546[] =
  {
  0, 0, 0, 0, 0, 0, 0, _BIT_MASK(sym_k_XmScale_object) |
  0, 0, 0, 0, 0};

/* sym_k_XmNscalingString_arg */
static unsigned char arg_class_vec547[] =
  {
  0, 0, 0, _BIT_MASK(sym_k_XmFontSelector_object) |
  0, 0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_XmNscreen_arg */
static unsigned char arg_class_vec548[] =
  {
  _BIT_MASK(sym_k_DtEditor_object) |
  _BIT_MASK(sym_k_DtHelpDialog_object) |
  _BIT_MASK(sym_k_DtHelpQuickDialog_object) |
  _BIT_MASK(sym_k_DtMenuButton_object) |
  _BIT_MASK(sym_k_DtPrintSetupBox_object) |
  _BIT_MASK(sym_k_DtPrintSetupDialog_object) |
  _BIT_MASK(sym_k_DtTerm_object) |
  0, _BIT_MASK(sym_k_DtTermPrimitive_object) |
  _BIT_MASK(sym_k_XmArrowButton_object) |
  _BIT_MASK(sym_k_XmBulletinBoard_object) |
  _BIT_MASK(sym_k_XmBulletinBoardDialog_object) |
  _BIT_MASK(sym_k_XmButtonBox_object) |
  _BIT_MASK(sym_k_XmCascadeButton_object) |
  0, _BIT_MASK(sym_k_XmCheckBox_object) |
  _BIT_MASK(sym_k_XmColorSelector_object) |
  _BIT_MASK(sym_k_XmColumn_object) |
  _BIT_MASK(sym_k_XmComboBox_object) |
  _BIT_MASK(sym_k_XmCommand_object) |
  _BIT_MASK(sym_k_XmCommandDialog_object) |
  _BIT_MASK(sym_k_XmContainer_object) |
  _BIT_MASK(sym_k_XmDataField_object) |
  0, _BIT_MASK(sym_k_XmDialogShell_object) |
  _BIT_MASK(sym_k_XmDrawingArea_object) |
  _BIT_MASK(sym_k_XmDrawnButton_object) |
  _BIT_MASK(sym_k_XmDropDown_object) |
  _BIT_MASK(sym_k_XmErrorDialog_object) |
  _BIT_MASK(sym_k_XmFileSelectionBox_object) |
  _BIT_MASK(sym_k_XmFileSelectionDialog_object) |
  _BIT_MASK(sym_k_XmFontSelector_object) |
  0, _BIT_MASK(sym_k_XmForm_object) |
  _BIT_MASK(sym_k_XmFormDialog_object) |
  _BIT_MASK(sym_k_XmFrame_object) |
  _BIT_MASK(sym_k_XmIconBox_object) |
  _BIT_MASK(sym_k_XmIconButton_object) |
  _BIT_MASK(sym_k_XmInformationDialog_object) |
  _BIT_MASK(sym_k_XmLabel_object) |
  0, _BIT_MASK(sym_k_XmList_object) |
  _BIT_MASK(sym_k_XmMainWindow_object) |
  _BIT_MASK(sym_k_XmMenuBar_object) |
  _BIT_MASK(sym_k_XmMenuShell_object) |
  _BIT_MASK(sym_k_XmMessageBox_object) |
  _BIT_MASK(sym_k_XmMessageDialog_object) |
  _BIT_MASK(sym_k_XmMultiList_object) |
  0, _BIT_MASK(sym_k_XmNotebook_object) |
  _BIT_MASK(sym_k_XmOptionMenu_object) |
  _BIT_MASK(sym_k_XmOutline_object) |
  _BIT_MASK(sym_k_XmPaned_object) |
  _BIT_MASK(sym_k_XmPanedWindow_object) |
  _BIT_MASK(sym_k_XmPopupMenu_object) |
  _BIT_MASK(sym_k_XmPromptDialog_object) |
  _BIT_MASK(sym_k_XmPulldownMenu_object) |
  0, _BIT_MASK(sym_k_XmPushButton_object) |
  _BIT_MASK(sym_k_XmQuestionDialog_object) |
  _BIT_MASK(sym_k_XmRadioBox_object) |
  _BIT_MASK(sym_k_XmRowColumn_object) |
  _BIT_MASK(sym_k_XmScale_object) |
  0, _BIT_MASK(sym_k_XmScrollBar_object) |
  _BIT_MASK(sym_k_XmScrolledList_object) |
  _BIT_MASK(sym_k_XmScrolledText_object) |
  _BIT_MASK(sym_k_XmScrolledWindow_object) |
  _BIT_MASK(sym_k_XmSelectionBox_object) |
  _BIT_MASK(sym_k_XmSelectionDialog_object) |
  _BIT_MASK(sym_k_XmSeparator_object) |
  0, _BIT_MASK(sym_k_XmSimpleSpinBox_object) |
  _BIT_MASK(sym_k_XmSpinBox_object) |
  _BIT_MASK(sym_k_XmTabBox_object) |
  _BIT_MASK(sym_k_XmTabStack_object) |
  _BIT_MASK(sym_k_XmTearOffButton_object) |
  _BIT_MASK(sym_k_XmTemplateDialog_object) |
  0, _BIT_MASK(sym_k_XmText_object) |
  _BIT_MASK(sym_k_XmTextField_object) |
  _BIT_MASK(sym_k_XmToggleButton_object) |
  _BIT_MASK(sym_k_XmTree_object) |
  _BIT_MASK(sym_k_XmWarningDialog_object) |
  _BIT_MASK(sym_k_XmWorkArea_object) |
  _BIT_MASK(sym_k_XmWorkingDialog_object) |
  0, 0};

/* sym_k_XmNscrollBarDisplayPolicy_arg */
static unsigned char arg_class_vec549[] =
  {
  0, 0, 0, 0, 0, _BIT_MASK(sym_k_XmMainWindow_object) |
  0, 0, 0, _BIT_MASK(sym_k_XmScrolledList_object) |
  _BIT_MASK(sym_k_XmScrolledText_object) |
  _BIT_MASK(sym_k_XmScrolledWindow_object) |
  0, 0, 0, 0};

/* sym_k_XmNscrollBarPlacement_arg */
static unsigned char arg_class_vec550[] =
  {
  0, 0, 0, 0, 0, _BIT_MASK(sym_k_XmMainWindow_object) |
  0, 0, 0, _BIT_MASK(sym_k_XmScrolledList_object) |
  _BIT_MASK(sym_k_XmScrolledText_object) |
  _BIT_MASK(sym_k_XmScrolledWindow_object) |
  0, 0, 0, 0};

/* sym_k_XmNscrollHorizontal_arg */
static unsigned char arg_class_vec551[] =
  {
  0, 0, 0, 0, 0, 0, 0, 0, _BIT_MASK(sym_k_XmScrolledText_object) |
  0, 0, 0, 0};

/* sym_k_XmNscrollLeftSide_arg */
static unsigned char arg_class_vec552[] =
  {
  0, 0, 0, 0, 0, 0, 0, 0, _BIT_MASK(sym_k_XmScrolledText_object) |
  0, 0, 0, 0};

/* sym_k_XmNscrollTopSide_arg */
static unsigned char arg_class_vec553[] =
  {
  0, 0, 0, 0, 0, 0, 0, 0, _BIT_MASK(sym_k_XmScrolledText_object) |
  0, 0, 0, 0};

/* sym_k_XmNscrollVertical_arg */
static unsigned char arg_class_vec554[] =
  {
  0, 0, 0, 0, 0, 0, 0, 0, _BIT_MASK(sym_k_XmScrolledText_object) |
  0, 0, 0, 0};

/* sym_k_XmNscrolledWindowChildType_arg */
static unsigned char arg_class_vec555[] =
  {
  0, 0, 0, 0, 0, _BIT_MASK(sym_k_XmMainWindow_object) |
  0, 0, 0, _BIT_MASK(sym_k_XmScrolledList_object) |
  _BIT_MASK(sym_k_XmScrolledText_object) |
  _BIT_MASK(sym_k_XmScrolledWindow_object) |
  0, 0, 0, 0};

/* sym_k_XmNscrolledWindowMarginHeight_arg */
static unsigned char arg_class_vec556[] =
  {
  0, 0, 0, 0, 0, _BIT_MASK(sym_k_XmMainWindow_object) |
  0, 0, 0, _BIT_MASK(sym_k_XmScrolledList_object) |
  _BIT_MASK(sym_k_XmScrolledText_object) |
  _BIT_MASK(sym_k_XmScrolledWindow_object) |
  0, 0, 0, 0};

/* sym_k_XmNscrolledWindowMarginWidth_arg */
static unsigned char arg_class_vec557[] =
  {
  0, 0, 0, 0, 0, _BIT_MASK(sym_k_XmMainWindow_object) |
  0, 0, 0, _BIT_MASK(sym_k_XmScrolledList_object) |
  _BIT_MASK(sym_k_XmScrolledText_object) |
  _BIT_MASK(sym_k_XmScrolledWindow_object) |
  0, 0, 0, 0};

/* sym_k_XmNscrollingPolicy_arg */
static unsigned char arg_class_vec558[] =
  {
  0, 0, 0, 0, 0, _BIT_MASK(sym_k_XmMainWindow_object) |
  0, 0, 0, _BIT_MASK(sym_k_XmScrolledList_object) |
  _BIT_MASK(sym_k_XmScrolledText_object) |
  _BIT_MASK(sym_k_XmScrolledWindow_object) |
  0, 0, 0, 0};

/* sym_k_XmNselectColor_arg */
static unsigned char arg_class_vec559[] =
  {
  0, 0, _BIT_MASK(sym_k_XmContainer_object) |
  0, 0, 0, 0, 0, 0, 0, 0, _BIT_MASK(sym_k_XmToggleButton_object) |
  _BIT_MASK(sym_k_XmToggleButtonGadget_object) |
  0, 0};

/* sym_k_XmNselectInsensitivePixmap_arg */
static unsigned char arg_class_vec560[] =
  {
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, _BIT_MASK(sym_k_XmToggleButton_object) |
  _BIT_MASK(sym_k_XmToggleButtonGadget_object) |
  0, 0};

/* sym_k_XmNselectPixmap_arg */
static unsigned char arg_class_vec561[] =
  {
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, _BIT_MASK(sym_k_XmToggleButton_object) |
  _BIT_MASK(sym_k_XmToggleButtonGadget_object) |
  0, 0};

/* sym_k_XmNselectThreshold_arg */
static unsigned char arg_class_vec562[] =
  {
  0, 0, _BIT_MASK(sym_k_XmDataField_object) |
  0, 0, 0, 0, 0, 0, _BIT_MASK(sym_k_XmScrolledText_object) |
  0, 0, _BIT_MASK(sym_k_XmText_object) |
  _BIT_MASK(sym_k_XmTextField_object) |
  0, 0};

/* sym_k_XmNselectedColumn_arg */
static unsigned char arg_class_vec563[] =
  {
  0, 0, 0, 0, 0, _BIT_MASK(sym_k_XmMultiList_object) |
  0, 0, 0, 0, 0, 0, 0};

/* sym_k_XmNselectedItem_arg */
static unsigned char arg_class_vec564[] =
  {
  0, 0, _BIT_MASK(sym_k_XmComboBox_object) |
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_XmNselectedItemCount_arg */
static unsigned char arg_class_vec565[] =
  {
  0, 0, 0, 0, 0, _BIT_MASK(sym_k_XmList_object) |
  0, 0, 0, _BIT_MASK(sym_k_XmScrolledList_object) |
  0, 0, 0, 0};

/* sym_k_XmNselectedItems_arg */
static unsigned char arg_class_vec566[] =
  {
  0, 0, 0, 0, 0, _BIT_MASK(sym_k_XmList_object) |
  0, 0, 0, _BIT_MASK(sym_k_XmScrolledList_object) |
  0, 0, 0, 0};

/* sym_k_XmNselectedPosition_arg */
static unsigned char arg_class_vec567[] =
  {
  0, 0, _BIT_MASK(sym_k_XmComboBox_object) |
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_XmNselectedPositionCount_arg */
static unsigned char arg_class_vec568[] =
  {
  0, 0, 0, 0, 0, _BIT_MASK(sym_k_XmList_object) |
  0, 0, 0, _BIT_MASK(sym_k_XmScrolledList_object) |
  0, 0, 0, 0};

/* sym_k_XmNselectedPositions_arg */
static unsigned char arg_class_vec569[] =
  {
  0, 0, 0, 0, 0, _BIT_MASK(sym_k_XmList_object) |
  0, 0, 0, _BIT_MASK(sym_k_XmScrolledList_object) |
  0, 0, 0, 0};

/* sym_k_XmNselectionArray_arg */
static unsigned char arg_class_vec570[] =
  {
  0, 0, _BIT_MASK(sym_k_XmDataField_object) |
  0, 0, 0, 0, 0, 0, _BIT_MASK(sym_k_XmScrolledText_object) |
  0, 0, _BIT_MASK(sym_k_XmText_object) |
  _BIT_MASK(sym_k_XmTextField_object) |
  0, 0};

/* sym_k_XmNselectionArrayCount_arg */
static unsigned char arg_class_vec571[] =
  {
  0, 0, _BIT_MASK(sym_k_XmDataField_object) |
  0, 0, 0, 0, 0, 0, _BIT_MASK(sym_k_XmScrolledText_object) |
  0, 0, _BIT_MASK(sym_k_XmText_object) |
  _BIT_MASK(sym_k_XmTextField_object) |
  0, 0};

/* sym_k_XmNselectionLabelString_arg */
static unsigned char arg_class_vec572[] =
  {
  0, 0, _BIT_MASK(sym_k_XmCommand_object) |
  _BIT_MASK(sym_k_XmCommandDialog_object) |
  0, _BIT_MASK(sym_k_XmFileSelectionBox_object) |
  _BIT_MASK(sym_k_XmFileSelectionDialog_object) |
  0, 0, 0, _BIT_MASK(sym_k_XmPromptDialog_object) |
  0, 0, _BIT_MASK(sym_k_XmSelectionBox_object) |
  _BIT_MASK(sym_k_XmSelectionDialog_object) |
  0, 0, 0, 0};

/* sym_k_XmNselectionMode_arg */
static unsigned char arg_class_vec573[] =
  {
  0, 0, 0, 0, 0, _BIT_MASK(sym_k_XmList_object) |
  0, 0, 0, _BIT_MASK(sym_k_XmScrolledList_object) |
  0, 0, 0, 0};

/* sym_k_XmNselectionPolicy_arg */
static unsigned char arg_class_vec574[] =
  {
  0, 0, _BIT_MASK(sym_k_XmContainer_object) |
  0, _BIT_MASK(sym_k_XmDropDown_object) |
  0, 0, _BIT_MASK(sym_k_XmList_object) |
  _BIT_MASK(sym_k_XmMultiList_object) |
  0, 0, 0, _BIT_MASK(sym_k_XmScrolledList_object) |
  0, 0, 0, 0};

/* sym_k_XmNselectionTechnique_arg */
static unsigned char arg_class_vec575[] =
  {
  0, 0, _BIT_MASK(sym_k_XmContainer_object) |
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_XmNsensitive_arg */
static unsigned char arg_class_vec576[] =
  {
  _BIT_MASK(sym_k_DtEditor_object) |
  _BIT_MASK(sym_k_DtHelpDialog_object) |
  _BIT_MASK(sym_k_DtHelpQuickDialog_object) |
  _BIT_MASK(sym_k_DtMenuButton_object) |
  _BIT_MASK(sym_k_DtPrintSetupBox_object) |
  _BIT_MASK(sym_k_DtPrintSetupDialog_object) |
  _BIT_MASK(sym_k_DtTerm_object) |
  0, _BIT_MASK(sym_k_DtTermPrimitive_object) |
  _BIT_MASK(sym_k_XmArrowButton_object) |
  _BIT_MASK(sym_k_XmArrowButtonGadget_object) |
  _BIT_MASK(sym_k_XmBulletinBoard_object) |
  _BIT_MASK(sym_k_XmBulletinBoardDialog_object) |
  _BIT_MASK(sym_k_XmButtonBox_object) |
  _BIT_MASK(sym_k_XmCascadeButton_object) |
  _BIT_MASK(sym_k_XmCascadeButtonGadget_object) |
  0, _BIT_MASK(sym_k_XmCheckBox_object) |
  _BIT_MASK(sym_k_XmColorSelector_object) |
  _BIT_MASK(sym_k_XmColumn_object) |
  _BIT_MASK(sym_k_XmComboBox_object) |
  _BIT_MASK(sym_k_XmCommand_object) |
  _BIT_MASK(sym_k_XmCommandDialog_object) |
  _BIT_MASK(sym_k_XmContainer_object) |
  _BIT_MASK(sym_k_XmDataField_object) |
  0, _BIT_MASK(sym_k_XmDialogShell_object) |
  _BIT_MASK(sym_k_XmDrawingArea_object) |
  _BIT_MASK(sym_k_XmDrawnButton_object) |
  _BIT_MASK(sym_k_XmDropDown_object) |
  _BIT_MASK(sym_k_XmErrorDialog_object) |
  _BIT_MASK(sym_k_XmFileSelectionBox_object) |
  _BIT_MASK(sym_k_XmFileSelectionDialog_object) |
  _BIT_MASK(sym_k_XmFontSelector_object) |
  0, _BIT_MASK(sym_k_XmForm_object) |
  _BIT_MASK(sym_k_XmFormDialog_object) |
  _BIT_MASK(sym_k_XmFrame_object) |
  _BIT_MASK(sym_k_XmIconBox_object) |
  _BIT_MASK(sym_k_XmIconButton_object) |
  _BIT_MASK(sym_k_XmIconGadget_object) |
  _BIT_MASK(sym_k_XmInformationDialog_object) |
  _BIT_MASK(sym_k_XmLabel_object) |
  0, _BIT_MASK(sym_k_XmLabelGadget_object) |
  _BIT_MASK(sym_k_XmList_object) |
  _BIT_MASK(sym_k_XmMainWindow_object) |
  _BIT_MASK(sym_k_XmMenuBar_object) |
  _BIT_MASK(sym_k_XmMenuShell_object) |
  _BIT_MASK(sym_k_XmMessageBox_object) |
  _BIT_MASK(sym_k_XmMessageDialog_object) |
  _BIT_MASK(sym_k_XmMultiList_object) |
  0, _BIT_MASK(sym_k_XmNotebook_object) |
  _BIT_MASK(sym_k_XmOptionMenu_object) |
  _BIT_MASK(sym_k_XmOutline_object) |
  _BIT_MASK(sym_k_XmPaned_object) |
  _BIT_MASK(sym_k_XmPanedWindow_object) |
  _BIT_MASK(sym_k_XmPopupMenu_object) |
  _BIT_MASK(sym_k_XmPromptDialog_object) |
  _BIT_MASK(sym_k_XmPulldownMenu_object) |
  0, _BIT_MASK(sym_k_XmPushButton_object) |
  _BIT_MASK(sym_k_XmPushButtonGadget_object) |
  _BIT_MASK(sym_k_XmQuestionDialog_object) |
  _BIT_MASK(sym_k_XmRadioBox_object) |
  _BIT_MASK(sym_k_XmRowColumn_object) |
  _BIT_MASK(sym_k_XmScale_object) |
  0, _BIT_MASK(sym_k_XmScrollBar_object) |
  _BIT_MASK(sym_k_XmScrolledList_object) |
  _BIT_MASK(sym_k_XmScrolledText_object) |
  _BIT_MASK(sym_k_XmScrolledWindow_object) |
  _BIT_MASK(sym_k_XmSelectionBox_object) |
  _BIT_MASK(sym_k_XmSelectionDialog_object) |
  _BIT_MASK(sym_k_XmSeparator_object) |
  _BIT_MASK(sym_k_XmSeparatorGadget_object) |
  0, _BIT_MASK(sym_k_XmSimpleSpinBox_object) |
  _BIT_MASK(sym_k_XmSpinBox_object) |
  _BIT_MASK(sym_k_XmTabBox_object) |
  _BIT_MASK(sym_k_XmTabStack_object) |
  _BIT_MASK(sym_k_XmTearOffButton_object) |
  _BIT_MASK(sym_k_XmTemplateDialog_object) |
  0, _BIT_MASK(sym_k_XmText_object) |
  _BIT_MASK(sym_k_XmTextField_object) |
  _BIT_MASK(sym_k_XmToggleButton_object) |
  _BIT_MASK(sym_k_XmToggleButtonGadget_object) |
  _BIT_MASK(sym_k_XmTree_object) |
  _BIT_MASK(sym_k_XmWarningDialog_object) |
  _BIT_MASK(sym_k_XmWorkArea_object) |
  _BIT_MASK(sym_k_XmWorkingDialog_object) |
  0, 0};

/* sym_k_XmNseparatorOn_arg */
static unsigned char arg_class_vec577[] =
  {
  0, 0, 0, _BIT_MASK(sym_k_XmFontSelector_object) |
  0, 0, 0, _BIT_MASK(sym_k_XmPaned_object) |
  _BIT_MASK(sym_k_XmPanedWindow_object) |
  0, 0, 0, 0, 0, 0};

/* sym_k_XmNseparatorType_arg */
static unsigned char arg_class_vec578[] =
  {
  0, 0, 0, 0, 0, 0, 0, 0, _BIT_MASK(sym_k_XmSeparator_object) |
  _BIT_MASK(sym_k_XmSeparatorGadget_object) |
  0, _BIT_MASK(sym_k_XmTearOffButton_object) |
  0, 0, 0};

/* sym_k_XmNset_arg */
static unsigned char arg_class_vec579[] =
  {
  0, 0, 0, 0, _BIT_MASK(sym_k_XmIconButton_object) |
  0, 0, 0, 0, 0, 0, _BIT_MASK(sym_k_XmToggleButton_object) |
  _BIT_MASK(sym_k_XmToggleButtonGadget_object) |
  0, 0};

/* sym_k_XmNshadowThickness_arg */
static unsigned char arg_class_vec580[] =
  {
  _BIT_MASK(sym_k_DtEditor_object) |
  _BIT_MASK(sym_k_DtHelpDialog_object) |
  _BIT_MASK(sym_k_DtHelpQuickDialog_object) |
  _BIT_MASK(sym_k_DtMenuButton_object) |
  _BIT_MASK(sym_k_DtPrintSetupBox_object) |
  _BIT_MASK(sym_k_DtPrintSetupDialog_object) |
  _BIT_MASK(sym_k_DtTerm_object) |
  0, _BIT_MASK(sym_k_DtTermPrimitive_object) |
  _BIT_MASK(sym_k_XmArrowButton_object) |
  _BIT_MASK(sym_k_XmArrowButtonGadget_object) |
  _BIT_MASK(sym_k_XmBulletinBoard_object) |
  _BIT_MASK(sym_k_XmBulletinBoardDialog_object) |
  _BIT_MASK(sym_k_XmButtonBox_object) |
  _BIT_MASK(sym_k_XmCascadeButton_object) |
  _BIT_MASK(sym_k_XmCascadeButtonGadget_object) |
  0, _BIT_MASK(sym_k_XmCheckBox_object) |
  _BIT_MASK(sym_k_XmColorSelector_object) |
  _BIT_MASK(sym_k_XmColumn_object) |
  _BIT_MASK(sym_k_XmComboBox_object) |
  _BIT_MASK(sym_k_XmCommand_object) |
  _BIT_MASK(sym_k_XmCommandDialog_object) |
  _BIT_MASK(sym_k_XmContainer_object) |
  _BIT_MASK(sym_k_XmDataField_object) |
  0, _BIT_MASK(sym_k_XmDrawingArea_object) |
  _BIT_MASK(sym_k_XmDrawnButton_object) |
  _BIT_MASK(sym_k_XmDropDown_object) |
  _BIT_MASK(sym_k_XmErrorDialog_object) |
  _BIT_MASK(sym_k_XmFileSelectionBox_object) |
  _BIT_MASK(sym_k_XmFileSelectionDialog_object) |
  _BIT_MASK(sym_k_XmFontSelector_object) |
  0, _BIT_MASK(sym_k_XmForm_object) |
  _BIT_MASK(sym_k_XmFormDialog_object) |
  _BIT_MASK(sym_k_XmFrame_object) |
  _BIT_MASK(sym_k_XmIconBox_object) |
  _BIT_MASK(sym_k_XmIconButton_object) |
  _BIT_MASK(sym_k_XmIconGadget_object) |
  _BIT_MASK(sym_k_XmInformationDialog_object) |
  _BIT_MASK(sym_k_XmLabel_object) |
  0, _BIT_MASK(sym_k_XmLabelGadget_object) |
  _BIT_MASK(sym_k_XmList_object) |
  _BIT_MASK(sym_k_XmMainWindow_object) |
  _BIT_MASK(sym_k_XmMenuBar_object) |
  _BIT_MASK(sym_k_XmMessageBox_object) |
  _BIT_MASK(sym_k_XmMessageDialog_object) |
  _BIT_MASK(sym_k_XmMultiList_object) |
  0, _BIT_MASK(sym_k_XmNotebook_object) |
  _BIT_MASK(sym_k_XmOptionMenu_object) |
  _BIT_MASK(sym_k_XmOutline_object) |
  _BIT_MASK(sym_k_XmPaned_object) |
  _BIT_MASK(sym_k_XmPanedWindow_object) |
  _BIT_MASK(sym_k_XmPopupMenu_object) |
  _BIT_MASK(sym_k_XmPromptDialog_object) |
  _BIT_MASK(sym_k_XmPulldownMenu_object) |
  0, _BIT_MASK(sym_k_XmPushButton_object) |
  _BIT_MASK(sym_k_XmPushButtonGadget_object) |
  _BIT_MASK(sym_k_XmQuestionDialog_object) |
  _BIT_MASK(sym_k_XmRadioBox_object) |
  _BIT_MASK(sym_k_XmRowColumn_object) |
  _BIT_MASK(sym_k_XmScale_object) |
  0, _BIT_MASK(sym_k_XmScrollBar_object) |
  _BIT_MASK(sym_k_XmScrolledList_object) |
  _BIT_MASK(sym_k_XmScrolledText_object) |
  _BIT_MASK(sym_k_XmScrolledWindow_object) |
  _BIT_MASK(sym_k_XmSelectionBox_object) |
  _BIT_MASK(sym_k_XmSelectionDialog_object) |
  _BIT_MASK(sym_k_XmSeparator_object) |
  _BIT_MASK(sym_k_XmSeparatorGadget_object) |
  0, _BIT_MASK(sym_k_XmSimpleSpinBox_object) |
  _BIT_MASK(sym_k_XmSpinBox_object) |
  _BIT_MASK(sym_k_XmTabBox_object) |
  _BIT_MASK(sym_k_XmTabStack_object) |
  _BIT_MASK(sym_k_XmTearOffButton_object) |
  _BIT_MASK(sym_k_XmTemplateDialog_object) |
  0, _BIT_MASK(sym_k_XmText_object) |
  _BIT_MASK(sym_k_XmTextField_object) |
  _BIT_MASK(sym_k_XmToggleButton_object) |
  _BIT_MASK(sym_k_XmToggleButtonGadget_object) |
  _BIT_MASK(sym_k_XmTree_object) |
  _BIT_MASK(sym_k_XmWarningDialog_object) |
  _BIT_MASK(sym_k_XmWorkArea_object) |
  _BIT_MASK(sym_k_XmWorkingDialog_object) |
  0, 0};

/* sym_k_XmNshadowType_arg */
static unsigned char arg_class_vec581[] =
  {
  _BIT_MASK(sym_k_DtEditor_object) |
  _BIT_MASK(sym_k_DtHelpDialog_object) |
  _BIT_MASK(sym_k_DtHelpQuickDialog_object) |
  _BIT_MASK(sym_k_DtPrintSetupBox_object) |
  _BIT_MASK(sym_k_DtPrintSetupDialog_object) |
  0, _BIT_MASK(sym_k_XmBulletinBoard_object) |
  _BIT_MASK(sym_k_XmBulletinBoardDialog_object) |
  0, _BIT_MASK(sym_k_XmColumn_object) |
  _BIT_MASK(sym_k_XmCommand_object) |
  _BIT_MASK(sym_k_XmCommandDialog_object) |
  0, _BIT_MASK(sym_k_XmDrawnButton_object) |
  _BIT_MASK(sym_k_XmErrorDialog_object) |
  _BIT_MASK(sym_k_XmFileSelectionBox_object) |
  _BIT_MASK(sym_k_XmFileSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmForm_object) |
  _BIT_MASK(sym_k_XmFormDialog_object) |
  _BIT_MASK(sym_k_XmFrame_object) |
  _BIT_MASK(sym_k_XmInformationDialog_object) |
  0, _BIT_MASK(sym_k_XmMessageBox_object) |
  _BIT_MASK(sym_k_XmMessageDialog_object) |
  0, _BIT_MASK(sym_k_XmPromptDialog_object) |
  0, _BIT_MASK(sym_k_XmQuestionDialog_object) |
  0, _BIT_MASK(sym_k_XmSelectionBox_object) |
  _BIT_MASK(sym_k_XmSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmTabStack_object) |
  _BIT_MASK(sym_k_XmTemplateDialog_object) |
  0, _BIT_MASK(sym_k_XmWarningDialog_object) |
  _BIT_MASK(sym_k_XmWorkingDialog_object) |
  0, 0};

/* sym_k_XmNshellUnitType_arg */
static unsigned char arg_class_vec582[] =
  {
  _BIT_MASK(sym_k_DtHelpDialog_object) |
  _BIT_MASK(sym_k_DtHelpQuickDialog_object) |
  _BIT_MASK(sym_k_DtPrintSetupDialog_object) |
  0, _BIT_MASK(sym_k_XmBulletinBoardDialog_object) |
  0, _BIT_MASK(sym_k_XmCommandDialog_object) |
  0, _BIT_MASK(sym_k_XmDialogShell_object) |
  _BIT_MASK(sym_k_XmErrorDialog_object) |
  _BIT_MASK(sym_k_XmFileSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmFormDialog_object) |
  _BIT_MASK(sym_k_XmInformationDialog_object) |
  0, _BIT_MASK(sym_k_XmMessageDialog_object) |
  0, _BIT_MASK(sym_k_XmPromptDialog_object) |
  0, _BIT_MASK(sym_k_XmQuestionDialog_object) |
  0, _BIT_MASK(sym_k_XmSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmTemplateDialog_object) |
  0, _BIT_MASK(sym_k_XmWarningDialog_object) |
  _BIT_MASK(sym_k_XmWorkingDialog_object) |
  0, 0};

/* sym_k_XmNshowArrows_arg */
static unsigned char arg_class_vec583[] =
  {
  0, 0, 0, 0, 0, 0, 0, _BIT_MASK(sym_k_XmScale_object) |
  0, _BIT_MASK(sym_k_XmScrollBar_object) |
  0, 0, 0, 0};

/* sym_k_XmNshowAsDefault_arg */
static unsigned char arg_class_vec584[] =
  {
  0, 0, 0, 0, 0, 0, 0, _BIT_MASK(sym_k_XmPushButton_object) |
  _BIT_MASK(sym_k_XmPushButtonGadget_object) |
  0, 0, _BIT_MASK(sym_k_XmTearOffButton_object) |
  0, 0, 0};

/* sym_k_XmNshowEntryLabel_arg */
static unsigned char arg_class_vec585[] =
  {
  0, 0, _BIT_MASK(sym_k_XmColumn_object) |
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_XmNshowFind_arg */
static unsigned char arg_class_vec586[] =
  {
  0, 0, 0, 0, 0, _BIT_MASK(sym_k_XmMultiList_object) |
  0, 0, 0, 0, 0, 0, 0};

/* sym_k_XmNshowFontName_arg */
static unsigned char arg_class_vec587[] =
  {
  0, 0, 0, _BIT_MASK(sym_k_XmFontSelector_object) |
  0, 0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_XmNshowLabel_arg */
static unsigned char arg_class_vec588[] =
  {
  0, 0, 0, _BIT_MASK(sym_k_XmDropDown_object) |
  0, 0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_XmNshowNameString_arg */
static unsigned char arg_class_vec589[] =
  {
  0, 0, 0, _BIT_MASK(sym_k_XmFontSelector_object) |
  0, 0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_XmNshowSash_arg */
static unsigned char arg_class_vec590[] =
  {
  0, 0, 0, _BIT_MASK(sym_k_XmFontSelector_object) |
  0, 0, 0, _BIT_MASK(sym_k_XmPaned_object) |
  0, 0, 0, 0, 0, 0};

/* sym_k_XmNshowSeparator_arg */
static unsigned char arg_class_vec591[] =
  {
  0, 0, 0, 0, 0, _BIT_MASK(sym_k_XmMainWindow_object) |
  0, 0, 0, 0, 0, 0, 0};

/* sym_k_XmNshowValue_arg */
static unsigned char arg_class_vec592[] =
  {
  0, 0, 0, 0, 0, 0, 0, _BIT_MASK(sym_k_XmScale_object) |
  0, 0, 0, 0, 0};

/* sym_k_XmNsizeString_arg */
static unsigned char arg_class_vec593[] =
  {
  0, 0, 0, _BIT_MASK(sym_k_XmFontSelector_object) |
  0, 0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_XmNskipAdjust_arg */
static unsigned char arg_class_vec594[] =
  {
  0, 0, 0, _BIT_MASK(sym_k_XmFontSelector_object) |
  0, 0, 0, _BIT_MASK(sym_k_XmPaned_object) |
  _BIT_MASK(sym_k_XmPanedWindow_object) |
  0, 0, 0, 0, 0, 0};

/* sym_k_XmNsliderMark_arg */
static unsigned char arg_class_vec595[] =
  {
  0, 0, 0, 0, 0, 0, 0, 0, _BIT_MASK(sym_k_XmScrollBar_object) |
  0, 0, 0, 0};

/* sym_k_XmNsliderSize_arg */
static unsigned char arg_class_vec596[] =
  {
  0, 0, 0, 0, 0, 0, 0, 0, _BIT_MASK(sym_k_XmScrollBar_object) |
  0, 0, 0, 0};

/* sym_k_XmNsliderTogLabel_arg */
static unsigned char arg_class_vec597[] =
  {
  0, 0, _BIT_MASK(sym_k_XmColorSelector_object) |
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_XmNsliderVisual_arg */
static unsigned char arg_class_vec598[] =
  {
  0, 0, 0, 0, 0, 0, 0, _BIT_MASK(sym_k_XmScale_object) |
  0, _BIT_MASK(sym_k_XmScrollBar_object) |
  0, 0, 0, 0};

/* sym_k_XmNslidingMode_arg */
static unsigned char arg_class_vec599[] =
  {
  0, 0, 0, 0, 0, 0, 0, _BIT_MASK(sym_k_XmScale_object) |
  0, _BIT_MASK(sym_k_XmScrollBar_object) |
  0, 0, 0, 0};

/* sym_k_XmNsmallCellHeight_arg */
static unsigned char arg_class_vec600[] =
  {
  0, 0, _BIT_MASK(sym_k_XmContainer_object) |
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_XmNsmallCellWidth_arg */
static unsigned char arg_class_vec601[] =
  {
  0, 0, _BIT_MASK(sym_k_XmContainer_object) |
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_XmNsmallIconMask_arg */
static unsigned char arg_class_vec602[] =
  {
  0, 0, 0, 0, _BIT_MASK(sym_k_XmIconGadget_object) |
  0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_XmNsmallIconPixmap_arg */
static unsigned char arg_class_vec603[] =
  {
  0, 0, 0, 0, _BIT_MASK(sym_k_XmIconGadget_object) |
  0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_XmNsmallIconX_arg */
static unsigned char arg_class_vec604[] =
  {
  0, 0, _BIT_MASK(sym_k_XmContainer_object) |
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_XmNsmallIconY_arg */
static unsigned char arg_class_vec605[] =
  {
  0, 0, _BIT_MASK(sym_k_XmContainer_object) |
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_XmNsnapBackMultiple_arg */
static unsigned char arg_class_vec606[] =
  {
  0, 0, 0, 0, 0, 0, 0, 0, _BIT_MASK(sym_k_XmScrollBar_object) |
  0, 0, 0, 0};

/* sym_k_XmNsortFunctions_arg */
static unsigned char arg_class_vec607[] =
  {
  0, 0, 0, 0, 0, _BIT_MASK(sym_k_XmMultiList_object) |
  0, 0, 0, 0, 0, 0, 0};

/* sym_k_XmNsource_arg */
static unsigned char arg_class_vec608[] =
  {
  0, 0, 0, 0, 0, 0, 0, 0, _BIT_MASK(sym_k_XmScrolledText_object) |
  0, 0, _BIT_MASK(sym_k_XmText_object) |
  0, 0};

/* sym_k_XmNspacing_arg */
static unsigned char arg_class_vec609[] =
  {
  0, 0, _BIT_MASK(sym_k_XmCheckBox_object) |
  0, _BIT_MASK(sym_k_XmFontSelector_object) |
  0, _BIT_MASK(sym_k_XmIconGadget_object) |
  0, _BIT_MASK(sym_k_XmMainWindow_object) |
  _BIT_MASK(sym_k_XmMenuBar_object) |
  0, _BIT_MASK(sym_k_XmOptionMenu_object) |
  _BIT_MASK(sym_k_XmPaned_object) |
  _BIT_MASK(sym_k_XmPanedWindow_object) |
  _BIT_MASK(sym_k_XmPopupMenu_object) |
  _BIT_MASK(sym_k_XmPulldownMenu_object) |
  0, _BIT_MASK(sym_k_XmRadioBox_object) |
  _BIT_MASK(sym_k_XmRowColumn_object) |
  0, _BIT_MASK(sym_k_XmScrolledList_object) |
  _BIT_MASK(sym_k_XmScrolledText_object) |
  _BIT_MASK(sym_k_XmScrolledWindow_object) |
  0, _BIT_MASK(sym_k_XmSimpleSpinBox_object) |
  _BIT_MASK(sym_k_XmSpinBox_object) |
  0, _BIT_MASK(sym_k_XmToggleButton_object) |
  _BIT_MASK(sym_k_XmToggleButtonGadget_object) |
  _BIT_MASK(sym_k_XmWorkArea_object) |
  0, 0};

/* sym_k_XmNspatialIncludeModel_arg */
static unsigned char arg_class_vec610[] =
  {
  0, 0, _BIT_MASK(sym_k_XmContainer_object) |
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_XmNspatialResizeModel_arg */
static unsigned char arg_class_vec611[] =
  {
  0, 0, _BIT_MASK(sym_k_XmContainer_object) |
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_XmNspatialSnapModel_arg */
static unsigned char arg_class_vec612[] =
  {
  0, 0, _BIT_MASK(sym_k_XmContainer_object) |
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_XmNspatialStyle_arg */
static unsigned char arg_class_vec613[] =
  {
  0, 0, _BIT_MASK(sym_k_XmContainer_object) |
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_XmNspinBoxChildType_arg */
static unsigned char arg_class_vec614[] =
  {
  0, 0, 0, 0, 0, 0, 0, 0, 0, _BIT_MASK(sym_k_XmSimpleSpinBox_object) |
  _BIT_MASK(sym_k_XmSpinBox_object) |
  0, 0, 0};

/* sym_k_XmNstackedEffect_arg */
static unsigned char arg_class_vec615[] =
  {
  0, 0, 0, 0, 0, 0, 0, 0, 0, _BIT_MASK(sym_k_XmTabBox_object) |
  _BIT_MASK(sym_k_XmTabStack_object) |
  0, 0, 0};

/* sym_k_XmNstretchable_arg */
static unsigned char arg_class_vec616[] =
  {
  0, 0, _BIT_MASK(sym_k_XmColumn_object) |
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_XmNstrikethruType_arg */
static unsigned char arg_class_vec617[] =
  {
  0, 0, 0, 0, 0, 0, 0, _BIT_MASK(sym_k_XmRendition_object) |
  0, 0, 0, 0, 0};

/* sym_k_XmNstringDirection_arg */
static unsigned char arg_class_vec618[] =
  {
  _BIT_MASK(sym_k_DtEditor_object) |
  _BIT_MASK(sym_k_DtHelpDialog_object) |
  _BIT_MASK(sym_k_DtHelpQuickDialog_object) |
  _BIT_MASK(sym_k_DtMenuButton_object) |
  _BIT_MASK(sym_k_DtPrintSetupBox_object) |
  _BIT_MASK(sym_k_DtPrintSetupDialog_object) |
  0, _BIT_MASK(sym_k_XmBulletinBoard_object) |
  _BIT_MASK(sym_k_XmBulletinBoardDialog_object) |
  _BIT_MASK(sym_k_XmButtonBox_object) |
  _BIT_MASK(sym_k_XmCascadeButton_object) |
  _BIT_MASK(sym_k_XmCascadeButtonGadget_object) |
  0, _BIT_MASK(sym_k_XmCheckBox_object) |
  _BIT_MASK(sym_k_XmColorSelector_object) |
  _BIT_MASK(sym_k_XmColumn_object) |
  _BIT_MASK(sym_k_XmComboBox_object) |
  _BIT_MASK(sym_k_XmCommand_object) |
  _BIT_MASK(sym_k_XmCommandDialog_object) |
  _BIT_MASK(sym_k_XmContainer_object) |
  0, _BIT_MASK(sym_k_XmDrawingArea_object) |
  _BIT_MASK(sym_k_XmDrawnButton_object) |
  _BIT_MASK(sym_k_XmDropDown_object) |
  _BIT_MASK(sym_k_XmErrorDialog_object) |
  _BIT_MASK(sym_k_XmFileSelectionBox_object) |
  _BIT_MASK(sym_k_XmFileSelectionDialog_object) |
  _BIT_MASK(sym_k_XmFontSelector_object) |
  0, _BIT_MASK(sym_k_XmForm_object) |
  _BIT_MASK(sym_k_XmFormDialog_object) |
  _BIT_MASK(sym_k_XmFrame_object) |
  _BIT_MASK(sym_k_XmIconBox_object) |
  _BIT_MASK(sym_k_XmIconButton_object) |
  _BIT_MASK(sym_k_XmInformationDialog_object) |
  _BIT_MASK(sym_k_XmLabel_object) |
  0, _BIT_MASK(sym_k_XmLabelGadget_object) |
  _BIT_MASK(sym_k_XmList_object) |
  _BIT_MASK(sym_k_XmMainWindow_object) |
  _BIT_MASK(sym_k_XmMenuBar_object) |
  _BIT_MASK(sym_k_XmMessageBox_object) |
  _BIT_MASK(sym_k_XmMessageDialog_object) |
  _BIT_MASK(sym_k_XmMultiList_object) |
  0, _BIT_MASK(sym_k_XmNotebook_object) |
  _BIT_MASK(sym_k_XmOptionMenu_object) |
  _BIT_MASK(sym_k_XmOutline_object) |
  _BIT_MASK(sym_k_XmPaned_object) |
  _BIT_MASK(sym_k_XmPanedWindow_object) |
  _BIT_MASK(sym_k_XmPopupMenu_object) |
  _BIT_MASK(sym_k_XmPromptDialog_object) |
  _BIT_MASK(sym_k_XmPulldownMenu_object) |
  0, _BIT_MASK(sym_k_XmPushButton_object) |
  _BIT_MASK(sym_k_XmPushButtonGadget_object) |
  _BIT_MASK(sym_k_XmQuestionDialog_object) |
  _BIT_MASK(sym_k_XmRadioBox_object) |
  _BIT_MASK(sym_k_XmRowColumn_object) |
  _BIT_MASK(sym_k_XmScale_object) |
  0, _BIT_MASK(sym_k_XmScrolledList_object) |
  _BIT_MASK(sym_k_XmScrolledText_object) |
  _BIT_MASK(sym_k_XmScrolledWindow_object) |
  _BIT_MASK(sym_k_XmSelectionBox_object) |
  _BIT_MASK(sym_k_XmSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmSimpleSpinBox_object) |
  _BIT_MASK(sym_k_XmSpinBox_object) |
  _BIT_MASK(sym_k_XmTabStack_object) |
  _BIT_MASK(sym_k_XmTearOffButton_object) |
  _BIT_MASK(sym_k_XmTemplateDialog_object) |
  0, _BIT_MASK(sym_k_XmToggleButton_object) |
  _BIT_MASK(sym_k_XmToggleButtonGadget_object) |
  _BIT_MASK(sym_k_XmTree_object) |
  _BIT_MASK(sym_k_XmWarningDialog_object) |
  _BIT_MASK(sym_k_XmWorkArea_object) |
  _BIT_MASK(sym_k_XmWorkingDialog_object) |
  0, 0};

/* sym_k_XmNsubMenuId_arg */
static unsigned char arg_class_vec619[] =
  {
  0, _BIT_MASK(sym_k_XmCascadeButton_object) |
  _BIT_MASK(sym_k_XmCascadeButtonGadget_object) |
  0, _BIT_MASK(sym_k_XmCheckBox_object) |
  0, 0, 0, _BIT_MASK(sym_k_XmMenuBar_object) |
  0, _BIT_MASK(sym_k_XmOptionMenu_object) |
  _BIT_MASK(sym_k_XmPopupMenu_object) |
  _BIT_MASK(sym_k_XmPulldownMenu_object) |
  0, _BIT_MASK(sym_k_XmRadioBox_object) |
  _BIT_MASK(sym_k_XmRowColumn_object) |
  0, 0, 0, _BIT_MASK(sym_k_XmWorkArea_object) |
  0, 0};

/* sym_k_XmNsymbolPixmap_arg */
static unsigned char arg_class_vec620[] =
  {
  0, 0, 0, _BIT_MASK(sym_k_XmErrorDialog_object) |
  0, _BIT_MASK(sym_k_XmInformationDialog_object) |
  0, _BIT_MASK(sym_k_XmMessageBox_object) |
  _BIT_MASK(sym_k_XmMessageDialog_object) |
  0, 0, _BIT_MASK(sym_k_XmQuestionDialog_object) |
  0, 0, _BIT_MASK(sym_k_XmTemplateDialog_object) |
  0, _BIT_MASK(sym_k_XmWarningDialog_object) |
  _BIT_MASK(sym_k_XmWorkingDialog_object) |
  0, 0};

/* sym_k_XmNtabAlignment_arg */
static unsigned char arg_class_vec621[] =
  {
  0, 0, 0, 0, 0, 0, 0, 0, 0, _BIT_MASK(sym_k_XmTabStack_object) |
  0, 0, 0};

/* sym_k_XmNtabAutoSelect_arg */
static unsigned char arg_class_vec622[] =
  {
  0, 0, 0, 0, 0, 0, 0, 0, 0, _BIT_MASK(sym_k_XmTabBox_object) |
  _BIT_MASK(sym_k_XmTabStack_object) |
  0, 0, 0};

/* sym_k_XmNtabBackground_arg */
static unsigned char arg_class_vec623[] =
  {
  0, 0, 0, 0, 0, 0, 0, 0, 0, _BIT_MASK(sym_k_XmTabStack_object) |
  0, 0, 0};

/* sym_k_XmNtabBackgroundPixmap_arg */
static unsigned char arg_class_vec624[] =
  {
  0, 0, 0, 0, 0, 0, 0, 0, 0, _BIT_MASK(sym_k_XmTabStack_object) |
  0, 0, 0};

/* sym_k_XmNtabCornerPercent_arg */
static unsigned char arg_class_vec625[] =
  {
  0, 0, 0, 0, 0, 0, 0, 0, 0, _BIT_MASK(sym_k_XmTabBox_object) |
  _BIT_MASK(sym_k_XmTabStack_object) |
  0, 0, 0};

/* sym_k_XmNtabEdge_arg */
static unsigned char arg_class_vec626[] =
  {
  0, 0, 0, 0, 0, 0, 0, 0, 0, _BIT_MASK(sym_k_XmTabBox_object) |
  0, 0, 0};

/* sym_k_XmNtabForeground_arg */
static unsigned char arg_class_vec627[] =
  {
  0, 0, 0, 0, 0, 0, 0, 0, 0, _BIT_MASK(sym_k_XmTabStack_object) |
  0, 0, 0};

/* sym_k_XmNtabLabelPixmap_arg */
static unsigned char arg_class_vec628[] =
  {
  0, 0, 0, 0, 0, 0, 0, 0, 0, _BIT_MASK(sym_k_XmTabStack_object) |
  0, 0, 0};

/* sym_k_XmNtabLabelSpacing_arg */
static unsigned char arg_class_vec629[] =
  {
  0, 0, 0, 0, 0, 0, 0, 0, 0, _BIT_MASK(sym_k_XmTabBox_object) |
  _BIT_MASK(sym_k_XmTabStack_object) |
  0, 0, 0};

/* sym_k_XmNtabLabelString_arg */
static unsigned char arg_class_vec630[] =
  {
  0, 0, 0, 0, 0, 0, 0, 0, 0, _BIT_MASK(sym_k_XmTabStack_object) |
  0, 0, 0};

/* sym_k_XmNtabList_arg */
static unsigned char arg_class_vec631[] =
  {
  0, 0, 0, 0, 0, 0, 0, 0, 0, _BIT_MASK(sym_k_XmTabBox_object) |
  0, 0, 0};

/* sym_k_XmNtabMarginHeight_arg */
static unsigned char arg_class_vec632[] =
  {
  0, 0, 0, 0, 0, 0, 0, 0, 0, _BIT_MASK(sym_k_XmTabBox_object) |
  _BIT_MASK(sym_k_XmTabStack_object) |
  0, 0, 0};

/* sym_k_XmNtabMarginWidth_arg */
static unsigned char arg_class_vec633[] =
  {
  0, 0, 0, 0, 0, 0, 0, 0, 0, _BIT_MASK(sym_k_XmTabBox_object) |
  _BIT_MASK(sym_k_XmTabStack_object) |
  0, 0, 0};

/* sym_k_XmNtabMode_arg */
static unsigned char arg_class_vec634[] =
  {
  0, 0, 0, 0, 0, 0, 0, 0, 0, _BIT_MASK(sym_k_XmTabBox_object) |
  _BIT_MASK(sym_k_XmTabStack_object) |
  0, 0, 0};

/* sym_k_XmNtabOffset_arg */
static unsigned char arg_class_vec635[] =
  {
  0, 0, 0, 0, 0, 0, 0, 0, 0, _BIT_MASK(sym_k_XmTabBox_object) |
  _BIT_MASK(sym_k_XmTabStack_object) |
  0, 0, 0};

/* sym_k_XmNtabOrientation_arg */
static unsigned char arg_class_vec636[] =
  {
  0, 0, 0, 0, 0, 0, 0, 0, 0, _BIT_MASK(sym_k_XmTabBox_object) |
  _BIT_MASK(sym_k_XmTabStack_object) |
  0, 0, 0};

/* sym_k_XmNtabPixmapPlacement_arg */
static unsigned char arg_class_vec637[] =
  {
  0, 0, 0, 0, 0, 0, 0, 0, 0, _BIT_MASK(sym_k_XmTabStack_object) |
  0, 0, 0};

/* sym_k_XmNtabSelectColor_arg */
static unsigned char arg_class_vec638[] =
  {
  0, 0, 0, 0, 0, 0, 0, 0, 0, _BIT_MASK(sym_k_XmTabBox_object) |
  _BIT_MASK(sym_k_XmTabStack_object) |
  0, 0, 0};

/* sym_k_XmNtabSelectPixmap_arg */
static unsigned char arg_class_vec639[] =
  {
  0, 0, 0, 0, 0, 0, 0, 0, 0, _BIT_MASK(sym_k_XmTabBox_object) |
  _BIT_MASK(sym_k_XmTabStack_object) |
  0, 0, 0};

/* sym_k_XmNtabSide_arg */
static unsigned char arg_class_vec640[] =
  {
  0, 0, 0, 0, 0, 0, 0, 0, 0, _BIT_MASK(sym_k_XmTabStack_object) |
  0, 0, 0};

/* sym_k_XmNtabStringDirection_arg */
static unsigned char arg_class_vec641[] =
  {
  0, 0, 0, 0, 0, 0, 0, 0, 0, _BIT_MASK(sym_k_XmTabStack_object) |
  0, 0, 0};

/* sym_k_XmNtabStyle_arg */
static unsigned char arg_class_vec642[] =
  {
  0, 0, 0, 0, 0, 0, 0, 0, 0, _BIT_MASK(sym_k_XmTabBox_object) |
  _BIT_MASK(sym_k_XmTabStack_object) |
  0, 0, 0};

/* sym_k_XmNtabValue_arg */
static unsigned char arg_class_vec643[] =
  {
  0, 0, 0, 0, 0, 0, 0, 0, 0, _BIT_MASK(sym_k_XmTab_object) |
  0, 0, 0};

/* sym_k_XmNtearOffModel_arg */
static unsigned char arg_class_vec644[] =
  {
  0, 0, _BIT_MASK(sym_k_XmCheckBox_object) |
  0, 0, 0, _BIT_MASK(sym_k_XmMenuBar_object) |
  0, _BIT_MASK(sym_k_XmOptionMenu_object) |
  _BIT_MASK(sym_k_XmPopupMenu_object) |
  _BIT_MASK(sym_k_XmPulldownMenu_object) |
  0, _BIT_MASK(sym_k_XmRadioBox_object) |
  _BIT_MASK(sym_k_XmRowColumn_object) |
  0, 0, 0, _BIT_MASK(sym_k_XmWorkArea_object) |
  0, 0};

/* sym_k_XmNtearOffTitle_arg */
static unsigned char arg_class_vec645[] =
  {
  0, 0, _BIT_MASK(sym_k_XmCheckBox_object) |
  0, 0, 0, _BIT_MASK(sym_k_XmMenuBar_object) |
  0, _BIT_MASK(sym_k_XmOptionMenu_object) |
  _BIT_MASK(sym_k_XmPopupMenu_object) |
  _BIT_MASK(sym_k_XmPulldownMenu_object) |
  0, _BIT_MASK(sym_k_XmRadioBox_object) |
  _BIT_MASK(sym_k_XmRowColumn_object) |
  0, 0, 0, _BIT_MASK(sym_k_XmWorkArea_object) |
  0, 0};

/* sym_k_XmNtextAccelerators_arg */
static unsigned char arg_class_vec646[] =
  {
  0, 0, _BIT_MASK(sym_k_XmCommand_object) |
  _BIT_MASK(sym_k_XmCommandDialog_object) |
  0, _BIT_MASK(sym_k_XmFileSelectionBox_object) |
  _BIT_MASK(sym_k_XmFileSelectionDialog_object) |
  0, 0, 0, _BIT_MASK(sym_k_XmPromptDialog_object) |
  0, 0, _BIT_MASK(sym_k_XmSelectionBox_object) |
  _BIT_MASK(sym_k_XmSelectionDialog_object) |
  0, 0, 0, 0};

/* sym_k_XmNtextColumns_arg */
static unsigned char arg_class_vec647[] =
  {
  0, 0, _BIT_MASK(sym_k_XmCommand_object) |
  _BIT_MASK(sym_k_XmCommandDialog_object) |
  0, _BIT_MASK(sym_k_XmFileSelectionBox_object) |
  _BIT_MASK(sym_k_XmFileSelectionDialog_object) |
  0, 0, 0, _BIT_MASK(sym_k_XmPromptDialog_object) |
  0, 0, _BIT_MASK(sym_k_XmSelectionBox_object) |
  _BIT_MASK(sym_k_XmSelectionDialog_object) |
  0, 0, 0, 0};

/* sym_k_XmNtextField_arg */
static unsigned char arg_class_vec648[] =
  {
  0, 0, _BIT_MASK(sym_k_XmComboBox_object) |
  0, 0, 0, 0, 0, 0, 0, _BIT_MASK(sym_k_XmSimpleSpinBox_object) |
  0, 0, 0};

/* sym_k_XmNtextFontList_arg */
static unsigned char arg_class_vec649[] =
  {
  _BIT_MASK(sym_k_DtEditor_object) |
  _BIT_MASK(sym_k_DtHelpDialog_object) |
  _BIT_MASK(sym_k_DtHelpQuickDialog_object) |
  _BIT_MASK(sym_k_DtPrintSetupBox_object) |
  _BIT_MASK(sym_k_DtPrintSetupDialog_object) |
  0, _BIT_MASK(sym_k_XmBulletinBoard_object) |
  _BIT_MASK(sym_k_XmBulletinBoardDialog_object) |
  0, _BIT_MASK(sym_k_XmColumn_object) |
  _BIT_MASK(sym_k_XmCommand_object) |
  _BIT_MASK(sym_k_XmCommandDialog_object) |
  0, _BIT_MASK(sym_k_XmDialogShell_object) |
  _BIT_MASK(sym_k_XmErrorDialog_object) |
  _BIT_MASK(sym_k_XmFileSelectionBox_object) |
  _BIT_MASK(sym_k_XmFileSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmForm_object) |
  _BIT_MASK(sym_k_XmFormDialog_object) |
  _BIT_MASK(sym_k_XmInformationDialog_object) |
  0, _BIT_MASK(sym_k_XmMessageBox_object) |
  _BIT_MASK(sym_k_XmMessageDialog_object) |
  0, _BIT_MASK(sym_k_XmPromptDialog_object) |
  0, _BIT_MASK(sym_k_XmQuestionDialog_object) |
  0, _BIT_MASK(sym_k_XmSelectionBox_object) |
  _BIT_MASK(sym_k_XmSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmTabStack_object) |
  _BIT_MASK(sym_k_XmTemplateDialog_object) |
  0, _BIT_MASK(sym_k_XmWarningDialog_object) |
  _BIT_MASK(sym_k_XmWorkingDialog_object) |
  0, 0};

/* sym_k_XmNtextRenderTable_arg */
static unsigned char arg_class_vec650[] =
  {
  _BIT_MASK(sym_k_DtEditor_object) |
  _BIT_MASK(sym_k_DtHelpDialog_object) |
  _BIT_MASK(sym_k_DtHelpQuickDialog_object) |
  _BIT_MASK(sym_k_DtPrintSetupBox_object) |
  _BIT_MASK(sym_k_DtPrintSetupDialog_object) |
  0, _BIT_MASK(sym_k_XmBulletinBoard_object) |
  _BIT_MASK(sym_k_XmBulletinBoardDialog_object) |
  0, _BIT_MASK(sym_k_XmColumn_object) |
  _BIT_MASK(sym_k_XmCommand_object) |
  _BIT_MASK(sym_k_XmCommandDialog_object) |
  0, _BIT_MASK(sym_k_XmDialogShell_object) |
  _BIT_MASK(sym_k_XmErrorDialog_object) |
  _BIT_MASK(sym_k_XmFileSelectionBox_object) |
  _BIT_MASK(sym_k_XmFileSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmForm_object) |
  _BIT_MASK(sym_k_XmFormDialog_object) |
  _BIT_MASK(sym_k_XmInformationDialog_object) |
  0, _BIT_MASK(sym_k_XmMenuShell_object) |
  _BIT_MASK(sym_k_XmMessageBox_object) |
  _BIT_MASK(sym_k_XmMessageDialog_object) |
  0, _BIT_MASK(sym_k_XmPopupMenu_object) |
  _BIT_MASK(sym_k_XmPromptDialog_object) |
  _BIT_MASK(sym_k_XmPulldownMenu_object) |
  0, _BIT_MASK(sym_k_XmQuestionDialog_object) |
  0, _BIT_MASK(sym_k_XmSelectionBox_object) |
  _BIT_MASK(sym_k_XmSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmTabStack_object) |
  _BIT_MASK(sym_k_XmTemplateDialog_object) |
  0, _BIT_MASK(sym_k_XmWarningDialog_object) |
  _BIT_MASK(sym_k_XmWorkingDialog_object) |
  0, 0};

/* sym_k_XmNtextRows_arg */
static unsigned char arg_class_vec651[] =
  {
  0, 0, 0, _BIT_MASK(sym_k_XmFontSelector_object) |
  0, 0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_XmNtextString_arg */
static unsigned char arg_class_vec652[] =
  {
  0, 0, _BIT_MASK(sym_k_XmCommand_object) |
  _BIT_MASK(sym_k_XmCommandDialog_object) |
  0, _BIT_MASK(sym_k_XmFileSelectionBox_object) |
  _BIT_MASK(sym_k_XmFileSelectionDialog_object) |
  0, 0, 0, _BIT_MASK(sym_k_XmPromptDialog_object) |
  0, 0, _BIT_MASK(sym_k_XmSelectionBox_object) |
  _BIT_MASK(sym_k_XmSelectionDialog_object) |
  0, 0, 0, 0};

/* sym_k_XmNtextTranslations_arg */
static unsigned char arg_class_vec653[] =
  {
  _BIT_MASK(sym_k_DtEditor_object) |
  _BIT_MASK(sym_k_DtHelpDialog_object) |
  _BIT_MASK(sym_k_DtHelpQuickDialog_object) |
  _BIT_MASK(sym_k_DtPrintSetupBox_object) |
  _BIT_MASK(sym_k_DtPrintSetupDialog_object) |
  0, _BIT_MASK(sym_k_XmBulletinBoard_object) |
  _BIT_MASK(sym_k_XmBulletinBoardDialog_object) |
  0, _BIT_MASK(sym_k_XmColumn_object) |
  _BIT_MASK(sym_k_XmCommand_object) |
  _BIT_MASK(sym_k_XmCommandDialog_object) |
  0, _BIT_MASK(sym_k_XmErrorDialog_object) |
  _BIT_MASK(sym_k_XmFileSelectionBox_object) |
  _BIT_MASK(sym_k_XmFileSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmForm_object) |
  _BIT_MASK(sym_k_XmFormDialog_object) |
  _BIT_MASK(sym_k_XmInformationDialog_object) |
  0, _BIT_MASK(sym_k_XmMessageBox_object) |
  _BIT_MASK(sym_k_XmMessageDialog_object) |
  0, _BIT_MASK(sym_k_XmPromptDialog_object) |
  0, _BIT_MASK(sym_k_XmQuestionDialog_object) |
  0, _BIT_MASK(sym_k_XmSelectionBox_object) |
  _BIT_MASK(sym_k_XmSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmTabStack_object) |
  _BIT_MASK(sym_k_XmTemplateDialog_object) |
  0, _BIT_MASK(sym_k_XmWarningDialog_object) |
  _BIT_MASK(sym_k_XmWorkingDialog_object) |
  0, 0};

/* sym_k_XmNtitle_arg */
static unsigned char arg_class_vec654[] =
  {
  _BIT_MASK(sym_k_DtHelpDialog_object) |
  _BIT_MASK(sym_k_DtHelpQuickDialog_object) |
  _BIT_MASK(sym_k_DtPrintSetupDialog_object) |
  0, _BIT_MASK(sym_k_XmBulletinBoardDialog_object) |
  0, _BIT_MASK(sym_k_XmCommandDialog_object) |
  0, _BIT_MASK(sym_k_XmDialogShell_object) |
  _BIT_MASK(sym_k_XmErrorDialog_object) |
  _BIT_MASK(sym_k_XmFileSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmFormDialog_object) |
  _BIT_MASK(sym_k_XmInformationDialog_object) |
  0, _BIT_MASK(sym_k_XmMessageDialog_object) |
  0, _BIT_MASK(sym_k_XmPromptDialog_object) |
  0, _BIT_MASK(sym_k_XmQuestionDialog_object) |
  0, _BIT_MASK(sym_k_XmSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmTemplateDialog_object) |
  0, _BIT_MASK(sym_k_XmWarningDialog_object) |
  _BIT_MASK(sym_k_XmWorkingDialog_object) |
  0, 0};

/* sym_k_XmNtitleEncoding_arg */
static unsigned char arg_class_vec655[] =
  {
  _BIT_MASK(sym_k_DtHelpDialog_object) |
  _BIT_MASK(sym_k_DtHelpQuickDialog_object) |
  _BIT_MASK(sym_k_DtPrintSetupDialog_object) |
  0, _BIT_MASK(sym_k_XmBulletinBoardDialog_object) |
  0, _BIT_MASK(sym_k_XmCommandDialog_object) |
  0, _BIT_MASK(sym_k_XmDialogShell_object) |
  _BIT_MASK(sym_k_XmErrorDialog_object) |
  _BIT_MASK(sym_k_XmFileSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmFormDialog_object) |
  _BIT_MASK(sym_k_XmInformationDialog_object) |
  0, _BIT_MASK(sym_k_XmMessageDialog_object) |
  0, _BIT_MASK(sym_k_XmPromptDialog_object) |
  0, _BIT_MASK(sym_k_XmQuestionDialog_object) |
  0, _BIT_MASK(sym_k_XmSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmTemplateDialog_object) |
  0, _BIT_MASK(sym_k_XmWarningDialog_object) |
  _BIT_MASK(sym_k_XmWorkingDialog_object) |
  0, 0};

/* sym_k_XmNtitleString_arg */
static unsigned char arg_class_vec656[] =
  {
  0, 0, 0, 0, 0, _BIT_MASK(sym_k_XmMultiList_object) |
  0, 0, _BIT_MASK(sym_k_XmScale_object) |
  0, 0, 0, 0, 0};

/* sym_k_XmNtoggleMode_arg */
static unsigned char arg_class_vec657[] =
  {
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, _BIT_MASK(sym_k_XmToggleButton_object) |
  _BIT_MASK(sym_k_XmToggleButtonGadget_object) |
  0, 0};

/* sym_k_XmNtoolTipEnable_arg */
static unsigned char arg_class_vec658[] =
  {
  _BIT_MASK(sym_k_DtHelpDialog_object) |
  _BIT_MASK(sym_k_DtHelpQuickDialog_object) |
  _BIT_MASK(sym_k_DtPrintSetupDialog_object) |
  0, _BIT_MASK(sym_k_XmBulletinBoardDialog_object) |
  0, _BIT_MASK(sym_k_XmCommandDialog_object) |
  0, _BIT_MASK(sym_k_XmDialogShell_object) |
  _BIT_MASK(sym_k_XmErrorDialog_object) |
  _BIT_MASK(sym_k_XmFileSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmFormDialog_object) |
  _BIT_MASK(sym_k_XmInformationDialog_object) |
  0, _BIT_MASK(sym_k_XmMessageDialog_object) |
  0, _BIT_MASK(sym_k_XmPromptDialog_object) |
  0, _BIT_MASK(sym_k_XmQuestionDialog_object) |
  0, _BIT_MASK(sym_k_XmSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmTemplateDialog_object) |
  0, _BIT_MASK(sym_k_XmWarningDialog_object) |
  _BIT_MASK(sym_k_XmWorkingDialog_object) |
  0, 0};

/* sym_k_XmNtoolTipPostDelay_arg */
static unsigned char arg_class_vec659[] =
  {
  _BIT_MASK(sym_k_DtHelpDialog_object) |
  _BIT_MASK(sym_k_DtHelpQuickDialog_object) |
  _BIT_MASK(sym_k_DtPrintSetupDialog_object) |
  0, _BIT_MASK(sym_k_XmBulletinBoardDialog_object) |
  0, _BIT_MASK(sym_k_XmCommandDialog_object) |
  0, _BIT_MASK(sym_k_XmDialogShell_object) |
  _BIT_MASK(sym_k_XmErrorDialog_object) |
  _BIT_MASK(sym_k_XmFileSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmFormDialog_object) |
  _BIT_MASK(sym_k_XmInformationDialog_object) |
  0, _BIT_MASK(sym_k_XmMessageDialog_object) |
  0, _BIT_MASK(sym_k_XmPromptDialog_object) |
  0, _BIT_MASK(sym_k_XmQuestionDialog_object) |
  0, _BIT_MASK(sym_k_XmSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmTemplateDialog_object) |
  0, _BIT_MASK(sym_k_XmWarningDialog_object) |
  _BIT_MASK(sym_k_XmWorkingDialog_object) |
  0, 0};

/* sym_k_XmNtoolTipPostDuration_arg */
static unsigned char arg_class_vec660[] =
  {
  _BIT_MASK(sym_k_DtHelpDialog_object) |
  _BIT_MASK(sym_k_DtHelpQuickDialog_object) |
  _BIT_MASK(sym_k_DtPrintSetupDialog_object) |
  0, _BIT_MASK(sym_k_XmBulletinBoardDialog_object) |
  0, _BIT_MASK(sym_k_XmCommandDialog_object) |
  0, _BIT_MASK(sym_k_XmDialogShell_object) |
  _BIT_MASK(sym_k_XmErrorDialog_object) |
  _BIT_MASK(sym_k_XmFileSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmFormDialog_object) |
  _BIT_MASK(sym_k_XmInformationDialog_object) |
  0, _BIT_MASK(sym_k_XmMessageDialog_object) |
  0, _BIT_MASK(sym_k_XmPromptDialog_object) |
  0, _BIT_MASK(sym_k_XmQuestionDialog_object) |
  0, _BIT_MASK(sym_k_XmSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmTemplateDialog_object) |
  0, _BIT_MASK(sym_k_XmWarningDialog_object) |
  _BIT_MASK(sym_k_XmWorkingDialog_object) |
  0, 0};

/* sym_k_XmNtoolTipString_arg */
static unsigned char arg_class_vec661[] =
  {
  _BIT_MASK(sym_k_DtMenuButton_object) |
  _BIT_MASK(sym_k_DtTerm_object) |
  0, _BIT_MASK(sym_k_DtTermPrimitive_object) |
  _BIT_MASK(sym_k_XmArrowButton_object) |
  _BIT_MASK(sym_k_XmArrowButtonGadget_object) |
  _BIT_MASK(sym_k_XmCascadeButton_object) |
  _BIT_MASK(sym_k_XmCascadeButtonGadget_object) |
  0, _BIT_MASK(sym_k_XmDataField_object) |
  0, _BIT_MASK(sym_k_XmDrawnButton_object) |
  0, _BIT_MASK(sym_k_XmIconButton_object) |
  _BIT_MASK(sym_k_XmIconGadget_object) |
  _BIT_MASK(sym_k_XmLabel_object) |
  0, _BIT_MASK(sym_k_XmLabelGadget_object) |
  _BIT_MASK(sym_k_XmList_object) |
  0, 0, _BIT_MASK(sym_k_XmPushButton_object) |
  _BIT_MASK(sym_k_XmPushButtonGadget_object) |
  0, _BIT_MASK(sym_k_XmScrollBar_object) |
  _BIT_MASK(sym_k_XmScrolledList_object) |
  _BIT_MASK(sym_k_XmScrolledText_object) |
  _BIT_MASK(sym_k_XmSeparator_object) |
  _BIT_MASK(sym_k_XmSeparatorGadget_object) |
  0, _BIT_MASK(sym_k_XmTabBox_object) |
  _BIT_MASK(sym_k_XmTearOffButton_object) |
  0, _BIT_MASK(sym_k_XmText_object) |
  _BIT_MASK(sym_k_XmTextField_object) |
  _BIT_MASK(sym_k_XmToggleButton_object) |
  _BIT_MASK(sym_k_XmToggleButtonGadget_object) |
  0, 0};

/* sym_k_XmNtopAttachment_arg */
static unsigned char arg_class_vec662[] =
  {
  _BIT_MASK(sym_k_DtEditor_object) |
  0, 0, 0, 0, _BIT_MASK(sym_k_XmForm_object) |
  _BIT_MASK(sym_k_XmFormDialog_object) |
  0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_XmNtopCharacter_arg */
static unsigned char arg_class_vec663[] =
  {
  0, 0, 0, 0, 0, 0, 0, 0, _BIT_MASK(sym_k_XmScrolledText_object) |
  0, 0, _BIT_MASK(sym_k_XmText_object) |
  0, 0};

/* sym_k_XmNtopItemPosition_arg */
static unsigned char arg_class_vec664[] =
  {
  0, 0, 0, 0, 0, _BIT_MASK(sym_k_XmList_object) |
  0, 0, 0, _BIT_MASK(sym_k_XmScrolledList_object) |
  0, 0, 0, 0};

/* sym_k_XmNtopOffset_arg */
static unsigned char arg_class_vec665[] =
  {
  _BIT_MASK(sym_k_DtEditor_object) |
  0, 0, 0, 0, _BIT_MASK(sym_k_XmForm_object) |
  _BIT_MASK(sym_k_XmFormDialog_object) |
  0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_XmNtopPosition_arg */
static unsigned char arg_class_vec666[] =
  {
  _BIT_MASK(sym_k_DtEditor_object) |
  0, 0, 0, 0, _BIT_MASK(sym_k_XmForm_object) |
  _BIT_MASK(sym_k_XmFormDialog_object) |
  0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_XmNtopShadowColor_arg */
static unsigned char arg_class_vec667[] =
  {
  _BIT_MASK(sym_k_DtEditor_object) |
  _BIT_MASK(sym_k_DtHelpDialog_object) |
  _BIT_MASK(sym_k_DtHelpQuickDialog_object) |
  _BIT_MASK(sym_k_DtMenuButton_object) |
  _BIT_MASK(sym_k_DtPrintSetupBox_object) |
  _BIT_MASK(sym_k_DtPrintSetupDialog_object) |
  _BIT_MASK(sym_k_DtTerm_object) |
  0, _BIT_MASK(sym_k_DtTermPrimitive_object) |
  _BIT_MASK(sym_k_XmArrowButton_object) |
  _BIT_MASK(sym_k_XmBulletinBoard_object) |
  _BIT_MASK(sym_k_XmBulletinBoardDialog_object) |
  _BIT_MASK(sym_k_XmButtonBox_object) |
  _BIT_MASK(sym_k_XmCascadeButton_object) |
  0, _BIT_MASK(sym_k_XmCheckBox_object) |
  _BIT_MASK(sym_k_XmColorSelector_object) |
  _BIT_MASK(sym_k_XmColumn_object) |
  _BIT_MASK(sym_k_XmComboBox_object) |
  _BIT_MASK(sym_k_XmCommand_object) |
  _BIT_MASK(sym_k_XmCommandDialog_object) |
  _BIT_MASK(sym_k_XmContainer_object) |
  _BIT_MASK(sym_k_XmDataField_object) |
  0, _BIT_MASK(sym_k_XmDrawingArea_object) |
  _BIT_MASK(sym_k_XmDrawnButton_object) |
  _BIT_MASK(sym_k_XmDropDown_object) |
  _BIT_MASK(sym_k_XmErrorDialog_object) |
  _BIT_MASK(sym_k_XmFileSelectionBox_object) |
  _BIT_MASK(sym_k_XmFileSelectionDialog_object) |
  _BIT_MASK(sym_k_XmFontSelector_object) |
  0, _BIT_MASK(sym_k_XmForm_object) |
  _BIT_MASK(sym_k_XmFormDialog_object) |
  _BIT_MASK(sym_k_XmFrame_object) |
  _BIT_MASK(sym_k_XmIconBox_object) |
  _BIT_MASK(sym_k_XmIconButton_object) |
  _BIT_MASK(sym_k_XmInformationDialog_object) |
  _BIT_MASK(sym_k_XmLabel_object) |
  0, _BIT_MASK(sym_k_XmList_object) |
  _BIT_MASK(sym_k_XmMainWindow_object) |
  _BIT_MASK(sym_k_XmMenuBar_object) |
  _BIT_MASK(sym_k_XmMessageBox_object) |
  _BIT_MASK(sym_k_XmMessageDialog_object) |
  _BIT_MASK(sym_k_XmMultiList_object) |
  0, _BIT_MASK(sym_k_XmNotebook_object) |
  _BIT_MASK(sym_k_XmOptionMenu_object) |
  _BIT_MASK(sym_k_XmOutline_object) |
  _BIT_MASK(sym_k_XmPaned_object) |
  _BIT_MASK(sym_k_XmPanedWindow_object) |
  _BIT_MASK(sym_k_XmPopupMenu_object) |
  _BIT_MASK(sym_k_XmPromptDialog_object) |
  _BIT_MASK(sym_k_XmPulldownMenu_object) |
  0, _BIT_MASK(sym_k_XmPushButton_object) |
  _BIT_MASK(sym_k_XmQuestionDialog_object) |
  _BIT_MASK(sym_k_XmRadioBox_object) |
  _BIT_MASK(sym_k_XmRowColumn_object) |
  _BIT_MASK(sym_k_XmScale_object) |
  0, _BIT_MASK(sym_k_XmScrollBar_object) |
  _BIT_MASK(sym_k_XmScrolledList_object) |
  _BIT_MASK(sym_k_XmScrolledText_object) |
  _BIT_MASK(sym_k_XmScrolledWindow_object) |
  _BIT_MASK(sym_k_XmSelectionBox_object) |
  _BIT_MASK(sym_k_XmSelectionDialog_object) |
  _BIT_MASK(sym_k_XmSeparator_object) |
  0, _BIT_MASK(sym_k_XmSimpleSpinBox_object) |
  _BIT_MASK(sym_k_XmSpinBox_object) |
  _BIT_MASK(sym_k_XmTabBox_object) |
  _BIT_MASK(sym_k_XmTabStack_object) |
  _BIT_MASK(sym_k_XmTearOffButton_object) |
  _BIT_MASK(sym_k_XmTemplateDialog_object) |
  0, _BIT_MASK(sym_k_XmText_object) |
  _BIT_MASK(sym_k_XmTextField_object) |
  _BIT_MASK(sym_k_XmToggleButton_object) |
  _BIT_MASK(sym_k_XmTree_object) |
  _BIT_MASK(sym_k_XmWarningDialog_object) |
  _BIT_MASK(sym_k_XmWorkArea_object) |
  _BIT_MASK(sym_k_XmWorkingDialog_object) |
  0, 0};

/* sym_k_XmNtopShadowPixmap_arg */
static unsigned char arg_class_vec668[] =
  {
  _BIT_MASK(sym_k_DtEditor_object) |
  _BIT_MASK(sym_k_DtHelpDialog_object) |
  _BIT_MASK(sym_k_DtHelpQuickDialog_object) |
  _BIT_MASK(sym_k_DtMenuButton_object) |
  _BIT_MASK(sym_k_DtPrintSetupBox_object) |
  _BIT_MASK(sym_k_DtPrintSetupDialog_object) |
  _BIT_MASK(sym_k_DtTerm_object) |
  0, _BIT_MASK(sym_k_DtTermPrimitive_object) |
  _BIT_MASK(sym_k_XmArrowButton_object) |
  _BIT_MASK(sym_k_XmBulletinBoard_object) |
  _BIT_MASK(sym_k_XmBulletinBoardDialog_object) |
  _BIT_MASK(sym_k_XmButtonBox_object) |
  _BIT_MASK(sym_k_XmCascadeButton_object) |
  0, _BIT_MASK(sym_k_XmCheckBox_object) |
  _BIT_MASK(sym_k_XmColorSelector_object) |
  _BIT_MASK(sym_k_XmColumn_object) |
  _BIT_MASK(sym_k_XmComboBox_object) |
  _BIT_MASK(sym_k_XmCommand_object) |
  _BIT_MASK(sym_k_XmCommandDialog_object) |
  _BIT_MASK(sym_k_XmContainer_object) |
  _BIT_MASK(sym_k_XmDataField_object) |
  0, _BIT_MASK(sym_k_XmDrawingArea_object) |
  _BIT_MASK(sym_k_XmDrawnButton_object) |
  _BIT_MASK(sym_k_XmDropDown_object) |
  _BIT_MASK(sym_k_XmErrorDialog_object) |
  _BIT_MASK(sym_k_XmFileSelectionBox_object) |
  _BIT_MASK(sym_k_XmFileSelectionDialog_object) |
  _BIT_MASK(sym_k_XmFontSelector_object) |
  0, _BIT_MASK(sym_k_XmForm_object) |
  _BIT_MASK(sym_k_XmFormDialog_object) |
  _BIT_MASK(sym_k_XmFrame_object) |
  _BIT_MASK(sym_k_XmIconBox_object) |
  _BIT_MASK(sym_k_XmIconButton_object) |
  _BIT_MASK(sym_k_XmInformationDialog_object) |
  _BIT_MASK(sym_k_XmLabel_object) |
  0, _BIT_MASK(sym_k_XmList_object) |
  _BIT_MASK(sym_k_XmMainWindow_object) |
  _BIT_MASK(sym_k_XmMenuBar_object) |
  _BIT_MASK(sym_k_XmMessageBox_object) |
  _BIT_MASK(sym_k_XmMessageDialog_object) |
  _BIT_MASK(sym_k_XmMultiList_object) |
  0, _BIT_MASK(sym_k_XmNotebook_object) |
  _BIT_MASK(sym_k_XmOptionMenu_object) |
  _BIT_MASK(sym_k_XmOutline_object) |
  _BIT_MASK(sym_k_XmPaned_object) |
  _BIT_MASK(sym_k_XmPanedWindow_object) |
  _BIT_MASK(sym_k_XmPopupMenu_object) |
  _BIT_MASK(sym_k_XmPromptDialog_object) |
  _BIT_MASK(sym_k_XmPulldownMenu_object) |
  0, _BIT_MASK(sym_k_XmPushButton_object) |
  _BIT_MASK(sym_k_XmQuestionDialog_object) |
  _BIT_MASK(sym_k_XmRadioBox_object) |
  _BIT_MASK(sym_k_XmRowColumn_object) |
  _BIT_MASK(sym_k_XmScale_object) |
  0, _BIT_MASK(sym_k_XmScrollBar_object) |
  _BIT_MASK(sym_k_XmScrolledList_object) |
  _BIT_MASK(sym_k_XmScrolledText_object) |
  _BIT_MASK(sym_k_XmScrolledWindow_object) |
  _BIT_MASK(sym_k_XmSelectionBox_object) |
  _BIT_MASK(sym_k_XmSelectionDialog_object) |
  _BIT_MASK(sym_k_XmSeparator_object) |
  0, _BIT_MASK(sym_k_XmSimpleSpinBox_object) |
  _BIT_MASK(sym_k_XmSpinBox_object) |
  _BIT_MASK(sym_k_XmTabBox_object) |
  _BIT_MASK(sym_k_XmTabStack_object) |
  _BIT_MASK(sym_k_XmTearOffButton_object) |
  _BIT_MASK(sym_k_XmTemplateDialog_object) |
  0, _BIT_MASK(sym_k_XmText_object) |
  _BIT_MASK(sym_k_XmTextField_object) |
  _BIT_MASK(sym_k_XmToggleButton_object) |
  _BIT_MASK(sym_k_XmTree_object) |
  _BIT_MASK(sym_k_XmWarningDialog_object) |
  _BIT_MASK(sym_k_XmWorkArea_object) |
  _BIT_MASK(sym_k_XmWorkingDialog_object) |
  0, 0};

/* sym_k_XmNtopWidget_arg */
static unsigned char arg_class_vec669[] =
  {
  _BIT_MASK(sym_k_DtEditor_object) |
  0, 0, 0, 0, _BIT_MASK(sym_k_XmForm_object) |
  _BIT_MASK(sym_k_XmFormDialog_object) |
  0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_XmNtransient_arg */
static unsigned char arg_class_vec670[] =
  {
  _BIT_MASK(sym_k_DtHelpDialog_object) |
  _BIT_MASK(sym_k_DtHelpQuickDialog_object) |
  _BIT_MASK(sym_k_DtPrintSetupDialog_object) |
  0, _BIT_MASK(sym_k_XmBulletinBoardDialog_object) |
  0, _BIT_MASK(sym_k_XmCommandDialog_object) |
  0, _BIT_MASK(sym_k_XmDialogShell_object) |
  _BIT_MASK(sym_k_XmErrorDialog_object) |
  _BIT_MASK(sym_k_XmFileSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmFormDialog_object) |
  _BIT_MASK(sym_k_XmInformationDialog_object) |
  0, _BIT_MASK(sym_k_XmMessageDialog_object) |
  0, _BIT_MASK(sym_k_XmPromptDialog_object) |
  0, _BIT_MASK(sym_k_XmQuestionDialog_object) |
  0, _BIT_MASK(sym_k_XmSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmTemplateDialog_object) |
  0, _BIT_MASK(sym_k_XmWarningDialog_object) |
  _BIT_MASK(sym_k_XmWorkingDialog_object) |
  0, 0};

/* sym_k_XmNtransientFor_arg */
static unsigned char arg_class_vec671[] =
  {
  _BIT_MASK(sym_k_DtHelpDialog_object) |
  _BIT_MASK(sym_k_DtHelpQuickDialog_object) |
  _BIT_MASK(sym_k_DtPrintSetupDialog_object) |
  0, _BIT_MASK(sym_k_XmBulletinBoardDialog_object) |
  0, _BIT_MASK(sym_k_XmCommandDialog_object) |
  0, _BIT_MASK(sym_k_XmDialogShell_object) |
  _BIT_MASK(sym_k_XmErrorDialog_object) |
  _BIT_MASK(sym_k_XmFileSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmFormDialog_object) |
  _BIT_MASK(sym_k_XmInformationDialog_object) |
  0, _BIT_MASK(sym_k_XmMessageDialog_object) |
  0, _BIT_MASK(sym_k_XmPromptDialog_object) |
  0, _BIT_MASK(sym_k_XmQuestionDialog_object) |
  0, _BIT_MASK(sym_k_XmSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmTemplateDialog_object) |
  0, _BIT_MASK(sym_k_XmWarningDialog_object) |
  _BIT_MASK(sym_k_XmWorkingDialog_object) |
  0, 0};

/* sym_k_XmNtranslations_arg */
static unsigned char arg_class_vec672[] =
  {
  _BIT_MASK(sym_k_DtEditor_object) |
  _BIT_MASK(sym_k_DtHelpDialog_object) |
  _BIT_MASK(sym_k_DtHelpQuickDialog_object) |
  _BIT_MASK(sym_k_DtMenuButton_object) |
  _BIT_MASK(sym_k_DtPrintSetupBox_object) |
  _BIT_MASK(sym_k_DtPrintSetupDialog_object) |
  _BIT_MASK(sym_k_DtTerm_object) |
  0, _BIT_MASK(sym_k_DtTermPrimitive_object) |
  _BIT_MASK(sym_k_XmArrowButton_object) |
  _BIT_MASK(sym_k_XmBulletinBoard_object) |
  _BIT_MASK(sym_k_XmBulletinBoardDialog_object) |
  _BIT_MASK(sym_k_XmButtonBox_object) |
  _BIT_MASK(sym_k_XmCascadeButton_object) |
  0, _BIT_MASK(sym_k_XmCheckBox_object) |
  _BIT_MASK(sym_k_XmColorSelector_object) |
  _BIT_MASK(sym_k_XmColumn_object) |
  _BIT_MASK(sym_k_XmComboBox_object) |
  _BIT_MASK(sym_k_XmCommand_object) |
  _BIT_MASK(sym_k_XmCommandDialog_object) |
  _BIT_MASK(sym_k_XmContainer_object) |
  _BIT_MASK(sym_k_XmDataField_object) |
  0, _BIT_MASK(sym_k_XmDialogShell_object) |
  _BIT_MASK(sym_k_XmDrawingArea_object) |
  _BIT_MASK(sym_k_XmDrawnButton_object) |
  _BIT_MASK(sym_k_XmDropDown_object) |
  _BIT_MASK(sym_k_XmErrorDialog_object) |
  _BIT_MASK(sym_k_XmFileSelectionBox_object) |
  _BIT_MASK(sym_k_XmFileSelectionDialog_object) |
  _BIT_MASK(sym_k_XmFontSelector_object) |
  0, _BIT_MASK(sym_k_XmForm_object) |
  _BIT_MASK(sym_k_XmFormDialog_object) |
  _BIT_MASK(sym_k_XmFrame_object) |
  _BIT_MASK(sym_k_XmIconBox_object) |
  _BIT_MASK(sym_k_XmIconButton_object) |
  _BIT_MASK(sym_k_XmInformationDialog_object) |
  _BIT_MASK(sym_k_XmLabel_object) |
  0, _BIT_MASK(sym_k_XmList_object) |
  _BIT_MASK(sym_k_XmMainWindow_object) |
  _BIT_MASK(sym_k_XmMenuBar_object) |
  _BIT_MASK(sym_k_XmMenuShell_object) |
  _BIT_MASK(sym_k_XmMessageBox_object) |
  _BIT_MASK(sym_k_XmMessageDialog_object) |
  _BIT_MASK(sym_k_XmMultiList_object) |
  0, _BIT_MASK(sym_k_XmNotebook_object) |
  _BIT_MASK(sym_k_XmOptionMenu_object) |
  _BIT_MASK(sym_k_XmOutline_object) |
  _BIT_MASK(sym_k_XmPaned_object) |
  _BIT_MASK(sym_k_XmPanedWindow_object) |
  _BIT_MASK(sym_k_XmPopupMenu_object) |
  _BIT_MASK(sym_k_XmPromptDialog_object) |
  _BIT_MASK(sym_k_XmPulldownMenu_object) |
  0, _BIT_MASK(sym_k_XmPushButton_object) |
  _BIT_MASK(sym_k_XmQuestionDialog_object) |
  _BIT_MASK(sym_k_XmRadioBox_object) |
  _BIT_MASK(sym_k_XmRowColumn_object) |
  _BIT_MASK(sym_k_XmScale_object) |
  0, _BIT_MASK(sym_k_XmScrollBar_object) |
  _BIT_MASK(sym_k_XmScrolledList_object) |
  _BIT_MASK(sym_k_XmScrolledText_object) |
  _BIT_MASK(sym_k_XmScrolledWindow_object) |
  _BIT_MASK(sym_k_XmSelectionBox_object) |
  _BIT_MASK(sym_k_XmSelectionDialog_object) |
  _BIT_MASK(sym_k_XmSeparator_object) |
  0, _BIT_MASK(sym_k_XmSimpleSpinBox_object) |
  _BIT_MASK(sym_k_XmSpinBox_object) |
  _BIT_MASK(sym_k_XmTabBox_object) |
  _BIT_MASK(sym_k_XmTabStack_object) |
  _BIT_MASK(sym_k_XmTearOffButton_object) |
  _BIT_MASK(sym_k_XmTemplateDialog_object) |
  0, _BIT_MASK(sym_k_XmText_object) |
  _BIT_MASK(sym_k_XmTextField_object) |
  _BIT_MASK(sym_k_XmToggleButton_object) |
  _BIT_MASK(sym_k_XmTree_object) |
  _BIT_MASK(sym_k_XmWarningDialog_object) |
  _BIT_MASK(sym_k_XmWorkArea_object) |
  _BIT_MASK(sym_k_XmWorkingDialog_object) |
  0, 0};

/* sym_k_XmNtraversalOn_arg */
static unsigned char arg_class_vec673[] =
  {
  _BIT_MASK(sym_k_DtEditor_object) |
  _BIT_MASK(sym_k_DtHelpDialog_object) |
  _BIT_MASK(sym_k_DtHelpQuickDialog_object) |
  _BIT_MASK(sym_k_DtMenuButton_object) |
  _BIT_MASK(sym_k_DtPrintSetupBox_object) |
  _BIT_MASK(sym_k_DtPrintSetupDialog_object) |
  _BIT_MASK(sym_k_DtTerm_object) |
  0, _BIT_MASK(sym_k_DtTermPrimitive_object) |
  _BIT_MASK(sym_k_XmArrowButton_object) |
  _BIT_MASK(sym_k_XmArrowButtonGadget_object) |
  _BIT_MASK(sym_k_XmBulletinBoard_object) |
  _BIT_MASK(sym_k_XmBulletinBoardDialog_object) |
  _BIT_MASK(sym_k_XmButtonBox_object) |
  _BIT_MASK(sym_k_XmCascadeButton_object) |
  _BIT_MASK(sym_k_XmCascadeButtonGadget_object) |
  0, _BIT_MASK(sym_k_XmCheckBox_object) |
  _BIT_MASK(sym_k_XmColorSelector_object) |
  _BIT_MASK(sym_k_XmColumn_object) |
  _BIT_MASK(sym_k_XmComboBox_object) |
  _BIT_MASK(sym_k_XmCommand_object) |
  _BIT_MASK(sym_k_XmCommandDialog_object) |
  _BIT_MASK(sym_k_XmContainer_object) |
  _BIT_MASK(sym_k_XmDataField_object) |
  0, _BIT_MASK(sym_k_XmDrawingArea_object) |
  _BIT_MASK(sym_k_XmDrawnButton_object) |
  _BIT_MASK(sym_k_XmDropDown_object) |
  _BIT_MASK(sym_k_XmErrorDialog_object) |
  _BIT_MASK(sym_k_XmFileSelectionBox_object) |
  _BIT_MASK(sym_k_XmFileSelectionDialog_object) |
  _BIT_MASK(sym_k_XmFontSelector_object) |
  0, _BIT_MASK(sym_k_XmForm_object) |
  _BIT_MASK(sym_k_XmFormDialog_object) |
  _BIT_MASK(sym_k_XmFrame_object) |
  _BIT_MASK(sym_k_XmIconBox_object) |
  _BIT_MASK(sym_k_XmIconButton_object) |
  _BIT_MASK(sym_k_XmIconGadget_object) |
  _BIT_MASK(sym_k_XmInformationDialog_object) |
  _BIT_MASK(sym_k_XmLabel_object) |
  0, _BIT_MASK(sym_k_XmLabelGadget_object) |
  _BIT_MASK(sym_k_XmList_object) |
  _BIT_MASK(sym_k_XmMainWindow_object) |
  _BIT_MASK(sym_k_XmMenuBar_object) |
  _BIT_MASK(sym_k_XmMessageBox_object) |
  _BIT_MASK(sym_k_XmMessageDialog_object) |
  _BIT_MASK(sym_k_XmMultiList_object) |
  0, _BIT_MASK(sym_k_XmNotebook_object) |
  _BIT_MASK(sym_k_XmOptionMenu_object) |
  _BIT_MASK(sym_k_XmOutline_object) |
  _BIT_MASK(sym_k_XmPaned_object) |
  _BIT_MASK(sym_k_XmPanedWindow_object) |
  _BIT_MASK(sym_k_XmPopupMenu_object) |
  _BIT_MASK(sym_k_XmPromptDialog_object) |
  _BIT_MASK(sym_k_XmPulldownMenu_object) |
  0, _BIT_MASK(sym_k_XmPushButton_object) |
  _BIT_MASK(sym_k_XmPushButtonGadget_object) |
  _BIT_MASK(sym_k_XmQuestionDialog_object) |
  _BIT_MASK(sym_k_XmRadioBox_object) |
  _BIT_MASK(sym_k_XmRowColumn_object) |
  _BIT_MASK(sym_k_XmScale_object) |
  0, _BIT_MASK(sym_k_XmScrollBar_object) |
  _BIT_MASK(sym_k_XmScrolledList_object) |
  _BIT_MASK(sym_k_XmScrolledText_object) |
  _BIT_MASK(sym_k_XmScrolledWindow_object) |
  _BIT_MASK(sym_k_XmSelectionBox_object) |
  _BIT_MASK(sym_k_XmSelectionDialog_object) |
  _BIT_MASK(sym_k_XmSeparator_object) |
  _BIT_MASK(sym_k_XmSeparatorGadget_object) |
  0, _BIT_MASK(sym_k_XmSimpleSpinBox_object) |
  _BIT_MASK(sym_k_XmSpinBox_object) |
  _BIT_MASK(sym_k_XmTabBox_object) |
  _BIT_MASK(sym_k_XmTabStack_object) |
  _BIT_MASK(sym_k_XmTearOffButton_object) |
  _BIT_MASK(sym_k_XmTemplateDialog_object) |
  0, _BIT_MASK(sym_k_XmText_object) |
  _BIT_MASK(sym_k_XmTextField_object) |
  _BIT_MASK(sym_k_XmToggleButton_object) |
  _BIT_MASK(sym_k_XmToggleButtonGadget_object) |
  _BIT_MASK(sym_k_XmTree_object) |
  _BIT_MASK(sym_k_XmWarningDialog_object) |
  _BIT_MASK(sym_k_XmWorkArea_object) |
  _BIT_MASK(sym_k_XmWorkingDialog_object) |
  0, 0};

/* sym_k_XmNtroughColor_arg */
static unsigned char arg_class_vec674[] =
  {
  0, 0, 0, 0, 0, 0, 0, 0, _BIT_MASK(sym_k_XmScrollBar_object) |
  0, 0, 0, 0};

/* sym_k_XmNunderlineType_arg */
static unsigned char arg_class_vec675[] =
  {
  0, 0, 0, 0, 0, 0, 0, _BIT_MASK(sym_k_XmRendition_object) |
  0, 0, 0, 0, 0};

/* sym_k_XmNuniformTabSize_arg */
static unsigned char arg_class_vec676[] =
  {
  0, 0, 0, 0, 0, 0, 0, 0, 0, _BIT_MASK(sym_k_XmTabBox_object) |
  _BIT_MASK(sym_k_XmTabStack_object) |
  0, 0, 0};

/* sym_k_XmNunitType_arg */
static unsigned char arg_class_vec677[] =
  {
  _BIT_MASK(sym_k_DtEditor_object) |
  _BIT_MASK(sym_k_DtHelpDialog_object) |
  _BIT_MASK(sym_k_DtHelpQuickDialog_object) |
  _BIT_MASK(sym_k_DtMenuButton_object) |
  _BIT_MASK(sym_k_DtPrintSetupBox_object) |
  _BIT_MASK(sym_k_DtPrintSetupDialog_object) |
  _BIT_MASK(sym_k_DtTerm_object) |
  0, _BIT_MASK(sym_k_DtTermPrimitive_object) |
  _BIT_MASK(sym_k_XmArrowButton_object) |
  _BIT_MASK(sym_k_XmArrowButtonGadget_object) |
  _BIT_MASK(sym_k_XmBulletinBoard_object) |
  _BIT_MASK(sym_k_XmBulletinBoardDialog_object) |
  _BIT_MASK(sym_k_XmButtonBox_object) |
  _BIT_MASK(sym_k_XmCascadeButton_object) |
  _BIT_MASK(sym_k_XmCascadeButtonGadget_object) |
  0, _BIT_MASK(sym_k_XmCheckBox_object) |
  _BIT_MASK(sym_k_XmColorSelector_object) |
  _BIT_MASK(sym_k_XmColumn_object) |
  _BIT_MASK(sym_k_XmComboBox_object) |
  _BIT_MASK(sym_k_XmCommand_object) |
  _BIT_MASK(sym_k_XmCommandDialog_object) |
  _BIT_MASK(sym_k_XmContainer_object) |
  _BIT_MASK(sym_k_XmDataField_object) |
  0, _BIT_MASK(sym_k_XmDrawingArea_object) |
  _BIT_MASK(sym_k_XmDrawnButton_object) |
  _BIT_MASK(sym_k_XmDropDown_object) |
  _BIT_MASK(sym_k_XmErrorDialog_object) |
  _BIT_MASK(sym_k_XmFileSelectionBox_object) |
  _BIT_MASK(sym_k_XmFileSelectionDialog_object) |
  _BIT_MASK(sym_k_XmFontSelector_object) |
  0, _BIT_MASK(sym_k_XmForm_object) |
  _BIT_MASK(sym_k_XmFormDialog_object) |
  _BIT_MASK(sym_k_XmFrame_object) |
  _BIT_MASK(sym_k_XmIconBox_object) |
  _BIT_MASK(sym_k_XmIconButton_object) |
  _BIT_MASK(sym_k_XmIconGadget_object) |
  _BIT_MASK(sym_k_XmInformationDialog_object) |
  _BIT_MASK(sym_k_XmLabel_object) |
  0, _BIT_MASK(sym_k_XmLabelGadget_object) |
  _BIT_MASK(sym_k_XmList_object) |
  _BIT_MASK(sym_k_XmMainWindow_object) |
  _BIT_MASK(sym_k_XmMenuBar_object) |
  _BIT_MASK(sym_k_XmMessageBox_object) |
  _BIT_MASK(sym_k_XmMessageDialog_object) |
  _BIT_MASK(sym_k_XmMultiList_object) |
  0, _BIT_MASK(sym_k_XmNotebook_object) |
  _BIT_MASK(sym_k_XmOptionMenu_object) |
  _BIT_MASK(sym_k_XmOutline_object) |
  _BIT_MASK(sym_k_XmPaned_object) |
  _BIT_MASK(sym_k_XmPanedWindow_object) |
  _BIT_MASK(sym_k_XmPopupMenu_object) |
  _BIT_MASK(sym_k_XmPromptDialog_object) |
  _BIT_MASK(sym_k_XmPulldownMenu_object) |
  0, _BIT_MASK(sym_k_XmPushButton_object) |
  _BIT_MASK(sym_k_XmPushButtonGadget_object) |
  _BIT_MASK(sym_k_XmQuestionDialog_object) |
  _BIT_MASK(sym_k_XmRadioBox_object) |
  _BIT_MASK(sym_k_XmRowColumn_object) |
  _BIT_MASK(sym_k_XmScale_object) |
  0, _BIT_MASK(sym_k_XmScrollBar_object) |
  _BIT_MASK(sym_k_XmScrolledList_object) |
  _BIT_MASK(sym_k_XmScrolledText_object) |
  _BIT_MASK(sym_k_XmScrolledWindow_object) |
  _BIT_MASK(sym_k_XmSelectionBox_object) |
  _BIT_MASK(sym_k_XmSelectionDialog_object) |
  _BIT_MASK(sym_k_XmSeparator_object) |
  _BIT_MASK(sym_k_XmSeparatorGadget_object) |
  0, _BIT_MASK(sym_k_XmSimpleSpinBox_object) |
  _BIT_MASK(sym_k_XmSpinBox_object) |
  _BIT_MASK(sym_k_XmTab_object) |
  _BIT_MASK(sym_k_XmTabBox_object) |
  _BIT_MASK(sym_k_XmTabStack_object) |
  _BIT_MASK(sym_k_XmTearOffButton_object) |
  _BIT_MASK(sym_k_XmTemplateDialog_object) |
  0, _BIT_MASK(sym_k_XmText_object) |
  _BIT_MASK(sym_k_XmTextField_object) |
  _BIT_MASK(sym_k_XmToggleButton_object) |
  _BIT_MASK(sym_k_XmToggleButtonGadget_object) |
  _BIT_MASK(sym_k_XmTree_object) |
  _BIT_MASK(sym_k_XmWarningDialog_object) |
  _BIT_MASK(sym_k_XmWorkArea_object) |
  _BIT_MASK(sym_k_XmWorkingDialog_object) |
  0, 0};

/* sym_k_XmNunpostBehavior_arg */
static unsigned char arg_class_vec678[] =
  {
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_XmNunselectColor_arg */
static unsigned char arg_class_vec679[] =
  {
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, _BIT_MASK(sym_k_XmToggleButton_object) |
  _BIT_MASK(sym_k_XmToggleButtonGadget_object) |
  0, 0};

/* sym_k_XmNuseAsyncGeometry_arg */
static unsigned char arg_class_vec680[] =
  {
  _BIT_MASK(sym_k_DtHelpDialog_object) |
  _BIT_MASK(sym_k_DtHelpQuickDialog_object) |
  _BIT_MASK(sym_k_DtPrintSetupDialog_object) |
  0, _BIT_MASK(sym_k_XmBulletinBoardDialog_object) |
  0, _BIT_MASK(sym_k_XmCommandDialog_object) |
  0, _BIT_MASK(sym_k_XmDialogShell_object) |
  _BIT_MASK(sym_k_XmErrorDialog_object) |
  _BIT_MASK(sym_k_XmFileSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmFormDialog_object) |
  _BIT_MASK(sym_k_XmInformationDialog_object) |
  0, _BIT_MASK(sym_k_XmMessageDialog_object) |
  0, _BIT_MASK(sym_k_XmPromptDialog_object) |
  0, _BIT_MASK(sym_k_XmQuestionDialog_object) |
  0, _BIT_MASK(sym_k_XmSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmTemplateDialog_object) |
  0, _BIT_MASK(sym_k_XmWarningDialog_object) |
  _BIT_MASK(sym_k_XmWorkingDialog_object) |
  0, 0};

/* sym_k_XmNuseImageCache_arg */
static unsigned char arg_class_vec681[] =
  {
  0, 0, 0, 0, 0, 0, 0, 0, 0, _BIT_MASK(sym_k_XmTabBox_object) |
  _BIT_MASK(sym_k_XmTabStack_object) |
  0, 0, 0};

/* sym_k_XmNuseScaling_arg */
static unsigned char arg_class_vec682[] =
  {
  0, 0, 0, _BIT_MASK(sym_k_XmFontSelector_object) |
  0, 0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_XmNuseTextField_arg */
static unsigned char arg_class_vec683[] =
  {
  0, 0, 0, _BIT_MASK(sym_k_XmDropDown_object) |
  0, 0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_XmNuserData_arg */
static unsigned char arg_class_vec684[] =
  {
  _BIT_MASK(sym_k_DtEditor_object) |
  _BIT_MASK(sym_k_DtHelpDialog_object) |
  _BIT_MASK(sym_k_DtHelpQuickDialog_object) |
  _BIT_MASK(sym_k_DtMenuButton_object) |
  _BIT_MASK(sym_k_DtPrintSetupBox_object) |
  _BIT_MASK(sym_k_DtPrintSetupDialog_object) |
  _BIT_MASK(sym_k_DtTerm_object) |
  0, _BIT_MASK(sym_k_DtTermPrimitive_object) |
  _BIT_MASK(sym_k_XmArrowButton_object) |
  _BIT_MASK(sym_k_XmArrowButtonGadget_object) |
  _BIT_MASK(sym_k_XmBulletinBoard_object) |
  _BIT_MASK(sym_k_XmBulletinBoardDialog_object) |
  _BIT_MASK(sym_k_XmButtonBox_object) |
  _BIT_MASK(sym_k_XmCascadeButton_object) |
  _BIT_MASK(sym_k_XmCascadeButtonGadget_object) |
  0, _BIT_MASK(sym_k_XmCheckBox_object) |
  _BIT_MASK(sym_k_XmColorSelector_object) |
  _BIT_MASK(sym_k_XmColumn_object) |
  _BIT_MASK(sym_k_XmComboBox_object) |
  _BIT_MASK(sym_k_XmCommand_object) |
  _BIT_MASK(sym_k_XmCommandDialog_object) |
  _BIT_MASK(sym_k_XmContainer_object) |
  _BIT_MASK(sym_k_XmDataField_object) |
  0, _BIT_MASK(sym_k_XmDrawingArea_object) |
  _BIT_MASK(sym_k_XmDrawnButton_object) |
  _BIT_MASK(sym_k_XmDropDown_object) |
  _BIT_MASK(sym_k_XmErrorDialog_object) |
  _BIT_MASK(sym_k_XmFileSelectionBox_object) |
  _BIT_MASK(sym_k_XmFileSelectionDialog_object) |
  _BIT_MASK(sym_k_XmFontSelector_object) |
  0, _BIT_MASK(sym_k_XmForm_object) |
  _BIT_MASK(sym_k_XmFormDialog_object) |
  _BIT_MASK(sym_k_XmFrame_object) |
  _BIT_MASK(sym_k_XmIconBox_object) |
  _BIT_MASK(sym_k_XmIconButton_object) |
  _BIT_MASK(sym_k_XmIconGadget_object) |
  _BIT_MASK(sym_k_XmInformationDialog_object) |
  _BIT_MASK(sym_k_XmLabel_object) |
  0, _BIT_MASK(sym_k_XmLabelGadget_object) |
  _BIT_MASK(sym_k_XmList_object) |
  _BIT_MASK(sym_k_XmMainWindow_object) |
  _BIT_MASK(sym_k_XmMenuBar_object) |
  _BIT_MASK(sym_k_XmMessageBox_object) |
  _BIT_MASK(sym_k_XmMessageDialog_object) |
  _BIT_MASK(sym_k_XmMultiList_object) |
  0, _BIT_MASK(sym_k_XmNotebook_object) |
  _BIT_MASK(sym_k_XmOptionMenu_object) |
  _BIT_MASK(sym_k_XmOutline_object) |
  _BIT_MASK(sym_k_XmPaned_object) |
  _BIT_MASK(sym_k_XmPanedWindow_object) |
  _BIT_MASK(sym_k_XmPopupMenu_object) |
  _BIT_MASK(sym_k_XmPromptDialog_object) |
  _BIT_MASK(sym_k_XmPulldownMenu_object) |
  0, _BIT_MASK(sym_k_XmPushButton_object) |
  _BIT_MASK(sym_k_XmPushButtonGadget_object) |
  _BIT_MASK(sym_k_XmQuestionDialog_object) |
  _BIT_MASK(sym_k_XmRadioBox_object) |
  _BIT_MASK(sym_k_XmRowColumn_object) |
  _BIT_MASK(sym_k_XmScale_object) |
  0, _BIT_MASK(sym_k_XmScrollBar_object) |
  _BIT_MASK(sym_k_XmScrolledList_object) |
  _BIT_MASK(sym_k_XmScrolledText_object) |
  _BIT_MASK(sym_k_XmScrolledWindow_object) |
  _BIT_MASK(sym_k_XmSelectionBox_object) |
  _BIT_MASK(sym_k_XmSelectionDialog_object) |
  _BIT_MASK(sym_k_XmSeparator_object) |
  _BIT_MASK(sym_k_XmSeparatorGadget_object) |
  0, _BIT_MASK(sym_k_XmSimpleSpinBox_object) |
  _BIT_MASK(sym_k_XmSpinBox_object) |
  _BIT_MASK(sym_k_XmTabBox_object) |
  _BIT_MASK(sym_k_XmTabStack_object) |
  _BIT_MASK(sym_k_XmTearOffButton_object) |
  _BIT_MASK(sym_k_XmTemplateDialog_object) |
  0, _BIT_MASK(sym_k_XmText_object) |
  _BIT_MASK(sym_k_XmTextField_object) |
  _BIT_MASK(sym_k_XmToggleButton_object) |
  _BIT_MASK(sym_k_XmToggleButtonGadget_object) |
  _BIT_MASK(sym_k_XmTree_object) |
  _BIT_MASK(sym_k_XmWarningDialog_object) |
  _BIT_MASK(sym_k_XmWorkArea_object) |
  _BIT_MASK(sym_k_XmWorkingDialog_object) |
  0, 0};

/* sym_k_XmNvalue_arg */
static unsigned char arg_class_vec685[] =
  {
  0, 0, _BIT_MASK(sym_k_XmDataField_object) |
  0, _BIT_MASK(sym_k_XmDropDown_object) |
  0, 0, 0, 0, _BIT_MASK(sym_k_XmScale_object) |
  0, _BIT_MASK(sym_k_XmScrollBar_object) |
  _BIT_MASK(sym_k_XmScrolledText_object) |
  0, 0, _BIT_MASK(sym_k_XmText_object) |
  _BIT_MASK(sym_k_XmTextField_object) |
  0, 0};

/* sym_k_XmNvalueWcs_arg */
static unsigned char arg_class_vec686[] =
  {
  0, 0, _BIT_MASK(sym_k_XmDataField_object) |
  0, 0, 0, 0, 0, 0, _BIT_MASK(sym_k_XmScrolledText_object) |
  0, 0, _BIT_MASK(sym_k_XmText_object) |
  _BIT_MASK(sym_k_XmTextField_object) |
  0, 0};

/* sym_k_XmNvalues_arg */
static unsigned char arg_class_vec687[] =
  {
  0, 0, 0, 0, 0, 0, 0, 0, 0, _BIT_MASK(sym_k_XmSimpleSpinBox_object) |
  _BIT_MASK(sym_k_XmSpinBox_object) |
  0, 0, 0};

/* sym_k_XmNverify_arg */
static unsigned char arg_class_vec688[] =
  {
  0, 0, 0, _BIT_MASK(sym_k_XmDropDown_object) |
  0, 0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_XmNverifyBell_arg */
static unsigned char arg_class_vec689[] =
  {
  0, 0, _BIT_MASK(sym_k_XmDataField_object) |
  0, 0, 0, 0, 0, 0, _BIT_MASK(sym_k_XmScrolledText_object) |
  0, 0, _BIT_MASK(sym_k_XmText_object) |
  _BIT_MASK(sym_k_XmTextField_object) |
  0, 0};

/* sym_k_XmNverticalDelta_arg */
static unsigned char arg_class_vec690[] =
  {
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, _BIT_MASK(sym_k_XmTree_object) |
  0, 0};

/* sym_k_XmNverticalMargin_arg */
static unsigned char arg_class_vec691[] =
  {
  0, 0, 0, _BIT_MASK(sym_k_XmDropDown_object) |
  0, _BIT_MASK(sym_k_XmIconBox_object) |
  _BIT_MASK(sym_k_XmIconButton_object) |
  0, 0, _BIT_MASK(sym_k_XmOutline_object) |
  0, 0, 0, 0, _BIT_MASK(sym_k_XmTree_object) |
  0, 0};

/* sym_k_XmNverticalNodeSpace_arg */
static unsigned char arg_class_vec692[] =
  {
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, _BIT_MASK(sym_k_XmTree_object) |
  0, 0};

/* sym_k_XmNverticalScrollBar_arg */
static unsigned char arg_class_vec693[] =
  {
  0, 0, 0, 0, 0, _BIT_MASK(sym_k_XmMainWindow_object) |
  _BIT_MASK(sym_k_XmMultiList_object) |
  0, 0, 0, _BIT_MASK(sym_k_XmScrolledList_object) |
  _BIT_MASK(sym_k_XmScrolledText_object) |
  _BIT_MASK(sym_k_XmScrolledWindow_object) |
  0, 0, 0, 0};

/* sym_k_XmNverticalSpacing_arg */
static unsigned char arg_class_vec694[] =
  {
  _BIT_MASK(sym_k_DtEditor_object) |
  0, 0, 0, 0, _BIT_MASK(sym_k_XmForm_object) |
  _BIT_MASK(sym_k_XmFormDialog_object) |
  0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_XmNviewType_arg */
static unsigned char arg_class_vec695[] =
  {
  0, 0, 0, 0, _BIT_MASK(sym_k_XmIconGadget_object) |
  0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_XmNvisibleItemCount_arg */
static unsigned char arg_class_vec696[] =
  {
  0, 0, _BIT_MASK(sym_k_XmComboBox_object) |
  0, _BIT_MASK(sym_k_XmDropDown_object) |
  0, 0, _BIT_MASK(sym_k_XmList_object) |
  _BIT_MASK(sym_k_XmMultiList_object) |
  0, 0, 0, _BIT_MASK(sym_k_XmScrolledList_object) |
  0, 0, 0, 0};

/* sym_k_XmNvisibleWhenOff_arg */
static unsigned char arg_class_vec697[] =
  {
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, _BIT_MASK(sym_k_XmToggleButton_object) |
  _BIT_MASK(sym_k_XmToggleButtonGadget_object) |
  0, 0};

/* sym_k_XmNvisual_arg */
static unsigned char arg_class_vec698[] =
  {
  _BIT_MASK(sym_k_DtHelpDialog_object) |
  _BIT_MASK(sym_k_DtHelpQuickDialog_object) |
  _BIT_MASK(sym_k_DtPrintSetupDialog_object) |
  0, _BIT_MASK(sym_k_XmBulletinBoardDialog_object) |
  0, _BIT_MASK(sym_k_XmCommandDialog_object) |
  0, _BIT_MASK(sym_k_XmDialogShell_object) |
  _BIT_MASK(sym_k_XmErrorDialog_object) |
  _BIT_MASK(sym_k_XmFileSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmFormDialog_object) |
  _BIT_MASK(sym_k_XmInformationDialog_object) |
  0, _BIT_MASK(sym_k_XmMenuShell_object) |
  _BIT_MASK(sym_k_XmMessageDialog_object) |
  0, _BIT_MASK(sym_k_XmPopupMenu_object) |
  _BIT_MASK(sym_k_XmPromptDialog_object) |
  _BIT_MASK(sym_k_XmPulldownMenu_object) |
  0, _BIT_MASK(sym_k_XmQuestionDialog_object) |
  0, _BIT_MASK(sym_k_XmSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmTemplateDialog_object) |
  0, _BIT_MASK(sym_k_XmWarningDialog_object) |
  _BIT_MASK(sym_k_XmWorkingDialog_object) |
  0, 0};

/* sym_k_XmNvisualEmphasis_arg */
static unsigned char arg_class_vec699[] =
  {
  0, 0, 0, 0, _BIT_MASK(sym_k_XmIconGadget_object) |
  0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_XmNvisualPolicy_arg */
static unsigned char arg_class_vec700[] =
  {
  0, 0, 0, 0, 0, _BIT_MASK(sym_k_XmMainWindow_object) |
  0, 0, 0, _BIT_MASK(sym_k_XmScrolledList_object) |
  _BIT_MASK(sym_k_XmScrolledText_object) |
  _BIT_MASK(sym_k_XmScrolledWindow_object) |
  0, 0, 0, 0};

/* sym_k_XmNwaitForWm_arg */
static unsigned char arg_class_vec701[] =
  {
  _BIT_MASK(sym_k_DtHelpDialog_object) |
  _BIT_MASK(sym_k_DtHelpQuickDialog_object) |
  _BIT_MASK(sym_k_DtPrintSetupDialog_object) |
  0, _BIT_MASK(sym_k_XmBulletinBoardDialog_object) |
  0, _BIT_MASK(sym_k_XmCommandDialog_object) |
  0, _BIT_MASK(sym_k_XmDialogShell_object) |
  _BIT_MASK(sym_k_XmErrorDialog_object) |
  _BIT_MASK(sym_k_XmFileSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmFormDialog_object) |
  _BIT_MASK(sym_k_XmInformationDialog_object) |
  0, _BIT_MASK(sym_k_XmMessageDialog_object) |
  0, _BIT_MASK(sym_k_XmPromptDialog_object) |
  0, _BIT_MASK(sym_k_XmQuestionDialog_object) |
  0, _BIT_MASK(sym_k_XmSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmTemplateDialog_object) |
  0, _BIT_MASK(sym_k_XmWarningDialog_object) |
  _BIT_MASK(sym_k_XmWorkingDialog_object) |
  0, 0};

/* sym_k_XmNwhichButton_arg */
static unsigned char arg_class_vec702[] =
  {
  0, 0, _BIT_MASK(sym_k_XmCheckBox_object) |
  0, 0, 0, _BIT_MASK(sym_k_XmMenuBar_object) |
  0, _BIT_MASK(sym_k_XmOptionMenu_object) |
  _BIT_MASK(sym_k_XmPopupMenu_object) |
  _BIT_MASK(sym_k_XmPulldownMenu_object) |
  0, _BIT_MASK(sym_k_XmRadioBox_object) |
  _BIT_MASK(sym_k_XmRowColumn_object) |
  0, 0, 0, _BIT_MASK(sym_k_XmWorkArea_object) |
  0, 0};

/* sym_k_XmNwidth_arg */
static unsigned char arg_class_vec703[] =
  {
  _BIT_MASK(sym_k_DtEditor_object) |
  _BIT_MASK(sym_k_DtHelpDialog_object) |
  _BIT_MASK(sym_k_DtHelpQuickDialog_object) |
  _BIT_MASK(sym_k_DtMenuButton_object) |
  _BIT_MASK(sym_k_DtPrintSetupBox_object) |
  _BIT_MASK(sym_k_DtPrintSetupDialog_object) |
  _BIT_MASK(sym_k_DtTerm_object) |
  0, _BIT_MASK(sym_k_DtTermPrimitive_object) |
  _BIT_MASK(sym_k_XmArrowButton_object) |
  _BIT_MASK(sym_k_XmArrowButtonGadget_object) |
  _BIT_MASK(sym_k_XmBulletinBoard_object) |
  _BIT_MASK(sym_k_XmBulletinBoardDialog_object) |
  _BIT_MASK(sym_k_XmButtonBox_object) |
  _BIT_MASK(sym_k_XmCascadeButton_object) |
  _BIT_MASK(sym_k_XmCascadeButtonGadget_object) |
  0, _BIT_MASK(sym_k_XmCheckBox_object) |
  _BIT_MASK(sym_k_XmColorSelector_object) |
  _BIT_MASK(sym_k_XmColumn_object) |
  _BIT_MASK(sym_k_XmComboBox_object) |
  _BIT_MASK(sym_k_XmCommand_object) |
  _BIT_MASK(sym_k_XmCommandDialog_object) |
  _BIT_MASK(sym_k_XmContainer_object) |
  _BIT_MASK(sym_k_XmDataField_object) |
  0, _BIT_MASK(sym_k_XmDialogShell_object) |
  _BIT_MASK(sym_k_XmDrawingArea_object) |
  _BIT_MASK(sym_k_XmDrawnButton_object) |
  _BIT_MASK(sym_k_XmDropDown_object) |
  _BIT_MASK(sym_k_XmErrorDialog_object) |
  _BIT_MASK(sym_k_XmFileSelectionBox_object) |
  _BIT_MASK(sym_k_XmFileSelectionDialog_object) |
  _BIT_MASK(sym_k_XmFontSelector_object) |
  0, _BIT_MASK(sym_k_XmForm_object) |
  _BIT_MASK(sym_k_XmFormDialog_object) |
  _BIT_MASK(sym_k_XmFrame_object) |
  _BIT_MASK(sym_k_XmIconBox_object) |
  _BIT_MASK(sym_k_XmIconButton_object) |
  _BIT_MASK(sym_k_XmIconGadget_object) |
  _BIT_MASK(sym_k_XmInformationDialog_object) |
  _BIT_MASK(sym_k_XmLabel_object) |
  0, _BIT_MASK(sym_k_XmLabelGadget_object) |
  _BIT_MASK(sym_k_XmList_object) |
  _BIT_MASK(sym_k_XmMainWindow_object) |
  _BIT_MASK(sym_k_XmMenuBar_object) |
  _BIT_MASK(sym_k_XmMenuShell_object) |
  _BIT_MASK(sym_k_XmMessageBox_object) |
  _BIT_MASK(sym_k_XmMessageDialog_object) |
  _BIT_MASK(sym_k_XmMultiList_object) |
  0, _BIT_MASK(sym_k_XmNotebook_object) |
  _BIT_MASK(sym_k_XmOptionMenu_object) |
  _BIT_MASK(sym_k_XmOutline_object) |
  _BIT_MASK(sym_k_XmPaned_object) |
  _BIT_MASK(sym_k_XmPanedWindow_object) |
  _BIT_MASK(sym_k_XmPopupMenu_object) |
  _BIT_MASK(sym_k_XmPromptDialog_object) |
  _BIT_MASK(sym_k_XmPulldownMenu_object) |
  0, _BIT_MASK(sym_k_XmPushButton_object) |
  _BIT_MASK(sym_k_XmPushButtonGadget_object) |
  _BIT_MASK(sym_k_XmQuestionDialog_object) |
  _BIT_MASK(sym_k_XmRadioBox_object) |
  _BIT_MASK(sym_k_XmRowColumn_object) |
  _BIT_MASK(sym_k_XmScale_object) |
  0, _BIT_MASK(sym_k_XmScrollBar_object) |
  _BIT_MASK(sym_k_XmScrolledList_object) |
  _BIT_MASK(sym_k_XmScrolledText_object) |
  _BIT_MASK(sym_k_XmScrolledWindow_object) |
  _BIT_MASK(sym_k_XmSelectionBox_object) |
  _BIT_MASK(sym_k_XmSelectionDialog_object) |
  _BIT_MASK(sym_k_XmSeparator_object) |
  _BIT_MASK(sym_k_XmSeparatorGadget_object) |
  0, _BIT_MASK(sym_k_XmSimpleSpinBox_object) |
  _BIT_MASK(sym_k_XmSpinBox_object) |
  _BIT_MASK(sym_k_XmTabBox_object) |
  _BIT_MASK(sym_k_XmTabStack_object) |
  _BIT_MASK(sym_k_XmTearOffButton_object) |
  _BIT_MASK(sym_k_XmTemplateDialog_object) |
  0, _BIT_MASK(sym_k_XmText_object) |
  _BIT_MASK(sym_k_XmTextField_object) |
  _BIT_MASK(sym_k_XmToggleButton_object) |
  _BIT_MASK(sym_k_XmToggleButtonGadget_object) |
  _BIT_MASK(sym_k_XmTree_object) |
  _BIT_MASK(sym_k_XmWarningDialog_object) |
  _BIT_MASK(sym_k_XmWorkArea_object) |
  _BIT_MASK(sym_k_XmWorkingDialog_object) |
  0, 0};

/* sym_k_XmNwidthInc_arg */
static unsigned char arg_class_vec704[] =
  {
  _BIT_MASK(sym_k_DtHelpDialog_object) |
  _BIT_MASK(sym_k_DtHelpQuickDialog_object) |
  _BIT_MASK(sym_k_DtPrintSetupDialog_object) |
  0, _BIT_MASK(sym_k_XmBulletinBoardDialog_object) |
  0, _BIT_MASK(sym_k_XmCommandDialog_object) |
  0, _BIT_MASK(sym_k_XmDialogShell_object) |
  _BIT_MASK(sym_k_XmErrorDialog_object) |
  _BIT_MASK(sym_k_XmFileSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmFormDialog_object) |
  _BIT_MASK(sym_k_XmInformationDialog_object) |
  0, _BIT_MASK(sym_k_XmMessageDialog_object) |
  0, _BIT_MASK(sym_k_XmPromptDialog_object) |
  0, _BIT_MASK(sym_k_XmQuestionDialog_object) |
  0, _BIT_MASK(sym_k_XmSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmTemplateDialog_object) |
  0, _BIT_MASK(sym_k_XmWarningDialog_object) |
  _BIT_MASK(sym_k_XmWorkingDialog_object) |
  0, 0};

/* sym_k_XmNwinGravity_arg */
static unsigned char arg_class_vec705[] =
  {
  _BIT_MASK(sym_k_DtHelpDialog_object) |
  _BIT_MASK(sym_k_DtHelpQuickDialog_object) |
  _BIT_MASK(sym_k_DtPrintSetupDialog_object) |
  0, _BIT_MASK(sym_k_XmBulletinBoardDialog_object) |
  0, _BIT_MASK(sym_k_XmCommandDialog_object) |
  0, _BIT_MASK(sym_k_XmDialogShell_object) |
  _BIT_MASK(sym_k_XmErrorDialog_object) |
  _BIT_MASK(sym_k_XmFileSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmFormDialog_object) |
  _BIT_MASK(sym_k_XmInformationDialog_object) |
  0, _BIT_MASK(sym_k_XmMessageDialog_object) |
  0, _BIT_MASK(sym_k_XmPromptDialog_object) |
  0, _BIT_MASK(sym_k_XmQuestionDialog_object) |
  0, _BIT_MASK(sym_k_XmSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmTemplateDialog_object) |
  0, _BIT_MASK(sym_k_XmWarningDialog_object) |
  _BIT_MASK(sym_k_XmWorkingDialog_object) |
  0, 0};

/* sym_k_XmNwindowGroup_arg */
static unsigned char arg_class_vec706[] =
  {
  _BIT_MASK(sym_k_DtHelpDialog_object) |
  _BIT_MASK(sym_k_DtHelpQuickDialog_object) |
  _BIT_MASK(sym_k_DtPrintSetupDialog_object) |
  0, _BIT_MASK(sym_k_XmBulletinBoardDialog_object) |
  0, _BIT_MASK(sym_k_XmCommandDialog_object) |
  0, _BIT_MASK(sym_k_XmDialogShell_object) |
  _BIT_MASK(sym_k_XmErrorDialog_object) |
  _BIT_MASK(sym_k_XmFileSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmFormDialog_object) |
  _BIT_MASK(sym_k_XmInformationDialog_object) |
  0, _BIT_MASK(sym_k_XmMessageDialog_object) |
  0, _BIT_MASK(sym_k_XmPromptDialog_object) |
  0, _BIT_MASK(sym_k_XmQuestionDialog_object) |
  0, _BIT_MASK(sym_k_XmSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmTemplateDialog_object) |
  0, _BIT_MASK(sym_k_XmWarningDialog_object) |
  _BIT_MASK(sym_k_XmWorkingDialog_object) |
  0, 0};

/* sym_k_XmNwmTimeout_arg */
static unsigned char arg_class_vec707[] =
  {
  _BIT_MASK(sym_k_DtHelpDialog_object) |
  _BIT_MASK(sym_k_DtHelpQuickDialog_object) |
  _BIT_MASK(sym_k_DtPrintSetupDialog_object) |
  0, _BIT_MASK(sym_k_XmBulletinBoardDialog_object) |
  0, _BIT_MASK(sym_k_XmCommandDialog_object) |
  0, _BIT_MASK(sym_k_XmDialogShell_object) |
  _BIT_MASK(sym_k_XmErrorDialog_object) |
  _BIT_MASK(sym_k_XmFileSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmFormDialog_object) |
  _BIT_MASK(sym_k_XmInformationDialog_object) |
  0, _BIT_MASK(sym_k_XmMessageDialog_object) |
  0, _BIT_MASK(sym_k_XmPromptDialog_object) |
  0, _BIT_MASK(sym_k_XmQuestionDialog_object) |
  0, _BIT_MASK(sym_k_XmSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmTemplateDialog_object) |
  0, _BIT_MASK(sym_k_XmWarningDialog_object) |
  _BIT_MASK(sym_k_XmWorkingDialog_object) |
  0, 0};

/* sym_k_XmNwordWrap_arg */
static unsigned char arg_class_vec708[] =
  {
  0, 0, _BIT_MASK(sym_k_XmDataField_object) |
  0, 0, 0, 0, 0, 0, _BIT_MASK(sym_k_XmScrolledText_object) |
  0, 0, _BIT_MASK(sym_k_XmText_object) |
  _BIT_MASK(sym_k_XmTextField_object) |
  0, 0};

/* sym_k_XmNworkWindow_arg */
static unsigned char arg_class_vec709[] =
  {
  0, 0, 0, 0, 0, _BIT_MASK(sym_k_XmMainWindow_object) |
  0, 0, 0, _BIT_MASK(sym_k_XmScrolledList_object) |
  _BIT_MASK(sym_k_XmScrolledText_object) |
  _BIT_MASK(sym_k_XmScrolledWindow_object) |
  0, 0, 0, 0};

/* sym_k_XmNwrap_arg */
static unsigned char arg_class_vec710[] =
  {
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_XmNx_arg */
static unsigned char arg_class_vec711[] =
  {
  _BIT_MASK(sym_k_DtEditor_object) |
  _BIT_MASK(sym_k_DtHelpDialog_object) |
  _BIT_MASK(sym_k_DtHelpQuickDialog_object) |
  _BIT_MASK(sym_k_DtMenuButton_object) |
  _BIT_MASK(sym_k_DtPrintSetupBox_object) |
  _BIT_MASK(sym_k_DtPrintSetupDialog_object) |
  _BIT_MASK(sym_k_DtTerm_object) |
  0, _BIT_MASK(sym_k_DtTermPrimitive_object) |
  _BIT_MASK(sym_k_XmArrowButton_object) |
  _BIT_MASK(sym_k_XmArrowButtonGadget_object) |
  _BIT_MASK(sym_k_XmBulletinBoard_object) |
  _BIT_MASK(sym_k_XmBulletinBoardDialog_object) |
  _BIT_MASK(sym_k_XmButtonBox_object) |
  _BIT_MASK(sym_k_XmCascadeButton_object) |
  _BIT_MASK(sym_k_XmCascadeButtonGadget_object) |
  0, _BIT_MASK(sym_k_XmCheckBox_object) |
  _BIT_MASK(sym_k_XmColorSelector_object) |
  _BIT_MASK(sym_k_XmColumn_object) |
  _BIT_MASK(sym_k_XmComboBox_object) |
  _BIT_MASK(sym_k_XmCommand_object) |
  _BIT_MASK(sym_k_XmCommandDialog_object) |
  _BIT_MASK(sym_k_XmContainer_object) |
  _BIT_MASK(sym_k_XmDataField_object) |
  0, _BIT_MASK(sym_k_XmDialogShell_object) |
  _BIT_MASK(sym_k_XmDrawingArea_object) |
  _BIT_MASK(sym_k_XmDrawnButton_object) |
  _BIT_MASK(sym_k_XmDropDown_object) |
  _BIT_MASK(sym_k_XmErrorDialog_object) |
  _BIT_MASK(sym_k_XmFileSelectionBox_object) |
  _BIT_MASK(sym_k_XmFileSelectionDialog_object) |
  _BIT_MASK(sym_k_XmFontSelector_object) |
  0, _BIT_MASK(sym_k_XmForm_object) |
  _BIT_MASK(sym_k_XmFormDialog_object) |
  _BIT_MASK(sym_k_XmFrame_object) |
  _BIT_MASK(sym_k_XmIconBox_object) |
  _BIT_MASK(sym_k_XmIconButton_object) |
  _BIT_MASK(sym_k_XmIconGadget_object) |
  _BIT_MASK(sym_k_XmInformationDialog_object) |
  _BIT_MASK(sym_k_XmLabel_object) |
  0, _BIT_MASK(sym_k_XmLabelGadget_object) |
  _BIT_MASK(sym_k_XmList_object) |
  _BIT_MASK(sym_k_XmMainWindow_object) |
  _BIT_MASK(sym_k_XmMenuBar_object) |
  _BIT_MASK(sym_k_XmMenuShell_object) |
  _BIT_MASK(sym_k_XmMessageBox_object) |
  _BIT_MASK(sym_k_XmMessageDialog_object) |
  _BIT_MASK(sym_k_XmMultiList_object) |
  0, _BIT_MASK(sym_k_XmNotebook_object) |
  _BIT_MASK(sym_k_XmOptionMenu_object) |
  _BIT_MASK(sym_k_XmOutline_object) |
  _BIT_MASK(sym_k_XmPaned_object) |
  _BIT_MASK(sym_k_XmPanedWindow_object) |
  _BIT_MASK(sym_k_XmPopupMenu_object) |
  _BIT_MASK(sym_k_XmPromptDialog_object) |
  _BIT_MASK(sym_k_XmPulldownMenu_object) |
  0, _BIT_MASK(sym_k_XmPushButton_object) |
  _BIT_MASK(sym_k_XmPushButtonGadget_object) |
  _BIT_MASK(sym_k_XmQuestionDialog_object) |
  _BIT_MASK(sym_k_XmRadioBox_object) |
  _BIT_MASK(sym_k_XmRowColumn_object) |
  _BIT_MASK(sym_k_XmScale_object) |
  0, _BIT_MASK(sym_k_XmScrollBar_object) |
  _BIT_MASK(sym_k_XmScrolledList_object) |
  _BIT_MASK(sym_k_XmScrolledText_object) |
  _BIT_MASK(sym_k_XmScrolledWindow_object) |
  _BIT_MASK(sym_k_XmSelectionBox_object) |
  _BIT_MASK(sym_k_XmSelectionDialog_object) |
  _BIT_MASK(sym_k_XmSeparator_object) |
  _BIT_MASK(sym_k_XmSeparatorGadget_object) |
  0, _BIT_MASK(sym_k_XmSimpleSpinBox_object) |
  _BIT_MASK(sym_k_XmSpinBox_object) |
  _BIT_MASK(sym_k_XmTabBox_object) |
  _BIT_MASK(sym_k_XmTabStack_object) |
  _BIT_MASK(sym_k_XmTearOffButton_object) |
  _BIT_MASK(sym_k_XmTemplateDialog_object) |
  0, _BIT_MASK(sym_k_XmText_object) |
  _BIT_MASK(sym_k_XmTextField_object) |
  _BIT_MASK(sym_k_XmToggleButton_object) |
  _BIT_MASK(sym_k_XmToggleButtonGadget_object) |
  _BIT_MASK(sym_k_XmTree_object) |
  _BIT_MASK(sym_k_XmWarningDialog_object) |
  _BIT_MASK(sym_k_XmWorkArea_object) |
  _BIT_MASK(sym_k_XmWorkingDialog_object) |
  0, 0};

/* sym_k_XmNxlfdString_arg */
static unsigned char arg_class_vec712[] =
  {
  0, 0, 0, _BIT_MASK(sym_k_XmFontSelector_object) |
  0, 0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_XmNy_arg */
static unsigned char arg_class_vec713[] =
  {
  _BIT_MASK(sym_k_DtEditor_object) |
  _BIT_MASK(sym_k_DtHelpDialog_object) |
  _BIT_MASK(sym_k_DtHelpQuickDialog_object) |
  _BIT_MASK(sym_k_DtMenuButton_object) |
  _BIT_MASK(sym_k_DtPrintSetupBox_object) |
  _BIT_MASK(sym_k_DtPrintSetupDialog_object) |
  _BIT_MASK(sym_k_DtTerm_object) |
  0, _BIT_MASK(sym_k_DtTermPrimitive_object) |
  _BIT_MASK(sym_k_XmArrowButton_object) |
  _BIT_MASK(sym_k_XmArrowButtonGadget_object) |
  _BIT_MASK(sym_k_XmBulletinBoard_object) |
  _BIT_MASK(sym_k_XmBulletinBoardDialog_object) |
  _BIT_MASK(sym_k_XmButtonBox_object) |
  _BIT_MASK(sym_k_XmCascadeButton_object) |
  _BIT_MASK(sym_k_XmCascadeButtonGadget_object) |
  0, _BIT_MASK(sym_k_XmCheckBox_object) |
  _BIT_MASK(sym_k_XmColorSelector_object) |
  _BIT_MASK(sym_k_XmColumn_object) |
  _BIT_MASK(sym_k_XmComboBox_object) |
  _BIT_MASK(sym_k_XmCommand_object) |
  _BIT_MASK(sym_k_XmCommandDialog_object) |
  _BIT_MASK(sym_k_XmContainer_object) |
  _BIT_MASK(sym_k_XmDataField_object) |
  0, _BIT_MASK(sym_k_XmDialogShell_object) |
  _BIT_MASK(sym_k_XmDrawingArea_object) |
  _BIT_MASK(sym_k_XmDrawnButton_object) |
  _BIT_MASK(sym_k_XmDropDown_object) |
  _BIT_MASK(sym_k_XmErrorDialog_object) |
  _BIT_MASK(sym_k_XmFileSelectionBox_object) |
  _BIT_MASK(sym_k_XmFileSelectionDialog_object) |
  _BIT_MASK(sym_k_XmFontSelector_object) |
  0, _BIT_MASK(sym_k_XmForm_object) |
  _BIT_MASK(sym_k_XmFormDialog_object) |
  _BIT_MASK(sym_k_XmFrame_object) |
  _BIT_MASK(sym_k_XmIconBox_object) |
  _BIT_MASK(sym_k_XmIconButton_object) |
  _BIT_MASK(sym_k_XmIconGadget_object) |
  _BIT_MASK(sym_k_XmInformationDialog_object) |
  _BIT_MASK(sym_k_XmLabel_object) |
  0, _BIT_MASK(sym_k_XmLabelGadget_object) |
  _BIT_MASK(sym_k_XmList_object) |
  _BIT_MASK(sym_k_XmMainWindow_object) |
  _BIT_MASK(sym_k_XmMenuBar_object) |
  _BIT_MASK(sym_k_XmMenuShell_object) |
  _BIT_MASK(sym_k_XmMessageBox_object) |
  _BIT_MASK(sym_k_XmMessageDialog_object) |
  _BIT_MASK(sym_k_XmMultiList_object) |
  0, _BIT_MASK(sym_k_XmNotebook_object) |
  _BIT_MASK(sym_k_XmOptionMenu_object) |
  _BIT_MASK(sym_k_XmOutline_object) |
  _BIT_MASK(sym_k_XmPaned_object) |
  _BIT_MASK(sym_k_XmPanedWindow_object) |
  _BIT_MASK(sym_k_XmPopupMenu_object) |
  _BIT_MASK(sym_k_XmPromptDialog_object) |
  _BIT_MASK(sym_k_XmPulldownMenu_object) |
  0, _BIT_MASK(sym_k_XmPushButton_object) |
  _BIT_MASK(sym_k_XmPushButtonGadget_object) |
  _BIT_MASK(sym_k_XmQuestionDialog_object) |
  _BIT_MASK(sym_k_XmRadioBox_object) |
  _BIT_MASK(sym_k_XmRowColumn_object) |
  _BIT_MASK(sym_k_XmScale_object) |
  0, _BIT_MASK(sym_k_XmScrollBar_object) |
  _BIT_MASK(sym_k_XmScrolledList_object) |
  _BIT_MASK(sym_k_XmScrolledText_object) |
  _BIT_MASK(sym_k_XmScrolledWindow_object) |
  _BIT_MASK(sym_k_XmSelectionBox_object) |
  _BIT_MASK(sym_k_XmSelectionDialog_object) |
  _BIT_MASK(sym_k_XmSeparator_object) |
  _BIT_MASK(sym_k_XmSeparatorGadget_object) |
  0, _BIT_MASK(sym_k_XmSimpleSpinBox_object) |
  _BIT_MASK(sym_k_XmSpinBox_object) |
  _BIT_MASK(sym_k_XmTabBox_object) |
  _BIT_MASK(sym_k_XmTabStack_object) |
  _BIT_MASK(sym_k_XmTearOffButton_object) |
  _BIT_MASK(sym_k_XmTemplateDialog_object) |
  0, _BIT_MASK(sym_k_XmText_object) |
  _BIT_MASK(sym_k_XmTextField_object) |
  _BIT_MASK(sym_k_XmToggleButton_object) |
  _BIT_MASK(sym_k_XmToggleButtonGadget_object) |
  _BIT_MASK(sym_k_XmTree_object) |
  _BIT_MASK(sym_k_XmWarningDialog_object) |
  _BIT_MASK(sym_k_XmWorkArea_object) |
  _BIT_MASK(sym_k_XmWorkingDialog_object) |
  0, 0};

/* sym_k_XmStringComponent_arg */
static unsigned char arg_class_vec714[] =
  {
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0};

/*
 * Table of bit vectors accessed by sym_k_..._arg
 */
static unsigned char *allowed_argument_table_vec[] =
  {
  NULL,	/* UNUSED */
  arg_class_vec1,
  arg_class_vec2,
  arg_class_vec3,
  arg_class_vec4,
  arg_class_vec5,
  arg_class_vec6,
  arg_class_vec7,
  arg_class_vec8,
  arg_class_vec9,
  arg_class_vec10,
  arg_class_vec11,
  arg_class_vec12,
  arg_class_vec13,
  arg_class_vec14,
  arg_class_vec15,
  arg_class_vec16,
  arg_class_vec17,
  arg_class_vec18,
  arg_class_vec19,
  arg_class_vec20,
  arg_class_vec21,
  arg_class_vec22,
  arg_class_vec23,
  arg_class_vec24,
  arg_class_vec25,
  arg_class_vec26,
  arg_class_vec27,
  arg_class_vec28,
  arg_class_vec29,
  arg_class_vec30,
  arg_class_vec31,
  arg_class_vec32,
  arg_class_vec33,
  arg_class_vec34,
  arg_class_vec35,
  arg_class_vec36,
  arg_class_vec37,
  arg_class_vec38,
  arg_class_vec39,
  arg_class_vec40,
  arg_class_vec41,
  arg_class_vec42,
  arg_class_vec43,
  arg_class_vec44,
  arg_class_vec45,
  arg_class_vec46,
  arg_class_vec47,
  arg_class_vec48,
  arg_class_vec49,
  arg_class_vec50,
  arg_class_vec51,
  arg_class_vec52,
  arg_class_vec53,
  arg_class_vec54,
  arg_class_vec55,
  arg_class_vec56,
  arg_class_vec57,
  arg_class_vec58,
  arg_class_vec59,
  arg_class_vec60,
  arg_class_vec61,
  arg_class_vec62,
  arg_class_vec63,
  arg_class_vec64,
  arg_class_vec65,
  arg_class_vec66,
  arg_class_vec67,
  arg_class_vec68,
  arg_class_vec69,
  arg_class_vec70,
  arg_class_vec71,
  arg_class_vec72,
  arg_class_vec73,
  arg_class_vec74,
  arg_class_vec75,
  arg_class_vec76,
  arg_class_vec77,
  arg_class_vec78,
  arg_class_vec79,
  arg_class_vec80,
  arg_class_vec81,
  arg_class_vec82,
  arg_class_vec83,
  arg_class_vec84,
  arg_class_vec85,
  arg_class_vec86,
  arg_class_vec87,
  arg_class_vec88,
  arg_class_vec89,
  arg_class_vec90,
  arg_class_vec91,
  arg_class_vec92,
  arg_class_vec93,
  arg_class_vec94,
  arg_class_vec95,
  arg_class_vec96,
  arg_class_vec97,
  arg_class_vec98,
  arg_class_vec99,
  arg_class_vec100,
  arg_class_vec101,
  arg_class_vec102,
  arg_class_vec103,
  arg_class_vec104,
  arg_class_vec105,
  arg_class_vec106,
  arg_class_vec107,
  arg_class_vec108,
  arg_class_vec109,
  arg_class_vec110,
  arg_class_vec111,
  arg_class_vec112,
  arg_class_vec113,
  arg_class_vec114,
  arg_class_vec115,
  arg_class_vec116,
  arg_class_vec117,
  arg_class_vec118,
  arg_class_vec119,
  arg_class_vec120,
  arg_class_vec121,
  arg_class_vec122,
  arg_class_vec123,
  arg_class_vec124,
  arg_class_vec125,
  arg_class_vec126,
  arg_class_vec127,
  arg_class_vec128,
  arg_class_vec129,
  arg_class_vec130,
  arg_class_vec131,
  arg_class_vec132,
  arg_class_vec133,
  arg_class_vec134,
  arg_class_vec135,
  arg_class_vec136,
  arg_class_vec137,
  arg_class_vec138,
  arg_class_vec139,
  arg_class_vec140,
  arg_class_vec141,
  arg_class_vec142,
  arg_class_vec143,
  arg_class_vec144,
  arg_class_vec145,
  arg_class_vec146,
  arg_class_vec147,
  arg_class_vec148,
  arg_class_vec149,
  arg_class_vec150,
  arg_class_vec151,
  arg_class_vec152,
  arg_class_vec153,
  arg_class_vec154,
  arg_class_vec155,
  arg_class_vec156,
  arg_class_vec157,
  arg_class_vec158,
  arg_class_vec159,
  arg_class_vec160,
  arg_class_vec161,
  arg_class_vec162,
  arg_class_vec163,
  arg_class_vec164,
  arg_class_vec165,
  arg_class_vec166,
  arg_class_vec167,
  arg_class_vec168,
  arg_class_vec169,
  arg_class_vec170,
  arg_class_vec171,
  arg_class_vec172,
  arg_class_vec173,
  arg_class_vec174,
  arg_class_vec175,
  arg_class_vec176,
  arg_class_vec177,
  arg_class_vec178,
  arg_class_vec179,
  arg_class_vec180,
  arg_class_vec181,
  arg_class_vec182,
  arg_class_vec183,
  arg_class_vec184,
  arg_class_vec185,
  arg_class_vec186,
  arg_class_vec187,
  arg_class_vec188,
  arg_class_vec189,
  arg_class_vec190,
  arg_class_vec191,
  arg_class_vec192,
  arg_class_vec193,
  arg_class_vec194,
  arg_class_vec195,
  arg_class_vec196,
  arg_class_vec197,
  arg_class_vec198,
  arg_class_vec199,
  arg_class_vec200,
  arg_class_vec201,
  arg_class_vec202,
  arg_class_vec203,
  arg_class_vec204,
  arg_class_vec205,
  arg_class_vec206,
  arg_class_vec207,
  arg_class_vec208,
  arg_class_vec209,
  arg_class_vec210,
  arg_class_vec211,
  arg_class_vec212,
  arg_class_vec213,
  arg_class_vec214,
  arg_class_vec215,
  arg_class_vec216,
  arg_class_vec217,
  arg_class_vec218,
  arg_class_vec219,
  arg_class_vec220,
  arg_class_vec221,
  arg_class_vec222,
  arg_class_vec223,
  arg_class_vec224,
  arg_class_vec225,
  arg_class_vec226,
  arg_class_vec227,
  arg_class_vec228,
  arg_class_vec229,
  arg_class_vec230,
  arg_class_vec231,
  arg_class_vec232,
  arg_class_vec233,
  arg_class_vec234,
  arg_class_vec235,
  arg_class_vec236,
  arg_class_vec237,
  arg_class_vec238,
  arg_class_vec239,
  arg_class_vec240,
  arg_class_vec241,
  arg_class_vec242,
  arg_class_vec243,
  arg_class_vec244,
  arg_class_vec245,
  arg_class_vec246,
  arg_class_vec247,
  arg_class_vec248,
  arg_class_vec249,
  arg_class_vec250,
  arg_class_vec251,
  arg_class_vec252,
  arg_class_vec253,
  arg_class_vec254,
  arg_class_vec255,
  arg_class_vec256,
  arg_class_vec257,
  arg_class_vec258,
  arg_class_vec259,
  arg_class_vec260,
  arg_class_vec261,
  arg_class_vec262,
  arg_class_vec263,
  arg_class_vec264,
  arg_class_vec265,
  arg_class_vec266,
  arg_class_vec267,
  arg_class_vec268,
  arg_class_vec269,
  arg_class_vec270,
  arg_class_vec271,
  arg_class_vec272,
  arg_class_vec273,
  arg_class_vec274,
  arg_class_vec275,
  arg_class_vec276,
  arg_class_vec277,
  arg_class_vec278,
  arg_class_vec279,
  arg_class_vec280,
  arg_class_vec281,
  arg_class_vec282,
  arg_class_vec283,
  arg_class_vec284,
  arg_class_vec285,
  arg_class_vec286,
  arg_class_vec287,
  arg_class_vec288,
  arg_class_vec289,
  arg_class_vec290,
  arg_class_vec291,
  arg_class_vec292,
  arg_class_vec293,
  arg_class_vec294,
  arg_class_vec295,
  arg_class_vec296,
  arg_class_vec297,
  arg_class_vec298,
  arg_class_vec299,
  arg_class_vec300,
  arg_class_vec301,
  arg_class_vec302,
  arg_class_vec303,
  arg_class_vec304,
  arg_class_vec305,
  arg_class_vec306,
  arg_class_vec307,
  arg_class_vec308,
  arg_class_vec309,
  arg_class_vec310,
  arg_class_vec311,
  arg_class_vec312,
  arg_class_vec313,
  arg_class_vec314,
  arg_class_vec315,
  arg_class_vec316,
  arg_class_vec317,
  arg_class_vec318,
  arg_class_vec319,
  arg_class_vec320,
  arg_class_vec321,
  arg_class_vec322,
  arg_class_vec323,
  arg_class_vec324,
  arg_class_vec325,
  arg_class_vec326,
  arg_class_vec327,
  arg_class_vec328,
  arg_class_vec329,
  arg_class_vec330,
  arg_class_vec331,
  arg_class_vec332,
  arg_class_vec333,
  arg_class_vec334,
  arg_class_vec335,
  arg_class_vec336,
  arg_class_vec337,
  arg_class_vec338,
  arg_class_vec339,
  arg_class_vec340,
  arg_class_vec341,
  arg_class_vec342,
  arg_class_vec343,
  arg_class_vec344,
  arg_class_vec345,
  arg_class_vec346,
  arg_class_vec347,
  arg_class_vec348,
  arg_class_vec349,
  arg_class_vec350,
  arg_class_vec351,
  arg_class_vec352,
  arg_class_vec353,
  arg_class_vec354,
  arg_class_vec355,
  arg_class_vec356,
  arg_class_vec357,
  arg_class_vec358,
  arg_class_vec359,
  arg_class_vec360,
  arg_class_vec361,
  arg_class_vec362,
  arg_class_vec363,
  arg_class_vec364,
  arg_class_vec365,
  arg_class_vec366,
  arg_class_vec367,
  arg_class_vec368,
  arg_class_vec369,
  arg_class_vec370,
  arg_class_vec371,
  arg_class_vec372,
  arg_class_vec373,
  arg_class_vec374,
  arg_class_vec375,
  arg_class_vec376,
  arg_class_vec377,
  arg_class_vec378,
  arg_class_vec379,
  arg_class_vec380,
  arg_class_vec381,
  arg_class_vec382,
  arg_class_vec383,
  arg_class_vec384,
  arg_class_vec385,
  arg_class_vec386,
  arg_class_vec387,
  arg_class_vec388,
  arg_class_vec389,
  arg_class_vec390,
  arg_class_vec391,
  arg_class_vec392,
  arg_class_vec393,
  arg_class_vec394,
  arg_class_vec395,
  arg_class_vec396,
  arg_class_vec397,
  arg_class_vec398,
  arg_class_vec399,
  arg_class_vec400,
  arg_class_vec401,
  arg_class_vec402,
  arg_class_vec403,
  arg_class_vec404,
  arg_class_vec405,
  arg_class_vec406,
  arg_class_vec407,
  arg_class_vec408,
  arg_class_vec409,
  arg_class_vec410,
  arg_class_vec411,
  arg_class_vec412,
  arg_class_vec413,
  arg_class_vec414,
  arg_class_vec415,
  arg_class_vec416,
  arg_class_vec417,
  arg_class_vec418,
  arg_class_vec419,
  arg_class_vec420,
  arg_class_vec421,
  arg_class_vec422,
  arg_class_vec423,
  arg_class_vec424,
  arg_class_vec425,
  arg_class_vec426,
  arg_class_vec427,
  arg_class_vec428,
  arg_class_vec429,
  arg_class_vec430,
  arg_class_vec431,
  arg_class_vec432,
  arg_class_vec433,
  arg_class_vec434,
  arg_class_vec435,
  arg_class_vec436,
  arg_class_vec437,
  arg_class_vec438,
  arg_class_vec439,
  arg_class_vec440,
  arg_class_vec441,
  arg_class_vec442,
  arg_class_vec443,
  arg_class_vec444,
  arg_class_vec445,
  arg_class_vec446,
  arg_class_vec447,
  arg_class_vec448,
  arg_class_vec449,
  arg_class_vec450,
  arg_class_vec451,
  arg_class_vec452,
  arg_class_vec453,
  arg_class_vec454,
  arg_class_vec455,
  arg_class_vec456,
  arg_class_vec457,
  arg_class_vec458,
  arg_class_vec459,
  arg_class_vec460,
  arg_class_vec461,
  arg_class_vec462,
  arg_class_vec463,
  arg_class_vec464,
  arg_class_vec465,
  arg_class_vec466,
  arg_class_vec467,
  arg_class_vec468,
  arg_class_vec469,
  arg_class_vec470,
  arg_class_vec471,
  arg_class_vec472,
  arg_class_vec473,
  arg_class_vec474,
  arg_class_vec475,
  arg_class_vec476,
  arg_class_vec477,
  arg_class_vec478,
  arg_class_vec479,
  arg_class_vec480,
  arg_class_vec481,
  arg_class_vec482,
  arg_class_vec483,
  arg_class_vec484,
  arg_class_vec485,
  arg_class_vec486,
  arg_class_vec487,
  arg_class_vec488,
  arg_class_vec489,
  arg_class_vec490,
  arg_class_vec491,
  arg_class_vec492,
  arg_class_vec493,
  arg_class_vec494,
  arg_class_vec495,
  arg_class_vec496,
  arg_class_vec497,
  arg_class_vec498,
  arg_class_vec499,
  arg_class_vec500,
  arg_class_vec501,
  arg_class_vec502,
  arg_class_vec503,
  arg_class_vec504,
  arg_class_vec505,
  arg_class_vec506,
  arg_class_vec507,
  arg_class_vec508,
  arg_class_vec509,
  arg_class_vec510,
  arg_class_vec511,
  arg_class_vec512,
  arg_class_vec513,
  arg_class_vec514,
  arg_class_vec515,
  arg_class_vec516,
  arg_class_vec517,
  arg_class_vec518,
  arg_class_vec519,
  arg_class_vec520,
  arg_class_vec521,
  arg_class_vec522,
  arg_class_vec523,
  arg_class_vec524,
  arg_class_vec525,
  arg_class_vec526,
  arg_class_vec527,
  arg_class_vec528,
  arg_class_vec529,
  arg_class_vec530,
  arg_class_vec531,
  arg_class_vec532,
  arg_class_vec533,
  arg_class_vec534,
  arg_class_vec535,
  arg_class_vec536,
  arg_class_vec537,
  arg_class_vec538,
  arg_class_vec539,
  arg_class_vec540,
  arg_class_vec541,
  arg_class_vec542,
  arg_class_vec543,
  arg_class_vec544,
  arg_class_vec545,
  arg_class_vec546,
  arg_class_vec547,
  arg_class_vec548,
  arg_class_vec549,
  arg_class_vec550,
  arg_class_vec551,
  arg_class_vec552,
  arg_class_vec553,
  arg_class_vec554,
  arg_class_vec555,
  arg_class_vec556,
  arg_class_vec557,
  arg_class_vec558,
  arg_class_vec559,
  arg_class_vec560,
  arg_class_vec561,
  arg_class_vec562,
  arg_class_vec563,
  arg_class_vec564,
  arg_class_vec565,
  arg_class_vec566,
  arg_class_vec567,
  arg_class_vec568,
  arg_class_vec569,
  arg_class_vec570,
  arg_class_vec571,
  arg_class_vec572,
  arg_class_vec573,
  arg_class_vec574,
  arg_class_vec575,
  arg_class_vec576,
  arg_class_vec577,
  arg_class_vec578,
  arg_class_vec579,
  arg_class_vec580,
  arg_class_vec581,
  arg_class_vec582,
  arg_class_vec583,
  arg_class_vec584,
  arg_class_vec585,
  arg_class_vec586,
  arg_class_vec587,
  arg_class_vec588,
  arg_class_vec589,
  arg_class_vec590,
  arg_class_vec591,
  arg_class_vec592,
  arg_class_vec593,
  arg_class_vec594,
  arg_class_vec595,
  arg_class_vec596,
  arg_class_vec597,
  arg_class_vec598,
  arg_class_vec599,
  arg_class_vec600,
  arg_class_vec601,
  arg_class_vec602,
  arg_class_vec603,
  arg_class_vec604,
  arg_class_vec605,
  arg_class_vec606,
  arg_class_vec607,
  arg_class_vec608,
  arg_class_vec609,
  arg_class_vec610,
  arg_class_vec611,
  arg_class_vec612,
  arg_class_vec613,
  arg_class_vec614,
  arg_class_vec615,
  arg_class_vec616,
  arg_class_vec617,
  arg_class_vec618,
  arg_class_vec619,
  arg_class_vec620,
  arg_class_vec621,
  arg_class_vec622,
  arg_class_vec623,
  arg_class_vec624,
  arg_class_vec625,
  arg_class_vec626,
  arg_class_vec627,
  arg_class_vec628,
  arg_class_vec629,
  arg_class_vec630,
  arg_class_vec631,
  arg_class_vec632,
  arg_class_vec633,
  arg_class_vec634,
  arg_class_vec635,
  arg_class_vec636,
  arg_class_vec637,
  arg_class_vec638,
  arg_class_vec639,
  arg_class_vec640,
  arg_class_vec641,
  arg_class_vec642,
  arg_class_vec643,
  arg_class_vec644,
  arg_class_vec645,
  arg_class_vec646,
  arg_class_vec647,
  arg_class_vec648,
  arg_class_vec649,
  arg_class_vec650,
  arg_class_vec651,
  arg_class_vec652,
  arg_class_vec653,
  arg_class_vec654,
  arg_class_vec655,
  arg_class_vec656,
  arg_class_vec657,
  arg_class_vec658,
  arg_class_vec659,
  arg_class_vec660,
  arg_class_vec661,
  arg_class_vec662,
  arg_class_vec663,
  arg_class_vec664,
  arg_class_vec665,
  arg_class_vec666,
  arg_class_vec667,
  arg_class_vec668,
  arg_class_vec669,
  arg_class_vec670,
  arg_class_vec671,
  arg_class_vec672,
  arg_class_vec673,
  arg_class_vec674,
  arg_class_vec675,
  arg_class_vec676,
  arg_class_vec677,
  arg_class_vec678,
  arg_class_vec679,
  arg_class_vec680,
  arg_class_vec681,
  arg_class_vec682,
  arg_class_vec683,
  arg_class_vec684,
  arg_class_vec685,
  arg_class_vec686,
  arg_class_vec687,
  arg_class_vec688,
  arg_class_vec689,
  arg_class_vec690,
  arg_class_vec691,
  arg_class_vec692,
  arg_class_vec693,
  arg_class_vec694,
  arg_class_vec695,
  arg_class_vec696,
  arg_class_vec697,
  arg_class_vec698,
  arg_class_vec699,
  arg_class_vec700,
  arg_class_vec701,
  arg_class_vec702,
  arg_class_vec703,
  arg_class_vec704,
  arg_class_vec705,
  arg_class_vec706,
  arg_class_vec707,
  arg_class_vec708,
  arg_class_vec709,
  arg_class_vec710,
  arg_class_vec711,
  arg_class_vec712,
  arg_class_vec713,
  arg_class_vec714,
  };
externaldef(uil_sym_glbl) unsigned char **allowed_argument_table =
		allowed_argument_table_vec;
